// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = (typeof Module !== 'undefined' ? Module : null) || {};

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function' && !ENVIRONMENT_IS_WEB;
// Three configurations we can be running in:
// 1) We could be the application main() thread running in the main JS UI thread. (ENVIRONMENT_IS_WORKER == false and ENVIRONMENT_IS_PTHREAD == false)
// 2) We could be the application main() thread proxied to worker. (with Emscripten -s PROXY_TO_WORKER=1) (ENVIRONMENT_IS_WORKER == true, ENVIRONMENT_IS_PTHREAD == false)
// 3) We could be an application pthread running in a worker. (ENVIRONMENT_IS_WORKER == true and ENVIRONMENT_IS_PTHREAD == true)
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = function print(x) {
    process['stdout'].write(x + '\n');
  };
  if (!Module['printErr']) Module['printErr'] = function printErr(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function read(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };

  Module['readBinary'] = function readBinary(filename) { return Module['read'](filename, true) };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  if (!Module['thisProgram']) {
    if (process['argv'].length > 1) {
      Module['thisProgram'] = process['argv'][1].replace(/\\/g, '/');
    } else {
      Module['thisProgram'] = 'unknown-program';
    }
  }

  Module['arguments'] = process['argv'].slice(2);

  if (typeof module !== 'undefined') {
    module['exports'] = Module;
  }

  process['on']('uncaughtException', function(ex) {
    // suppress ExitStatus exceptions from showing an error
    if (!(ex instanceof ExitStatus)) {
      throw ex;
    }
  });

  Module['inspect'] = function () { return '[Emscripten Module object]'; };
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function read() { throw 'no read() available (jsc?)' };
  }

  Module['readBinary'] = function readBinary(f) {
    if (typeof readbuffer === 'function') {
      return new Uint8Array(readbuffer(f));
    }
    var data = read(f, 'binary');
    assert(typeof data === 'object');
    return data;
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function printErr(x) {
      console.log(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WORKER) {
    Module['load'] = importScripts;
  }

  if (typeof Module['setWindowTitle'] === 'undefined') {
    Module['setWindowTitle'] = function(title) { document.title = title };
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
if (!Module['thisProgram']) {
  Module['thisProgram'] = './this.program';
}

// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}



// === Preamble library stuff ===

// Documentation for the public APIs defined in this file must be updated in: 
//    site/source/docs/api_reference/preamble.js.rst
// A prebuilt local version of the documentation is available at: 
//    site/build/text/docs/api_reference/preamble.js.txt
// You can also build docs locally as HTML or other formats in site/
// An online HTML version (which may be of a different version of Emscripten)
//    is up at http://kripken.github.io/emscripten-site/docs/api_reference/preamble.js.html

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  setTempRet0: function (value) {
    tempRet0 = value;
  },
  getTempRet0: function () {
    return tempRet0;
  },
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  STACK_ALIGN: 16,
  prepVararg: function (ptr, type) {
    if (type === 'double' || type === 'i64') {
      // move so the load is aligned
      if (ptr & 7) {
        assert((ptr & 7) === 4);
        ptr += 4;
      }
    } else {
      assert((ptr & 3) === 0);
    }
    return ptr;
  },
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      assert(args.length == sig.length-1);
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      assert(('dynCall_' + sig) in Module, 'bad function pointer type - no table for sig \'' + sig + '\'');
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      assert(sig.length == 1);
      assert(('dynCall_' + sig) in Module, 'bad function pointer type - no table for sig \'' + sig + '\'');
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[sig]) {
      Runtime.funcWrappers[sig] = {};
    }
    var sigCache = Runtime.funcWrappers[sig];
    if (!sigCache[func]) {
      sigCache[func] = function dynCall_wrapper() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return sigCache[func];
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+15)&-16);(assert((((STACKTOP|0) < (STACK_MAX|0))|0))|0); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + (assert(!staticSealed),size))|0;STATICTOP = (((STATICTOP)+15)&-16); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + (assert(DYNAMICTOP > 0),size))|0;DYNAMICTOP = (((DYNAMICTOP)+15)&-16); if (DYNAMICTOP >= TOTAL_MEMORY) { var success = enlargeMemory(); if (!success) { DYNAMICTOP = ret; return 0; } }; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 16))*(quantum ? quantum : 16); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*4294967296.0)) : ((+((low>>>0)))+((+((high|0)))*4294967296.0))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}


Module['Runtime'] = Runtime;



//========================================
// Runtime essentials
//========================================

var __THREW__ = 0; // Used in checking for thrown exceptions.

var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD, tempDouble, tempFloat;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  var func = Module['_' + ident]; // closure exported function
  if (!func) {
    try {
      func = eval('_' + ident); // explicit lookup
    } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

var cwrap, ccall;
(function(){
  var JSfuncs = {
    // Helpers for cwrap -- it can't refer to Runtime directly because it might
    // be renamed by closure, instead it calls JSfuncs['stackSave'].body to find
    // out what the minified function name is.
    'stackSave': function() {
      Runtime.stackSave()
    },
    'stackRestore': function() {
      Runtime.stackRestore()
    },
    // type conversion from js to c
    'arrayToC' : function(arr) {
      var ret = Runtime.stackAlloc(arr.length);
      writeArrayToMemory(arr, ret);
      return ret;
    },
    'stringToC' : function(str) {
      var ret = 0;
      if (str !== null && str !== undefined && str !== 0) { // null string
        // at most 4 bytes per UTF-8 code point, +1 for the trailing '\0'
        ret = Runtime.stackAlloc((str.length << 2) + 1);
        writeStringToMemory(str, ret);
      }
      return ret;
    }
  };
  // For fast lookup of conversion functions
  var toC = {'string' : JSfuncs['stringToC'], 'array' : JSfuncs['arrayToC']};

  // C calling interface. 
  ccall = function ccallFunc(ident, returnType, argTypes, args, opts) {
    var func = getCFunc(ident);
    var cArgs = [];
    var stack = 0;
    assert(returnType !== 'array', 'Return type should not be "array".');
    if (args) {
      for (var i = 0; i < args.length; i++) {
        var converter = toC[argTypes[i]];
        if (converter) {
          if (stack === 0) stack = Runtime.stackSave();
          cArgs[i] = converter(args[i]);
        } else {
          cArgs[i] = args[i];
        }
      }
    }
    var ret = func.apply(null, cArgs);
    if ((!opts || !opts.async) && typeof EmterpreterAsync === 'object') {
      assert(!EmterpreterAsync.state, 'cannot start async op with normal JS calling ccall');
    }
    if (opts && opts.async) assert(!returnType, 'async ccalls cannot return values');
    if (returnType === 'string') ret = Pointer_stringify(ret);
    if (stack !== 0) {
      if (opts && opts.async) {
        EmterpreterAsync.asyncFinalizers.push(function() {
          Runtime.stackRestore(stack);
        });
        return;
      }
      Runtime.stackRestore(stack);
    }
    return ret;
  }

  var sourceRegex = /^function\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;
  function parseJSFunc(jsfunc) {
    // Match the body and the return value of a javascript function source
    var parsed = jsfunc.toString().match(sourceRegex).slice(1);
    return {arguments : parsed[0], body : parsed[1], returnValue: parsed[2]}
  }
  var JSsource = {};
  for (var fun in JSfuncs) {
    if (JSfuncs.hasOwnProperty(fun)) {
      // Elements of toCsource are arrays of three items:
      // the code, and the return value
      JSsource[fun] = parseJSFunc(JSfuncs[fun]);
    }
  }

  
  cwrap = function cwrap(ident, returnType, argTypes) {
    argTypes = argTypes || [];
    var cfunc = getCFunc(ident);
    // When the function takes numbers and returns a number, we can just return
    // the original function
    var numericArgs = argTypes.every(function(type){ return type === 'number'});
    var numericRet = (returnType !== 'string');
    if ( numericRet && numericArgs) {
      return cfunc;
    }
    // Creation of the arguments list (["$1","$2",...,"$nargs"])
    var argNames = argTypes.map(function(x,i){return '$'+i});
    var funcstr = "(function(" + argNames.join(',') + ") {";
    var nargs = argTypes.length;
    if (!numericArgs) {
      // Generate the code needed to convert the arguments from javascript
      // values to pointers
      funcstr += 'var stack = ' + JSsource['stackSave'].body + ';';
      for (var i = 0; i < nargs; i++) {
        var arg = argNames[i], type = argTypes[i];
        if (type === 'number') continue;
        var convertCode = JSsource[type + 'ToC']; // [code, return]
        funcstr += 'var ' + convertCode.arguments + ' = ' + arg + ';';
        funcstr += convertCode.body + ';';
        funcstr += arg + '=' + convertCode.returnValue + ';';
      }
    }

    // When the code is compressed, the name of cfunc is not literally 'cfunc' anymore
    var cfuncname = parseJSFunc(function(){return cfunc}).returnValue;
    // Call the function
    funcstr += 'var ret = ' + cfuncname + '(' + argNames.join(',') + ');';
    if (!numericRet) { // Return type can only by 'string' or 'number'
      // Convert the result to a string
      var strgfy = parseJSFunc(function(){return Pointer_stringify}).returnValue;
      funcstr += 'ret = ' + strgfy + '(ret);';
    }
    funcstr += "if (typeof EmterpreterAsync === 'object') { assert(!EmterpreterAsync.state, 'cannot start async op with normal JS calling cwrap') }";
    if (!numericArgs) {
      // If we had a stack, restore it
      funcstr += JSsource['stackRestore'].body.replace('()', '(stack)') + ';';
    }
    funcstr += 'return ret})';
    return eval(funcstr);
  };
})();
Module["cwrap"] = cwrap;
Module["ccall"] = ccall;


function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[((ptr)>>0)]=value; break;
      case 'i8': HEAP8[((ptr)>>0)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;


function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[((ptr)>>0)];
      case 'i8': return HEAP8[((ptr)>>0)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)>>0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    assert(type, 'Must know what type to store in allocate!');

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module['allocate'] = allocate;

// Allocate memory during any stage of startup - static memory early on, dynamic memory later, malloc when ready
function getMemory(size) {
  if (!staticSealed) return Runtime.staticAlloc(size);
  if ((typeof _sbrk !== 'undefined' && !_sbrk.called) || !runtimeInitialized) return Runtime.dynamicAlloc(size);
  return _malloc(size);
}
Module['getMemory'] = getMemory;

function Pointer_stringify(ptr, /* optional */ length) {
  if (length === 0 || !ptr) return '';
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = 0;
  var t;
  var i = 0;
  while (1) {
    assert(ptr + i < TOTAL_MEMORY);
    t = HEAPU8[(((ptr)+(i))>>0)];
    hasUtf |= t;
    if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (hasUtf < 128) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  return Module['UTF8ToString'](ptr);
}
Module['Pointer_stringify'] = Pointer_stringify;

// Given a pointer 'ptr' to a null-terminated ASCII-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function AsciiToString(ptr) {
  var str = '';
  while (1) {
    var ch = HEAP8[((ptr++)>>0)];
    if (!ch) return str;
    str += String.fromCharCode(ch);
  }
}
Module['AsciiToString'] = AsciiToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in ASCII form. The copy will require at most str.length+1 bytes of space in the HEAP.

function stringToAscii(str, outPtr) {
  return writeAsciiToMemory(str, outPtr, false);
}
Module['stringToAscii'] = stringToAscii;

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the given array that contains uint8 values, returns
// a copy of that string as a Javascript String object.

function UTF8ArrayToString(u8Array, idx) {
  var u0, u1, u2, u3, u4, u5;

  var str = '';
  while (1) {
    // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
    u0 = u8Array[idx++];
    if (!u0) return str;
    if (!(u0 & 0x80)) { str += String.fromCharCode(u0); continue; }
    u1 = u8Array[idx++] & 63;
    if ((u0 & 0xE0) == 0xC0) { str += String.fromCharCode(((u0 & 31) << 6) | u1); continue; }
    u2 = u8Array[idx++] & 63;
    if ((u0 & 0xF0) == 0xE0) {
      u0 = ((u0 & 15) << 12) | (u1 << 6) | u2;
    } else {
      u3 = u8Array[idx++] & 63;
      if ((u0 & 0xF8) == 0xF0) {
        u0 = ((u0 & 7) << 18) | (u1 << 12) | (u2 << 6) | u3;
      } else {
        u4 = u8Array[idx++] & 63;
        if ((u0 & 0xFC) == 0xF8) {
          u0 = ((u0 & 3) << 24) | (u1 << 18) | (u2 << 12) | (u3 << 6) | u4;
        } else {
          u5 = u8Array[idx++] & 63;
          u0 = ((u0 & 1) << 30) | (u1 << 24) | (u2 << 18) | (u3 << 12) | (u4 << 6) | u5;
        }
      }
    }
    if (u0 < 0x10000) {
      str += String.fromCharCode(u0);
    } else {
      var ch = u0 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    }
  }
}
Module['UTF8ArrayToString'] = UTF8ArrayToString;

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function UTF8ToString(ptr) {
  return UTF8ArrayToString(HEAPU8, ptr);
}
Module['UTF8ToString'] = UTF8ToString;

// Copies the given Javascript String object 'str' to the given byte array at address 'outIdx',
// encoded in UTF8 form and null-terminated. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outU8Array: the array to copy to. Each index in this array is assumed to be one 8-byte element.
//   outIdx: The starting offset in the array to begin the copying.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null 
//                    terminator, i.e. if maxBytesToWrite=1, only the null terminator will be written and nothing else.
//                    maxBytesToWrite=0 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8Array(str, outU8Array, outIdx, maxBytesToWrite) {
  if (!(maxBytesToWrite > 0)) // Parameter maxBytesToWrite is not optional. Negative values, 0, null, undefined and false each don't write out any bytes.
    return 0;

  var startIdx = outIdx;
  var endIdx = outIdx + maxBytesToWrite - 1; // -1 for string null terminator.
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      if (outIdx >= endIdx) break;
      outU8Array[outIdx++] = u;
    } else if (u <= 0x7FF) {
      if (outIdx + 1 >= endIdx) break;
      outU8Array[outIdx++] = 0xC0 | (u >> 6);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0xFFFF) {
      if (outIdx + 2 >= endIdx) break;
      outU8Array[outIdx++] = 0xE0 | (u >> 12);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x1FFFFF) {
      if (outIdx + 3 >= endIdx) break;
      outU8Array[outIdx++] = 0xF0 | (u >> 18);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x3FFFFFF) {
      if (outIdx + 4 >= endIdx) break;
      outU8Array[outIdx++] = 0xF8 | (u >> 24);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else {
      if (outIdx + 5 >= endIdx) break;
      outU8Array[outIdx++] = 0xFC | (u >> 30);
      outU8Array[outIdx++] = 0x80 | ((u >> 24) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    }
  }
  // Null-terminate the pointer to the buffer.
  outU8Array[outIdx] = 0;
  return outIdx - startIdx;
}
Module['stringToUTF8Array'] = stringToUTF8Array;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF8 form. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8(str, outPtr, maxBytesToWrite) {
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF8(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  return stringToUTF8Array(str, HEAPU8, outPtr, maxBytesToWrite);
}
Module['stringToUTF8'] = stringToUTF8;

// Returns the number of bytes the given Javascript string takes if encoded as a UTF8 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF8(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      ++len;
    } else if (u <= 0x7FF) {
      len += 2;
    } else if (u <= 0xFFFF) {
      len += 3;
    } else if (u <= 0x1FFFFF) {
      len += 4;
    } else if (u <= 0x3FFFFFF) {
      len += 5;
    } else {
      len += 6;
    }
  }
  return len;
}
Module['lengthBytesUTF8'] = lengthBytesUTF8;

// Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function UTF16ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
    if (codeUnit == 0)
      return str;
    ++i;
    // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
    str += String.fromCharCode(codeUnit);
  }
}
Module['UTF16ToString'] = UTF16ToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF16 form. The copy will require at most str.length*4+2 bytes of space in the HEAP.
// Use the function lengthBytesUTF16() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null 
//                    terminator, i.e. if maxBytesToWrite=2, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<2 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF16(str, outPtr, maxBytesToWrite) {
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF16(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 2) return 0;
  maxBytesToWrite -= 2; // Null terminator.
  var startPtr = outPtr;
  var numCharsToWrite = (maxBytesToWrite < str.length*2) ? (maxBytesToWrite / 2) : str.length;
  for (var i = 0; i < numCharsToWrite; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[((outPtr)>>1)]=codeUnit;
    outPtr += 2;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[((outPtr)>>1)]=0;
  return outPtr - startPtr;
}
Module['stringToUTF16'] = stringToUTF16;

// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF16(str) {
  return str.length*2;
}
Module['lengthBytesUTF16'] = lengthBytesUTF16;

function UTF32ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}
Module['UTF32ToString'] = UTF32ToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF32 form. The copy will require at most str.length*4+4 bytes of space in the HEAP.
// Use the function lengthBytesUTF32() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null 
//                    terminator, i.e. if maxBytesToWrite=4, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<4 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF32(str, outPtr, maxBytesToWrite) {
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF32(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 4) return 0;
  var startPtr = outPtr;
  var endPtr = startPtr + maxBytesToWrite - 4;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++i);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[((outPtr)>>2)]=codeUnit;
    outPtr += 4;
    if (outPtr + 4 > endPtr) break;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[((outPtr)>>2)]=0;
  return outPtr - startPtr;
}
Module['stringToUTF32'] = stringToUTF32;

// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF32(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i);
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) ++i; // possibly a lead surrogate, so skip over the tail surrogate.
    len += 4;
  }

  return len;
}
Module['lengthBytesUTF32'] = lengthBytesUTF32;

function demangle(func) {
  var hasLibcxxabi = !!Module['___cxa_demangle'];
  if (hasLibcxxabi) {
    try {
      var buf = _malloc(func.length);
      writeStringToMemory(func.substr(1), buf);
      var status = _malloc(4);
      var ret = Module['___cxa_demangle'](buf, 0, 0, status);
      if (getValue(status, 'i32') === 0 && ret) {
        return Pointer_stringify(ret);
      }
      // otherwise, libcxxabi failed, we can try ours which may return a partial result
    } catch(e) {
      // failure when using libcxxabi, we can try ours which may return a partial result
    } finally {
      if (buf) _free(buf);
      if (status) _free(status);
      if (ret) _free(ret);
    }
  }
  var i = 3;
  // params, etc.
  var basicTypes = {
    'v': 'void',
    'b': 'bool',
    'c': 'char',
    's': 'short',
    'i': 'int',
    'l': 'long',
    'f': 'float',
    'd': 'double',
    'w': 'wchar_t',
    'a': 'signed char',
    'h': 'unsigned char',
    't': 'unsigned short',
    'j': 'unsigned int',
    'm': 'unsigned long',
    'x': 'long long',
    'y': 'unsigned long long',
    'z': '...'
  };
  var subs = [];
  var first = true;
  function dump(x) {
    //return;
    if (x) Module.print(x);
    Module.print(func);
    var pre = '';
    for (var a = 0; a < i; a++) pre += ' ';
    Module.print (pre + '^');
  }
  function parseNested() {
    i++;
    if (func[i] === 'K') i++; // ignore const
    var parts = [];
    while (func[i] !== 'E') {
      if (func[i] === 'S') { // substitution
        i++;
        var next = func.indexOf('_', i);
        var num = func.substring(i, next) || 0;
        parts.push(subs[num] || '?');
        i = next+1;
        continue;
      }
      if (func[i] === 'C') { // constructor
        parts.push(parts[parts.length-1]);
        i += 2;
        continue;
      }
      var size = parseInt(func.substr(i));
      var pre = size.toString().length;
      if (!size || !pre) { i--; break; } // counter i++ below us
      var curr = func.substr(i + pre, size);
      parts.push(curr);
      subs.push(curr);
      i += pre + size;
    }
    i++; // skip E
    return parts;
  }
  function parse(rawList, limit, allowVoid) { // main parser
    limit = limit || Infinity;
    var ret = '', list = [];
    function flushList() {
      return '(' + list.join(', ') + ')';
    }
    var name;
    if (func[i] === 'N') {
      // namespaced N-E
      name = parseNested().join('::');
      limit--;
      if (limit === 0) return rawList ? [name] : name;
    } else {
      // not namespaced
      if (func[i] === 'K' || (first && func[i] === 'L')) i++; // ignore const and first 'L'
      var size = parseInt(func.substr(i));
      if (size) {
        var pre = size.toString().length;
        name = func.substr(i + pre, size);
        i += pre + size;
      }
    }
    first = false;
    if (func[i] === 'I') {
      i++;
      var iList = parse(true);
      var iRet = parse(true, 1, true);
      ret += iRet[0] + ' ' + name + '<' + iList.join(', ') + '>';
    } else {
      ret = name;
    }
    paramLoop: while (i < func.length && limit-- > 0) {
      //dump('paramLoop');
      var c = func[i++];
      if (c in basicTypes) {
        list.push(basicTypes[c]);
      } else {
        switch (c) {
          case 'P': list.push(parse(true, 1, true)[0] + '*'); break; // pointer
          case 'R': list.push(parse(true, 1, true)[0] + '&'); break; // reference
          case 'L': { // literal
            i++; // skip basic type
            var end = func.indexOf('E', i);
            var size = end - i;
            list.push(func.substr(i, size));
            i += size + 2; // size + 'EE'
            break;
          }
          case 'A': { // array
            var size = parseInt(func.substr(i));
            i += size.toString().length;
            if (func[i] !== '_') throw '?';
            i++; // skip _
            list.push(parse(true, 1, true)[0] + ' [' + size + ']');
            break;
          }
          case 'E': break paramLoop;
          default: ret += '?' + c; break paramLoop;
        }
      }
    }
    if (!allowVoid && list.length === 1 && list[0] === 'void') list = []; // avoid (void)
    if (rawList) {
      if (ret) {
        list.push(ret + '?');
      }
      return list;
    } else {
      return ret + flushList();
    }
  }
  var parsed = func;
  try {
    // Special-case the entry point, since its name differs from other name mangling.
    if (func == 'Object._main' || func == '_main') {
      return 'main()';
    }
    if (typeof func === 'number') func = Pointer_stringify(func);
    if (func[0] !== '_') return func;
    if (func[1] !== '_') return func; // C function
    if (func[2] !== 'Z') return func;
    switch (func[3]) {
      case 'n': return 'operator new()';
      case 'd': return 'operator delete()';
    }
    parsed = parse();
  } catch(e) {
    parsed += '?';
  }
  if (parsed.indexOf('?') >= 0 && !hasLibcxxabi) {
    Runtime.warnOnce('warning: a problem occurred in builtin C++ name demangling; build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling');
  }
  return parsed;
}

function demangleAll(text) {
  return text.replace(/__Z[\w\d_]+/g, function(x) { var y = demangle(x); return x === y ? x : (x + ' [' + y + ']') });
}

function jsStackTrace() {
  var err = new Error();
  if (!err.stack) {
    // IE10+ special cases: It does have callstack info, but it is only populated if an Error object is thrown,
    // so try that as a special-case.
    try {
      throw new Error(0);
    } catch(e) {
      err = e;
    }
    if (!err.stack) {
      return '(no stack trace available)';
    }
  }
  return err.stack.toString();
}

function stackTrace() {
  return demangleAll(jsStackTrace());
}
Module['stackTrace'] = stackTrace;

// Memory management

var PAGE_SIZE = 4096;

function alignMemoryPage(x) {
  if (x % 4096 > 0) {
    x += (4096 - (x % 4096));
  }
  return x;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk


function enlargeMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with ALLOW_MEMORY_GROWTH which adjusts the size at runtime but prevents some optimizations, or (3) set Module.TOTAL_MEMORY before the program runs.');
}


var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 16777216;

var totalMemory = 64*1024;
while (totalMemory < TOTAL_MEMORY || totalMemory < 2*TOTAL_STACK) {
  if (totalMemory < 16*1024*1024) {
    totalMemory *= 2;
  } else {
    totalMemory += 16*1024*1024
  }
}
if (totalMemory !== TOTAL_MEMORY) {
  Module.printErr('increasing TOTAL_MEMORY to ' + totalMemory + ' to be compliant with the asm.js spec (and given that TOTAL_STACK=' + TOTAL_STACK + ')');
  TOTAL_MEMORY = totalMemory;
}

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'JS engine does not provide full typed array support');

var buffer;
buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);

// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['buffer'] = buffer;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;
var runtimeExited = false;


function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
  runtimeExited = true;
}

function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;

// Tools


function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var len = length > 0 ? length : lengthBytesUTF8(stringy)+1;
  var u8array = new Array(len);
  var numBytesWritten = stringToUTF8Array(stringy, u8array, 0, u8array.length);
  if (dontAddNull) u8array.length = numBytesWritten;
  return u8array;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
        assert(false, 'Character code ' + chr + ' (' + String.fromCharCode(chr) + ')  at offset ' + i + ' not in 0x00-0xFF.');
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))>>0)]=chr;
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[((buffer++)>>0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; ++i) {
    assert(str.charCodeAt(i) === str.charCodeAt(i)&0xff);
    HEAP8[((buffer++)>>0)]=str.charCodeAt(i);
  }
  // Null-terminate the pointer to the HEAP.
  if (!dontAddNull) HEAP8[((buffer)>>0)]=0;
}
Module['writeAsciiToMemory'] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}


// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];


if (!Math['clz32']) Math['clz32'] = function(x) {
  x = x >>> 0;
  for (var i = 0; i < 32; i++) {
    if (x & (1 << (31 - i))) return i;
  }
  return 32;
};
Math.clz32 = Math['clz32']

var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_min = Math.min;
var Math_clz32 = Math.clz32;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled
var runDependencyTracking = {};

function getUniqueRunDependency(id) {
  var orig = id;
  while (1) {
    if (!runDependencyTracking[id]) return id;
    id = orig + Math.random();
  }
  return id;
}

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
    if (runDependencyWatcher === null && typeof setInterval !== 'undefined') {
      // Check for missing dependencies every few seconds
      runDependencyWatcher = setInterval(function() {
        if (ABORT) {
          clearInterval(runDependencyWatcher);
          runDependencyWatcher = null;
          return;
        }
        var shown = false;
        for (var dep in runDependencyTracking) {
          if (!shown) {
            shown = true;
            Module.printErr('still waiting on run dependencies:');
          }
          Module.printErr('dependency: ' + dep);
        }
        if (shown) {
          Module.printErr('(end of list)');
        }
      }, 10000);
    }
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data



var memoryInitializer = null;



// === Body ===

var ASM_CONSTS = [];




STATIC_BASE = 8;

STATICTOP = STATIC_BASE + 7440;
  /* global initializers */  __ATINIT__.push();
  

/* memory initializer */ allocate([224,4,0,0,0,0,0,0,45,45,0,0,0,0,0,0,45,0,0,0,0,0,0,0,45,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,111,0,0,0,0,0,0,128,0,0,0,0,0,0,0,39,45,111,39,32,110,101,101,100,115,32,97,114,103,117,109,101,110,116,0,0,0,0,0,45,112,0,0,0,0,0,0,1,0,0,0,0,0,0,0,45,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,118,0,0,0,0,0,0,108,117,97,99,46,111,117,116,0,0,0,0,0,0,0,0,76,117,97,32,53,46,51,46,48,32,32,67,111,112,121,114,105,103,104,116,32,40,67,41,32,49,57,57,52,45,50,48,49,53,32,76,117,97,46,111,114,103,44,32,80,85,67,45,82,105,111,0,0,0,0,0,110,111,32,105,110,112,117,116,32,102,105,108,101,115,32,103,105,118,101,110,0,0,0,0,99,97,110,110,111,116,32,99,114,101,97,116,101,32,115,116,97,116,101,58,32,110,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,0,0,116,111,111,32,109,97,110,121,32,105,110,112,117,116,32,102,105,108,101,115,0,0,0,0,61,40,108,117,97,99,41,0,119,98,0,0,0,0,0,0,119,114,105,116,101,0,0,0,99,108,111,115,101,0,0,0,37,115,58,32,99,97,110,110,111,116,32,37,115,32,37,115,58,32,37,115,10,0,0,0,61,63,0,0,0,0,0,0,40,115,116,114,105,110,103,41,0,0,0,0,0,0,0,0,40,98,115,116,114,105,110,103,41,0,0,0,0,0,0,0,109,97,105,110,0,0,0,0,115,0,0,0,0,0,0,0,10,37,115,32,60,37,115,58,37,100,44,37,100,62,32,40,37,100,32,105,110,115,116,114,117,99,116,105,111,110,37,115,32,97,116,32,37,112,41,10,0,0,0,0,0,0,0,0,43,0,0,0,0,0,0,0,37,100,37,115,32,112,97,114,97,109,37,115,44,32,37,100,32,115,108,111,116,37,115,44,32,37,100,32,117,112,118,97,108,117,101,37,115,44,32,0,37,100,32,108,111,99,97,108,37,115,44,32,37,100,32,99,111,110,115,116,97,110,116,37,115,44,32,37,100,32,102,117,110,99,116,105,111,110,37,115,10,0,0,0,0,0,0,0,9,37,100,9,0,0,0,0,91,37,100,93,9,0,0,0,91,45,93,9,0,0,0,0,37,45,57,115,9,0,0,0,37,100,0,0,0,0,0,0,32,37,100,0,0,0,0,0,37,100,32,37,100,0,0,0,9,59,32,0,0,0,0,0,9,59,32,37,115,0,0,0,9,59,32,116,111,32,37,100,0,0,0,0,0,0,0,0,9,59,32,37,112,0,0,0,9,59,32,37,100,0,0,0,99,111,110,115,116,97,110,116,115,32,40,37,100,41,32,102,111,114,32,37,112,58,10,0,108,111,99,97,108,115,32,40,37,100,41,32,102,111,114,32,37,112,58,10,0,0,0,0,9,37,100,9,37,115,9,37,100,9,37,100,10,0,0,0,117,112,118,97,108,117,101,115,32,40,37,100,41,32,102,111,114,32,37,112,58,10,0,0,37,115,0,0,0,0,0,0,46,48,0,0,0,0,0,0,92,34,0,0,0,0,0,0,92,92,0,0,0,0,0,0,92,97,0,0,0,0,0,0,92,98,0,0,0,0,0,0,92,102,0,0,0,0,0,0,92,110,0,0,0,0,0,0,92,114,0,0,0,0,0,0,92,116,0,0,0,0,0,0,92,118,0,0,0,0,0,0,92,37,48,51,100,0,0,0,63,32,116,121,112,101,61,37,100,0,0,0,0,0,0,0,40,102,117,110,99,116,105,111,110,40,41,101,110,100,41,40,41,59,0,0,0,0,0,0,37,115,58,32,37,115,10,0,37,115,58,32,117,110,114,101,99,111,103,110,105,122,101,100,32,111,112,116,105,111,110,32,39,37,115,39,10,0,0,0,117,115,97,103,101,58,32,37,115,32,91,111,112,116,105,111,110,115,93,32,91,102,105,108,101,110,97,109,101,115,93,10,65,118,97,105,108,97,98,108,101,32,111,112,116,105,111,110,115,32,97,114,101,58,10,32,32,45,108,32,32,32,32,32,32,32,108,105,115,116,32,40,117,115,101,32,45,108,32,45,108,32,102,111,114,32,102,117,108,108,32,108,105,115,116,105,110,103,41,10,32,32,45,111,32,110,97,109,101,32,32,111,117,116,112,117,116,32,116,111,32,102,105,108,101,32,39,110,97,109,101,39,32,40,100,101,102,97,117,108,116,32,105,115,32,34,37,115,34,41,10,32,32,45,112,32,32,32,32,32,32,32,112,97,114,115,101,32,111,110,108,121,10,32,32,45,115,32,32,32,32,32,32,32,115,116,114,105,112,32,100,101,98,117,103,32,105,110,102,111,114,109,97,116,105,111,110,10,32,32,45,118,32,32,32,32,32,32,32,115,104,111,119,32,118,101,114,115,105,111,110,32,105,110,102,111,114,109,97,116,105,111,110,10,32,32,45,45,32,32,32,32,32,32,32,115,116,111,112,32,104,97,110,100,108,105,110,103,32,111,112,116,105,111,110,115,10,32,32,45,32,32,32,32,32,32,32,32,115,116,111,112,32,104,97,110,100,108,105,110,103,32,111,112,116,105,111,110,115,32,97,110,100,32,112,114,111,99,101,115,115,32,115,116,100,105,110,10,0,0,0,0,0,0,0,0,108,117,97,99,0,0,0,0,0,0,0,0,0,112,127,64,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,37,115,32,97,32,37,115,32,118,97,108,117,101,37,115,0,0,0,0,0,0,99,111,110,99,97,116,101,110,97,116,101,0,0,0,0,0,110,117,109,98,101,114,37,115,32,104,97,115,32,110,111,32,105,110,116,101,103,101,114,32,114,101,112,114,101,115,101,110,116,97,116,105,111,110,0,0,97,116,116,101,109,112,116,32,116,111,32,99,111,109,112,97,114,101,32,116,119,111,32,37,115,32,118,97,108,117,101,115,0,0,0,0,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,99,111,109,112,97,114,101,32,37,115,32,119,105,116,104,32,37,115,0,0,0,117,112,118,97,108,117,101,0,32,40,37,115,32,39,37,115,39,41,0,0,0,0,0,0,103,108,111,98,97,108,0,0,102,105,101,108,100,0,0,0,99,111,110,115,116,97,110,116,0,0,0,0,0,0,0,0,109,101,116,104,111,100,0,0,101,114,114,111,114,32,105,110,32,101,114,114,111,114,32,104,97,110,100,108,105,110,103,0,115,116,97,99,107,32,111,118,101,114,102,108,111,119,0,0,99,97,108,108,0,0,0,0,67,32,115,116,97,99,107,32,111,118,101,114,102,108,111,119,0,0,0,0,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,108,111,97,100,32,97,32,37,115,32,99,104,117,110,107,32,40,109,111,100,101,32,105,115,32,39,37,115,39,41,0,0,0,0,0,0,0,98,105,110,97,114,121,0,0,116,101,120,116,0,0,0,0,110,111,32,109,101,115,115,97,103,101,0,0,0,0,0,0,101,114,114,111,114,32,105,110,32,95,95,103,99,32,109,101,116,97,109,101,116,104,111,100,32,40,37,115,41,0,0,0,116,111,111,32,109,97,110,121,32,37,115,32,40,108,105,109,105,116,32,105,115,32,37,100,41,0,0,0,0,0,0,0,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,101,114,114,111,114,58,32,98,108,111,99,107,32,116,111,111,32,98,105,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,110,78,0,0,0,0,0,0,37,108,108,100,0,0,0,0,37,46,49,52,103,0,0,0,45,48,49,50,51,52,53,54,55,56,57,0,0,0,0,0,60,92,37,100,62,0,0,0,37,112,0,0,0,0,0,0,37,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,111,112,116,105,111,110,32,39,37,37,37,99,39,32,116,111,32,39,108,117,97,95,112,117,115,104,102,115,116,114,105,110,103,39,0,0,0,0,0,0,91,115,116,114,105,110,103,32,34,0,0,0,0,0,0,0,34,93,0,0,0,0,0,0,104,9,0,0,112,9,0,0,120,9,0,0,128,9,0,0,144,9,0,0,152,9,0,0,168,9,0,0,184,9,0,0,200,9,0,0,216,9,0,0,232,9,0,0,248,9,0,0,8,10,0,0,16,10,0,0,24,10,0,0,32,10,0,0,40,10,0,0,48,10,0,0,56,10,0,0,64,10,0,0,72,10,0,0,80,10,0,0,88,10,0,0,96,10,0,0,104,10,0,0,112,10,0,0,120,10,0,0,128,10,0,0,136,10,0,0,144,10,0,0,152,10,0,0,160,10,0,0,168,10,0,0,176,10,0,0,184,10,0,0,192,10,0,0,200,10,0,0,208,10,0,0,224,10,0,0,232,10,0,0,240,10,0,0,248,10,0,0,8,11,0,0,24,11,0,0,32,11,0,0,40,11,0,0,48,11,0,0,0,0,0,0,96,113,65,84,80,80,92,108,60,16,60,84,108,124,124,124,124,124,124,124,124,124,124,124,124,96,96,96,96,104,34,188,188,188,132,228,84,84,16,98,98,4,98,20,81,80,23,0,77,79,86,69,0,0,0,0,76,79,65,68,75,0,0,0,76,79,65,68,75,88,0,0,76,79,65,68,66,79,79,76,0,0,0,0,0,0,0,0,76,79,65,68,78,73,76,0,71,69,84,85,80,86,65,76,0,0,0,0,0,0,0,0,71,69,84,84,65,66,85,80,0,0,0,0,0,0,0,0,71,69,84,84,65,66,76,69,0,0,0,0,0,0,0,0,83,69,84,84,65,66,85,80,0,0,0,0,0,0,0,0,83,69,84,85,80,86,65,76,0,0,0,0,0,0,0,0,83,69,84,84,65,66,76,69,0,0,0,0,0,0,0,0,78,69,87,84,65,66,76,69,0,0,0,0,0,0,0,0,83,69,76,70,0,0,0,0,65,68,68,0,0,0,0,0,83,85,66,0,0,0,0,0,77,85,76,0,0,0,0,0,77,79,68,0,0,0,0,0,80,79,87,0,0,0,0,0,68,73,86,0,0,0,0,0,73,68,73,86,0,0,0,0,66,65,78,68,0,0,0,0,66,79,82,0,0,0,0,0,66,88,79,82,0,0,0,0,83,72,76,0,0,0,0,0,83,72,82,0,0,0,0,0,85,78,77,0,0,0,0,0,66,78,79,84,0,0,0,0,78,79,84,0,0,0,0,0,76,69,78,0,0,0,0,0,67,79,78,67,65,84,0,0,74,77,80,0,0,0,0,0,69,81,0,0,0,0,0,0,76,84,0,0,0,0,0,0,76,69,0,0,0,0,0,0,84,69,83,84,0,0,0,0,84,69,83,84,83,69,84,0,67,65,76,76,0,0,0,0,84,65,73,76,67,65,76,76,0,0,0,0,0,0,0,0,82,69,84,85,82,78,0,0,70,79,82,76,79,79,80,0,70,79,82,80,82,69,80,0,84,70,79,82,67,65,76,76,0,0,0,0,0,0,0,0,84,70,79,82,76,79,79,80,0,0,0,0,0,0,0,0,83,69,84,76,73,83,84,0,67,76,79,83,85,82,69,0,86,65,82,65,82,71,0,0,69,88,84,82,65,65,82,71,0,0,0,0,0,0,0,0,108,97,98,101,108,115,47,103,111,116,111,115,0,0,0,0,60,37,115,62,32,97,116,32,108,105,110,101,32,37,100,32,110,111,116,32,105,110,115,105,100,101,32,97,32,108,111,111,112,0,0,0,0,0,0,0,110,111,32,118,105,115,105,98,108,101,32,108,97,98,101,108,32,39,37,115,39,32,102,111,114,32,60,103,111,116,111,62,32,97,116,32,108,105,110,101,32,37,100,0,0,0,0,0,60,103,111,116,111,32,37,115,62,32,97,116,32,108,105,110,101,32,37,100,32,106,117,109,112,115,32,105,110,116,111,32,116,104,101,32,115,99,111,112,101,32,111,102,32,108,111,99,97,108,32,39,37,115,39,0,37,115,32,101,120,112,101,99,116,101,100,0,0,0,0,0,102,117,110,99,116,105,111,110,32,97,116,32,108,105,110,101,32,37,100,0,0,0,0,0,109,97,105,110,32,102,117,110,99,116,105,111,110,0,0,0,116,111,111,32,109,97,110,121,32,37,115,32,40,108,105,109,105,116,32,105,115,32,37,100,41,32,105,110,32,37,115,0,67,32,108,101,118,101,108,115,0,0,0,0,0,0,0,0,37,115,32,101,120,112,101,99,116,101,100,32,40,116,111,32,99,108,111,115,101,32,37,115,32,97,116,32,108,105,110,101,32,37,100,41,0,0,0,0,40,102,111,114,32,105,110,100,101,120,41,0,0,0,0,0,40,102,111,114,32,108,105,109,105,116,41,0,0,0,0,0,40,102,111,114,32,115,116,101,112,41,0,0,0,0,0,0,40,102,111,114,32,103,101,110,101,114,97,116,111,114,41,0,40,102,111,114,32,115,116,97,116,101,41,0,0,0,0,0,40,102,111,114,32,99,111,110,116,114,111,108,41,0,0,0,39,61,39,32,111,114,32,39,105,110,39,32,101,120,112,101,99,116,101,100,0,0,0,0,108,97,98,101,108,32,39,37,115,39,32,97,108,114,101,97,100,121,32,100,101,102,105,110,101,100,32,111,110,32,108,105,110,101,32,37,100,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,115,121,109,98,111,108,0,0,0,0,0,0,0,102,117,110,99,116,105,111,110,32,97,114,103,117,109,101,110,116,115,32,101,120,112,101,99,116,101,100,0,0,0,0,0,102,117,110,99,116,105,111,110,115,0,0,0,0,0,0,0,115,101,108,102,0,0,0,0,60,110,97,109,101,62,32,111,114,32,39,46,46,46,39,32,101,120,112,101,99,116,101,100,0,0,0,0,0,0,0,0,108,111,99,97,108,32,118,97,114,105,97,98,108,101,115,0,99,97,110,110,111,116,32,117,115,101,32,39,46,46,46,39,32,111,117,116,115,105,100,101,32,97,32,118,97,114,97,114,103,32,102,117,110,99,116,105,111,110,0,0,0,0,0,0,10,10,10,10,11,11,11,11,14,13,11,11,11,11,6,6,4,4,5,5,7,7,7,7,9,8,3,3,3,3,3,3,3,3,3,3,3,3,2,2,1,1,0,0,0,0,0,0,117,112,118,97,108,117,101,115,0,0,0,0,0,0,0,0,110,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,97,98,108,101,32,111,118,101,114,102,108,111,119,0,0,116,97,98,108,101,32,105,110,100,101,120,32,105,115,32,110,105,108,0,0,0,0,0,0,116,97,98,108,101,32,105,110,100,101,120,32,105,115,32,78,97,78,0,0,0,0,0,0,80,15,0,0,112,23,0,0,96,15,0,0,104,15,0,0,120,15,0,0,160,22,0,0,128,15,0,0,64,23,0,0,104,15,0,0,136,15,0,0,144,15,0,0,0,0,0,0,152,15,0,0,160,15,0,0,176,15,0,0,184,15,0,0,192,15,0,0,200,15,0,0,208,15,0,0,216,15,0,0,224,15,0,0,232,15,0,0,240,15,0,0,248,15,0,0,0,16,0,0,8,16,0,0,16,16,0,0,24,16,0,0,32,16,0,0,40,16,0,0,48,16,0,0,56,16,0,0,64,16,0,0,72,16,0,0,80,16,0,0,96,16,0,0,112,101,114,102,111,114,109,32,98,105,116,119,105,115,101,32,111,112,101,114,97,116,105,111,110,32,111,110,0,0,0,0,112,101,114,102,111,114,109,32,97,114,105,116,104,109,101,116,105,99,32,111,110,0,0,0,110,111,32,118,97,108,117,101,0,0,0,0,0,0,0,0,98,111,111,108,101,97,110,0,117,115,101,114,100,97,116,97,0,0,0,0,0,0,0,0,110,117,109,98,101,114,0,0,116,97,98,108,101,0,0,0,116,104,114,101,97,100,0,0,112,114,111,116,111,0,0,0,95,95,105,110,100,101,120,0,95,95,110,101,119,105,110,100,101,120,0,0,0,0,0,0,95,95,103,99,0,0,0,0,95,95,109,111,100,101,0,0,95,95,108,101,110,0,0,0,95,95,101,113,0,0,0,0,95,95,97,100,100,0,0,0,95,95,115,117,98,0,0,0,95,95,109,117,108,0,0,0,95,95,109,111,100,0,0,0,95,95,112,111,119,0,0,0,95,95,100,105,118,0,0,0,95,95,105,100,105,118,0,0,95,95,98,97,110,100,0,0,95,95,98,111,114,0,0,0,95,95,98,120,111,114,0,0,95,95,115,104,108,0,0,0,95,95,115,104,114,0,0,0,95,95,117,110,109,0,0,0,95,95,98,110,111,116,0,0,95,95,108,116,0,0,0,0,95,95,108,101,0,0,0,0,95,95,99,111,110,99,97,116,0,0,0,0,0,0,0,0,95,95,99,97,108,108,0,0,98,105,110,97,114,121,32,115,116,114,105,110,103,0,0,0,116,114,117,110,99,97,116,101,100,0,0,0,0,0,0,0,27,76,117,97,0,0,0,0,110,111,116,32,97,0,0,0,118,101,114,115,105,111,110,32,109,105,115,109,97,116,99,104,32,105,110,0,0,0,0,0,102,111,114,109,97,116,32,109,105,115,109,97,116,99,104,32,105,110,0,0,0,0,0,0,25,147,13,10,26,10,0,0,99,111,114,114,117,112,116,101,100,0,0,0,0,0,0,0,37,115,32,115,105,122,101,32,109,105,115,109,97,116,99,104,32,105,110,0,0,0,0,0,105,110,116,0,0,0,0,0,115,105,122,101,95,116,0,0,73,110,115,116,114,117,99,116,105,111,110,0,0,0,0,0,108,117,97,95,73,110,116,101,103,101,114,0,0,0,0,0,108,117,97,95,78,117,109,98,101,114,0,0,0,0,0,0,101,110,100,105,97,110,110,101,115,115,32,109,105,115,109,97,116,99,104,32,105,110,0,0,102,108,111,97,116,32,102,111,114,109,97,116,32,109,105,115,109,97,116,99,104,32,105,110,0,0,0,0,0,0,0,0,37,115,58,32,37,115,32,112,114,101,99,111,109,112,105,108,101,100,32,99,104,117,110,107,0,0,0,0,0,0,0,0,105,110,100,101,120,0,0,0,103,101,116,116,97,98,108,101,32,99,104,97,105,110,32,116,111,111,32,108,111,110,103,59,32,112,111,115,115,105,98,108,101,32,108,111,111,112,0,0,115,101,116,116,97,98,108,101,32,99,104,97,105,110,32,116,111,111,32,108,111,110,103,59,32,112,111,115,115,105,98,108,101,32,108,111,111,112,0,0,115,116,114,105,110,103,32,108,101,110,103,116,104,32,111,118,101,114,102,108,111,119,0,0,103,101,116,32,108,101,110,103,116,104,32,111,102,0,0,0,97,116,116,101,109,112,116,32,116,111,32,100,105,118,105,100,101,32,98,121,32,122,101,114,111,0,0,0,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,112,101,114,102,111,114,109,32,39,110,37,37,48,39,0,0,0,0,0,0,0,39,102,111,114,39,32,108,105,109,105,116,32,109,117,115,116,32,98,101,32,97,32,110,117,109,98,101,114,0,0,0,0,39,102,111,114,39,32,115,116,101,112,32,109,117,115,116,32,98,101,32,97,32,110,117,109,98,101,114,0,0,0,0,0,39,102,111,114,39,32,105,110,105,116,105,97,108,32,118,97,108,117,101,32,109,117,115,116,32,98,101,32,97,32,110,117,109,98,101,114,0,0,0,0,61,115,116,100,105,110,0,0,64,37,115,0,0,0,0,0,114,0,0,0,0,0,0,0,99,97,110,110,111,116,32,37,115,32,37,115,58,32,37,115,0,0,0,0,0,0,0,0,111,112,101,110,0,0,0,0,114,98,0,0,0,0,0,0,114,101,111,112,101,110,0,0,114,101,97,100,0,0,0,0,80,65,78,73,67,58,32,117,110,112,114,111,116,101,99,116,101,100,32,101,114,114,111,114,32,105,110,32,99,97,108,108,32,116,111,32,76,117,97,32,65,80,73,32,40,37,115,41,10,0,0,0,0,0,0,0,99,111,110,116,114,111,108,32,115,116,114,117,99,116,117,114,101,32,116,111,111,32,108,111,110,103,0,0,0,0,0,0,102,117,110,99,116,105,111,110,32,111,114,32,101,120,112,114,101,115,115,105,111,110,32,116,111,111,32,99,111,109,112,108,101,120,0,0,0,0,0,0,99,111,110,115,116,114,117,99,116,111,114,32,116,111,111,32,108,111,110,103,0,0,0,0,99,111,110,115,116,97,110,116,115,0,0,0,0,0,0,0,111,112,99,111,100,101,115,0,0,0,0,0,0,0,0,0,0,0,8,8,8,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,22,22,22,22,22,22,22,22,22,22,4,4,4,4,4,4,4,21,21,21,21,21,21,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,4,4,4,4,5,4,21,21,21,21,21,21,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,4,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,69,78,86,0,0,0,0,0,23,0,0,8,23,0,0,16,23,0,0,24,23,0,0,32,23,0,0,40,23,0,0,48,23,0,0,56,23,0,0,64,23,0,0,80,23,0,0,88,23,0,0,96,23,0,0,104,23,0,0,112,23,0,0,120,23,0,0,128,23,0,0,136,23,0,0,144,23,0,0,152,23,0,0,160,23,0,0,168,23,0,0,176,23,0,0,184,23,0,0,192,23,0,0,200,23,0,0,208,23,0,0,216,23,0,0,224,23,0,0,232,23,0,0,240,23,0,0,248,23,0,0,0,24,0,0,8,24,0,0,16,24,0,0,32,24,0,0,48,24,0,0,56,24,0,0,0,0,0,0,39,37,99,39,0,0,0,0,39,37,115,39,0,0,0,0,99,104,117,110,107,32,104,97,115,32,116,111,111,32,109,97,110,121,32,108,105,110,101,115,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,108,111,110,103,32,115,116,114,105,110,103,32,100,101,108,105,109,105,116,101,114,0,0,0,108,101,120,105,99,97,108,32,101,108,101,109,101,110,116,32,116,111,111,32,108,111,110,103,0,0,0,0,0,0,0,0,117,110,102,105,110,105,115,104,101,100,32,115,116,114,105,110,103,0,0,0,0,0,0,0,104,101,120,97,100,101,99,105,109,97,108,32,100,105,103,105,116,32,101,120,112,101,99,116,101,100,0,0,0,0,0,0,109,105,115,115,105,110,103,32,39,123,39,0,0,0,0,0,85,84,70,45,56,32,118,97,108,117,101,32,116,111,111,32,108,97,114,103,101,0,0,0,109,105,115,115,105,110,103,32,39,125,39,0,0,0,0,0,105,110,118,97,108,105,100,32,101,115,99,97,112,101,32,115,101,113,117,101,110,99,101,0,100,101,99,105,109,97,108,32,101,115,99,97,112,101,32,116,111,111,32,108,97,114,103,101,0,0,0,0,0,0,0,0,69,101,0,0,0,0,0,0,80,112,0,0,0,0,0,0,109,97,108,102,111,114,109,101,100,32,110,117,109,98,101,114,0,0,0,0,0,0,0,0,115,116,114,105,110,103,0,0,99,111,109,109,101,110,116,0,117,110,102,105,110,105,115,104,101,100,32,108,111,110,103,32,37,115,32,40,115,116,97,114,116,105,110,103,32,97,116,32,108,105,110,101,32,37,100,41,0,0,0,0,0,0,0,0,37,115,58,37,100,58,32,37,115,0,0,0,0,0,0,0,37,115,32,110,101,97,114,32,37,115,0,0,0,0,0,0,97,110,100,0,0,0,0,0,98,114,101,97,107,0,0,0,100,111,0,0,0,0,0,0,101,108,115,101,0,0,0,0,101,108,115,101,105,102,0,0,101,110,100,0,0,0,0,0,102,97,108,115,101,0,0,0,102,111,114,0,0,0,0,0,102,117,110,99,116,105,111,110,0,0,0,0,0,0,0,0,103,111,116,111,0,0,0,0,105,102,0,0,0,0,0,0,105,110,0,0,0,0,0,0,108,111,99,97,108,0,0,0,110,105,108,0,0,0,0,0,110,111,116,0,0,0,0,0,111,114,0,0,0,0,0,0,114,101,112,101,97,116,0,0,114,101,116,117,114,110,0,0,116,104,101,110,0,0,0,0,116,114,117,101,0,0,0,0,117,110,116,105,108,0,0,0,119,104,105,108,101,0,0,0,47,47,0,0,0,0,0,0,46,46,0,0,0,0,0,0,46,46,46,0,0,0,0,0,61,61,0,0,0,0,0,0,62,61,0,0,0,0,0,0,60,61,0,0,0,0,0,0,126,61,0,0,0,0,0,0,60,60,0,0,0,0,0,0,62,62,0,0,0,0,0,0,58,58,0,0,0,0,0,0,60,101,111,102,62,0,0,0,60,110,117,109,98,101,114,62,0,0,0,0,0,0,0,0,60,105,110,116,101,103,101,114,62,0,0,0,0,0,0,0,60,110,97,109,101,62,0,0,60,115,116,114,105,110,103,62,0,0,0,0,0,0,0,0,105,110,102,105,110,105,116,121,0,0,0,0,0,0,0,0,10,0,0,0,100,0,0,0,232,3,0,0,16,39,0,0,160,134,1,0,64,66,15,0,128,150,152,0,0,225,245,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,10,0,17,17,17,0,0,0,0,5,0,0,0,0,0,0,9,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,15,10,17,17,17,3,10,7,0,1,19,9,11,11,0,0,9,6,11,0,0,11,0,6,17,0,0,0,17,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,10,10,17,17,17,0,10,0,0,2,0,9,11,0,0,0,9,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,4,13,0,0,0,0,9,14,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,15,0,0,0,0,9,16,0,0,0,0,0,16,0,0,16,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,0,9,11,0,0,0,0,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,45,43,32,32,32,48,88,48,120,0,0,0,0,0,0,0,40,110,117,108,108,41,0,0,45,48,88,43,48,88,32,48,88,45,48,120,43,48,120,32,48,120,0,0,0,0,0,0,105,110,102,0,0,0,0,0,73,78,70,0,0,0,0,0,110,97,110,0,0,0,0,0,78,65,78,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);





/* no memory initializer */
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}

// {{PRE_LIBRARY}}


   
  Module["_i64Subtract"] = _i64Subtract;

  var _DtoILow=true;

  
  
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value;
      return value;
    }
  
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 30: return PAGE_SIZE;
        case 85: return totalMemory / PAGE_SIZE;
        case 132:
        case 133:
        case 12:
        case 137:
        case 138:
        case 15:
        case 235:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
        case 149:
        case 13:
        case 10:
        case 236:
        case 153:
        case 9:
        case 21:
        case 22:
        case 159:
        case 154:
        case 14:
        case 77:
        case 78:
        case 139:
        case 80:
        case 81:
        case 82:
        case 68:
        case 67:
        case 164:
        case 11:
        case 29:
        case 47:
        case 48:
        case 95:
        case 52:
        case 51:
        case 46:
          return 200809;
        case 79:
          return 0;
        case 27:
        case 246:
        case 127:
        case 128:
        case 23:
        case 24:
        case 160:
        case 161:
        case 181:
        case 182:
        case 242:
        case 183:
        case 184:
        case 243:
        case 244:
        case 245:
        case 165:
        case 178:
        case 179:
        case 49:
        case 50:
        case 168:
        case 169:
        case 175:
        case 170:
        case 171:
        case 172:
        case 97:
        case 76:
        case 32:
        case 173:
        case 35:
          return -1;
        case 176:
        case 177:
        case 7:
        case 155:
        case 8:
        case 157:
        case 125:
        case 126:
        case 92:
        case 93:
        case 129:
        case 130:
        case 131:
        case 94:
        case 91:
          return 1;
        case 74:
        case 60:
        case 69:
        case 70:
        case 4:
          return 1024;
        case 31:
        case 42:
        case 72:
          return 32;
        case 87:
        case 26:
        case 33:
          return 2147483647;
        case 34:
        case 1:
          return 47839;
        case 38:
        case 36:
          return 99;
        case 43:
        case 37:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 28: return 32768;
        case 44: return 32767;
        case 75: return 16384;
        case 39: return 1000;
        case 89: return 700;
        case 71: return 256;
        case 40: return 255;
        case 2: return 100;
        case 180: return 64;
        case 25: return 20;
        case 5: return 16;
        case 6: return 6;
        case 73: return 4;
        case 84: {
          if (typeof navigator === 'object') return navigator['hardwareConcurrency'] || 1;
          return 1;
        }
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }

  var _SItoD=true;

  function ___errno_location() {
      return ___errno_state;
    }

   
  Module["_memset"] = _memset;

  
  
  
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};
  
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            return ''; // an invalid portion invalidates the whole thing
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          stream.tty.ops.flush(stream.tty);
        },flush:function (stream) {
          stream.tty.ops.flush(stream.tty);
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              // we will read data by chunks of BUFSIZE
              var BUFSIZE = 256;
              var buf = new Buffer(BUFSIZE);
              var bytesRead = 0;
  
              var fd = process.stdin.fd;
              // Linux and Mac cannot use process.stdin.fd (which isn't set up as sync)
              var usingDevice = false;
              try {
                fd = fs.openSync('/dev/stdin', 'r');
                usingDevice = true;
              } catch (e) {}
  
              bytesRead = fs.readSync(fd, buf, 0, BUFSIZE, null);
  
              if (usingDevice) { fs.closeSync(fd); }
              if (bytesRead > 0) {
                result = buf.slice(0, bytesRead).toString('utf-8');
              } else {
                result = null;
              }
  
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          } else {
            if (val != 0) tty.output.push(val); // val == 0 would cut text output off in the middle.
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            Module['print'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          } else {
            if (val != 0) tty.output.push(val);
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            Module['printErr'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          }
        }}};
  
  var MEMFS={ops_table:null,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap,
                msync: MEMFS.stream_ops.msync
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            }
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.usedBytes = 0; // The actual number of bytes used in the typed array, as opposed to contents.buffer.byteLength which gives the whole capacity.
          // When the byte data of the file is populated, this will point to either a typed array, or a normal JS array. Typed arrays are preferred
          // for performance, and used by default. However, typed arrays are not resizable like normal JS arrays are, so there is a small disk size
          // penalty involved for appending file writes that continuously grow a file similar to std::vector capacity vs used -scheme.
          node.contents = null; 
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },getFileDataAsRegularArray:function (node) {
        if (node.contents && node.contents.subarray) {
          var arr = [];
          for (var i = 0; i < node.usedBytes; ++i) arr.push(node.contents[i]);
          return arr; // Returns a copy of the original data.
        }
        return node.contents; // No-op, the file contents are already in a JS array. Return as-is.
      },getFileDataAsTypedArray:function (node) {
        if (!node.contents) return new Uint8Array;
        if (node.contents.subarray) return node.contents.subarray(0, node.usedBytes); // Make sure to not return excess unused bytes.
        return new Uint8Array(node.contents);
      },expandFileStorage:function (node, newCapacity) {
        // If we are asked to expand the size of a file that already exists, revert to using a standard JS array to store the file
        // instead of a typed array. This makes resizing the array more flexible because we can just .push() elements at the back to
        // increase the size.
        if (node.contents && node.contents.subarray && newCapacity > node.contents.length) {
          node.contents = MEMFS.getFileDataAsRegularArray(node);
          node.usedBytes = node.contents.length; // We might be writing to a lazy-loaded file which had overridden this property, so force-reset it.
        }
  
        if (!node.contents || node.contents.subarray) { // Keep using a typed array if creating a new storage, or if old one was a typed array as well.
          var prevCapacity = node.contents ? node.contents.buffer.byteLength : 0;
          if (prevCapacity >= newCapacity) return; // No need to expand, the storage was already large enough.
          // Don't expand strictly to the given requested limit if it's only a very small increase, but instead geometrically grow capacity.
          // For small filesizes (<1MB), perform size*2 geometric increase, but for large sizes, do a much more conservative size*1.125 increase to
          // avoid overshooting the allocation cap by a very large margin.
          var CAPACITY_DOUBLING_MAX = 1024 * 1024;
          newCapacity = Math.max(newCapacity, (prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2.0 : 1.125)) | 0);
          if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256); // At minimum allocate 256b for each file when expanding.
          var oldContents = node.contents;
          node.contents = new Uint8Array(newCapacity); // Allocate new storage.
          if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0); // Copy old data over to the new storage.
          return;
        }
        // Not using a typed array to back the file storage. Use a standard JS array instead.
        if (!node.contents && newCapacity > 0) node.contents = [];
        while (node.contents.length < newCapacity) node.contents.push(0);
      },resizeFileStorage:function (node, newSize) {
        if (node.usedBytes == newSize) return;
        if (newSize == 0) {
          node.contents = null; // Fully decommit when requesting a resize to zero.
          node.usedBytes = 0;
          return;
        }
        if (!node.contents || node.contents.subarray) { // Resize a typed array if that is being used as the backing store.
          var oldContents = node.contents;
          node.contents = new Uint8Array(new ArrayBuffer(newSize)); // Allocate new storage.
          if (oldContents) {
            node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes))); // Copy old data over to the new storage.
          }
          node.usedBytes = newSize;
          return;
        }
        // Backing with a JS array.
        if (!node.contents) node.contents = [];
        if (node.contents.length > newSize) node.contents.length = newSize;
        else while (node.contents.length < newSize) node.contents.push(0);
        node.usedBytes = newSize;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.usedBytes;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.resizeFileStorage(node, attr.size);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= stream.node.usedBytes) return 0;
          var size = Math.min(stream.node.usedBytes - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else {
            for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i];
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          if (!length) return 0;
          var node = stream.node;
          node.timestamp = Date.now();
  
          if (buffer.subarray && (!node.contents || node.contents.subarray)) { // This write is from a typed array to a typed array?
            if (canOwn) { // Can we just reuse the buffer we are given?
              assert(position === 0, 'canOwn must imply no weird position inside the file');
              node.contents = buffer.subarray(offset, offset + length);
              node.usedBytes = length;
              return length;
            } else if (node.usedBytes === 0 && position === 0) { // If this is a simple first write to an empty file, do a fast set since we don't need to care about old data.
              node.contents = new Uint8Array(buffer.subarray(offset, offset + length));
              node.usedBytes = length;
              return length;
            } else if (position + length <= node.usedBytes) { // Writing to an already allocated and used subrange of the file?
              node.contents.set(buffer.subarray(offset, offset + length), position);
              return length;
            }
          }
  
          // Appending to an existing file and we need to reallocate, or source data did not come as a typed array.
          MEMFS.expandFileStorage(node, position+length);
          if (node.contents.subarray && buffer.subarray) node.contents.set(buffer.subarray(offset, offset + length), position); // Use typed array write if available.
          else {
            for (var i = 0; i < length; i++) {
             node.contents[position + i] = buffer[offset + i]; // Or fall back to manual write if not.
            }
          }
          node.usedBytes = Math.max(node.usedBytes, position+length);
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.usedBytes;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.expandFileStorage(stream.node, offset + length);
          stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < stream.node.usedBytes) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        },msync:function (stream, buffer, offset, length, mmapFlags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          if (mmapFlags & 2) {
            // MAP_PRIVATE calls need not to be synced back to underlying fs
            return 0;
          }
  
          var bytesWritten = MEMFS.stream_ops.write(stream, buffer, 0, length, offset, false);
          // should we check if bytesWritten and length are the same?
          return 0;
        }}};
  
  var IDBFS={dbs:{},indexedDB:function () {
        if (typeof indexedDB !== 'undefined') return indexedDB;
        var ret = null;
        if (typeof window === 'object') ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
        assert(ret, 'IDBFS used, but indexedDB not supported');
        return ret;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
  
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
  
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
  
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
  
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;
  
          var fileStore;
  
          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }
  
          if (!fileStore.indexNames.contains('timestamp')) {
            fileStore.createIndex('timestamp', 'timestamp', { unique: false });
          }
        };
        req.onsuccess = function() {
          db = req.result;
  
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};
  
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
  
        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  
        while (check.length) {
          var path = check.pop();
          var stat;
  
          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
  
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }
  
          entries[path] = { timestamp: stat.mtime };
        }
  
        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};
  
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
  
          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function(e) {
            callback(this.error);
            e.preventDefault();
          };
  
          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          var index = store.index('timestamp');
  
          index.openKeyCursor().onsuccess = function(event) {
            var cursor = event.target.result;
  
            if (!cursor) {
              return callback(null, { type: 'remote', db: db, entries: entries });
            }
  
            entries[cursor.primaryKey] = { timestamp: cursor.key };
  
            cursor.continue();
          };
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;
  
        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }
  
        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          // Performance consideration: storing a normal JavaScript array to a IndexedDB is much slower than storing a typed array.
          // Therefore always convert the file contents to a typed array first before writing the data to IndexedDB.
          node.contents = MEMFS.getFileDataAsTypedArray(node);
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { encoding: 'binary', canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }
  
          FS.chmod(path, entry.mode);
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);
  
          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },reconcile:function (src, dst, callback) {
        var total = 0;
  
        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });
  
        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });
  
        if (!total) {
          return callback(null);
        }
  
        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };
  
        transaction.onerror = function(e) {
          done(this.error);
          e.preventDefault();
        };
  
        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });
  
        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};
  
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          return flags;
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            path = fs.readlinkSync(path);
            path = NODEJS_PATH.relative(NODEJS_PATH.resolve(node.mount.opts.root), path);
            return path;
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          if (length === 0) return 0; // node errors on 0 length reads
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          return position;
        }}};
  
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
  
      /*
      // Disabled, see https://github.com/kripken/emscripten/issues/2770
      stream = FS.getStreamFromPtr(stream);
      if (stream.stream_ops.flush) {
        stream.stream_ops.flush(stream);
      }
      */
    }var FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,trackingDelegate:{},tracking:{openFlags:{READ:1,WRITE:2}},ErrnoError:null,genericErrors:{},handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};
  
        if (!path) return { path: '', node: null };
  
        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }
  
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
  
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
  
        // start at the root
        var current = FS.root;
        var current_path = '/';
  
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
  
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
  
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }
  
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
  
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
  
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
  
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
  
  
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err, parent);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };
  
          FS.FSNode.prototype = {};
  
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
  
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); }
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); }
            }
          });
        }
  
        var node = new FS.FSNode(parent, name, mode, rdev);
  
        FS.hashAddNode(node);
  
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 2097155;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        var err = FS.nodePermissions(dir, 'x');
        if (err) return err;
        if (!dir.node_ops.lookup) return ERRNO_CODES.EACCES;
        return 0;
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 2097155) !== 0 ||  // opening for write
              (flags & 512)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        // clone it, so we can return an instance of FSStream
        var newStream = new FS.FSStream();
        for (var p in stream) {
          newStream[p] = stream[p];
        }
        stream = newStream;
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getStreamFromPtr:function (ptr) {
        return FS.streams[ptr - 1];
      },getPtrForStream:function (stream) {
        return stream ? stream.fd + 1 : 0;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];
  
        while (check.length) {
          var m = check.pop();
  
          mounts.push(m);
  
          check.push.apply(check, m.mounts);
        }
  
        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
  
        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            callback(null);
          }
        };
  
        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;
  
        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;
  
          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }
  
          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }
  
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };
  
        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;
  
        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;
  
          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }
  
        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
  
        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);
  
        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];
  
          while (current) {
            var next = current.name_next;
  
            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }
  
            current = next;
          }
        });
  
        // no longer a mountpoint
        node.mounted = null;
  
        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        if (!name || name === '.' || name === '..') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        if (!PATH.resolve(oldpath)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        if (!parent) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        if (!old_dir || !new_dir) throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        try {
          if (FS.trackingDelegate['willMovePath']) {
            FS.trackingDelegate['willMovePath'](old_path, new_path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
        try {
          if (FS.trackingDelegate['onMovePath']) FS.trackingDelegate['onMovePath'](old_path, new_path);
        } catch(e) {
          console.log("FS.trackingDelegate['onMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return PATH.resolve(FS.getPath(lookup.node.parent), link.node_ops.readlink(link));
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        if (path === "") {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        var created = false;
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
            created = true;
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // check permissions, if this is not a file we just created now (it is ok to
        // create and write to a file with read-only permissions; it is read-only
        // for later use)
        if (!created) {
          var err = FS.mayOpen(node, flags);
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
  
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        try {
          if (FS.trackingDelegate['onOpenFile']) {
            var trackingFlags = 0;
            if ((flags & 2097155) !== 1) {
              trackingFlags |= FS.tracking.openFlags.READ;
            }
            if ((flags & 2097155) !== 0) {
              trackingFlags |= FS.tracking.openFlags.WRITE;
            }
            FS.trackingDelegate['onOpenFile'](path, trackingFlags);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['onOpenFile']('"+path+"', flags) threw an exception: " + e.message);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        stream.position = stream.stream_ops.llseek(stream, offset, whence);
        stream.ungotten = [];
        return stream.position;
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        try {
          if (stream.path && FS.trackingDelegate['onWriteToFile']) FS.trackingDelegate['onWriteToFile'](stream.path);
        } catch(e) {
          console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: " + e.message);
        }
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },msync:function (stream, buffer, offset, length, mmapFlags) {
        if (!stream || !stream.stream_ops.msync) {
          return 0;
        }
        return stream.stream_ops.msync(stream, buffer, offset, length, mmapFlags);
      },munmap:function (stream) {
        return 0;
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = UTF8ArrayToString(buf, 0);
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var buf = new Uint8Array(lengthBytesUTF8(data)+1);
          var actualNumBytes = stringToUTF8Array(data, buf, 0, buf.length);
          FS.write(stream, buf, 0, actualNumBytes, 0, opts.canOwn);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0, opts.canOwn);
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
        FS.mkdir('/home');
        FS.mkdir('/home/web_user');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function(stream, buffer, offset, length, pos) { return length; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // setup /dev/[u]random
        var random_device;
        if (typeof crypto !== 'undefined') {
          // for modern web browsers
          var randomBuffer = new Uint8Array(1);
          random_device = function() { crypto.getRandomValues(randomBuffer); return randomBuffer[0]; };
        } else if (ENVIRONMENT_IS_NODE) {
          // for nodejs
          random_device = function() { return require('crypto').randomBytes(1)[0]; };
        } else {
          // default for ES5 platforms
          random_device = function() { return (Math.random()*256)|0; };
        }
        FS.createDevice('/dev', 'random', random_device);
        FS.createDevice('/dev', 'urandom', random_device);
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
  
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
  
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=FS.getPtrForStream(stdin);
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');
  
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=FS.getPtrForStream(stdout);
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');
  
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=FS.getPtrForStream(stderr);
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno, node) {
          this.node = node;
          this.setErrno = function(errno) {
            this.errno = errno;
            for (var key in ERRNO_CODES) {
              if (ERRNO_CODES[key] === errno) {
                this.code = key;
                break;
              }
            }
          };
          this.setErrno(errno);
          this.message = ERRNO_MESSAGES[errno];
          if (this.stack) this.stack = demangleAll(this.stack);
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
  
        FS.nameTable = new Array(4096);
  
        FS.mount(MEMFS, {}, '/');
  
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureErrnoError();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
  
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
            obj.usedBytes = obj.contents.length;
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
        function LazyUint8Array() {
          this.lengthKnown = false;
          this.chunks = []; // Loaded chunks. Index is the chunk number
        }
        LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
          if (idx > this.length-1 || idx < 0) {
            return undefined;
          }
          var chunkOffset = idx % this.chunkSize;
          var chunkNum = (idx / this.chunkSize)|0;
          return this.getter(chunkNum)[chunkOffset];
        }
        LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
          this.getter = getter;
        }
        LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var chunkSize = 1024*1024; // Chunk size in bytes
  
          if (!hasByteServing) chunkSize = datalength;
  
          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
  
            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
  
            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }
  
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
          var lazyArray = this;
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * chunkSize;
            var end = (chunkNum+1) * chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });
  
          this._length = datalength;
          this._chunkSize = chunkSize;
          this.lengthKnown = true;
        }
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
  
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // Add a function that defers querying the file size until it is asked the first time.
        Object.defineProperty(node, "usedBytes", {
            get: function() { return this.contents.length; }
        });
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn, preFinish) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        var dep = getUniqueRunDependency('cp ' + fullname); // might have several active requests for the same fullname
        function processData(byteArray) {
          function finish(byteArray) {
            if (preFinish) preFinish();
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency(dep);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency(dep);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency(dep);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) return -1;
      return stream.fd;
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      var fd = _fileno(stream);
      return _close(fd);
    }

  var _emscripten_cleanup_setjmp=true;

  
  function _strerror_r(errnum, strerrbuf, buflen) {
      if (errnum in ERRNO_MESSAGES) {
        if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
          return ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          var msg = ERRNO_MESSAGES[errnum];
          writeAsciiToMemory(msg, strerrbuf);
          return 0;
        }
      } else {
        return ___setErrNo(ERRNO_CODES.EINVAL);
      }
    }function _strerror(errnum) {
      if (!_strerror.buffer) _strerror.buffer = _malloc(256);
      _strerror_r(errnum, _strerror.buffer, 256);
      return _strerror.buffer;
    }

  var _DtoIHigh=true;

   
  Module["_bitshift64Shl"] = _bitshift64Shl;

  function _abort() {
      Module['abort']();
    }

  
  
  
  
  
  function _mkport() { throw 'TODO' }var SOCKFS={mount:function (mount) {
        // If Module['websocket'] has already been defined (e.g. for configuring
        // the subprotocol/url) use that, if not initialise it to a new object.
        Module['websocket'] = (Module['websocket'] && 
                               ('object' === typeof Module['websocket'])) ? Module['websocket'] : {};
  
        // Add the Event registration mechanism to the exported websocket configuration
        // object so we can register network callbacks from native JavaScript too.
        // For more documentation see system/include/emscripten/emscripten.h
        Module['websocket']._callbacks = {};
        Module['websocket']['on'] = function(event, callback) {
  	    if ('function' === typeof callback) {
  		  this._callbacks[event] = callback;
          }
  	    return this;
        };
  
        Module['websocket'].emit = function(event, param) {
  	    if ('function' === typeof this._callbacks[event]) {
  		  this._callbacks[event].call(this, param);
          }
        };
  
        // If debug is enabled register simple default logging callbacks for each Event.
  
        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
  
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          error: null, // Used in getsockopt for SOL_SOCKET/SO_ERROR test
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
  
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;
  
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
  
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
  
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
  
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
  
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              // runtimeConfig gets set to true if WebSocket runtime configuration is available.
              var runtimeConfig = (Module['websocket'] && ('object' === typeof Module['websocket']));
  
              // The default value is 'ws://' the replace is needed because the compiler replaces '//' comments with '#'
              // comments without checking context, so we'd end up with ws:#, the replace swaps the '#' for '//' again.
              var url = 'ws:#'.replace('#', '//');
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['url']) {
                  url = Module['websocket']['url']; // Fetch runtime WebSocket URL config.
                }
              }
  
              if (url === 'ws://' || url === 'wss://') { // Is the supplied URL config just a prefix, if so complete it.
                var parts = addr.split('/');
                url = url + parts[0] + ":" + port + "/" + parts.slice(1).join('/');
              }
  
              // Make the WebSocket subprotocol (Sec-WebSocket-Protocol) default to binary if no configuration is set.
              var subProtocols = 'binary'; // The default value is 'binary'
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['subprotocol']) {
                  subProtocols = Module['websocket']['subprotocol']; // Fetch runtime WebSocket subprotocol config.
                }
              }
  
              // The regex trims the string (removes spaces at the beginning and end, then splits the string by
              // <any space>,<any space> into an Array. Whitespace removal is important for Websockify and ws.
              subProtocols = subProtocols.replace(/^ +| +$/g,"").split(/ *, */);
  
              // The node ws library API for specifying optional subprotocol is slightly different than the browser's.
              var opts = ENVIRONMENT_IS_NODE ? {'protocol': subProtocols.toString()} : subProtocols;
  
              // If node we use the ws library.
              var WebSocket = ENVIRONMENT_IS_NODE ? require('ws') : window['WebSocket'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
  
  
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
  
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
  
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
  
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
  
          var handleOpen = function () {
  
            Module['websocket'].emit('open', sock.stream.fd);
  
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
  
          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
  
  
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
  
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
            Module['websocket'].emit('message', sock.stream.fd);
          };
  
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('close', function() {
              Module['websocket'].emit('close', sock.stream.fd);
            });
            peer.socket.on('error', function(error) {
              // Although the ws library may pass errors that may be more descriptive than
              // ECONNREFUSED they are not necessarily the expected error code e.g. 
              // ENOTFOUND on getaddrinfo seems to be node.js specific, so using ECONNREFUSED
              // is still probably the most useful thing to do.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onclose = function() {
              Module['websocket'].emit('close', sock.stream.fd);
            };
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
            peer.socket.onerror = function(error) {
              // The WebSocket spec only allows a 'simple event' to be thrown on error,
              // so we only really know as much as ECONNREFUSED.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }
  
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
  
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }
  
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }
  
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
  
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
  
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
  
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
  
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
  
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          Module['websocket'].emit('listen', sock.stream.fd); // Send Event with listen fd.
  
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
  
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
  
              // push to queue for accept to pick up
              sock.pending.push(newsock);
              Module['websocket'].emit('connection', newsock.stream.fd);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
              Module['websocket'].emit('connection', sock.stream.fd);
            }
          });
          sock.server.on('closed', function() {
            Module['websocket'].emit('close', sock.stream.fd);
            sock.server = null;
          });
          sock.server.on('error', function(error) {
            // Although the ws library may pass errors that may be more descriptive than
            // ECONNREFUSED they are not necessarily the expected error code e.g. 
            // ENOTFOUND on getaddrinfo seems to be node.js specific, so using EHOSTUNREACH
            // is still probably the most useful thing to do. This error shouldn't
            // occur in a well written app as errors should get trapped in the compiled
            // app's own getaddrinfo call.
            sock.error = ERRNO_CODES.EHOSTUNREACH; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
            Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'EHOSTUNREACH: Host is unreachable']);
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
  
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
  
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
  
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
  
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
  
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
  
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
  
  
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
  
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var fd = _fileno(stream);
      var bytesWritten = _write(fd, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return (bytesWritten / size)|0;
      }
    }
  
  
   
  Module["_strlen"] = _strlen;
  
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      assert((varargs & 3) === 0);
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        argIndex = Runtime.prepVararg(argIndex, type);
        if (type === 'double') {
          ret = (HEAP32[((tempDoublePtr)>>2)]=HEAP32[(((varargs)+(argIndex))>>2)],HEAP32[(((tempDoublePtr)+(4))>>2)]=HEAP32[(((varargs)+((argIndex)+(4)))>>2)],(+(HEAPF64[(tempDoublePtr)>>3])));
          argIndex += 8;
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+4))>>2)]];
  
          argIndex += 8;
        } else {
          assert((argIndex & 3) === 0);
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += 4;
        }
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[((textIndex)>>0)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)>>0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          var flagPadSign = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              case 32:
                flagPadSign = true;
                break;
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          }
  
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)>>0)];
            }
          }
  
          // Handle precision.
          var precisionSet = false, precision = -1;
          if (next == 46) {
            precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)>>0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)>>0)];
          }
          if (precision < 0) {
            precision = 6; // Standard default.
            precisionSet = false;
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)>>0)];
  
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
  
              // Add sign if needed
              if (currArg >= 0) {
                if (flagAlwaysSigned) {
                  prefix = '+' + prefix;
                } else if (flagPadSign) {
                  prefix = ' ' + prefix;
                }
              }
  
              // Move sign to prefix so we zero-pad after the sign
              if (argText.charAt(0) == '-') {
                prefix = '-' + prefix;
                argText = argText.substr(1);
              }
  
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
  
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
  
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
  
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
  
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
  
                // Add sign.
                if (currArg >= 0) {
                  if (flagAlwaysSigned) {
                    argText = '+' + argText;
                  } else if (flagPadSign) {
                    argText = ' ' + argText;
                  }
                }
              }
  
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
  
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
  
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)>>0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length;
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[((i)>>0)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }

  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }

  var _emscripten_prep_setjmp=true;


  
  function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 512;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 1024;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var fd = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return fd === -1 ? 0 : FS.getPtrForStream(FS.getStream(fd));
    }

  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      stream = FS.getStreamFromPtr(stream);
      return Number(stream && stream.eof);
    }

  var _emscripten_check_longjmp=true;

   
  Module["_i64Add"] = _i64Add;

  var _emscripten_postinvoke=true;

  var _floor=Math_floor;


  
  
  
  
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)>>0)]=streamObj.ungotten.pop();
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(streamObj.fd, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return (bytesRead / size)|0;
    }function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)>>0)];
      }
    }function _getc() {
  return _fgetc.apply(null, arguments)
  }

  
  
  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 
  Module["_memcpy"] = _memcpy;function _realloc(ptr, size) {
      // Very simple, inefficient implementation - if you use a real malloc, best to use
      // a real realloc with it
      if (!size) {
        if (ptr) _free(ptr);
        return 0;
      }
      var ret = _malloc(size);
      if (ptr) {
        _memcpy(ret, ptr, size); // might be some invalid reads
        _free(ptr);
      }
      return ret;
    } 
  Module["_saveSetjmp"] = _saveSetjmp;

  
  
  function _emscripten_set_main_loop_timing(mode, value) {
      Browser.mainLoop.timingMode = mode;
      Browser.mainLoop.timingValue = value;
  
      if (!Browser.mainLoop.func) {
        console.error('emscripten_set_main_loop_timing: Cannot set timing mode for main loop since a main loop does not exist! Call emscripten_set_main_loop first to set one up.');
        return 1; // Return non-zero on failure, can't set timing mode when there is no main loop.
      }
  
      if (mode == 0 /*EM_TIMING_SETTIMEOUT*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          setTimeout(Browser.mainLoop.runner, value); // doing this each time means that on exception, we stop
        };
        Browser.mainLoop.method = 'timeout';
      } else if (mode == 1 /*EM_TIMING_RAF*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'rAF';
      }
      return 0;
    }function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg, noSetTiming) {
      Module['noExitRuntime'] = true;
  
      assert(!Browser.mainLoop.func, 'emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters.');
  
      Browser.mainLoop.func = func;
      Browser.mainLoop.arg = arg;
  
      var thisMainLoopId = Browser.mainLoop.currentlyRunningMainloop;
  
      Browser.mainLoop.runner = function Browser_mainLoop_runner() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
  
        // catch pauses from non-main loop sources
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Implement very basic swap interval control
        Browser.mainLoop.currentFrameNumber = Browser.mainLoop.currentFrameNumber + 1 | 0;
        if (Browser.mainLoop.timingMode == 1/*EM_TIMING_RAF*/ && Browser.mainLoop.timingValue > 1 && Browser.mainLoop.currentFrameNumber % Browser.mainLoop.timingValue != 0) {
          // Not the scheduled time to render this frame - skip.
          Browser.mainLoop.scheduler();
          return;
        }
  
        // Signal GL rendering layer that processing of a new frame is about to start. This helps it optimize
        // VBO double-buffering and reduce GPU stalls.
  
        if (Browser.mainLoop.method === 'timeout' && Module.ctx) {
          Module.printErr('Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!');
          Browser.mainLoop.method = ''; // just warn once per call to set main loop
        }
  
        Browser.mainLoop.runIter(function() {
          if (typeof arg !== 'undefined') {
            Runtime.dynCall('vi', func, [arg]);
          } else {
            Runtime.dynCall('v', func);
          }
        });
  
        // catch pauses from the main loop itself
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Queue new audio data. This is important to be right after the main loop invocation, so that we will immediately be able
        // to queue the newest produced audio samples.
        // TODO: Consider adding pre- and post- rAF callbacks so that GL.newRenderingFrameStarted() and SDL.audio.queueNewAudioData()
        //       do not need to be hardcoded into this function, but can be more generic.
        if (typeof SDL === 'object' && SDL.audio && SDL.audio.queueNewAudioData) SDL.audio.queueNewAudioData();
  
        Browser.mainLoop.scheduler();
      }
  
      if (!noSetTiming) {
        if (fps && fps > 0) _emscripten_set_main_loop_timing(0/*EM_TIMING_SETTIMEOUT*/, 1000.0 / fps);
        else _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, 1); // Do rAF by rendering each frame (no decimating)
  
        Browser.mainLoop.scheduler();
      }
  
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }var Browser={mainLoop:{scheduler:null,method:"",currentlyRunningMainloop:0,func:null,arg:0,timingMode:0,timingValue:0,currentFrameNumber:0,queue:[],pause:function () {
          Browser.mainLoop.scheduler = null;
          Browser.mainLoop.currentlyRunningMainloop++; // Incrementing this signals the previous main loop that it's now become old, and it must return.
        },resume:function () {
          Browser.mainLoop.currentlyRunningMainloop++;
          var timingMode = Browser.mainLoop.timingMode;
          var timingValue = Browser.mainLoop.timingValue;
          var func = Browser.mainLoop.func;
          Browser.mainLoop.func = null;
          _emscripten_set_main_loop(func, 0, false, Browser.mainLoop.arg, true /* do not set timing and call scheduler, we will do it on the next lines */);
          _emscripten_set_main_loop_timing(timingMode, timingValue);
          Browser.mainLoop.scheduler();
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        },runIter:function (func) {
          if (ABORT) return;
          if (Module['preMainLoop']) {
            var preRet = Module['preMainLoop']();
            if (preRet === false) {
              return; // |return false| skips a frame
            }
          }
          try {
            func();
          } catch (e) {
            if (e instanceof ExitStatus) {
              return;
            } else {
              if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
              throw e;
            }
          }
          if (Module['postMainLoop']) Module['postMainLoop']();
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
  
        if (Browser.initted) return;
        Browser.initted = true;
  
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          assert(typeof url == 'string', 'createObjectURL must return a url as a string');
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            assert(typeof url == 'string', 'createObjectURL must return a url as a string');
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
  
        // Canvas event setup
  
        var canvas = Module['canvas'];
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas ||
                                document['msPointerLockElement'] === canvas;
        }
        if (canvas) {
          // forced aspect ratio can be enabled by defining 'forcedAspectRatio' on Module
          // Module['forcedAspectRatio'] = 4 / 3;
          
          canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                      canvas['mozRequestPointerLock'] ||
                                      canvas['webkitRequestPointerLock'] ||
                                      canvas['msRequestPointerLock'] ||
                                      function(){};
          canvas.exitPointerLock = document['exitPointerLock'] ||
                                   document['mozExitPointerLock'] ||
                                   document['webkitExitPointerLock'] ||
                                   document['msExitPointerLock'] ||
                                   function(){}; // no-op if function does not exist
          canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
  
  
          document.addEventListener('pointerlockchange', pointerLockChange, false);
          document.addEventListener('mozpointerlockchange', pointerLockChange, false);
          document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
          document.addEventListener('mspointerlockchange', pointerLockChange, false);
  
          if (Module['elementPointerLock']) {
            canvas.addEventListener("click", function(ev) {
              if (!Browser.pointerLock && canvas.requestPointerLock) {
                canvas.requestPointerLock();
                ev.preventDefault();
              }
            }, false);
          }
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        if (useWebGL && Module.ctx && canvas == Module.canvas) return Module.ctx; // no need to recreate GL context if it's already been created for this canvas.
  
        var ctx;
        var contextHandle;
        if (useWebGL) {
          // For GLES2/desktop GL compatibility, adjust a few defaults to be different to WebGL defaults, so that they align better with the desktop defaults.
          var contextAttributes = {
            antialias: false,
            alpha: false
          };
  
          if (webGLContextAttributes) {
            for (var attribute in webGLContextAttributes) {
              contextAttributes[attribute] = webGLContextAttributes[attribute];
            }
          }
  
          contextHandle = GL.createContext(canvas, contextAttributes);
          if (contextHandle) {
            ctx = GL.getContext(contextHandle).GLctx;
          }
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
        } else {
          ctx = canvas.getContext('2d');
        }
  
        if (!ctx) return null;
  
        if (setInModule) {
          if (!useWebGL) assert(typeof GLctx === 'undefined', 'cannot set in module if GLctx is used, but we are a non-GL context that would replace it');
  
          Module.ctx = ctx;
          if (useWebGL) GL.makeContextCurrent(contextHandle);
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas, vrDevice) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        Browser.vrDevice = vrDevice;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        if (typeof Browser.vrDevice === 'undefined') Browser.vrDevice = null;
  
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          var canvasContainer = canvas.parentNode;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement'] ||
               document['msFullScreenElement'] || document['msFullscreenElement'] ||
               document['webkitCurrentFullScreenElement']) === canvasContainer) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'] ||
                                      document['msExitFullscreen'] ||
                                      document['exitFullscreen'] ||
                                      function() {};
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else {
            
            // remove the full screen specific parent of the canvas again to restore the HTML structure from before going full screen
            canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
            canvasContainer.parentNode.removeChild(canvasContainer);
            
            if (Browser.resizeCanvas) Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
          Browser.updateCanvasDimensions(canvas);
        }
  
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
          document.addEventListener('MSFullscreenChange', fullScreenChange, false);
        }
  
        // create a new parent to ensure the canvas has no siblings. this allows browsers to optimize full screen performance when its parent is the full screen root
        var canvasContainer = document.createElement("div");
        canvas.parentNode.insertBefore(canvasContainer, canvas);
        canvasContainer.appendChild(canvas);
  
        // use parent of canvas as full screen root to allow aspect ratio correction (Firefox stretches the root to screen size)
        canvasContainer.requestFullScreen = canvasContainer['requestFullScreen'] ||
                                            canvasContainer['mozRequestFullScreen'] ||
                                            canvasContainer['msRequestFullscreen'] ||
                                           (canvasContainer['webkitRequestFullScreen'] ? function() { canvasContainer['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
  
        if (vrDevice) {
          canvasContainer.requestFullScreen({ vrDisplay: vrDevice });
        } else {
          canvasContainer.requestFullScreen();
        }
      },nextRAF:0,fakeRequestAnimationFrame:function (func) {
        // try to keep 60fps between calls to here
        var now = Date.now();
        if (Browser.nextRAF === 0) {
          Browser.nextRAF = now + 1000/60;
        } else {
          while (now + 2 >= Browser.nextRAF) { // fudge a little, to avoid timer jitter causing us to do lots of delay:0
            Browser.nextRAF += 1000/60;
          }
        }
        var delay = Math.max(Browser.nextRAF - now, 0);
        setTimeout(func, delay);
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          Browser.fakeRequestAnimationFrame(func);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           Browser.fakeRequestAnimationFrame;
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },allowAsyncCallbacks:true,queuedAsyncCallbacks:[],pauseAsyncCallbacks:function () {
        Browser.allowAsyncCallbacks = false;
      },resumeAsyncCallbacks:function () { // marks future callbacks as ok to execute, and synchronously runs any remaining ones right now
        Browser.allowAsyncCallbacks = true;
        if (Browser.queuedAsyncCallbacks.length > 0) {
          var callbacks = Browser.queuedAsyncCallbacks;
          Browser.queuedAsyncCallbacks = [];
          callbacks.forEach(function(func) {
            func();
          });
        }
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } else {
            Browser.queuedAsyncCallbacks.push(func);
          }
        });
      },safeSetTimeout:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setTimeout(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } else {
            Browser.queuedAsyncCallbacks.push(func);
          }
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setInterval(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } // drop it on the floor otherwise, next interval will kick in
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        var delta = 0;
        switch (event.type) {
          case 'DOMMouseScroll': 
            delta = event.detail;
            break;
          case 'mousewheel': 
            delta = event.wheelDelta;
            break;
          case 'wheel': 
            delta = event['deltaY'];
            break;
          default:
            throw 'unrecognized mouse wheel event: ' + event.type;
        }
        return delta;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
  
          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);
          // If this assert lands, it's likely because the browser doesn't support scrollX or pageXOffset
          // and we have no viable fallback.
          assert((typeof scrollX !== 'undefined') && (typeof scrollY !== 'undefined'), 'Unable to retrieve scroll position, mouse positions likely broken.');
  
          if (event.type === 'touchstart' || event.type === 'touchend' || event.type === 'touchmove') {
            var touch = event.touch;
            if (touch === undefined) {
              return; // the "touch" property is only defined in SDL
  
            }
            var adjustedX = touch.pageX - (scrollX + rect.left);
            var adjustedY = touch.pageY - (scrollY + rect.top);
  
            adjustedX = adjustedX * (cw / rect.width);
            adjustedY = adjustedY * (ch / rect.height);
  
            var coords = { x: adjustedX, y: adjustedY };
            
            if (event.type === 'touchstart') {
              Browser.lastTouches[touch.identifier] = coords;
              Browser.touches[touch.identifier] = coords;
            } else if (event.type === 'touchend' || event.type === 'touchmove') {
              var last = Browser.touches[touch.identifier];
              if (!last) last = coords;
              Browser.lastTouches[touch.identifier] = last;
              Browser.touches[touch.identifier] = coords;
            } 
            return;
          }
  
          var x = event.pageX - (scrollX + rect.left);
          var y = event.pageY - (scrollY + rect.top);
  
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
  
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function xhr_onload() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        Browser.updateCanvasDimensions(canvas, width, height);
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },updateCanvasDimensions:function (canvas, wNative, hNative) {
        if (wNative && hNative) {
          canvas.widthNative = wNative;
          canvas.heightNative = hNative;
        } else {
          wNative = canvas.widthNative;
          hNative = canvas.heightNative;
        }
        var w = wNative;
        var h = hNative;
        if (Module['forcedAspectRatio'] && Module['forcedAspectRatio'] > 0) {
          if (w/h < Module['forcedAspectRatio']) {
            w = Math.round(h * Module['forcedAspectRatio']);
          } else {
            h = Math.round(w / Module['forcedAspectRatio']);
          }
        }
        if (((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
             document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
             document['fullScreenElement'] || document['fullscreenElement'] ||
             document['msFullScreenElement'] || document['msFullscreenElement'] ||
             document['webkitCurrentFullScreenElement']) === canvas.parentNode) && (typeof screen != 'undefined')) {
           var factor = Math.min(screen.width / w, screen.height / h);
           w = Math.round(w * factor);
           h = Math.round(h * factor);
        }
        if (Browser.resizeCanvas) {
          if (canvas.width  != w) canvas.width  = w;
          if (canvas.height != h) canvas.height = h;
          if (typeof canvas.style != 'undefined') {
            canvas.style.removeProperty( "width");
            canvas.style.removeProperty("height");
          }
        } else {
          if (canvas.width  != wNative) canvas.width  = wNative;
          if (canvas.height != hNative) canvas.height = hNative;
          if (typeof canvas.style != 'undefined') {
            if (w != wNative || h != hNative) {
              canvas.style.setProperty( "width", w + "px", "important");
              canvas.style.setProperty("height", h + "px", "important");
            } else {
              canvas.style.removeProperty( "width");
              canvas.style.removeProperty("height");
            }
          }
        }
      },wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle:function () {
        var handle = Browser.nextWgetRequestHandle;
        Browser.nextWgetRequestHandle++;
        return handle;
      }};

  var _emscripten_get_longjmp_result=true;

  function _time(ptr) {
      var ret = (Date.now()/1000)|0;
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }

   
  Module["_bitshift64Lshr"] = _bitshift64Lshr;


  
   
  Module["_testSetjmp"] = _testSetjmp;function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }

  var _BDtoILow=true;

  function _ferror(stream) {
      // int ferror(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ferror.html
      stream = FS.getStreamFromPtr(stream);
      return Number(stream && stream.error);
    }

  var _BDtoIHigh=true;

  function _emscripten_longjmp(env, value) {
      _longjmp(env, value);
    }


  var _llvm_pow_f64=Math_pow;

  var _emscripten_setjmp=true;

  
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)>>0)]=chr;
      var fd = _fileno(stream);
      var ret = _write(fd, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    }

  
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      var fd = _fileno(stream);
      return _write(fd, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }

  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) {
        var success = self.alloc(bytes);
        if (!success) return -1 >>> 0; // sbrk failure code
      }
      return ret;  // Previous break location.
    }

  var _fabs=Math_abs;

  function _localeconv() {
      // %struct.timeval = type { char* decimal point, other stuff... }
      // var indexes = Runtime.calculateStructAlignment({ fields: ['i32', 'i32'] });
      var me = _localeconv;
      if (!me.ret) {
      // These are defaults from the "C" locale
        me.ret = allocate([
          allocate(intArrayFromString('.'), 'i8', ALLOC_NORMAL),0,0,0, // decimal_point
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // thousands_sep
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // grouping
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // int_curr_symbol
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // currency_symbol
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // mon_decimal_point
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // mon_thousands_sep
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // mon_grouping
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // positive_sign
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0 // negative_sign
        ], 'i8*', ALLOC_NORMAL); // Allocate strings in lconv, still don't allocate chars
      }
      return me.ret;
    }

  var _emscripten_preinvoke=true;

  var _BItoD=true;

  function _freopen(filename, mode, stream) {
      // FILE *freopen(const char *restrict filename, const char *restrict mode, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/freopen.html
      if (!filename) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (!streamObj) {
          ___setErrNo(ERRNO_CODES.EBADF);
          return 0;
        }
        if (_freopen.buffer) _free(_freopen.buffer);
        filename = intArrayFromString(streamObj.path);
        filename = allocate(filename, 'i8', ALLOC_NORMAL);
      }
      _fclose(stream);
      return _fopen(filename, mode);
    }




___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
FS.staticInit();__ATINIT__.unshift(function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() });__ATMAIN__.push(function() { FS.ignorePermissions = false });__ATEXIT__.push(function() { FS.quit() });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
__ATINIT__.unshift(function() { TTY.init() });__ATEXIT__.push(function() { TTY.shutdown() });
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); var NODEJS_PATH = require("path"); NODEFS.staticInit(); }
__ATINIT__.push(function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); });
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas, vrDevice) { Browser.requestFullScreen(lockPointer, resizeCanvas, vrDevice) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
  Module["createContext"] = function Module_createContext(canvas, useWebGL, setInModule, webGLContextAttributes) { return Browser.createContext(canvas, useWebGL, setInModule, webGLContextAttributes) }
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

staticSealed = true; // seal the static portion of memory

STACK_MAX = STACK_BASE + TOTAL_STACK;

DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");

 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);


function nullFunc_ii(x) { Module["printErr"]("Invalid function pointer called with signature 'ii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vii(x) { Module["printErr"]("Invalid function pointer called with signature 'vii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iii(x) { Module["printErr"]("Invalid function pointer called with signature 'iii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

Module.asmGlobalArg = { "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array, "NaN": NaN, "Infinity": Infinity };
Module.asmLibraryArg = { "abort": abort, "assert": assert, "nullFunc_ii": nullFunc_ii, "nullFunc_iiii": nullFunc_iiii, "nullFunc_vii": nullFunc_vii, "nullFunc_iii": nullFunc_iii, "nullFunc_iiiii": nullFunc_iiiii, "invoke_ii": invoke_ii, "invoke_iiii": invoke_iiii, "invoke_vii": invoke_vii, "invoke_iii": invoke_iii, "invoke_iiiii": invoke_iiiii, "_fabs": _fabs, "_freopen": _freopen, "_llvm_pow_f64": _llvm_pow_f64, "_send": _send, "_fread": _fread, "__reallyNegative": __reallyNegative, "_emscripten_set_main_loop_timing": _emscripten_set_main_loop_timing, "_write": _write, "_floor": _floor, "_longjmp": _longjmp, "_fflush": _fflush, "_pwrite": _pwrite, "_strerror_r": _strerror_r, "_open": _open, "_sbrk": _sbrk, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_fileno": _fileno, "_sysconf": _sysconf, "_close": _close, "_ferror": _ferror, "_putchar": _putchar, "_pread": _pread, "_localeconv": _localeconv, "_mkport": _mkport, "_fclose": _fclose, "_getc": _getc, "_feof": _feof, "_emscripten_set_main_loop": _emscripten_set_main_loop, "___errno_location": ___errno_location, "_puts": _puts, "_recv": _recv, "_fgetc": _fgetc, "_printf": _printf, "__exit": __exit, "_read": _read, "_fputc": _fputc, "_abort": _abort, "_fwrite": _fwrite, "_time": _time, "_fprintf": _fprintf, "_strerror": _strerror, "_emscripten_longjmp": _emscripten_longjmp, "__formatString": __formatString, "_fputs": _fputs, "_fopen": _fopen, "_exit": _exit, "___setErrNo": ___setErrNo, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "_stderr": _stderr, "_stdin": _stdin, "_stdout": _stdout };
// EMSCRIPTEN_START_ASM
var asm = (function(global, env, buffer) {
  'almost asm';
  
  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);


  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var cttz_i8=env.cttz_i8|0;
  var _stderr=env._stderr|0;
  var _stdin=env._stdin|0;
  var _stdout=env._stdout|0;

  var __THREW__ = 0;
  var threwValue = 0;
  var setjmpId = 0;
  var undef = 0;
  var nan = global.NaN, inf = global.Infinity;
  var tempInt = 0, tempBigInt = 0, tempBigIntP = 0, tempBigIntS = 0, tempBigIntR = 0.0, tempBigIntI = 0, tempBigIntD = 0, tempValue = 0, tempDouble = 0.0;

  var tempRet0 = 0;
  var tempRet1 = 0;
  var tempRet2 = 0;
  var tempRet3 = 0;
  var tempRet4 = 0;
  var tempRet5 = 0;
  var tempRet6 = 0;
  var tempRet7 = 0;
  var tempRet8 = 0;
  var tempRet9 = 0;
  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var Math_min=global.Math.min;
  var Math_clz32=global.Math.clz32;
  var abort=env.abort;
  var assert=env.assert;
  var nullFunc_ii=env.nullFunc_ii;
  var nullFunc_iiii=env.nullFunc_iiii;
  var nullFunc_vii=env.nullFunc_vii;
  var nullFunc_iii=env.nullFunc_iii;
  var nullFunc_iiiii=env.nullFunc_iiiii;
  var invoke_ii=env.invoke_ii;
  var invoke_iiii=env.invoke_iiii;
  var invoke_vii=env.invoke_vii;
  var invoke_iii=env.invoke_iii;
  var invoke_iiiii=env.invoke_iiiii;
  var _fabs=env._fabs;
  var _freopen=env._freopen;
  var _llvm_pow_f64=env._llvm_pow_f64;
  var _send=env._send;
  var _fread=env._fread;
  var __reallyNegative=env.__reallyNegative;
  var _emscripten_set_main_loop_timing=env._emscripten_set_main_loop_timing;
  var _write=env._write;
  var _floor=env._floor;
  var _longjmp=env._longjmp;
  var _fflush=env._fflush;
  var _pwrite=env._pwrite;
  var _strerror_r=env._strerror_r;
  var _open=env._open;
  var _sbrk=env._sbrk;
  var _emscripten_memcpy_big=env._emscripten_memcpy_big;
  var _fileno=env._fileno;
  var _sysconf=env._sysconf;
  var _close=env._close;
  var _ferror=env._ferror;
  var _putchar=env._putchar;
  var _pread=env._pread;
  var _localeconv=env._localeconv;
  var _mkport=env._mkport;
  var _fclose=env._fclose;
  var _getc=env._getc;
  var _feof=env._feof;
  var _emscripten_set_main_loop=env._emscripten_set_main_loop;
  var ___errno_location=env.___errno_location;
  var _puts=env._puts;
  var _recv=env._recv;
  var _fgetc=env._fgetc;
  var _printf=env._printf;
  var __exit=env.__exit;
  var _read=env._read;
  var _fputc=env._fputc;
  var _abort=env._abort;
  var _fwrite=env._fwrite;
  var _time=env._time;
  var _fprintf=env._fprintf;
  var _strerror=env._strerror;
  var _emscripten_longjmp=env._emscripten_longjmp;
  var __formatString=env.__formatString;
  var _fputs=env._fputs;
  var _fopen=env._fopen;
  var _exit=env._exit;
  var ___setErrNo=env.___setErrNo;
  var tempFloat = 0.0;

// EMSCRIPTEN_START_FUNCS
function stackAlloc(size) {
  size = size|0;
  var ret = 0;
  ret = STACKTOP;
  STACKTOP = (STACKTOP + size)|0;
  STACKTOP = (STACKTOP + 15)&-16;
if ((STACKTOP|0) >= (STACK_MAX|0)) abort();

  return ret|0;
}
function stackSave() {
  return STACKTOP|0;
}
function stackRestore(top) {
  top = top|0;
  STACKTOP = top;
}
function establishStackSpace(stackBase, stackMax) {
  stackBase = stackBase|0;
  stackMax = stackMax|0;
  STACKTOP = stackBase;
  STACK_MAX = stackMax;
}

function setThrew(threw, value) {
  threw = threw|0;
  value = value|0;
  if ((__THREW__|0) == 0) {
    __THREW__ = threw;
    threwValue = value;
  }
}
function copyTempFloat(ptr) {
  ptr = ptr|0;
  HEAP8[tempDoublePtr>>0] = HEAP8[ptr>>0];
  HEAP8[tempDoublePtr+1>>0] = HEAP8[ptr+1>>0];
  HEAP8[tempDoublePtr+2>>0] = HEAP8[ptr+2>>0];
  HEAP8[tempDoublePtr+3>>0] = HEAP8[ptr+3>>0];
}
function copyTempDouble(ptr) {
  ptr = ptr|0;
  HEAP8[tempDoublePtr>>0] = HEAP8[ptr>>0];
  HEAP8[tempDoublePtr+1>>0] = HEAP8[ptr+1>>0];
  HEAP8[tempDoublePtr+2>>0] = HEAP8[ptr+2>>0];
  HEAP8[tempDoublePtr+3>>0] = HEAP8[ptr+3>>0];
  HEAP8[tempDoublePtr+4>>0] = HEAP8[ptr+4>>0];
  HEAP8[tempDoublePtr+5>>0] = HEAP8[ptr+5>>0];
  HEAP8[tempDoublePtr+6>>0] = HEAP8[ptr+6>>0];
  HEAP8[tempDoublePtr+7>>0] = HEAP8[ptr+7>>0];
}

function setTempRet0(value) {
  value = value|0;
  tempRet0 = value;
}
function getTempRet0() {
  return tempRet0|0;
}

function _main($argc,$argv) {
 $argc = $argc|0;
 $argv = $argv|0;
 var $$lcssa53 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$010$i = 0, $i$010$i$lcssa49 = 0, $i$1$i = 0, $i$2$i = 0, $i$3$i = 0, $or$cond$i = 0, $version$0$$i = 0, $version$011$i = 0, $version$011$i$lcssa46 = 0, $version$1$i = 0, $version$2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$argv>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP8[$0>>0]|0;
  $3 = ($2<<24>>24)==(0);
  if (!($3)) {
   HEAP32[8>>2] = $0;
  }
 }
 $4 = ($argc|0)>(1);
 L5: do {
  if ($4) {
   $i$010$i = 1;$version$011$i = 0;
   L6: while(1) {
    $5 = (($argv) + ($i$010$i<<2)|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = HEAP8[$6>>0]|0;
    $8 = ($7<<24>>24)==(45);
    if (!($8)) {
     $i$2$i = $i$010$i;$version$2$i = $version$011$i;
     break L5;
    }
    $9 = (_strcmp($6,16)|0);
    $10 = ($9|0)==(0);
    if ($10) {
     $i$010$i$lcssa49 = $i$010$i;$version$011$i$lcssa46 = $version$011$i;
     label = 7;
     break;
    }
    $14 = (_strcmp($6,24)|0);
    $15 = ($14|0)==(0);
    if ($15) {
     $i$2$i = $i$010$i;$version$2$i = $version$011$i;
     break L5;
    }
    $16 = (_strcmp($6,32)|0);
    $17 = ($16|0)==(0);
    do {
     if ($17) {
      $18 = HEAP32[40>>2]|0;
      $19 = (($18) + 1)|0;
      HEAP32[40>>2] = $19;
      $i$1$i = $i$010$i;$version$1$i = $version$011$i;
     } else {
      $20 = (_strcmp($6,48)|0);
      $21 = ($20|0)==(0);
      if ($21) {
       $22 = (($i$010$i) + 1)|0;
       $23 = (($argv) + ($22<<2)|0);
       $24 = HEAP32[$23>>2]|0;
       HEAP32[56>>2] = $24;
       $25 = ($24|0)==(0|0);
       if ($25) {
        label = 15;
        break L6;
       }
       $26 = HEAP8[$24>>0]|0;
       if ((($26<<24>>24) == 45)) {
        $27 = ((($24)) + 1|0);
        $28 = HEAP8[$27>>0]|0;
        $29 = ($28<<24>>24)==(0);
        if (!($29)) {
         label = 15;
         break L6;
        }
       } else if ((($26<<24>>24) == 0)) {
        label = 15;
        break L6;
       }
       $30 = HEAP32[$23>>2]|0;
       $31 = (_strcmp($30,24)|0);
       $32 = ($31|0)==(0);
       if (!($32)) {
        $i$1$i = $22;$version$1$i = $version$011$i;
        break;
       }
       HEAP32[56>>2] = 0;
       $i$1$i = $22;$version$1$i = $version$011$i;
       break;
      }
      $33 = (_strcmp($6,88)|0);
      $34 = ($33|0)==(0);
      if ($34) {
       HEAP32[96>>2] = 0;
       $i$1$i = $i$010$i;$version$1$i = $version$011$i;
       break;
      }
      $35 = (_strcmp($6,104)|0);
      $36 = ($35|0)==(0);
      if ($36) {
       HEAP32[112>>2] = 1;
       $i$1$i = $i$010$i;$version$1$i = $version$011$i;
       break;
      }
      $37 = (_strcmp($6,120)|0);
      $38 = ($37|0)==(0);
      if (!($38)) {
       $$lcssa53 = $6;
       label = 24;
       break L6;
      }
      $39 = (($version$011$i) + 1)|0;
      $i$1$i = $i$010$i;$version$1$i = $39;
     }
    } while(0);
    $40 = (($i$1$i) + 1)|0;
    $41 = ($40|0)<($argc|0);
    if ($41) {
     $i$010$i = $40;$version$011$i = $version$1$i;
    } else {
     $i$2$i = $40;$version$2$i = $version$1$i;
     break L5;
    }
   }
   if ((label|0) == 7) {
    $11 = (($i$010$i$lcssa49) + 1)|0;
    $12 = ($version$011$i$lcssa46|0)==(0);
    $13 = (($version$011$i$lcssa46) + 1)|0;
    $version$0$$i = $12 ? 0 : $13;
    $i$2$i = $11;$version$2$i = $version$0$$i;
    break;
   }
   else if ((label|0) == 15) {
    _usage(64);
    // unreachable;
   }
   else if ((label|0) == 24) {
    _usage($$lcssa53);
    // unreachable;
   }
  } else {
   $i$2$i = 1;$version$2$i = 0;
  }
 } while(0);
 $42 = ($i$2$i|0)==($argc|0);
 if ($42) {
  $43 = HEAP32[40>>2]|0;
  $44 = ($43|0)==(0);
  $45 = HEAP32[96>>2]|0;
  $46 = ($45|0)!=(0);
  $or$cond$i = $44 & $46;
  if ($or$cond$i) {
   $i$3$i = $argc;
  } else {
   HEAP32[96>>2] = 0;
   $47 = (($argc) + -1)|0;
   $48 = (($argv) + ($47<<2)|0);
   HEAP32[$48>>2] = 128;
   $i$3$i = $47;
  }
 } else {
  $i$3$i = $i$2$i;
 }
 $49 = ($version$2$i|0)==(0);
 if (!($49)) {
  (_puts((144|0))|0);
  $50 = (($argc) + -1)|0;
  $51 = ($version$2$i|0)==($50|0);
  if ($51) {
   _exit(0);
   // unreachable;
  }
 }
 $52 = (($argc) - ($i$3$i))|0;
 $53 = (($argv) + ($i$3$i<<2)|0);
 $54 = ($52|0)<(1);
 if ($54) {
  _usage(200);
  // unreachable;
 }
 $55 = (_luaL_newstate()|0);
 $56 = ($55|0)==(0|0);
 if ($56) {
  _fatal(224);
  // unreachable;
 }
 _lua_pushcclosure($55,2,0);
 $57 = ($52|0)<(0);
 $58 = $57 << 31 >> 31;
 _lua_pushinteger($55,$52,$58);
 _lua_pushlightuserdata($55,$53);
 $59 = (_lua_pcallk($55,2,0,0,0,0)|0);
 $60 = ($59|0)==(0);
 if ($60) {
  _lua_close($55);
  return 0;
 } else {
  $61 = (_lua_tolstring($55,-1,0)|0);
  _fatal($61);
  // unreachable;
 }
 return (0)|0;
}
function _usage($message) {
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer6 = sp + 16|0;
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = HEAP8[$message>>0]|0;
 $1 = ($0<<24>>24)==(45);
 $2 = HEAP32[_stderr>>2]|0;
 $3 = HEAP32[8>>2]|0;
 if ($1) {
  HEAP32[$vararg_buffer>>2] = $3;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $message;
  (_fprintf(($2|0),(880|0),($vararg_buffer|0))|0);
 } else {
  HEAP32[$vararg_buffer2>>2] = $3;
  $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
  HEAP32[$vararg_ptr5>>2] = $message;
  (_fprintf(($2|0),(872|0),($vararg_buffer2|0))|0);
 }
 $4 = HEAP32[8>>2]|0;
 HEAP32[$vararg_buffer6>>2] = $4;
 $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
 HEAP32[$vararg_ptr9>>2] = 128;
 (_fprintf(($2|0),(912|0),($vararg_buffer6|0))|0);
 _exit(1);
 // unreachable;
}
function _fatal($message) {
 $message = $message|0;
 var $0 = 0, $1 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[_stderr>>2]|0;
 $1 = HEAP32[8>>2]|0;
 HEAP32[$vararg_buffer>>2] = $1;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $message;
 (_fprintf(($0|0),(872|0),($vararg_buffer|0))|0);
 _exit(1);
 // unreachable;
}
function _pmain($L) {
 $L = $L|0;
 var $$ = 0, $$0$i = 0, $$pre$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $i$i = sp;
 $0 = (_lua_tointegerx($L,1,0)|0);
 $1 = tempRet0;
 $2 = (_lua_touserdata($L,2)|0);
 $3 = (_lua_checkstack($L,$0)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  _fatal(264);
  // unreachable;
 }
 $5 = ($0|0)>(0);
 if ($5) {
  $i$01 = 0;
  while(1) {
   $8 = (($2) + ($i$01<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (_strcmp($9,24)|0);
   $11 = ($10|0)==(0);
   $$ = $11 ? 0 : $9;
   $12 = (_luaL_loadfilex($L,$$,0)|0);
   $13 = ($12|0)==(0);
   $7 = (($i$01) + 1)|0;
   if (!($13)) {
    label = 7;
    break;
   }
   $6 = ($7|0)<($0|0);
   if ($6) {
    $i$01 = $7;
   } else {
    break;
   }
  }
  if ((label|0) == 7) {
   $14 = (_lua_tolstring($L,-1,0)|0);
   _fatal($14);
   // unreachable;
  }
  $15 = ($0|0)==(1);
  if ($15) {
   $16 = ((($L)) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($17)) + -16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($19)) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $$0$i = $21;$72 = $i$i;
  } else {
   $22 = $i$i;
   label = 10;
  }
 } else {
  $22 = $i$i;
  label = 10;
 }
 if ((label|0) == 10) {
  HEAP32[$i$i>>2] = $0;
  $23 = (_lua_load($L,3,$22,288,0)|0);
  $24 = ($23|0)==(0);
  if (!($24)) {
   $25 = (_lua_tolstring($L,-1,0)|0);
   _fatal($25);
   // unreachable;
  }
  $26 = ((($L)) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($27)) + -16|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ((($29)) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$i$i>>2] = 0;
  L18: do {
   if ($5) {
    $32 = $0 ^ -1;
    $33 = ((($31)) + 52|0);
    $$pre3$i = HEAP32[$33>>2]|0;
    $35 = 0;$37 = $27;$42 = $$pre3$i;
    while(1) {
     $34 = (($35) + ($32))|0;
     $36 = (($37) + ($34<<4)|0);
     $38 = HEAP32[$36>>2]|0;
     $39 = ((($38)) + 12|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($42) + ($35<<2)|0);
     HEAP32[$41>>2] = $40;
     $43 = HEAP32[$33>>2]|0;
     $44 = (($43) + ($35<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ((($45)) + 12|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)>(0);
     if ($48) {
      $49 = ((($45)) + 64|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ((($50)) + 4|0);
      HEAP8[$51>>0] = 0;
     }
     $52 = (($35) + 1)|0;
     HEAP32[$i$i>>2] = $52;
     $53 = ($52|0)<($0|0);
     if (!($53)) {
      break L18;
     }
     $$pre$i = HEAP32[$26>>2]|0;
     $35 = $52;$37 = $$pre$i;$42 = $43;
    }
   }
  } while(0);
  $54 = ((($31)) + 24|0);
  HEAP32[$54>>2] = 0;
  $$0$i = $31;$72 = $22;
 }
 $55 = HEAP32[40>>2]|0;
 $56 = ($55|0)==(0);
 if (!($56)) {
  $57 = ($55|0)>(1);
  $58 = $57&1;
  _PrintFunction($$0$i,$58);
 }
 $59 = HEAP32[96>>2]|0;
 $60 = ($59|0)==(0);
 if ($60) {
  STACKTOP = sp;return 0;
 }
 $61 = HEAP32[56>>2]|0;
 $62 = ($61|0)==(0|0);
 if ($62) {
  $63 = HEAP32[_stdout>>2]|0;
  $66 = $63;
 } else {
  $64 = (_fopen(($61|0),(296|0))|0);
  $66 = $64;
 }
 $65 = ($66|0)==(0|0);
 if ($65) {
  _cannot(4840);
  // unreachable;
 }
 $67 = HEAP32[112>>2]|0;
 (_luaU_dump($L,$$0$i,4,$66,$67)|0);
 $68 = (_ferror(($66|0))|0);
 $69 = ($68|0)==(0);
 if (!($69)) {
  _cannot(304);
  // unreachable;
 }
 $70 = (_fclose(($66|0))|0);
 $71 = ($70|0)==(0);
 if ($71) {
  STACKTOP = sp;return 0;
 } else {
  _cannot(312);
  // unreachable;
 }
 return (0)|0;
}
function _reader($L,$ud,$size) {
 $L = $L|0;
 $ud = $ud|0;
 $size = $size|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ud>>2]|0;
 $1 = (($0) + -1)|0;
 HEAP32[$ud>>2] = $1;
 $2 = ($0|0)==(0);
 $$ = $2 ? 0 : 18;
 $$1 = $2 ? 0 : 848;
 HEAP32[$size>>2] = $$;
 return ($$1|0);
}
function _PrintFunction($f,$full) {
 $f = $f|0;
 $full = $full|0;
 var $$not$i = 0, $$not7$i = 0, $$not8$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond10$i = 0, $exitcond11$i = 0, $f$idx$i = 0, $f$idx$val$i = 0, $f$idx$val$i1 = 0, $f$idx10$val$i = 0, $f$idx11$val$i = 0, $f$idx12$val$i = 0, $f$idx13$val$i = 0, $f$idx14$val$i = 0, $f$idx15$val$i = 0, $f$idx16$i = 0, $f$idx16$val$i = 0, $i$04 = 0, $i$06$i = 0;
 var $i$12$i = 0, $i$21$i = 0, $or$cond$i = 0, $pc$017$i = 0, $pc$1$i = 0, $s$0$i = 0, $vararg_buffer = 0, $vararg_buffer103 = 0, $vararg_buffer109 = 0, $vararg_buffer113 = 0, $vararg_buffer16 = 0, $vararg_buffer24 = 0, $vararg_buffer27 = 0, $vararg_buffer30 = 0, $vararg_buffer33 = 0, $vararg_buffer35 = 0, $vararg_buffer38 = 0, $vararg_buffer41 = 0, $vararg_buffer44 = 0, $vararg_buffer47 = 0;
 var $vararg_buffer50 = 0, $vararg_buffer53 = 0, $vararg_buffer56 = 0, $vararg_buffer60 = 0, $vararg_buffer63 = 0, $vararg_buffer65 = 0, $vararg_buffer68 = 0, $vararg_buffer7 = 0, $vararg_buffer71 = 0, $vararg_buffer74 = 0, $vararg_buffer76 = 0, $vararg_buffer78 = 0, $vararg_buffer81 = 0, $vararg_buffer84 = 0, $vararg_buffer87 = 0, $vararg_buffer90 = 0, $vararg_buffer92 = 0, $vararg_buffer96 = 0, $vararg_buffer99 = 0, $vararg_ptr1 = 0;
 var $vararg_ptr10 = 0, $vararg_ptr102 = 0, $vararg_ptr106 = 0, $vararg_ptr107 = 0, $vararg_ptr108 = 0, $vararg_ptr11 = 0, $vararg_ptr112 = 0, $vararg_ptr116 = 0, $vararg_ptr117 = 0, $vararg_ptr118 = 0, $vararg_ptr12 = 0, $vararg_ptr13 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr19 = 0, $vararg_ptr2 = 0, $vararg_ptr20 = 0, $vararg_ptr21 = 0, $vararg_ptr22 = 0, $vararg_ptr23 = 0;
 var $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr59 = 0, $vararg_ptr6 = 0, $vararg_ptr95 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer113 = sp + 328|0;
 $vararg_buffer109 = sp + 320|0;
 $vararg_buffer103 = sp + 304|0;
 $vararg_buffer99 = sp + 296|0;
 $vararg_buffer96 = sp + 288|0;
 $vararg_buffer92 = sp + 280|0;
 $vararg_buffer90 = sp + 272|0;
 $vararg_buffer87 = sp + 264|0;
 $vararg_buffer84 = sp + 256|0;
 $vararg_buffer81 = sp + 248|0;
 $vararg_buffer78 = sp + 240|0;
 $vararg_buffer76 = sp + 232|0;
 $vararg_buffer74 = sp + 224|0;
 $vararg_buffer71 = sp + 216|0;
 $vararg_buffer68 = sp + 208|0;
 $vararg_buffer65 = sp + 200|0;
 $vararg_buffer63 = sp + 192|0;
 $vararg_buffer60 = sp + 184|0;
 $vararg_buffer56 = sp + 176|0;
 $vararg_buffer53 = sp + 168|0;
 $vararg_buffer50 = sp + 160|0;
 $vararg_buffer47 = sp + 152|0;
 $vararg_buffer44 = sp + 144|0;
 $vararg_buffer41 = sp + 136|0;
 $vararg_buffer38 = sp + 128|0;
 $vararg_buffer35 = sp + 120|0;
 $vararg_buffer33 = sp + 112|0;
 $vararg_buffer30 = sp + 104|0;
 $vararg_buffer27 = sp + 96|0;
 $vararg_buffer24 = sp + 88|0;
 $vararg_buffer16 = sp + 64|0;
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer = sp;
 $0 = ((($f)) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($f)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = ((($3)) + 24|0);
 $6 = $4 ? 344 : $5;
 $7 = HEAP8[$6>>0]|0;
 if ((($7<<24>>24) == 61) | (($7<<24>>24) == 64)) {
  $8 = ((($6)) + 1|0);
  $s$0$i = $8;
 } else if ((($7<<24>>24) == 27)) {
  $s$0$i = 368;
 } else {
  $s$0$i = 352;
 }
 $9 = ((($f)) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 $12 = $11 ? 384 : 5952;
 $13 = ((($f)) + 40|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($f)) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(1);
 $18 = $17 ? 1272 : 392;
 HEAP32[$vararg_buffer>>2] = $12;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $s$0$i;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $10;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $14;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $16;
 $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
 HEAP32[$vararg_ptr5>>2] = $18;
 $vararg_ptr6 = ((($vararg_buffer)) + 24|0);
 HEAP32[$vararg_ptr6>>2] = $f;
 (_printf((400|0),($vararg_buffer|0))|0);
 $19 = ((($f)) + 6|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = ((($f)) + 7|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)!=(0);
 $25 = $24 ? 448 : 1272;
 $26 = ($20<<24>>24)==(1);
 $27 = $26 ? 1272 : 392;
 $28 = ((($f)) + 8|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = ($29<<24>>24)==(1);
 $32 = $31 ? 1272 : 392;
 $33 = ((($f)) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(1);
 $36 = $35 ? 1272 : 392;
 HEAP32[$vararg_buffer7>>2] = $21;
 $vararg_ptr10 = ((($vararg_buffer7)) + 4|0);
 HEAP32[$vararg_ptr10>>2] = $25;
 $vararg_ptr11 = ((($vararg_buffer7)) + 8|0);
 HEAP32[$vararg_ptr11>>2] = $27;
 $vararg_ptr12 = ((($vararg_buffer7)) + 12|0);
 HEAP32[$vararg_ptr12>>2] = $30;
 $vararg_ptr13 = ((($vararg_buffer7)) + 16|0);
 HEAP32[$vararg_ptr13>>2] = $32;
 $vararg_ptr14 = ((($vararg_buffer7)) + 20|0);
 HEAP32[$vararg_ptr14>>2] = $34;
 $vararg_ptr15 = ((($vararg_buffer7)) + 24|0);
 HEAP32[$vararg_ptr15>>2] = $36;
 (_printf((456|0),($vararg_buffer7|0))|0);
 $37 = ((($f)) + 32|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(1);
 $40 = $39 ? 1272 : 392;
 $41 = ((($f)) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(1);
 $44 = $43 ? 1272 : 392;
 $45 = HEAP32[$0>>2]|0;
 $46 = ($45|0)==(1);
 $47 = $46 ? 1272 : 392;
 HEAP32[$vararg_buffer16>>2] = $38;
 $vararg_ptr19 = ((($vararg_buffer16)) + 4|0);
 HEAP32[$vararg_ptr19>>2] = $40;
 $vararg_ptr20 = ((($vararg_buffer16)) + 8|0);
 HEAP32[$vararg_ptr20>>2] = $42;
 $vararg_ptr21 = ((($vararg_buffer16)) + 12|0);
 HEAP32[$vararg_ptr21>>2] = $44;
 $vararg_ptr22 = ((($vararg_buffer16)) + 16|0);
 HEAP32[$vararg_ptr22>>2] = $45;
 $vararg_ptr23 = ((($vararg_buffer16)) + 20|0);
 HEAP32[$vararg_ptr23>>2] = $47;
 (_printf((496|0),($vararg_buffer16|0))|0);
 $48 = ((($f)) + 48|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$15>>2]|0;
 $51 = ($50|0)>(0);
 L5: do {
  if ($51) {
   $52 = ((($f)) + 56|0);
   $f$idx16$i = ((($f)) + 44|0);
   $53 = ((($f)) + 64|0);
   $54 = ((($f)) + 52|0);
   $pc$017$i = 0;
   while(1) {
    $55 = (($49) + ($pc$017$i<<2)|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = $56 & 63;
    $58 = $56 >>> 6;
    $59 = $58 & 255;
    $60 = $56 >>> 23;
    $61 = $56 >>> 14;
    $62 = $61 & 511;
    $63 = (($61) + -131071)|0;
    $64 = HEAP32[$52>>2]|0;
    $65 = ($64|0)==(0|0);
    if ($65) {
     $66 = (($pc$017$i) + 1)|0;
     HEAP32[$vararg_buffer24>>2] = $66;
     (_printf((544|0),($vararg_buffer24|0))|0);
     $179 = $66;
     label = 10;
    } else {
     $67 = (($64) + ($pc$017$i<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($pc$017$i) + 1)|0;
     HEAP32[$vararg_buffer27>>2] = $69;
     (_printf((544|0),($vararg_buffer27|0))|0);
     $70 = ($68|0)>(0);
     if ($70) {
      HEAP32[$vararg_buffer30>>2] = $68;
      (_printf((552|0),($vararg_buffer30|0))|0);
      $135 = $69;
     } else {
      $179 = $69;
      label = 10;
     }
    }
    if ((label|0) == 10) {
     label = 0;
     (_printf((560|0),($vararg_buffer33|0))|0);
     $135 = $179;
    }
    $71 = (2168 + ($57<<2)|0);
    $72 = HEAP32[$71>>2]|0;
    HEAP32[$vararg_buffer35>>2] = $72;
    (_printf((568|0),($vararg_buffer35|0))|0);
    $73 = (2360 + ($57)|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = $75 & 3;
    do {
     if ((($76|0) == 0)) {
      HEAP32[$vararg_buffer38>>2] = $59;
      (_printf((576|0),($vararg_buffer38|0))|0);
      $77 = $74 & 48;
      $78 = ($77<<24>>24)==(0);
      if (!($78)) {
       $79 = $60 & 256;
       $80 = ($79|0)!=(0);
       $$not7$i = $60 | -256;
       $81 = $$not7$i ^ 255;
       $82 = $80 ? $81 : $60;
       HEAP32[$vararg_buffer41>>2] = $82;
       (_printf((584|0),($vararg_buffer41|0))|0);
      }
      $83 = $74 & 12;
      $84 = ($83<<24>>24)==(0);
      if (!($84)) {
       $85 = $61 & 256;
       $86 = ($85|0)!=(0);
       $$not$i = $61 | -256;
       $87 = $$not$i ^ 255;
       $88 = $86 ? $87 : $62;
       HEAP32[$vararg_buffer44>>2] = $88;
       (_printf((584|0),($vararg_buffer44|0))|0);
      }
     } else if ((($76|0) == 1)) {
      HEAP32[$vararg_buffer47>>2] = $59;
      (_printf((576|0),($vararg_buffer47|0))|0);
      $89 = $74 & 48;
      if ((($89<<24>>24) == 48)) {
       $90 = $61 ^ -1;
       HEAP32[$vararg_buffer50>>2] = $90;
       (_printf((584|0),($vararg_buffer50|0))|0);
       break;
      } else if ((($89<<24>>24) == 16)) {
       HEAP32[$vararg_buffer53>>2] = $61;
       (_printf((584|0),($vararg_buffer53|0))|0);
       break;
      } else {
       break;
      }
     } else if ((($76|0) == 2)) {
      HEAP32[$vararg_buffer56>>2] = $59;
      $vararg_ptr59 = ((($vararg_buffer56)) + 4|0);
      HEAP32[$vararg_ptr59>>2] = $63;
      (_printf((592|0),($vararg_buffer56|0))|0);
     } else if ((($76|0) == 3)) {
      $91 = $58 ^ -1;
      HEAP32[$vararg_buffer60>>2] = $91;
      (_printf((576|0),($vararg_buffer60|0))|0);
     }
    } while(0);
    L29: do {
     switch ($57|0) {
     case 1:  {
      (_printf((600|0),($vararg_buffer63|0))|0);
      $f$idx16$val$i = HEAP32[$f$idx16$i>>2]|0;
      _PrintConstant($f$idx16$val$i,$61);
      $pc$1$i = $pc$017$i;
      break;
     }
     case 9: case 5:  {
      $92 = HEAP32[$53>>2]|0;
      $93 = (($92) + ($60<<3)|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = ($94|0)==(0|0);
      $96 = ((($94)) + 24|0);
      $97 = $95 ? 24 : $96;
      HEAP32[$vararg_buffer65>>2] = $97;
      (_printf((608|0),($vararg_buffer65|0))|0);
      $pc$1$i = $pc$017$i;
      break;
     }
     case 6:  {
      $98 = HEAP32[$53>>2]|0;
      $99 = (($98) + ($60<<3)|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = ($100|0)==(0|0);
      $102 = ((($100)) + 24|0);
      $103 = $101 ? 24 : $102;
      HEAP32[$vararg_buffer68>>2] = $103;
      (_printf((608|0),($vararg_buffer68|0))|0);
      $104 = $61 & 256;
      $105 = ($104|0)==(0);
      if ($105) {
       $pc$1$i = $pc$017$i;
      } else {
       (_putchar(32)|0);
       $106 = $61 & 255;
       $f$idx15$val$i = HEAP32[$f$idx16$i>>2]|0;
       _PrintConstant($f$idx15$val$i,$106);
       $pc$1$i = $pc$017$i;
      }
      break;
     }
     case 12: case 7:  {
      $119 = $61 & 256;
      $120 = ($119|0)==(0);
      if ($120) {
       $pc$1$i = $pc$017$i;
      } else {
       (_printf((600|0),($vararg_buffer74|0))|0);
       $121 = $61 & 255;
       $f$idx12$val$i = HEAP32[$f$idx16$i>>2]|0;
       _PrintConstant($f$idx12$val$i,$121);
       $pc$1$i = $pc$017$i;
      }
      break;
     }
     case 33: case 32: case 31: case 24: case 23: case 22: case 21: case 20: case 19: case 18: case 17: case 15: case 14: case 13: case 10:  {
      $122 = $60 & 256;
      $123 = ($122|0)!=(0);
      $$not8$i = $123 ^ 1;
      $124 = $61 & 256;
      $125 = ($124|0)==(0);
      $or$cond$i = $125 & $$not8$i;
      if ($or$cond$i) {
       $pc$1$i = $pc$017$i;
      } else {
       (_printf((600|0),($vararg_buffer76|0))|0);
       if ($123) {
        $126 = $60 & 255;
        $f$idx11$val$i = HEAP32[$f$idx16$i>>2]|0;
        _PrintConstant($f$idx11$val$i,$126);
       } else {
        (_putchar(45)|0);
       }
       (_putchar(32)|0);
       if ($125) {
        (_putchar(45)|0);
        $pc$1$i = $pc$017$i;
        break L29;
       } else {
        $127 = $61 & 255;
        $f$idx10$val$i = HEAP32[$f$idx16$i>>2]|0;
        _PrintConstant($f$idx10$val$i,$127);
        $pc$1$i = $pc$017$i;
        break L29;
       }
      }
      break;
     }
     case 8:  {
      $107 = HEAP32[$53>>2]|0;
      $108 = (($107) + ($59<<3)|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = ($109|0)==(0|0);
      $111 = ((($109)) + 24|0);
      $112 = $110 ? 24 : $111;
      HEAP32[$vararg_buffer71>>2] = $112;
      (_printf((608|0),($vararg_buffer71|0))|0);
      $113 = $60 & 256;
      $114 = ($113|0)==(0);
      if (!($114)) {
       (_putchar(32)|0);
       $115 = $60 & 255;
       $f$idx14$val$i = HEAP32[$f$idx16$i>>2]|0;
       _PrintConstant($f$idx14$val$i,$115);
      }
      $116 = $61 & 256;
      $117 = ($116|0)==(0);
      if ($117) {
       $pc$1$i = $pc$017$i;
      } else {
       (_putchar(32)|0);
       $118 = $61 & 255;
       $f$idx13$val$i = HEAP32[$f$idx16$i>>2]|0;
       _PrintConstant($f$idx13$val$i,$118);
       $pc$1$i = $pc$017$i;
      }
      break;
     }
     case 42: case 40: case 39: case 30:  {
      $128 = (($pc$017$i) + 2)|0;
      $129 = (($128) + ($63))|0;
      HEAP32[$vararg_buffer78>>2] = $129;
      (_printf((616|0),($vararg_buffer78|0))|0);
      $pc$1$i = $pc$017$i;
      break;
     }
     case 44:  {
      $130 = HEAP32[$54>>2]|0;
      $131 = (($130) + ($61<<2)|0);
      $132 = HEAP32[$131>>2]|0;
      HEAP32[$vararg_buffer81>>2] = $132;
      (_printf((632|0),($vararg_buffer81|0))|0);
      $pc$1$i = $pc$017$i;
      break;
     }
     case 43:  {
      $133 = ($62|0)==(0);
      if ($133) {
       $134 = (($49) + ($135<<2)|0);
       $136 = HEAP32[$134>>2]|0;
       HEAP32[$vararg_buffer84>>2] = $136;
       (_printf((640|0),($vararg_buffer84|0))|0);
       $pc$1$i = $135;
       break L29;
      } else {
       HEAP32[$vararg_buffer87>>2] = $62;
       (_printf((640|0),($vararg_buffer87|0))|0);
       $pc$1$i = $pc$017$i;
       break L29;
      }
      break;
     }
     case 46:  {
      (_printf((600|0),($vararg_buffer90|0))|0);
      $f$idx$val$i = HEAP32[$f$idx16$i>>2]|0;
      _PrintConstant($f$idx$val$i,$58);
      $pc$1$i = $pc$017$i;
      break;
     }
     default: {
      $pc$1$i = $pc$017$i;
     }
     }
    } while(0);
    (_putchar(10)|0);
    $137 = (($pc$1$i) + 1)|0;
    $138 = ($137|0)<($50|0);
    if ($138) {
     $pc$017$i = $137;
    } else {
     break L5;
    }
   }
  }
 } while(0);
 $139 = ($full|0)==(0);
 if (!($139)) {
  $140 = HEAP32[$41>>2]|0;
  HEAP32[$vararg_buffer92>>2] = $140;
  $vararg_ptr95 = ((($vararg_buffer92)) + 4|0);
  HEAP32[$vararg_ptr95>>2] = $f;
  (_printf((648|0),($vararg_buffer92|0))|0);
  $141 = ($140|0)>(0);
  if ($141) {
   $f$idx$i = ((($f)) + 44|0);
   $i$06$i = 0;
   while(1) {
    $142 = (($i$06$i) + 1)|0;
    HEAP32[$vararg_buffer96>>2] = $142;
    (_printf((544|0),($vararg_buffer96|0))|0);
    $f$idx$val$i1 = HEAP32[$f$idx$i>>2]|0;
    _PrintConstant($f$idx$val$i1,$i$06$i);
    (_putchar(10)|0);
    $exitcond11$i = ($142|0)==($140|0);
    if ($exitcond11$i) {
     break;
    } else {
     $i$06$i = $142;
    }
   }
  }
  $143 = HEAP32[$37>>2]|0;
  HEAP32[$vararg_buffer99>>2] = $143;
  $vararg_ptr102 = ((($vararg_buffer99)) + 4|0);
  HEAP32[$vararg_ptr102>>2] = $f;
  (_printf((672|0),($vararg_buffer99|0))|0);
  $144 = ($143|0)>(0);
  if ($144) {
   $145 = ((($f)) + 60|0);
   $i$12$i = 0;
   while(1) {
    $146 = HEAP32[$145>>2]|0;
    $147 = (($146) + (($i$12$i*12)|0)|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ((($148)) + 24|0);
    $150 = (((($146) + (($i$12$i*12)|0)|0)) + 4|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = (($151) + 1)|0;
    $153 = (((($146) + (($i$12$i*12)|0)|0)) + 8|0);
    $154 = HEAP32[$153>>2]|0;
    $155 = (($154) + 1)|0;
    HEAP32[$vararg_buffer103>>2] = $i$12$i;
    $vararg_ptr106 = ((($vararg_buffer103)) + 4|0);
    HEAP32[$vararg_ptr106>>2] = $149;
    $vararg_ptr107 = ((($vararg_buffer103)) + 8|0);
    HEAP32[$vararg_ptr107>>2] = $152;
    $vararg_ptr108 = ((($vararg_buffer103)) + 12|0);
    HEAP32[$vararg_ptr108>>2] = $155;
    (_printf((696|0),($vararg_buffer103|0))|0);
    $156 = (($i$12$i) + 1)|0;
    $exitcond10$i = ($156|0)==($143|0);
    if ($exitcond10$i) {
     break;
    } else {
     $i$12$i = $156;
    }
   }
  }
  $157 = HEAP32[$33>>2]|0;
  HEAP32[$vararg_buffer109>>2] = $157;
  $vararg_ptr112 = ((($vararg_buffer109)) + 4|0);
  HEAP32[$vararg_ptr112>>2] = $f;
  (_printf((712|0),($vararg_buffer109|0))|0);
  $158 = ($157|0)>(0);
  if ($158) {
   $159 = ((($f)) + 64|0);
   $i$21$i = 0;
   while(1) {
    $160 = HEAP32[$159>>2]|0;
    $161 = (($160) + ($i$21$i<<3)|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = ($162|0)==(0|0);
    $164 = ((($162)) + 24|0);
    $165 = $163 ? 24 : $164;
    $166 = (((($160) + ($i$21$i<<3)|0)) + 4|0);
    $167 = HEAP8[$166>>0]|0;
    $168 = $167&255;
    $169 = (((($160) + ($i$21$i<<3)|0)) + 5|0);
    $170 = HEAP8[$169>>0]|0;
    $171 = $170&255;
    HEAP32[$vararg_buffer113>>2] = $i$21$i;
    $vararg_ptr116 = ((($vararg_buffer113)) + 4|0);
    HEAP32[$vararg_ptr116>>2] = $165;
    $vararg_ptr117 = ((($vararg_buffer113)) + 8|0);
    HEAP32[$vararg_ptr117>>2] = $168;
    $vararg_ptr118 = ((($vararg_buffer113)) + 12|0);
    HEAP32[$vararg_ptr118>>2] = $171;
    (_printf((696|0),($vararg_buffer113|0))|0);
    $172 = (($i$21$i) + 1)|0;
    $exitcond$i = ($172|0)==($157|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$21$i = $172;
    }
   }
  }
 }
 $173 = ($1|0)>(0);
 if (!($173)) {
  STACKTOP = sp;return;
 }
 $174 = ((($f)) + 52|0);
 $i$04 = 0;
 while(1) {
  $175 = HEAP32[$174>>2]|0;
  $176 = (($175) + ($i$04<<2)|0);
  $177 = HEAP32[$176>>2]|0;
  _PrintFunction($177,$full);
  $178 = (($i$04) + 1)|0;
  $exitcond = ($178|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$04 = $178;
  }
 }
 STACKTOP = sp;return;
}
function _cannot($what) {
 $what = $what|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[_stderr>>2]|0;
 $1 = HEAP32[8>>2]|0;
 $2 = HEAP32[56>>2]|0;
 $3 = (___errno_location()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (_strerror(($4|0))|0);
 HEAP32[$vararg_buffer>>2] = $1;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $what;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $5;
 (_fprintf(($0|0),(320|0),($vararg_buffer|0))|0);
 _exit(1);
 // unreachable;
}
function _writer($L,$p,$size,$u) {
 $L = $L|0;
 $p = $p|0;
 $size = $size|0;
 $u = $u|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_fwrite(($p|0),($size|0),1,($u|0))|0);
 $1 = ($0|0)!=(1);
 $2 = ($size|0)!=(0);
 $3 = $2 & $1;
 $4 = $3&1;
 return ($4|0);
}
function _PrintConstant($f$0$14$val,$i) {
 $f$0$14$val = $f$0$14$val|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, $buff = 0, $exitcond$i = 0, $i$03$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer10 = 0, $vararg_buffer13 = 0;
 var $vararg_buffer15 = 0, $vararg_buffer17 = 0, $vararg_buffer19 = 0, $vararg_buffer21 = 0, $vararg_buffer23 = 0, $vararg_buffer25 = 0, $vararg_buffer27 = 0, $vararg_buffer29 = 0, $vararg_buffer3 = 0, $vararg_buffer31 = 0, $vararg_buffer34 = 0, $vararg_buffer5 = 0, $vararg_buffer8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer34 = sp + 128|0;
 $vararg_buffer31 = sp + 120|0;
 $vararg_buffer29 = sp + 112|0;
 $vararg_buffer27 = sp + 104|0;
 $vararg_buffer25 = sp + 96|0;
 $vararg_buffer23 = sp + 88|0;
 $vararg_buffer21 = sp + 80|0;
 $vararg_buffer19 = sp + 72|0;
 $vararg_buffer17 = sp + 64|0;
 $vararg_buffer15 = sp + 56|0;
 $vararg_buffer13 = sp + 48|0;
 $vararg_buffer10 = sp + 40|0;
 $vararg_buffer8 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $buff = sp + 132|0;
 $0 = (($f$0$14$val) + ($i<<4)|0);
 $1 = (((($f$0$14$val) + ($i<<4)|0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 63;
 switch ($3|0) {
 case 1:  {
  $4 = HEAP32[$0>>2]|0;
  $5 = ($4|0)!=(0);
  $6 = $5 ? 6048 : 5936;
  (_printf(($6|0),($vararg_buffer1|0))|0);
  STACKTOP = sp;return;
  break;
 }
 case 19:  {
  $12 = $0;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $vararg_buffer10;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  (_printf((2040|0),($vararg_buffer10|0))|0);
  STACKTOP = sp;return;
  break;
 }
 case 20: case 4:  {
  $22 = HEAP32[$0>>2]|0;
  $23 = ((($22)) + 24|0);
  $24 = ((($22)) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  (_putchar(34)|0);
  $26 = ($25|0)==(0);
  L7: do {
   if (!($26)) {
    $i$03$i = 0;
    while(1) {
     $27 = (($23) + ($i$03$i)|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = $28&255;
     L10: do {
      switch ($29|0) {
      case 34:  {
       (_printf((752|0),($vararg_buffer13|0))|0);
       break;
      }
      case 92:  {
       (_printf((760|0),($vararg_buffer15|0))|0);
       break;
      }
      case 7:  {
       (_printf((768|0),($vararg_buffer17|0))|0);
       break;
      }
      case 8:  {
       (_printf((776|0),($vararg_buffer19|0))|0);
       break;
      }
      case 12:  {
       (_printf((784|0),($vararg_buffer21|0))|0);
       break;
      }
      case 10:  {
       (_printf((792|0),($vararg_buffer23|0))|0);
       break;
      }
      case 13:  {
       (_printf((800|0),($vararg_buffer25|0))|0);
       break;
      }
      case 9:  {
       (_printf((808|0),($vararg_buffer27|0))|0);
       break;
      }
      case 11:  {
       (_printf((816|0),($vararg_buffer29|0))|0);
       break;
      }
      default: {
       $30 = (_isprint($29)|0);
       $31 = ($30|0)==(0);
       if ($31) {
        HEAP32[$vararg_buffer31>>2] = $29;
        (_printf((824|0),($vararg_buffer31|0))|0);
        break L10;
       } else {
        (_putchar(($29|0))|0);
        break L10;
       }
      }
      }
     } while(0);
     $32 = (($i$03$i) + 1)|0;
     $exitcond$i = ($32|0)==($25|0);
     if ($exitcond$i) {
      break L7;
     } else {
      $i$03$i = $32;
     }
    }
   }
  } while(0);
  (_putchar(34)|0);
  STACKTOP = sp;return;
  break;
 }
 case 3:  {
  $7 = +HEAPF64[$0>>3];
  HEAPF64[$vararg_buffer3>>3] = $7;
  (_sprintf($buff,2048,$vararg_buffer3)|0);
  HEAP32[$vararg_buffer5>>2] = $buff;
  (_printf((736|0),($vararg_buffer5|0))|0);
  $8 = (_strspn($buff,2056)|0);
  $9 = (($buff) + ($8)|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   (_printf((744|0),($vararg_buffer8|0))|0);
  }
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  (_printf((6000|0),($vararg_buffer|0))|0);
  STACKTOP = sp;return;
  break;
 }
 default: {
  HEAP32[$vararg_buffer34>>2] = $3;
  (_printf((832|0),($vararg_buffer34|0))|0);
  STACKTOP = sp;return;
 }
 }
}
function _lua_checkstack($L,$n) {
 $L = $L|0;
 $n = $n|0;
 var $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $res$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $0 = sp;
 HEAP32[$0>>2] = $n;
 $1 = ((($L)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($L)) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($L)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 4;
 $11 = ($10|0)>($n|0);
 do {
  if ($11) {
   $25 = $6;$26 = $n;
  } else {
   $12 = ((($L)) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13;
   $15 = (($8) - ($14))|0;
   $16 = $15 >> 4;
   $17 = (($16) + 5)|0;
   $18 = (1000000 - ($n))|0;
   $19 = ($17|0)>($18|0);
   if ($19) {
    $res$01 = 0;
    STACKTOP = sp;return ($res$01|0);
   }
   $20 = (_luaD_rawrunprotected($L,5,$0)|0);
   $21 = ($20|0)==(0);
   if ($21) {
    $$pre = HEAP32[$5>>2]|0;
    $$pre4 = HEAP32[$0>>2]|0;
    $25 = $$pre;$26 = $$pre4;
    break;
   } else {
    $res$01 = 0;
    STACKTOP = sp;return ($res$01|0);
   }
  }
 } while(0);
 $22 = ((($2)) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($26<<4)|0);
 $27 = ($23>>>0)<($24>>>0);
 if (!($27)) {
  $res$01 = 1;
  STACKTOP = sp;return ($res$01|0);
 }
 HEAP32[$22>>2] = $24;
 $res$01 = 1;
 STACKTOP = sp;return ($res$01|0);
}
function _lua_atpanic($L,$panicf) {
 $L = $L|0;
 $panicf = $panicf|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 132|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$2>>2] = $panicf;
 return ($3|0);
}
function _lua_version($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($L|0)==(0|0);
 if ($0) {
  $$0 = 1256;
  return ($$0|0);
 }
 $1 = ((($L)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $$0 = $4;
 return ($$0|0);
}
function _lua_gettop($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 16|0);
 $6 = $1;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 4;
 return ($9|0);
}
function _lua_settop($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $scevgep = 0, $scevgep4 = 0, $scevgep7 = 0, $uglygep = 0, $uglygep6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($idx|0)>(-1);
 if (!($0)) {
  $16 = (($idx) + 1)|0;
  $17 = ((($L)) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + ($16<<4)|0);
  HEAP32[$17>>2] = $19;
  return;
 }
 $1 = ((($L)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($L)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $$sum = (($idx) + 1)|0;
 $6 = (($3) + ($$sum<<4)|0);
 $7 = ($5>>>0)<($6>>>0);
 if ($7) {
  $8 = $5;
  $scevgep = (((($3) + ($idx<<4)|0)) + 8|0);
  $scevgep4 = ((($scevgep)) + 4|0);
  $9 = (3 - ($8))|0;
  $uglygep = (($scevgep4) + ($9)|0);
  $uglygep6 = $uglygep;
  $10 = $uglygep6 >>> 4;
  $11 = (($10) + 1)|0;
  $13 = $5;
  while(1) {
   $12 = ((($13)) + 16|0);
   $14 = ((($13)) + 8|0);
   HEAP32[$14>>2] = 0;
   $15 = ($12>>>0)<($6>>>0);
   if ($15) {
    $13 = $12;
   } else {
    break;
   }
  }
  $scevgep7 = (($5) + ($11<<4)|0);
  HEAP32[$4>>2] = $scevgep7;
 }
 HEAP32[$4>>2] = $6;
 return;
}
function _lua_rotate($L,$idx,$n) {
 $L = $L|0;
 $idx = $idx|0;
 $n = $n|0;
 var $$0$i = 0, $$011$i = 0, $$011$i10 = 0, $$011$i5 = 0, $$02$i = 0, $$02$i4 = 0, $$02$i9 = 0, $$luaO_nilobject_$i = 0, $$sink = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $temp$i = 0, $temp$i2 = 0, $temp$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $temp$i7 = sp + 32|0;
 $temp$i2 = sp + 16|0;
 $temp$i = sp;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = ((($L)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($idx|0)>(0);
 do {
  if ($5) {
   $6 = HEAP32[$4>>2]|0;
   $7 = (($6) + ($idx<<4)|0);
   $8 = ($7>>>0)<($1>>>0);
   $$luaO_nilobject_$i = $8 ? $7 : 1760;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $9 = ($idx|0)<(-1000999);
   if (!($9)) {
    $10 = (($1) + ($idx<<4)|0);
    $$0$i = $10;
    break;
   }
   $11 = ($idx|0)==(-1001000);
   if ($11) {
    $12 = ((($L)) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ((($13)) + 40|0);
    $$0$i = $14;
    break;
   }
   $15 = (-1001000 - ($idx))|0;
   $16 = HEAP32[$4>>2]|0;
   $17 = ((($16)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(22);
   if ($19) {
    $$0$i = 1760;
   } else {
    $20 = HEAP32[$16>>2]|0;
    $21 = ((($20)) + 6|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = $22&255;
    $24 = ($15|0)>($23|0);
    $25 = (($15) + -1)|0;
    $26 = (((($20)) + 16|0) + ($25<<4)|0);
    $27 = $24 ? 1760 : $26;
    $$0$i = $27;
   }
  }
 } while(0);
 $28 = ($n|0)>(-1);
 $$sum1 = $n ^ -1;
 $$sink = $28 ? $1 : $$0$i;
 $29 = (($$sink) + ($$sum1<<4)|0);
 $30 = ($$0$i>>>0)<($29>>>0);
 if ($30) {
  $$011$i10 = $29;$$02$i9 = $$0$i;
  while(1) {
   ;HEAP32[$temp$i7>>2]=HEAP32[$$02$i9>>2]|0;HEAP32[$temp$i7+4>>2]=HEAP32[$$02$i9+4>>2]|0;HEAP32[$temp$i7+8>>2]=HEAP32[$$02$i9+8>>2]|0;HEAP32[$temp$i7+12>>2]=HEAP32[$$02$i9+12>>2]|0;
   ;HEAP32[$$02$i9>>2]=HEAP32[$$011$i10>>2]|0;HEAP32[$$02$i9+4>>2]=HEAP32[$$011$i10+4>>2]|0;HEAP32[$$02$i9+8>>2]=HEAP32[$$011$i10+8>>2]|0;HEAP32[$$02$i9+12>>2]=HEAP32[$$011$i10+12>>2]|0;
   ;HEAP32[$$011$i10>>2]=HEAP32[$temp$i7>>2]|0;HEAP32[$$011$i10+4>>2]=HEAP32[$temp$i7+4>>2]|0;HEAP32[$$011$i10+8>>2]=HEAP32[$temp$i7+8>>2]|0;HEAP32[$$011$i10+12>>2]=HEAP32[$temp$i7+12>>2]|0;
   $31 = ((($$02$i9)) + 16|0);
   $32 = ((($$011$i10)) + -16|0);
   $33 = ($31>>>0)<($32>>>0);
   if ($33) {
    $$011$i10 = $32;$$02$i9 = $31;
   } else {
    break;
   }
  }
 }
 $$sum = (0 - ($n))|0;
 $34 = (($$sink) + ($$sum<<4)|0);
 $35 = ($34>>>0)<($2>>>0);
 if ($35) {
  $$011$i5 = $2;$$02$i4 = $34;
  while(1) {
   ;HEAP32[$temp$i2>>2]=HEAP32[$$02$i4>>2]|0;HEAP32[$temp$i2+4>>2]=HEAP32[$$02$i4+4>>2]|0;HEAP32[$temp$i2+8>>2]=HEAP32[$$02$i4+8>>2]|0;HEAP32[$temp$i2+12>>2]=HEAP32[$$02$i4+12>>2]|0;
   ;HEAP32[$$02$i4>>2]=HEAP32[$$011$i5>>2]|0;HEAP32[$$02$i4+4>>2]=HEAP32[$$011$i5+4>>2]|0;HEAP32[$$02$i4+8>>2]=HEAP32[$$011$i5+8>>2]|0;HEAP32[$$02$i4+12>>2]=HEAP32[$$011$i5+12>>2]|0;
   ;HEAP32[$$011$i5>>2]=HEAP32[$temp$i2>>2]|0;HEAP32[$$011$i5+4>>2]=HEAP32[$temp$i2+4>>2]|0;HEAP32[$$011$i5+8>>2]=HEAP32[$temp$i2+8>>2]|0;HEAP32[$$011$i5+12>>2]=HEAP32[$temp$i2+12>>2]|0;
   $36 = ((($$02$i4)) + 16|0);
   $37 = ((($$011$i5)) + -16|0);
   $38 = ($36>>>0)<($37>>>0);
   if ($38) {
    $$011$i5 = $37;$$02$i4 = $36;
   } else {
    break;
   }
  }
 }
 $39 = ($$0$i>>>0)<($2>>>0);
 if ($39) {
  $$011$i = $2;$$02$i = $$0$i;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  ;HEAP32[$temp$i>>2]=HEAP32[$$02$i>>2]|0;HEAP32[$temp$i+4>>2]=HEAP32[$$02$i+4>>2]|0;HEAP32[$temp$i+8>>2]=HEAP32[$$02$i+8>>2]|0;HEAP32[$temp$i+12>>2]=HEAP32[$$02$i+12>>2]|0;
  ;HEAP32[$$02$i>>2]=HEAP32[$$011$i>>2]|0;HEAP32[$$02$i+4>>2]=HEAP32[$$011$i+4>>2]|0;HEAP32[$$02$i+8>>2]=HEAP32[$$011$i+8>>2]|0;HEAP32[$$02$i+12>>2]=HEAP32[$$011$i+12>>2]|0;
  ;HEAP32[$$011$i>>2]=HEAP32[$temp$i>>2]|0;HEAP32[$$011$i+4>>2]=HEAP32[$temp$i+4>>2]|0;HEAP32[$$011$i+8>>2]=HEAP32[$temp$i+8>>2]|0;HEAP32[$$011$i+12>>2]=HEAP32[$temp$i+12>>2]|0;
  $40 = ((($$02$i)) + 16|0);
  $41 = ((($$011$i)) + -16|0);
  $42 = ($40>>>0)<($41>>>0);
  if ($42) {
   $$011$i = $41;$$02$i = $40;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _lua_tointegerx($L,$idx,$pisnum) {
 $L = $L|0;
 $idx = $idx|0;
 $pisnum = $pisnum|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $res = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $res = sp;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1760;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1760;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1760 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(19);
 if ($31) {
  $32 = $$0$i;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $res;
  $39 = $38;
  HEAP32[$39>>2] = $34;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $37;
  $49 = 1;
 } else {
  $42 = (_luaV_tointeger_($$0$i,$res)|0);
  $43 = ($42|0)==(0);
  if ($43) {
   $44 = $res;
   $45 = $44;
   HEAP32[$45>>2] = 0;
   $46 = (($44) + 4)|0;
   $47 = $46;
   HEAP32[$47>>2] = 0;
   $49 = 0;
  } else {
   $49 = $42;
  }
 }
 $48 = ($pisnum|0)==(0|0);
 if ($48) {
  $50 = $res;
  $51 = $50;
  $52 = HEAP32[$51>>2]|0;
  $53 = (($50) + 4)|0;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  tempRet0 = ($55);
  STACKTOP = sp;return ($52|0);
 }
 HEAP32[$pisnum>>2] = $49;
 $50 = $res;
 $51 = $50;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($50) + 4)|0;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 tempRet0 = ($55);
 STACKTOP = sp;return ($52|0);
}
function _lua_tolstring($L,$idx,$len) {
 $L = $L|0;
 $idx = $idx|0;
 $len = $len|0;
 var $$0 = 0, $$0$i = 0, $$0$i2 = 0, $$luaO_nilobject_$i = 0, $$luaO_nilobject_$i1 = 0, $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $o$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1760;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1760;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1760 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 15;
 if ((($31|0) == 3)) {
  label = 12;
 } else if ((($31|0) == 4)) {
  $o$0 = $$0$i;
 } else {
  $32 = ($len|0)==(0|0);
  if ($32) {
   $$0 = 0;
   return ($$0|0);
  }
  HEAP32[$len>>2] = 0;
  $$0 = 0;
  return ($$0|0);
 }
 if ((label|0) == 12) {
  $33 = ((($L)) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ((($34)) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)>(0);
  if ($37) {
   _luaC_step($L);
   $$pre = HEAP32[$0>>2]|0;
   $39 = $$pre;
  } else {
   $39 = $1;
  }
  do {
   if ($2) {
    $38 = HEAP32[$39>>2]|0;
    $40 = (($38) + ($idx<<4)|0);
    $41 = ((($L)) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($40>>>0)<($42>>>0);
    $$luaO_nilobject_$i1 = $43 ? $40 : 1760;
    $$0$i2 = $$luaO_nilobject_$i1;
   } else {
    $44 = ($idx|0)<(-1000999);
    if (!($44)) {
     $45 = ((($L)) + 8|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($46) + ($idx<<4)|0);
     $$0$i2 = $47;
     break;
    }
    $48 = ($idx|0)==(-1001000);
    if ($48) {
     $49 = HEAP32[$33>>2]|0;
     $50 = ((($49)) + 40|0);
     $$0$i2 = $50;
     break;
    }
    $51 = (-1001000 - ($idx))|0;
    $52 = HEAP32[$39>>2]|0;
    $53 = ((($52)) + 8|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ($54|0)==(22);
    if ($55) {
     $$0$i2 = 1760;
    } else {
     $56 = HEAP32[$52>>2]|0;
     $57 = ((($56)) + 6|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = $58&255;
     $60 = ($51|0)>($59|0);
     $61 = (($51) + -1)|0;
     $62 = (((($56)) + 16|0) + ($61<<4)|0);
     $63 = $60 ? 1760 : $62;
     $$0$i2 = $63;
    }
   }
  } while(0);
  _luaO_tostring($L,$$0$i2);
  $o$0 = $$0$i2;
 }
 $64 = ($len|0)==(0|0);
 if ($64) {
  $$pre4 = HEAP32[$o$0>>2]|0;
  $69 = $$pre4;
 } else {
  $65 = HEAP32[$o$0>>2]|0;
  $66 = ((($65)) + 12|0);
  $67 = HEAP32[$66>>2]|0;
  HEAP32[$len>>2] = $67;
  $69 = $65;
 }
 $68 = ((($69)) + 24|0);
 $$0 = $68;
 return ($$0|0);
}
function _lua_touserdata($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0 = 0, $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1760;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1760;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1760 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 15;
 if ((($31|0) == 2)) {
  $34 = HEAP32[$$0$i>>2]|0;
  $$0 = $34;
  return ($$0|0);
 } else if ((($31|0) == 7)) {
  $32 = HEAP32[$$0$i>>2]|0;
  $33 = ((($32)) + 24|0);
  $$0 = $33;
  return ($$0|0);
 } else {
  $$0 = 0;
  return ($$0|0);
 }
 return (0)|0;
}
function _lua_pushinteger($L,$0,$1) {
 $L = $L|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($L)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3;
 $5 = $4;
 HEAP32[$5>>2] = $0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $1;
 $8 = ((($3)) + 8|0);
 HEAP32[$8>>2] = 19;
 $9 = ((($3)) + 16|0);
 HEAP32[$2>>2] = $9;
 return;
}
function _lua_pushlstring($L,$s,$len) {
 $L = $L|0;
 $s = $s|0;
 $len = $len|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  _luaC_step($L);
 }
 $5 = (_luaS_newlstr($L,$s,$len)|0);
 $6 = ((($L)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$7>>2] = $5;
 $8 = ((($5)) + 4|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 | 64;
 $12 = ((($7)) + 8|0);
 HEAP32[$12>>2] = $11;
 $13 = HEAP32[$6>>2]|0;
 $14 = ((($13)) + 16|0);
 HEAP32[$6>>2] = $14;
 $15 = ((($5)) + 24|0);
 return ($15|0);
}
function _lua_pushfstring($L,$fmt,$varargs) {
 $L = $L|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $argp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $argp = sp;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  _luaC_step($L);
 }
 HEAP32[$argp>>2] = $varargs;
 $5 = (_luaO_pushvfstring($L,$fmt,$argp)|0);
 STACKTOP = sp;return ($5|0);
}
function _lua_pushcclosure($L,$fn,$n) {
 $L = $L|0;
 $fn = $fn|0;
 $n = $n|0;
 var $$in = 0, $$pre$phiZ2D = 0, $$pre3 = 0, $$pre3$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if ($0) {
  $1 = ((($L)) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  HEAP32[$2>>2] = $fn;
  $3 = ((($2)) + 8|0);
  HEAP32[$3>>2] = 22;
  $$pre$phiZ2D = $1;
  $21 = HEAP32[$$pre$phiZ2D>>2]|0;
  $22 = ((($21)) + 16|0);
  HEAP32[$$pre$phiZ2D>>2] = $22;
  return;
 }
 $4 = ((($L)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 if ($8) {
  _luaC_step($L);
 }
 $9 = (_luaF_newCclosure($L,$n)|0);
 $10 = ((($9)) + 12|0);
 HEAP32[$10>>2] = $fn;
 $11 = ((($L)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (0 - ($n))|0;
 $14 = (($12) + ($13<<4)|0);
 HEAP32[$11>>2] = $14;
 $$in = $n;$18 = $14;
 while(1) {
  $15 = (($$in) + -1)|0;
  $16 = (((($9)) + 16|0) + ($15<<4)|0);
  $17 = (($18) + ($15<<4)|0);
  ;HEAP32[$16>>2]=HEAP32[$17>>2]|0;HEAP32[$16+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$17+12>>2]|0;
  $19 = ($15|0)==(0);
  $$pre3 = HEAP32[$11>>2]|0;
  if ($19) {
   $$pre3$lcssa = $$pre3;
   break;
  } else {
   $$in = $15;$18 = $$pre3;
  }
 }
 HEAP32[$$pre3$lcssa>>2] = $9;
 $20 = ((($$pre3$lcssa)) + 8|0);
 HEAP32[$20>>2] = 102;
 $$pre$phiZ2D = $11;
 $21 = HEAP32[$$pre$phiZ2D>>2]|0;
 $22 = ((($21)) + 16|0);
 HEAP32[$$pre$phiZ2D>>2] = $22;
 return;
}
function _lua_pushlightuserdata($L,$p) {
 $L = $L|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$1>>2] = $p;
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = 2;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 16|0);
 HEAP32[$0>>2] = $4;
 return;
}
function _lua_pcallk($L,$nargs,$nresults,$errfunc,$ctx,$k) {
 $L = $L|0;
 $nargs = $nargs|0;
 $nresults = $nresults|0;
 $errfunc = $errfunc|0;
 $ctx = $ctx|0;
 $k = $k|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $c = 0, $func$0 = 0, $status$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $c = sp;
 $0 = ($errfunc|0)==(0);
 if ($0) {
  $func$0 = 0;
 } else {
  $1 = ((($L)) + 16|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($errfunc|0)>(0);
  do {
   if ($3) {
    $4 = HEAP32[$2>>2]|0;
    $5 = (($4) + ($errfunc<<4)|0);
    $6 = ((($L)) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($5>>>0)<($7>>>0);
    $$luaO_nilobject_$i = $8 ? $5 : 1760;
    $$0$i = $$luaO_nilobject_$i;
   } else {
    $9 = ($errfunc|0)<(-1000999);
    if (!($9)) {
     $10 = ((($L)) + 8|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($11) + ($errfunc<<4)|0);
     $$0$i = $12;
     break;
    }
    $13 = ($errfunc|0)==(-1001000);
    if ($13) {
     $14 = ((($L)) + 12|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ((($15)) + 40|0);
     $$0$i = $16;
     break;
    }
    $17 = (-1001000 - ($errfunc))|0;
    $18 = HEAP32[$2>>2]|0;
    $19 = ((($18)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(22);
    if ($21) {
     $$0$i = 1760;
    } else {
     $22 = HEAP32[$18>>2]|0;
     $23 = ((($22)) + 6|0);
     $24 = HEAP8[$23>>0]|0;
     $25 = $24&255;
     $26 = ($17|0)>($25|0);
     $27 = (($17) + -1)|0;
     $28 = (((($22)) + 16|0) + ($27<<4)|0);
     $29 = $26 ? 1760 : $28;
     $$0$i = $29;
    }
   }
  } while(0);
  $30 = ((($L)) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = $$0$i;
  $33 = $31;
  $34 = (($32) - ($33))|0;
  $func$0 = $34;
 }
 $35 = ((($L)) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $nargs ^ -1;
 $38 = (($36) + ($37<<4)|0);
 HEAP32[$c>>2] = $38;
 $39 = ($k|0)==(0|0);
 if ($39) {
  label = 13;
 } else {
  $40 = ((($L)) + 104|0);
  $41 = HEAP16[$40>>1]|0;
  $42 = ($41<<16>>16)==(0);
  if ($42) {
   $50 = ((($L)) + 16|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($51)) + 16|0);
   HEAP32[$52>>2] = $k;
   $53 = ((($51)) + 24|0);
   HEAP32[$53>>2] = $ctx;
   $54 = ((($L)) + 28|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = $38;
   $57 = $55;
   $58 = (($56) - ($57))|0;
   $59 = ((($51)) + 28|0);
   HEAP32[$59>>2] = $58;
   $60 = ((($L)) + 88|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ((($51)) + 20|0);
   HEAP32[$62>>2] = $61;
   HEAP32[$60>>2] = $func$0;
   $63 = ((($51)) + 34|0);
   $64 = HEAP8[$63>>0]|0;
   $65 = $64&255;
   $66 = $65 & 238;
   $67 = ((($L)) + 109|0);
   $68 = HEAP8[$67>>0]|0;
   $69 = $68&255;
   $70 = $69 | $66;
   $71 = $70 | 16;
   $72 = $71&255;
   HEAP8[$63>>0] = $72;
   _luaD_call($L,$38,$nresults,1);
   $73 = HEAP8[$63>>0]|0;
   $74 = $73&255;
   $75 = $74 & 239;
   $76 = $75&255;
   HEAP8[$63>>0] = $76;
   $77 = HEAP32[$62>>2]|0;
   HEAP32[$60>>2] = $77;
   $status$0 = 0;
  } else {
   label = 13;
  }
 }
 if ((label|0) == 13) {
  $43 = ((($c)) + 4|0);
  HEAP32[$43>>2] = $nresults;
  $44 = ((($L)) + 28|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $38;
  $47 = $45;
  $48 = (($46) - ($47))|0;
  $49 = (_luaD_pcall($L,6,$c,$48,$func$0)|0);
  $status$0 = $49;
 }
 $78 = ($nresults|0)==(-1);
 if (!($78)) {
  STACKTOP = sp;return ($status$0|0);
 }
 $79 = ((($L)) + 16|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80)) + 4|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = HEAP32[$35>>2]|0;
 $84 = ($82>>>0)<($83>>>0);
 if (!($84)) {
  STACKTOP = sp;return ($status$0|0);
 }
 HEAP32[$81>>2] = $83;
 STACKTOP = sp;return ($status$0|0);
}
function _lua_load($L,$reader,$data,$chunkname,$mode) {
 $L = $L|0;
 $reader = $reader|0;
 $data = $data|0;
 $chunkname = $chunkname|0;
 $mode = $mode|0;
 var $$chunkname = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $z = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $z = sp;
 $0 = ($chunkname|0)==(0|0);
 $$chunkname = $0 ? 1264 : $chunkname;
 _luaZ_init($L,$z,$reader,$data);
 $1 = (_luaD_protectedparser($L,$z,$$chunkname,$mode)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return ($1|0);
 }
 $3 = ((($L)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 6|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  STACKTOP = sp;return ($1|0);
 }
 $10 = ((($L)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (_luaH_getint($13,2,0)|0);
 $15 = ((($6)) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 ;HEAP32[$17>>2]=HEAP32[$14>>2]|0;HEAP32[$17+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$14+12>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($19)) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 & 64;
 $23 = ($22|0)!=(0);
 $24 = ((($18)) + 8|0);
 $25 = ($19|0)==($24|0);
 $or$cond = $25 & $23;
 if (!($or$cond)) {
  STACKTOP = sp;return ($1|0);
 }
 _luaC_upvalbarrier_($L,$18);
 STACKTOP = sp;return ($1|0);
}
function _growstack($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ud>>2]|0;
 _luaD_growstack($L,$0);
 return;
}
function _f_call($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ud>>2]|0;
 $1 = ((($ud)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 _luaD_call($L,$0,$2,0);
 return;
}
function _luaG_typeerror($L,$o,$op) {
 $L = $L|0;
 $o = $o|0;
 $op = $op|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($o)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 $3 = (($2) + 1)|0;
 $4 = (3720 + ($3<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_varinfo($L,$o)|0);
 HEAP32[$vararg_buffer>>2] = $op;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $5;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $6;
 _luaG_runerror($L,1280,$vararg_buffer);
 // unreachable;
}
function _luaG_runerror($L,$fmt,$varargs) {
 $L = $L|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $argp = 0, $buff$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $buff$i = sp + 32|0;
 $argp = sp + 16|0;
 HEAP32[$argp>>2] = $varargs;
 $0 = (_luaO_pushvfstring($L,$fmt,$argp)|0);
 $1 = ((($L)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 34|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 2;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  _luaG_errormsg($L);
  // unreachable;
 }
 $7 = HEAP32[$2>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $30 = -1;
 } else {
  $14 = ((($2)) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($10)) + 48|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $15;
  $19 = $17;
  $20 = (($18) - ($19))|0;
  $21 = $20 >> 2;
  $22 = (($21) + -1)|0;
  $23 = (($12) + ($22<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $30 = $24;
 }
 $25 = ((($10)) + 72|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP8[$buff$i>>0] = 63;
  $29 = ((($buff$i)) + 1|0);
  HEAP8[$29>>0] = 0;
 } else {
  $28 = ((($26)) + 24|0);
  _luaO_chunkid($buff$i,$28,60);
 }
 HEAP32[$vararg_buffer>>2] = $buff$i;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $30;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $0;
 (_luaO_pushfstring($L,5856,$vararg_buffer)|0);
 _luaG_errormsg($L);
 // unreachable;
}
function _luaG_concaterror($L,$p1,$p2) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $$off = 0, $0 = 0, $1 = 0, $2 = 0, $p2$p1 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($p1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 $$off = (($2) + -3)|0;
 $switch = ($$off>>>0)<(2);
 $p2$p1 = $switch ? $p2 : $p1;
 _luaG_typeerror($L,$p2$p1,1312);
 // unreachable;
}
function _luaG_opinterror($L,$p1,$p2,$msg) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $msg = $msg|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $p1$p2 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $temp = sp;
 $0 = ((($p1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 if ($2) {
  $3 = +HEAPF64[$p1>>3];
  HEAPF64[$temp>>3] = $3;
  $$0 = $p2;
  _luaG_typeerror($L,$$0,$msg);
  // unreachable;
 } else {
  $4 = (_luaV_tonumber_($p1,$temp)|0);
  $5 = ($4|0)==(0);
  $p1$p2 = $5 ? $p1 : $p2;
  $$0 = $p1$p2;
  _luaG_typeerror($L,$$0,$msg);
  // unreachable;
 }
}
function _luaG_tointerror($L,$p1,$p2) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p1$p2 = 0, $temp = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 8|0;
 $temp = sp;
 $0 = ((($p1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(19);
 if ($2) {
  $3 = $p1;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $temp;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  $$0 = $p2;
 } else {
  $13 = (_luaV_tointeger_($p1,$temp)|0);
  $14 = ($13|0)==(0);
  $p1$p2 = $14 ? $p1 : $p2;
  $$0 = $p1$p2;
 }
 $15 = (_varinfo($L,$$0)|0);
 HEAP32[$vararg_buffer>>2] = $15;
 _luaG_runerror($L,1328,$vararg_buffer);
 // unreachable;
}
function _luaG_ordererror($L,$p1,$p2) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ((($p1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 $3 = (($2) + 1)|0;
 $4 = (3720 + ($3<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($p2)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 15;
 $9 = (($8) + 1)|0;
 $10 = (3720 + ($9<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($5|0)==($11|0);
 if ($12) {
  HEAP32[$vararg_buffer>>2] = $5;
  _luaG_runerror($L,1368,$vararg_buffer);
  // unreachable;
 } else {
  HEAP32[$vararg_buffer1>>2] = $5;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = $11;
  _luaG_runerror($L,1408,$vararg_buffer1);
  // unreachable;
 }
}
function _luaG_errormsg($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  _luaD_throw($L,2);
  // unreachable;
 }
 $3 = ((($L)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1)|0);
 $6 = ((($L)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + -16|0);
 ;HEAP32[$7>>2]=HEAP32[$8>>2]|0;HEAP32[$7+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$8+12>>2]|0;
 $9 = HEAP32[$6>>2]|0;
 $10 = ((($9)) + -16|0);
 ;HEAP32[$10>>2]=HEAP32[$5>>2]|0;HEAP32[$10+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$5+12>>2]|0;
 $11 = HEAP32[$6>>2]|0;
 $12 = ((($11)) + 16|0);
 HEAP32[$6>>2] = $12;
 $13 = ((($11)) + -16|0);
 _luaD_call($L,$13,1,0);
 _luaD_throw($L,2);
 // unreachable;
}
function _luaG_traceexec($L) {
 $L = $L|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 108|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 & 8;
 $6 = ($5|0)==(0);
 if ($6) {
  $67 = 0;
 } else {
  $7 = ((($L)) + 100|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $10 = ((($L)) + 96|0);
   $11 = HEAP32[$10>>2]|0;
   HEAP32[$7>>2] = $11;
   $67 = 1;
  } else {
   $67 = 0;
  }
 }
 $12 = ((($1)) + 34|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = $14 & 64;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = $14 & 191;
  $18 = $17&255;
  HEAP8[$12>>0] = $18;
  return;
 }
 if ($67) {
  _luaD_hook($L,3,-1);
 }
 $19 = $4 & 4;
 $20 = ($19|0)==(0);
 do {
  if ($20) {
   $$pre = ((($1)) + 20|0);
   $$pre$phi2Z2D = $$pre;$$pre$phiZ2D = $$pre;
  } else {
   $21 = HEAP32[$1>>2]|0;
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($22)) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ((($1)) + 20|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($24)) + 48|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = $26;
   $30 = $28;
   $31 = (($29) - ($30))|0;
   $32 = $31 >> 2;
   $33 = (($32) + -1)|0;
   $34 = ((($24)) + 56|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    $50 = -1;
   } else {
    $37 = (($35) + ($33<<2)|0);
    $38 = HEAP32[$37>>2]|0;
    $50 = $38;
   }
   $39 = ($33|0)==(0);
   if (!($39)) {
    $40 = ((($L)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($26>>>0)>($41>>>0);
    if ($42) {
     if ($36) {
      $51 = -1;
     } else {
      $43 = $41;
      $44 = (($43) - ($30))|0;
      $45 = $44 >> 2;
      $46 = (($45) + -1)|0;
      $47 = (($35) + ($46<<2)|0);
      $48 = HEAP32[$47>>2]|0;
      $51 = $48;
     }
     $49 = ($50|0)==($51|0);
     if ($49) {
      $$pre$phi2Z2D = $25;$$pre$phiZ2D = $25;
      break;
     }
    }
   }
   _luaD_hook($L,2,$50);
   $$pre$phi2Z2D = $25;$$pre$phiZ2D = $25;
  }
 } while(0);
 $52 = HEAP32[$$pre$phiZ2D>>2]|0;
 $53 = ((($L)) + 20|0);
 HEAP32[$53>>2] = $52;
 $54 = ((($L)) + 6|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(1);
 $57 = $52;
 if (!($56)) {
  return;
 }
 if (!($67)) {
  $59 = ((($57)) + -4|0);
  HEAP32[$$pre$phi2Z2D>>2] = $59;
  $60 = HEAP8[$12>>0]|0;
  $61 = $60&255;
  $62 = $61 | 64;
  $63 = $62&255;
  HEAP8[$12>>0] = $63;
  $64 = ((($L)) + 8|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -16|0);
  HEAP32[$1>>2] = $66;
  _luaD_throw($L,1);
  // unreachable;
 }
 $58 = ((($L)) + 100|0);
 HEAP32[$58>>2] = 1;
 $59 = ((($57)) + -4|0);
 HEAP32[$$pre$phi2Z2D>>2] = $59;
 $60 = HEAP8[$12>>0]|0;
 $61 = $60&255;
 $62 = $61 | 64;
 $63 = $62&255;
 HEAP8[$12>>0] = $63;
 $64 = ((($L)) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($65)) + -16|0);
 HEAP32[$1>>2] = $66;
 _luaD_throw($L,1);
 // unreachable;
}
function _getobjname($p,$lastpc,$reg,$name) {
 $p = $p|0;
 $lastpc = $lastpc|0;
 $reg = $reg|0;
 $name = $name|0;
 var $$0 = 0, $$0$i = 0, $$0$i2 = 0, $$jmptarget$0$i = 0, $$lcssa = 0, $$lcssa101 = 0, $$lcssa96 = 0, $$lcssa97 = 0, $$lcssa98 = 0, $$lcssa99 = 0, $$pc$i$i = 0, $$pc$i3$i = 0, $$pc$i4$i = 0, $$pc$i5$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $exitcond$i = 0, $jmptarget$06$i = 0, $jmptarget$1$i = 0, $lastpc$tr = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond$not$i = 0, $or$cond1$i = 0, $or$cond2$i = 0, $p$idx = 0, $p$idx$val = 0, $p$idx1 = 0, $p$idx1$val = 0, $pc$08$i = 0, $phitmp = 0, $reg$tr = 0, $setreg$07$i = 0, $setreg$1$i = 0;
 var $setreg$1$i$lcssa = 0, $setreg$1$i$lcssa$lcssa = 0, $setreg$1$i$lcssa$lcssa90 = 0, $setreg$1$i$lcssa$lcssa92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($p)) + 48|0);
 $lastpc$tr = $lastpc;$reg$tr = $reg;
 L1: while(1) {
  $1 = (($reg$tr) + 1)|0;
  $2 = (_luaF_getlocalname($p,$1,$lastpc$tr)|0);
  HEAP32[$name>>2] = $2;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $$0 = 5992;
   label = 42;
   break;
  }
  $4 = ($lastpc$tr|0)>(0);
  if (!($4)) {
   $$0 = 0;
   label = 42;
   break;
  }
  $5 = HEAP32[$0>>2]|0;
  $jmptarget$06$i = 0;$pc$08$i = 0;$setreg$07$i = -1;
  while(1) {
   $6 = (($5) + ($pc$08$i<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $7 & 63;
   $9 = $7 >>> 6;
   $10 = $9 & 255;
   switch ($8|0) {
   case 37: case 36:  {
    $19 = ($10|0)>($reg$tr|0);
    if ($19) {
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $setreg$07$i;
    } else {
     $20 = ($pc$08$i|0)<($jmptarget$06$i|0);
     $$pc$i4$i = $20 ? -1 : $pc$08$i;
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $$pc$i4$i;
    }
    break;
   }
   case 30:  {
    $21 = $7 >>> 14;
    $22 = (($pc$08$i) + -131070)|0;
    $23 = (($22) + ($21))|0;
    $notlhs$i = ($pc$08$i|0)<($23|0);
    $notrhs$i = ($23|0)<=($lastpc$tr|0);
    $or$cond$not$i = $notrhs$i & $notlhs$i;
    $24 = ($23|0)>($jmptarget$06$i|0);
    $or$cond1$i = $24 & $or$cond$not$i;
    $$jmptarget$0$i = $or$cond1$i ? $23 : $jmptarget$06$i;
    $jmptarget$1$i = $$jmptarget$0$i;$setreg$1$i = $setreg$07$i;
    break;
   }
   case 41:  {
    $16 = (($10) + 2)|0;
    $17 = ($16|0)>($reg$tr|0);
    if ($17) {
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $setreg$07$i;
    } else {
     $18 = ($pc$08$i|0)<($jmptarget$06$i|0);
     $$pc$i5$i = $18 ? -1 : $pc$08$i;
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $$pc$i5$i;
    }
    break;
   }
   case 4:  {
    $11 = ($10|0)>($reg$tr|0);
    if ($11) {
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $setreg$07$i;
    } else {
     $12 = $7 >>> 23;
     $13 = (($10) + ($12))|0;
     $14 = ($13|0)<($reg$tr|0);
     if ($14) {
      $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $setreg$07$i;
     } else {
      $15 = ($pc$08$i|0)<($jmptarget$06$i|0);
      $$pc$i$i = $15 ? -1 : $pc$08$i;
      $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $$pc$i$i;
     }
    }
    break;
   }
   default: {
    $25 = (2360 + ($8)|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = $26 & 64;
    $28 = ($27<<24>>24)!=(0);
    $29 = ($10|0)==($reg$tr|0);
    $or$cond2$i = $29 & $28;
    if ($or$cond2$i) {
     $30 = ($pc$08$i|0)<($jmptarget$06$i|0);
     $$pc$i3$i = $30 ? -1 : $pc$08$i;
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $$pc$i3$i;
    } else {
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $setreg$07$i;
    }
   }
   }
   $31 = (($pc$08$i) + 1)|0;
   $exitcond$i = ($31|0)==($lastpc$tr|0);
   if ($exitcond$i) {
    $setreg$1$i$lcssa = $setreg$1$i;
    break;
   } else {
    $jmptarget$06$i = $jmptarget$1$i;$pc$08$i = $31;$setreg$07$i = $setreg$1$i;
   }
  }
  $32 = ($setreg$1$i$lcssa|0)==(-1);
  if ($32) {
   $$0 = 0;
   label = 42;
   break;
  }
  $33 = (($5) + ($setreg$1$i$lcssa<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $34 & 63;
  switch ($35|0) {
  case 7: case 6:  {
   $$lcssa = $34;$$lcssa101 = $35;$setreg$1$i$lcssa$lcssa = $setreg$1$i$lcssa;
   label = 20;
   break L1;
   break;
  }
  case 1:  {
   $$lcssa99 = $34;
   label = 32;
   break L1;
   break;
  }
  case 5:  {
   $$lcssa97 = $34;
   label = 31;
   break L1;
   break;
  }
  case 0:  {
   break;
  }
  case 2:  {
   $$lcssa96 = $5;$setreg$1$i$lcssa$lcssa92 = $setreg$1$i$lcssa;
   label = 33;
   break L1;
   break;
  }
  case 12:  {
   $$lcssa98 = $34;$setreg$1$i$lcssa$lcssa90 = $setreg$1$i$lcssa;
   label = 36;
   break L1;
   break;
  }
  default: {
   $$0 = 0;
   label = 42;
   break L1;
  }
  }
  $36 = $34 >>> 23;
  $37 = $34 >>> 6;
  $38 = $37 & 255;
  $39 = ($36>>>0)<($38>>>0);
  if ($39) {
   $lastpc$tr = $setreg$1$i$lcssa;$reg$tr = $36;
  } else {
   $$0 = 0;
   label = 42;
   break;
  }
 }
 if ((label|0) == 20) {
  $40 = $$lcssa >>> 14;
  $41 = $40 & 511;
  $42 = $$lcssa >>> 23;
  $43 = ($$lcssa101|0)==(7);
  if ($43) {
   $44 = (($42) + 1)|0;
   $45 = (_luaF_getlocalname($p,$44,$setreg$1$i$lcssa$lcssa)|0);
   $67 = $45;
  } else {
   $p$idx1 = ((($p)) + 64|0);
   $p$idx1$val = HEAP32[$p$idx1>>2]|0;
   $46 = (($p$idx1$val) + ($42<<3)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   $49 = ((($47)) + 24|0);
   $$0$i2 = $48 ? 1264 : $49;
   $67 = $$0$i2;
  }
  $50 = $40 & 256;
  $51 = ($50|0)==(0);
  if ($51) {
   $62 = (_getobjname($p,$setreg$1$i$lcssa$lcssa,$41,$name)|0);
   $63 = ($62|0)==(0|0);
   if ($63) {
    label = 28;
   } else {
    $64 = HEAP8[$62>>0]|0;
    $65 = ($64<<24>>24)==(99);
    if (!($65)) {
     label = 28;
    }
   }
  } else {
   $52 = $40 & 255;
   $53 = ((($p)) + 44|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (((($54) + ($52<<4)|0)) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = $56 & 15;
   $58 = ($57|0)==(4);
   if ($58) {
    $59 = (($54) + ($52<<4)|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ((($60)) + 24|0);
    HEAP32[$name>>2] = $61;
   } else {
    label = 28;
   }
  }
  if ((label|0) == 28) {
   HEAP32[$name>>2] = 1264;
  }
  $66 = ($67|0)==(0|0);
  if ($66) {
   $$0 = 1472;
   return ($$0|0);
  }
  $68 = (_strcmp($67,5312)|0);
  $69 = ($68|0)==(0);
  $phitmp = $69 ? 1464 : 1472;
  $$0 = $phitmp;
  return ($$0|0);
 }
 else if ((label|0) == 31) {
  $70 = $$lcssa97 >>> 23;
  $p$idx = ((($p)) + 64|0);
  $p$idx$val = HEAP32[$p$idx>>2]|0;
  $71 = (($p$idx$val) + ($70<<3)|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0|0);
  $74 = ((($72)) + 24|0);
  $$0$i = $73 ? 1264 : $74;
  HEAP32[$name>>2] = $$0$i;
  $$0 = 1440;
  return ($$0|0);
 }
 else if ((label|0) == 32) {
  $75 = $$lcssa99 >>> 14;
  $83 = $75;
 }
 else if ((label|0) == 33) {
  $76 = (($setreg$1$i$lcssa$lcssa92) + 1)|0;
  $77 = (($$lcssa96) + ($76<<2)|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = $78 >>> 6;
  $83 = $79;
 }
 else if ((label|0) == 36) {
  $90 = $$lcssa98 >>> 14;
  $91 = $90 & 256;
  $92 = ($91|0)==(0);
  if ($92) {
   $103 = $90 & 511;
   $104 = (_getobjname($p,$setreg$1$i$lcssa$lcssa90,$103,$name)|0);
   $105 = ($104|0)==(0|0);
   if (!($105)) {
    $106 = HEAP8[$104>>0]|0;
    $107 = ($106<<24>>24)==(99);
    if ($107) {
     $$0 = 1496;
     return ($$0|0);
    }
   }
  } else {
   $93 = $90 & 255;
   $94 = ((($p)) + 44|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (((($95) + ($93<<4)|0)) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = $97 & 15;
   $99 = ($98|0)==(4);
   if ($99) {
    $100 = (($95) + ($93<<4)|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($101)) + 24|0);
    HEAP32[$name>>2] = $102;
    $$0 = 1496;
    return ($$0|0);
   }
  }
  HEAP32[$name>>2] = 1264;
  $$0 = 1496;
  return ($$0|0);
 }
 else if ((label|0) == 42) {
  return ($$0|0);
 }
 $80 = ((($p)) + 44|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (((($81) + ($83<<4)|0)) + 8|0);
 $84 = HEAP32[$82>>2]|0;
 $85 = $84 & 15;
 $86 = ($85|0)==(4);
 if (!($86)) {
  $$0 = 0;
  return ($$0|0);
 }
 $87 = (($81) + ($83<<4)|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ((($88)) + 24|0);
 HEAP32[$name>>2] = $89;
 $$0 = 1480;
 return ($$0|0);
}
function _varinfo($L,$o) {
 $L = $L|0;
 $o = $o|0;
 var $$0$i$i = 0, $$idx$i = 0, $$idx$val$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$i = 0, $i$02$i$lcssa = 0, $kind$03 = 0, $name = 0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $name = sp + 8|0;
 HEAP32[$name>>2] = 0;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 34|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 2;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $51 = 1272;
  STACKTOP = sp;return ($51|0);
 }
 $6 = HEAP32[$1>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 6|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 L4: do {
  if ($10) {
   label = 7;
  } else {
   $11 = $9&255;
   $i$02$i = 0;
   while(1) {
    $12 = (((($7)) + 16|0) + ($i$02$i<<2)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($o|0);
    if ($15) {
     $i$02$i$lcssa = $i$02$i;
     break;
    }
    $16 = (($i$02$i) + 1)|0;
    $17 = ($16|0)<($11|0);
    if ($17) {
     $i$02$i = $16;
    } else {
     label = 7;
     break L4;
    }
   }
   $18 = ((($7)) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $$idx$i = ((($19)) + 64|0);
   $$idx$val$i = HEAP32[$$idx$i>>2]|0;
   $20 = (($$idx$val$i) + ($i$02$i$lcssa<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0|0);
   $23 = ((($21)) + 24|0);
   $$0$i$i = $22 ? 1264 : $23;
   HEAP32[$name>>2] = $$0$i$i;
   $49 = $$0$i$i;$kind$03 = 1440;
  }
 } while(0);
 do {
  if ((label|0) == 7) {
   $24 = ((($1)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $o;
   $27 = $25;
   $28 = (($26) - ($27))|0;
   $29 = ($28|0)>(-16);
   if (!($29)) {
    $51 = 1272;
    STACKTOP = sp;return ($51|0);
   }
   $30 = ((($1)) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $31;
   $33 = (($32) - ($27))|0;
   $34 = ($28|0)<($33|0);
   if (!($34)) {
    $51 = 1272;
    STACKTOP = sp;return ($51|0);
   }
   $35 = ((($7)) + 12|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($1)) + 20|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($36)) + 48|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = $38;
   $42 = $40;
   $43 = (($41) - ($42))|0;
   $44 = $43 >> 2;
   $45 = (($44) + -1)|0;
   $46 = $28 >> 4;
   $47 = (_getobjname($36,$45,$46,$name)|0);
   $48 = ($47|0)==(0|0);
   if ($48) {
    $51 = 1272;
    STACKTOP = sp;return ($51|0);
   } else {
    $$pre = HEAP32[$name>>2]|0;
    $49 = $$pre;$kind$03 = $47;
    break;
   }
  }
 } while(0);
 HEAP32[$vararg_buffer>>2] = $kind$03;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $49;
 $50 = (_luaO_pushfstring($L,1448,$vararg_buffer)|0);
 $51 = $50;
 STACKTOP = sp;return ($51|0);
}
function _luaD_throw($L,$errcode) {
 $L = $L|0;
 $errcode = $errcode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 160|0);
  HEAP32[$3>>2] = $errcode;
  $4 = HEAP32[$0>>2]|0;
  $5 = ((($4)) + 4|0);
  _longjmp(($5|0),1);
  // unreachable;
 }
 $6 = ((($L)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $errcode&255;
 $9 = ((($L)) + 6|0);
 HEAP8[$9>>0] = $8;
 $10 = ((($7)) + 136|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ((($11)) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + 16|0);
  HEAP32[$15>>2] = $17;
  $18 = ((($L)) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($19)) + -16|0);
  ;HEAP32[$16>>2]=HEAP32[$20>>2]|0;HEAP32[$16+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$20+12>>2]|0;
  $21 = HEAP32[$10>>2]|0;
  _luaD_throw($21,$errcode);
  // unreachable;
 }
 $22 = ((($7)) + 132|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  _abort();
  // unreachable;
 }
 $25 = ((($L)) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 if ((($errcode|0) == 4)) {
  $27 = ((($7)) + 144|0);
  $28 = HEAP32[$27>>2]|0;
  HEAP32[$26>>2] = $28;
  $29 = ((($28)) + 4|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = $31 | 64;
  $33 = ((($26)) + 8|0);
  HEAP32[$33>>2] = $32;
 } else if ((($errcode|0) == 6)) {
  $34 = (_luaS_newlstr($L,1504,23)|0);
  HEAP32[$26>>2] = $34;
  $35 = ((($34)) + 4|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = $37 | 64;
  $39 = ((($26)) + 8|0);
  HEAP32[$39>>2] = $38;
 } else {
  $40 = ((($26)) + -16|0);
  ;HEAP32[$26>>2]=HEAP32[$40>>2]|0;HEAP32[$26+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$40+12>>2]|0;
 }
 $41 = ((($26)) + 16|0);
 HEAP32[$25>>2] = $41;
 $42 = ((($L)) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ((($43)) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45>>>0)<($41>>>0);
 if ($46) {
  HEAP32[$44>>2] = $41;
 }
 $47 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_ii[$47 & 15]($L)|0);
 _abort();
 // unreachable;
}
function _luaD_rawrunprotected($L,$f,$ud) {
 $L = $L|0;
 $f = $f|0;
 $ud = $ud|0;
 var $$reg2mem22$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond = 0, $cond1 = 0, $lj = 0, _setjmpTable = 0;
 var _setjmpTableSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 _setjmpTableSize = 4;_setjmpTable = _malloc(40) | 0;HEAP32[_setjmpTable>>2]=0;
 $lj = sp;
 $0 = ((($L)) + 106|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ((($lj)) + 160|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($L)) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$lj>>2] = $4;
 HEAP32[$3>>2] = $lj;
 $5 = ((($lj)) + 4|0);
 _setjmpTable = _saveSetjmp($5,1,_setjmpTable|0,_setjmpTableSize|0)|0;_setjmpTableSize = tempRet0;
 __THREW__ = 0;
 $6 = __THREW__; __THREW__ = 0;
 if ((($6|0) != 0) & ((threwValue|0) != 0)) { $7 = _testSetjmp(HEAP32[$6>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($7|0) == 0) { _longjmp($6|0, threwValue|0); } tempRet0 = (threwValue); } else { $7 = -1; };
 $8 = tempRet0;
 $cond = ($7|0)==(1);
 if ($cond) {
  $$reg2mem22$0 = $8;
 } else {
  $$reg2mem22$0 = 0;
 }
 while(1) {
  $9 = ($$reg2mem22$0|0)==(0);
  if (!($9)) {
   label = 6;
   break;
  }
  __THREW__ = 0;
  invoke_vii($f|0,($L|0),($ud|0));
  $10 = __THREW__; __THREW__ = 0;
  if ((($10|0) != 0) & ((threwValue|0) != 0)) { $11 = _testSetjmp(HEAP32[$10>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($11|0) == 0) { _longjmp($10|0, threwValue|0); } tempRet0 = (threwValue); } else { $11 = -1; };
  $12 = tempRet0;
  $cond1 = ($11|0)==(1);
  if ($cond1) {
   $$reg2mem22$0 = $12;
  } else {
   break;
  }
 }
 if ((label|0) == 6) {
  $13 = HEAP32[$lj>>2]|0;
  HEAP32[$3>>2] = $13;
  HEAP16[$0>>1] = $1;
  $14 = HEAP32[$2>>2]|0;
  _free(_setjmpTable|0);
  STACKTOP = sp;return ($14|0);
 }
 $13 = HEAP32[$lj>>2]|0;
 HEAP32[$3>>2] = $13;
 HEAP16[$0>>1] = $1;
 $14 = HEAP32[$2>>2]|0;
 _free(_setjmpTable|0);
 STACKTOP = sp;return ($14|0);
}
function _luaD_reallocstack($L,$newsize) {
 $L = $L|0;
 $newsize = $newsize|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$0$i = 0, $ci$01$i = 0, $ci$02$i = 0, $exitcond = 0;
 var $lim$01 = 0, $up$0$i = 0, $up$03$i = 0, $up$04$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($newsize) + 1)|0;
 $5 = ($4>>>0)>(268435455);
 if ($5) {
  _luaM_toobig($L);
  // unreachable;
 }
 $6 = $3 << 4;
 $7 = $newsize << 4;
 $8 = (_luaM_realloc_($L,$1,$6,$7)|0);
 HEAP32[$0>>2] = $8;
 $9 = ($3|0)<($newsize|0);
 if ($9) {
  $lim$01 = $3;
  while(1) {
   $10 = (((($8) + ($lim$01<<4)|0)) + 8|0);
   HEAP32[$10>>2] = 0;
   $11 = (($lim$01) + 1)|0;
   $exitcond = ($11|0)==($newsize|0);
   if ($exitcond) {
    break;
   } else {
    $lim$01 = $11;
   }
  }
 }
 HEAP32[$2>>2] = $newsize;
 $$sum = (($newsize) + -5)|0;
 $12 = (($8) + ($$sum<<4)|0);
 $13 = ((($L)) + 24|0);
 HEAP32[$13>>2] = $12;
 $14 = ((($L)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = $1;
 $18 = (($16) - ($17))|0;
 $19 = $18 >> 4;
 $20 = (($8) + ($19<<4)|0);
 HEAP32[$14>>2] = $20;
 $21 = ((($L)) + 32|0);
 $up$03$i = HEAP32[$21>>2]|0;
 $22 = ($up$03$i|0)==(0|0);
 if (!($22)) {
  $up$04$i = $up$03$i;
  while(1) {
   $23 = HEAP32[$up$04$i>>2]|0;
   $24 = $23;
   $25 = (($24) - ($17))|0;
   $26 = $25 >> 4;
   $27 = (($8) + ($26<<4)|0);
   HEAP32[$up$04$i>>2] = $27;
   $28 = ((($up$04$i)) + 8|0);
   $up$0$i = HEAP32[$28>>2]|0;
   $29 = ($up$0$i|0)==(0|0);
   if ($29) {
    break;
   } else {
    $up$04$i = $up$0$i;
   }
  }
 }
 $30 = ((($L)) + 16|0);
 $ci$01$i = HEAP32[$30>>2]|0;
 $31 = ($ci$01$i|0)==(0|0);
 if ($31) {
  return;
 } else {
  $ci$02$i = $ci$01$i;
 }
 while(1) {
  $32 = ((($ci$02$i)) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33;
  $35 = (($34) - ($17))|0;
  $36 = $35 >> 4;
  $37 = (($8) + ($36<<4)|0);
  HEAP32[$32>>2] = $37;
  $38 = HEAP32[$ci$02$i>>2]|0;
  $39 = $38;
  $40 = (($39) - ($17))|0;
  $41 = $40 >> 4;
  $42 = (($8) + ($41<<4)|0);
  HEAP32[$ci$02$i>>2] = $42;
  $43 = ((($ci$02$i)) + 34|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44 & 2;
  $46 = ($45<<24>>24)==(0);
  if (!($46)) {
   $47 = ((($ci$02$i)) + 16|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = $48;
   $50 = (($49) - ($17))|0;
   $51 = $50 >> 4;
   $52 = (($8) + ($51<<4)|0);
   HEAP32[$47>>2] = $52;
  }
  $53 = ((($ci$02$i)) + 8|0);
  $ci$0$i = HEAP32[$53>>2]|0;
  $54 = ($ci$0$i|0)==(0|0);
  if ($54) {
   break;
  } else {
   $ci$02$i = $ci$0$i;
  }
 }
 return;
}
function _luaD_growstack($L,$n) {
 $L = $L|0;
 $n = $n|0;
 var $$ = 0, $$$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($L)) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(1000000);
 if ($2) {
  _luaD_throw($L,6);
  // unreachable;
 }
 $3 = ((($L)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($L)) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 4;
 $11 = (($n) + 5)|0;
 $12 = (($11) + ($10))|0;
 $13 = $1 << 1;
 $14 = ($13|0)>(1000000);
 $$ = $14 ? 1000000 : $13;
 $15 = ($$|0)<($12|0);
 $$$ = $15 ? $12 : $$;
 $16 = ($$$|0)>(1000000);
 if ($16) {
  _luaD_reallocstack($L,1000200);
  _luaG_runerror($L,1528,$vararg_buffer);
  // unreachable;
 } else {
  _luaD_reallocstack($L,$$$);
  STACKTOP = sp;return;
 }
}
function _luaD_shrinkstack($L) {
 $L = $L|0;
 var $$ = 0, $$lim$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$0$i = 0, $ci$01$i = 0, $ci$03$i = 0, $lim$0$lcssa$i = 0, $lim$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 16|0);
 $ci$01$i = HEAP32[$2>>2]|0;
 $3 = ($ci$01$i|0)==(0|0);
 if ($3) {
  $lim$0$lcssa$i = $1;
 } else {
  $ci$03$i = $ci$01$i;$lim$02$i = $1;
  while(1) {
   $4 = ((($ci$03$i)) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($lim$02$i>>>0)<($5>>>0);
   $$lim$0$i = $6 ? $5 : $lim$02$i;
   $7 = ((($ci$03$i)) + 8|0);
   $ci$0$i = HEAP32[$7>>2]|0;
   $8 = ($ci$0$i|0)==(0|0);
   if ($8) {
    $lim$0$lcssa$i = $$lim$0$i;
    break;
   } else {
    $ci$03$i = $ci$0$i;$lim$02$i = $$lim$0$i;
   }
  }
 }
 $9 = ((($L)) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $lim$0$lcssa$i;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 4;
 $15 = (($14) + 1)|0;
 $16 = (($15|0) / 8)&-1;
 $17 = (($16) + 10)|0;
 $18 = (($17) + ($15))|0;
 $19 = ($18|0)>(1000000);
 $$ = $19 ? 1000000 : $18;
 $20 = ((($L)) + 92|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)>(1000000);
 if ($22) {
  _luaE_freeCI($L);
 } else {
  _luaE_shrinkCI($L);
 }
 $23 = ($13|0)>(15999984);
 if ($23) {
  return;
 }
 $24 = HEAP32[$20>>2]|0;
 $25 = ($$|0)<($24|0);
 if (!($25)) {
  return;
 }
 _luaD_reallocstack($L,$$);
 return;
}
function _luaD_hook($L,$event,$line) {
 $L = $L|0;
 $event = $event|0;
 $line = $line|0;
 var $$$$i = 0, $$$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ar = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $ar = sp + 4|0;
 $0 = ((($L)) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = ((($L)) + 109|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ((($L)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($L)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($L)) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $9;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = ((($7)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16;
 $18 = (($17) - ($13))|0;
 HEAP32[$ar>>2] = $event;
 $19 = ((($ar)) + 20|0);
 HEAP32[$19>>2] = $line;
 $20 = ((($ar)) + 96|0);
 HEAP32[$20>>2] = $7;
 $21 = ((($L)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22;
 $24 = $9;
 $25 = (($23) - ($24))|0;
 $26 = ($25|0)<(336);
 do {
  if ($26) {
   $27 = ((($L)) + 92|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)>(1000000);
   if ($29) {
    _luaD_throw($L,6);
    // unreachable;
   }
   $30 = $11;
   $31 = (($24) - ($30))|0;
   $32 = $31 >> 4;
   $33 = (($32) + 25)|0;
   $34 = $28 << 1;
   $35 = ($34|0)>(1000000);
   $$$i = $35 ? 1000000 : $34;
   $36 = ($$$i|0)<($33|0);
   $$$$i = $36 ? $33 : $$$i;
   $37 = ($$$$i|0)>(1000000);
   if ($37) {
    _luaD_reallocstack($L,1000200);
    _luaG_runerror($L,1528,$vararg_buffer);
    // unreachable;
   } else {
    _luaD_reallocstack($L,$$$$i);
    $$pre = HEAP32[$8>>2]|0;
    $39 = $$pre;
    break;
   }
  } else {
   $39 = $9;
  }
 } while(0);
 $38 = ((($39)) + 320|0);
 HEAP32[$15>>2] = $38;
 HEAP8[$3>>0] = 0;
 $40 = ((($7)) + 34|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = $41&255;
 $43 = $42 | 4;
 $44 = $43&255;
 HEAP8[$40>>0] = $44;
 FUNCTION_TABLE_vii[$1 & 15]($L,$ar);
 HEAP8[$3>>0] = 1;
 $45 = HEAP32[$10>>2]|0;
 $46 = (($45) + ($18)|0);
 HEAP32[$15>>2] = $46;
 $47 = (($45) + ($14)|0);
 HEAP32[$8>>2] = $47;
 $48 = HEAP8[$40>>0]|0;
 $49 = $48&255;
 $50 = $49 & 251;
 $51 = $50&255;
 HEAP8[$40>>0] = $51;
 STACKTOP = sp;return;
}
function _luaD_precall($L,$func,$nresults) {
 $L = $L|0;
 $func = $func|0;
 $nresults = $nresults|0;
 var $$$$i = 0, $$$$i$i = 0, $$$$i10 = 0, $$$$i4 = 0, $$$i = 0, $$$i$i = 0, $$$i3 = 0, $$$i9 = 0, $$0 = 0, $$0$i = 0, $$01$in = 0, $$1$i = 0, $$25$i = 0, $$idx2$val = 0, $$lcssa158 = 0, $$lcssa159 = 0, $$lcssa160 = 0, $$lcssa166 = 0, $$lcssa170 = 0, $$lcssa171 = 0;
 var $$lcssa172 = 0, $$lcssa176 = 0, $$phi$trans$insert$i = 0, $$pn = 0, $$pre = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$i6 = 0, $$pre3$i = 0, $$promoted = 0, $$sum = 0, $$sum$i = 0, $$sum$i47 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $base$0 = 0;
 var $exitcond$i = 0, $exitcond$i48 = 0, $f$0 = 0, $f$0$in = 0, $func$tr = 0, $func$tr$lcssa = 0, $func$tr$lcssa153 = 0, $func$tr$lcssa154 = 0, $hook$0$i = 0, $i$03$i = 0, $i$03$i$lcssa = 0, $i$11$i = 0, $n$0$lcssa = 0, $n$049 = 0, $p$01$i = 0, $res$04$i = 0, $res$04$i$lcssa = 0, $res$1$lcssa$i = 0, $res$12$i = 0, $scevgep = 0;
 var $scevgep$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ((($L)) + 28|0);
 $1 = ((($L)) + 24|0);
 $2 = ((($L)) + 8|0);
 $3 = ((($L)) + 92|0);
 $func$tr = $func;
 while(1) {
  $4 = HEAP32[$0>>2]|0;
  $5 = $func$tr;
  $6 = $4;
  $7 = (($5) - ($6))|0;
  $8 = ((($func$tr)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & 63;
  if ((($10|0) == 38)) {
   $$lcssa159 = $4;$$lcssa171 = $7;$func$tr$lcssa153 = $func$tr;
   label = 4;
   break;
  } else if ((($10|0) == 6)) {
   $$lcssa160 = $4;$$lcssa166 = $5;$$lcssa172 = $7;$func$tr$lcssa154 = $func$tr;
   label = 30;
   break;
  } else if ((($10|0) == 22)) {
   $$lcssa158 = $4;$$lcssa170 = $7;$func$tr$lcssa = $func$tr;
   label = 3;
   break;
  }
  $217 = HEAP32[$1>>2]|0;
  $218 = HEAP32[$2>>2]|0;
  $219 = $217;
  $220 = $218;
  $221 = (($219) - ($220))|0;
  $222 = ($221|0)<(32);
  if ($222) {
   $223 = HEAP32[$3>>2]|0;
   $224 = ($223|0)>(1000000);
   if ($224) {
    label = 63;
    break;
   }
   $225 = $4;
   $226 = (($220) - ($225))|0;
   $227 = $226 >> 4;
   $228 = (($227) + 6)|0;
   $229 = $223 << 1;
   $230 = ($229|0)>(1000000);
   $$$i9 = $230 ? 1000000 : $229;
   $231 = ($$$i9|0)<($228|0);
   $$$$i10 = $231 ? $228 : $$$i9;
   $232 = ($$$$i10|0)>(1000000);
   if ($232) {
    label = 65;
    break;
   }
   _luaD_reallocstack($L,$$$$i10);
   $$pre = HEAP32[$0>>2]|0;
   $234 = $$pre;
  } else {
   $234 = $4;
  }
  $233 = (($234) + ($7)|0);
  $235 = (_luaT_gettmbyobj($L,$233,23)|0);
  $236 = ((($235)) + 8|0);
  $237 = HEAP32[$236>>2]|0;
  $238 = $237 & 15;
  $239 = ($238|0)==(6);
  if (!($239)) {
   $$lcssa176 = $233;
   label = 68;
   break;
  }
  $240 = HEAP32[$2>>2]|0;
  $241 = ($240>>>0)>($233>>>0);
  if ($241) {
   $p$01$i = $240;
   while(1) {
    $242 = ((($p$01$i)) + -16|0);
    ;HEAP32[$p$01$i>>2]=HEAP32[$242>>2]|0;HEAP32[$p$01$i+4>>2]=HEAP32[$242+4>>2]|0;HEAP32[$p$01$i+8>>2]=HEAP32[$242+8>>2]|0;HEAP32[$p$01$i+12>>2]=HEAP32[$242+12>>2]|0;
    $243 = ($242>>>0)>($233>>>0);
    if ($243) {
     $p$01$i = $242;
    } else {
     break;
    }
   }
   $$pre$i13 = HEAP32[$2>>2]|0;
   $245 = $$pre$i13;
  } else {
   $245 = $240;
  }
  $244 = ((($245)) + 16|0);
  HEAP32[$2>>2] = $244;
  ;HEAP32[$233>>2]=HEAP32[$235>>2]|0;HEAP32[$233+4>>2]=HEAP32[$235+4>>2]|0;HEAP32[$233+8>>2]=HEAP32[$235+8>>2]|0;HEAP32[$233+12>>2]=HEAP32[$235+12>>2]|0;
  $func$tr = $233;
 }
 if ((label|0) == 3) {
  $22 = $$lcssa158;$41 = $$lcssa170;$f$0$in = $func$tr$lcssa;
 }
 else if ((label|0) == 4) {
  $11 = HEAP32[$func$tr$lcssa153>>2]|0;
  $12 = ((($11)) + 12|0);
  $22 = $$lcssa159;$41 = $$lcssa171;$f$0$in = $12;
 }
 else if ((label|0) == 30) {
  $95 = HEAP32[$func$tr$lcssa154>>2]|0;
  $96 = ((($95)) + 12|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = HEAP32[$2>>2]|0;
  $99 = $98;
  $100 = (($99) - ($$lcssa166))|0;
  $101 = $100 >> 4;
  $102 = (($101) + -1)|0;
  $103 = HEAP32[$1>>2]|0;
  $104 = $103;
  $105 = (($104) - ($99))|0;
  $106 = $105 >> 4;
  $107 = ((($97)) + 8|0);
  $108 = HEAP8[$107>>0]|0;
  $109 = $108&255;
  $110 = ($106|0)>($109|0);
  do {
   if (!($110)) {
    $111 = HEAP32[$3>>2]|0;
    $112 = ($111|0)>(1000000);
    if ($112) {
     _luaD_throw($L,6);
     // unreachable;
    }
    $113 = $$lcssa160;
    $114 = (($99) - ($113))|0;
    $115 = $114 >> 4;
    $116 = (($109) + 5)|0;
    $117 = (($116) + ($115))|0;
    $118 = $111 << 1;
    $119 = ($118|0)>(1000000);
    $$$i3 = $119 ? 1000000 : $118;
    $120 = ($$$i3|0)<($117|0);
    $$$$i4 = $120 ? $117 : $$$i3;
    $121 = ($$$$i4|0)>(1000000);
    if ($121) {
     _luaD_reallocstack($L,1000200);
     _luaG_runerror($L,1528,$vararg_buffer1);
     // unreachable;
    } else {
     _luaD_reallocstack($L,$$$$i4);
     break;
    }
   }
  } while(0);
  $122 = ((($97)) + 6|0);
  $123 = HEAP8[$122>>0]|0;
  $124 = $123&255;
  $125 = ($101|0)>($124|0);
  if ($125) {
   $n$0$lcssa = $102;
  } else {
   $$promoted = HEAP32[$2>>2]|0;
   $126 = (($124) + 1)|0;
   $127 = (($126) - ($101))|0;
   $129 = $$promoted;$n$049 = $102;
   while(1) {
    $128 = ((($129)) + 16|0);
    $130 = ((($129)) + 8|0);
    HEAP32[$130>>2] = 0;
    $131 = (($n$049) + 1)|0;
    $132 = ($131|0)<($124|0);
    if ($132) {
     $129 = $128;$n$049 = $131;
    } else {
     break;
    }
   }
   $scevgep = (($$promoted) + ($127<<4)|0);
   HEAP32[$2>>2] = $scevgep;
   $n$0$lcssa = $124;
  }
  $133 = ((($97)) + 7|0);
  $134 = HEAP8[$133>>0]|0;
  $135 = ($134<<24>>24)==(0);
  if ($135) {
   $136 = HEAP32[$0>>2]|0;
   $$sum = (($$lcssa172) + 16)|0;
   $137 = (($136) + ($$sum)|0);
   $$pn = $136;$base$0 = $137;
  } else {
   $$idx2$val = HEAP8[$107>>0]|0;
   $138 = HEAP32[$1>>2]|0;
   $139 = HEAP32[$2>>2]|0;
   $140 = $138;
   $141 = $139;
   $142 = (($140) - ($141))|0;
   $143 = $142 >> 4;
   $144 = $$idx2$val&255;
   $145 = ($143|0)>($144|0);
   do {
    if ($145) {
     $160 = $139;
    } else {
     $146 = HEAP32[$3>>2]|0;
     $147 = ($146|0)>(1000000);
     if ($147) {
      _luaD_throw($L,6);
      // unreachable;
     }
     $148 = HEAP32[$0>>2]|0;
     $149 = $148;
     $150 = (($141) - ($149))|0;
     $151 = $150 >> 4;
     $152 = (($144) + 5)|0;
     $153 = (($152) + ($151))|0;
     $154 = $146 << 1;
     $155 = ($154|0)>(1000000);
     $$$i$i = $155 ? 1000000 : $154;
     $156 = ($$$i$i|0)<($153|0);
     $$$$i$i = $156 ? $153 : $$$i$i;
     $157 = ($$$$i$i|0)>(1000000);
     if ($157) {
      _luaD_reallocstack($L,1000200);
      _luaG_runerror($L,1528,$vararg_buffer3);
      // unreachable;
     } else {
      _luaD_reallocstack($L,$$$$i$i);
      $$pre$i6 = HEAP32[$2>>2]|0;
      $160 = $$pre$i6;
      break;
     }
    }
   } while(0);
   $158 = ($123<<24>>24)==(0);
   if (!($158)) {
    $159 = ((($160)) + 16|0);
    HEAP32[$2>>2] = $159;
    $$sum$i47 = (0 - ($n$0$lcssa))|0;
    $161 = (($160) + ($$sum$i47<<4)|0);
    ;HEAP32[$160>>2]=HEAP32[$161>>2]|0;HEAP32[$160+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$160+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$160+12>>2]=HEAP32[$161+12>>2]|0;
    $162 = (((($160) + ($$sum$i47<<4)|0)) + 8|0);
    HEAP32[$162>>2] = 0;
    $exitcond$i48 = ($123<<24>>24)==(1);
    if (!($exitcond$i48)) {
     $164 = 1;
     while(1) {
      $$pre3$i = HEAP32[$2>>2]|0;
      $163 = ((($$pre3$i)) + 16|0);
      HEAP32[$2>>2] = $163;
      $$sum$i = (($164) - ($n$0$lcssa))|0;
      $165 = (($160) + ($$sum$i<<4)|0);
      ;HEAP32[$$pre3$i>>2]=HEAP32[$165>>2]|0;HEAP32[$$pre3$i+4>>2]=HEAP32[$165+4>>2]|0;HEAP32[$$pre3$i+8>>2]=HEAP32[$165+8>>2]|0;HEAP32[$$pre3$i+12>>2]=HEAP32[$165+12>>2]|0;
      $166 = (((($160) + ($$sum$i<<4)|0)) + 8|0);
      HEAP32[$166>>2] = 0;
      $167 = (($164) + 1)|0;
      $exitcond$i = ($167|0)==($124|0);
      if ($exitcond$i) {
       break;
      } else {
       $164 = $167;
      }
     }
    }
   }
   $168 = HEAP32[$0>>2]|0;
   $$pn = $168;$base$0 = $160;
  }
  $$01$in = (($$pn) + ($$lcssa172)|0);
  $169 = ((($L)) + 16|0);
  $170 = HEAP32[$169>>2]|0;
  $171 = ((($170)) + 12|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = ($172|0)==(0|0);
  if ($173) {
   $174 = (_luaE_extendCI($L)|0);
   $175 = $174;
  } else {
   $175 = $172;
  }
  HEAP32[$169>>2] = $175;
  $176 = $nresults&65535;
  $177 = ((($175)) + 32|0);
  HEAP16[$177>>1] = $176;
  HEAP32[$175>>2] = $$01$in;
  $178 = ((($175)) + 16|0);
  HEAP32[$178>>2] = $base$0;
  $179 = HEAP8[$107>>0]|0;
  $180 = $179&255;
  $181 = (($base$0) + ($180<<4)|0);
  $182 = ((($175)) + 4|0);
  HEAP32[$182>>2] = $181;
  $183 = ((($97)) + 48|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ((($175)) + 20|0);
  HEAP32[$185>>2] = $184;
  $186 = ((($175)) + 34|0);
  HEAP8[$186>>0] = 2;
  $187 = $181;
  HEAP32[$2>>2] = $187;
  $188 = ((($L)) + 12|0);
  $189 = HEAP32[$188>>2]|0;
  $190 = ((($189)) + 12|0);
  $191 = HEAP32[$190>>2]|0;
  $192 = ($191|0)>(0);
  if ($192) {
   _luaC_step($L);
  }
  $193 = ((($L)) + 108|0);
  $194 = HEAP8[$193>>0]|0;
  $195 = $194 & 1;
  $196 = ($195<<24>>24)==(0);
  if ($196) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $197 = HEAP32[$185>>2]|0;
  $198 = ((($197)) + 4|0);
  HEAP32[$185>>2] = $198;
  $199 = ((($175)) + 8|0);
  $200 = HEAP32[$199>>2]|0;
  $201 = ((($200)) + 34|0);
  $202 = HEAP8[$201>>0]|0;
  $203 = $202 & 2;
  $204 = ($203<<24>>24)==(0);
  if ($204) {
   $hook$0$i = 0;
  } else {
   $205 = ((($200)) + 20|0);
   $206 = HEAP32[$205>>2]|0;
   $207 = ((($206)) + -4|0);
   $208 = HEAP32[$207>>2]|0;
   $209 = $208 & 63;
   $210 = ($209|0)==(37);
   if ($210) {
    $211 = HEAP8[$186>>0]|0;
    $212 = $211&255;
    $213 = $212 | 32;
    $214 = $213&255;
    HEAP8[$186>>0] = $214;
    $hook$0$i = 4;
   } else {
    $hook$0$i = 0;
   }
  }
  _luaD_hook($L,$hook$0$i,-1);
  $215 = HEAP32[$185>>2]|0;
  $216 = ((($215)) + -4|0);
  HEAP32[$185>>2] = $216;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 63) {
  _luaD_throw($L,6);
  // unreachable;
 }
 else if ((label|0) == 65) {
  _luaD_reallocstack($L,1000200);
  _luaG_runerror($L,1528,$vararg_buffer5);
  // unreachable;
 }
 else if ((label|0) == 68) {
  _luaG_typeerror($L,$$lcssa176,1544);
  // unreachable;
 }
 $f$0 = HEAP32[$f$0$in>>2]|0;
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$2>>2]|0;
 $15 = $13;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = ($17|0)<(336);
 do {
  if ($18) {
   $19 = HEAP32[$3>>2]|0;
   $20 = ($19|0)>(1000000);
   if ($20) {
    _luaD_throw($L,6);
    // unreachable;
   }
   $21 = $22;
   $23 = (($16) - ($21))|0;
   $24 = $23 >> 4;
   $25 = (($24) + 25)|0;
   $26 = $19 << 1;
   $27 = ($26|0)>(1000000);
   $$$i = $27 ? 1000000 : $26;
   $28 = ($$$i|0)<($25|0);
   $$$$i = $28 ? $25 : $$$i;
   $29 = ($$$$i|0)>(1000000);
   if ($29) {
    _luaD_reallocstack($L,1000200);
    _luaG_runerror($L,1528,$vararg_buffer);
    // unreachable;
   } else {
    _luaD_reallocstack($L,$$$$i);
    break;
   }
  }
 } while(0);
 $30 = ((($L)) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31)) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  $35 = (_luaE_extendCI($L)|0);
  $36 = $35;
 } else {
  $36 = $33;
 }
 HEAP32[$30>>2] = $36;
 $37 = $nresults&65535;
 $38 = ((($36)) + 32|0);
 HEAP16[$38>>1] = $37;
 $39 = HEAP32[$0>>2]|0;
 $40 = (($39) + ($41)|0);
 HEAP32[$36>>2] = $40;
 $42 = HEAP32[$2>>2]|0;
 $43 = ((($42)) + 320|0);
 $44 = ((($36)) + 4|0);
 HEAP32[$44>>2] = $43;
 $45 = ((($36)) + 34|0);
 HEAP8[$45>>0] = 0;
 $46 = ((($L)) + 12|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($47)) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)>(0);
 if ($50) {
  _luaC_step($L);
 }
 $51 = ((($L)) + 108|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = $52 & 1;
 $54 = ($53<<24>>24)==(0);
 if (!($54)) {
  _luaD_hook($L,0,-1);
 }
 $55 = (FUNCTION_TABLE_ii[$f$0 & 15]($L)|0);
 $56 = HEAP32[$2>>2]|0;
 $57 = (0 - ($55))|0;
 $58 = (($56) + ($57<<4)|0);
 $59 = HEAP32[$30>>2]|0;
 $60 = HEAP8[$51>>0]|0;
 $61 = $60&255;
 $62 = $61 & 6;
 $63 = ($62|0)==(0);
 if ($63) {
  $$phi$trans$insert$i = ((($59)) + 8|0);
  $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
  $$1$i = $58;$81 = $$pre$i;
 } else {
  $64 = $61 & 2;
  $65 = ($64|0)==(0);
  if ($65) {
   $$0$i = $58;
  } else {
   $66 = HEAP32[$0>>2]|0;
   $67 = $58;
   $68 = $66;
   $69 = (($67) - ($68))|0;
   _luaD_hook($L,1,-1);
   $70 = HEAP32[$0>>2]|0;
   $71 = (($70) + ($69)|0);
   $$0$i = $71;
  }
  $72 = ((($59)) + 8|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ((($73)) + 20|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ((($L)) + 20|0);
  HEAP32[$76>>2] = $75;
  $77 = $73;
  $$1$i = $$0$i;$81 = $77;
 }
 $78 = HEAP32[$59>>2]|0;
 $79 = ((($59)) + 32|0);
 $80 = HEAP16[$79>>1]|0;
 HEAP32[$30>>2] = $81;
 $82 = ($80<<16>>16)==(0);
 L95: do {
  if ($82) {
   $res$1$lcssa$i = $78;
  } else {
   $83 = $80 << 16 >> 16;
   $$25$i = $$1$i;$i$03$i = $83;$res$04$i = $78;
   while(1) {
    $85 = HEAP32[$2>>2]|0;
    $86 = ($$25$i>>>0)<($85>>>0);
    if (!($86)) {
     $i$03$i$lcssa = $i$03$i;$res$04$i$lcssa = $res$04$i;
     break;
    }
    $87 = ((($res$04$i)) + 16|0);
    $88 = ((($$25$i)) + 16|0);
    ;HEAP32[$res$04$i>>2]=HEAP32[$$25$i>>2]|0;HEAP32[$res$04$i+4>>2]=HEAP32[$$25$i+4>>2]|0;HEAP32[$res$04$i+8>>2]=HEAP32[$$25$i+8>>2]|0;HEAP32[$res$04$i+12>>2]=HEAP32[$$25$i+12>>2]|0;
    $89 = (($i$03$i) + -1)|0;
    $90 = ($89|0)==(0);
    if ($90) {
     $res$1$lcssa$i = $87;
     break L95;
    } else {
     $$25$i = $88;$i$03$i = $89;$res$04$i = $87;
    }
   }
   $84 = ($i$03$i$lcssa|0)>(0);
   if ($84) {
    $i$11$i = $i$03$i$lcssa;$res$12$i = $res$04$i$lcssa;
    while(1) {
     $91 = (($i$11$i) + -1)|0;
     $92 = ((($res$12$i)) + 16|0);
     $93 = ((($res$12$i)) + 8|0);
     HEAP32[$93>>2] = 0;
     $94 = ($i$11$i|0)>(1);
     if ($94) {
      $i$11$i = $91;$res$12$i = $92;
     } else {
      break;
     }
    }
    $scevgep$i = (($res$04$i$lcssa) + ($i$03$i$lcssa<<4)|0);
    $res$1$lcssa$i = $scevgep$i;
   } else {
    $res$1$lcssa$i = $res$04$i$lcssa;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $res$1$lcssa$i;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _luaD_poscall($L,$firstResult) {
 $L = $L|0;
 $firstResult = $firstResult|0;
 var $$0 = 0, $$1 = 0, $$25 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $i$03$lcssa = 0, $i$11 = 0, $res$04 = 0, $res$04$lcssa = 0, $res$1$lcssa = 0, $res$12 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 108|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 & 6;
 $6 = ($5|0)==(0);
 if ($6) {
  $$phi$trans$insert = ((($1)) + 8|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$1 = $firstResult;$26 = $$pre;
 } else {
  $7 = $4 & 2;
  $8 = ($7|0)==(0);
  if ($8) {
   $$0 = $firstResult;
  } else {
   $9 = ((($L)) + 28|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $firstResult;
   $12 = $10;
   $13 = (($11) - ($12))|0;
   _luaD_hook($L,1,-1);
   $14 = HEAP32[$9>>2]|0;
   $15 = (($14) + ($13)|0);
   $$0 = $15;
  }
  $16 = ((($1)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($17)) + 20|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($L)) + 20|0);
  HEAP32[$20>>2] = $19;
  $21 = $17;
  $$1 = $$0;$26 = $21;
 }
 $22 = HEAP32[$1>>2]|0;
 $23 = ((($1)) + 32|0);
 $24 = HEAP16[$23>>1]|0;
 $25 = $24 << 16 >> 16;
 HEAP32[$0>>2] = $26;
 $27 = ((($L)) + 8|0);
 $28 = ($24<<16>>16)==(0);
 if ($28) {
  $res$1$lcssa = $22;
  HEAP32[$27>>2] = $res$1$lcssa;
  $40 = (($25) + 1)|0;
  return ($40|0);
 } else {
  $$25 = $$1;$i$03 = $25;$res$04 = $22;
 }
 while(1) {
  $30 = HEAP32[$27>>2]|0;
  $31 = ($$25>>>0)<($30>>>0);
  if (!($31)) {
   $i$03$lcssa = $i$03;$res$04$lcssa = $res$04;
   break;
  }
  $32 = ((($res$04)) + 16|0);
  $33 = ((($$25)) + 16|0);
  ;HEAP32[$res$04>>2]=HEAP32[$$25>>2]|0;HEAP32[$res$04+4>>2]=HEAP32[$$25+4>>2]|0;HEAP32[$res$04+8>>2]=HEAP32[$$25+8>>2]|0;HEAP32[$res$04+12>>2]=HEAP32[$$25+12>>2]|0;
  $34 = (($i$03) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   $res$1$lcssa = $32;
   label = 12;
   break;
  } else {
   $$25 = $33;$i$03 = $34;$res$04 = $32;
  }
 }
 if ((label|0) == 12) {
  HEAP32[$27>>2] = $res$1$lcssa;
  $40 = (($25) + 1)|0;
  return ($40|0);
 }
 $29 = ($i$03$lcssa|0)>(0);
 if ($29) {
  $i$11 = $i$03$lcssa;$res$12 = $res$04$lcssa;
 } else {
  $res$1$lcssa = $res$04$lcssa;
  HEAP32[$27>>2] = $res$1$lcssa;
  $40 = (($25) + 1)|0;
  return ($40|0);
 }
 while(1) {
  $36 = (($i$11) + -1)|0;
  $37 = ((($res$12)) + 16|0);
  $38 = ((($res$12)) + 8|0);
  HEAP32[$38>>2] = 0;
  $39 = ($i$11|0)>(1);
  if ($39) {
   $i$11 = $36;$res$12 = $37;
  } else {
   break;
  }
 }
 $scevgep = (($res$04$lcssa) + ($i$03$lcssa<<4)|0);
 $res$1$lcssa = $scevgep;
 HEAP32[$27>>2] = $res$1$lcssa;
 $40 = (($25) + 1)|0;
 return ($40|0);
}
function _luaD_call($L,$func,$nResults,$allowyield) {
 $L = $L|0;
 $func = $func|0;
 $nResults = $nResults|0;
 $allowyield = $allowyield|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($L)) + 106|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($1) + 1)<<16>>16;
 HEAP16[$0>>1] = $2;
 $3 = ($2&65535)>(199);
 if ($3) {
  $4 = ($2<<16>>16)==(200);
  if ($4) {
   _luaG_runerror($L,1552,$vararg_buffer);
   // unreachable;
  }
  $5 = ($2&65535)>(224);
  if ($5) {
   _luaD_throw($L,6);
   // unreachable;
  }
 }
 $6 = ($allowyield|0)!=(0);
 if (!($6)) {
  $7 = ((($L)) + 104|0);
  $8 = HEAP16[$7>>1]|0;
  $9 = (($8) + 1)<<16>>16;
  HEAP16[$7>>1] = $9;
 }
 $10 = (_luaD_precall($L,$func,$nResults)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  _luaV_execute($L);
 }
 if ($6) {
  $15 = HEAP16[$0>>1]|0;
  $16 = (($15) + -1)<<16>>16;
  HEAP16[$0>>1] = $16;
  STACKTOP = sp;return;
 }
 $12 = ((($L)) + 104|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = (($13) + -1)<<16>>16;
 HEAP16[$12>>1] = $14;
 $15 = HEAP16[$0>>1]|0;
 $16 = (($15) + -1)<<16>>16;
 HEAP16[$0>>1] = $16;
 STACKTOP = sp;return;
}
function _luaD_pcall($L,$func,$u,$old_top,$ef) {
 $L = $L|0;
 $func = $func|0;
 $u = $u|0;
 $old_top = $old_top|0;
 $ef = $ef|0;
 var $$$i = 0, $$lim$0$i$i = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $ci$0$i$i = 0, $ci$03$i$i = 0, $lim$0$lcssa$i$i = 0, $lim$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 109|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ((($L)) + 104|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = ((($L)) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$6>>2] = $ef;
 $8 = (_luaD_rawrunprotected($L,$func,$u)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  HEAP32[$6>>2] = $7;
  return ($8|0);
 }
 $10 = ((($L)) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($old_top)|0);
 _luaF_close($L,$12);
 if ((($8|0) == 6)) {
  $22 = (_luaS_newlstr($L,1504,23)|0);
  HEAP32[$12>>2] = $22;
  $23 = ((($22)) + 4|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = $25 | 64;
  $$sum = (($old_top) + 8)|0;
  $27 = (($11) + ($$sum)|0);
  HEAP32[$27>>2] = $26;
 } else if ((($8|0) == 4)) {
  $13 = ((($L)) + 12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($14)) + 144|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$12>>2] = $16;
  $17 = ((($16)) + 4|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = $19 | 64;
  $$sum2 = (($old_top) + 8)|0;
  $21 = (($11) + ($$sum2)|0);
  HEAP32[$21>>2] = $20;
 } else {
  $28 = ((($L)) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ((($29)) + -16|0);
  ;HEAP32[$12>>2]=HEAP32[$30>>2]|0;HEAP32[$12+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$30+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$30+12>>2]|0;
 }
 $$sum1 = (($old_top) + 16)|0;
 $31 = (($11) + ($$sum1)|0);
 $32 = ((($L)) + 8|0);
 HEAP32[$32>>2] = $31;
 HEAP32[$0>>2] = $1;
 HEAP8[$2>>0] = $3;
 HEAP16[$4>>1] = $5;
 $33 = ($1|0)==(0);
 if ($33) {
  $lim$0$lcssa$i$i = $31;
 } else {
  $34 = $1;
  $ci$03$i$i = $34;$lim$02$i$i = $31;
  while(1) {
   $35 = ((($ci$03$i$i)) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($lim$02$i$i>>>0)<($36>>>0);
   $$lim$0$i$i = $37 ? $36 : $lim$02$i$i;
   $38 = ((($ci$03$i$i)) + 8|0);
   $ci$0$i$i = HEAP32[$38>>2]|0;
   $39 = ($ci$0$i$i|0)==(0|0);
   if ($39) {
    $lim$0$lcssa$i$i = $$lim$0$i$i;
    break;
   } else {
    $ci$03$i$i = $ci$0$i$i;$lim$02$i$i = $$lim$0$i$i;
   }
  }
 }
 $40 = HEAP32[$10>>2]|0;
 $41 = $lim$0$lcssa$i$i;
 $42 = $40;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 4;
 $45 = (($44) + 1)|0;
 $46 = (($45|0) / 8)&-1;
 $47 = (($46) + 10)|0;
 $48 = (($47) + ($45))|0;
 $49 = ($48|0)>(1000000);
 $$$i = $49 ? 1000000 : $48;
 $50 = ((($L)) + 92|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)>(1000000);
 if ($52) {
  _luaE_freeCI($L);
 } else {
  _luaE_shrinkCI($L);
 }
 $53 = ($43|0)>(15999984);
 if ($53) {
  HEAP32[$6>>2] = $7;
  return ($8|0);
 }
 $54 = HEAP32[$50>>2]|0;
 $55 = ($$$i|0)<($54|0);
 if (!($55)) {
  HEAP32[$6>>2] = $7;
  return ($8|0);
 }
 _luaD_reallocstack($L,$$$i);
 HEAP32[$6>>2] = $7;
 return ($8|0);
}
function _luaD_protectedparser($L,$z,$name,$mode) {
 $L = $L|0;
 $z = $z|0;
 $name = $name|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $p = sp;
 $0 = ((($L)) + 104|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($1) + 1)<<16>>16;
 HEAP16[$0>>1] = $2;
 HEAP32[$p>>2] = $z;
 $3 = ((($p)) + 56|0);
 HEAP32[$3>>2] = $name;
 $4 = ((($p)) + 52|0);
 HEAP32[$4>>2] = $mode;
 $5 = ((($p)) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($p)) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($p)) + 28|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($p)) + 36|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($p)) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($p)) + 48|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($p)) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($p)) + 12|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($L)) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($L)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $14;
 $18 = $16;
 $19 = (($17) - ($18))|0;
 $20 = ((($L)) + 88|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (_luaD_pcall($L,7,$p,$19,$21)|0);
 $23 = HEAP32[$11>>2]|0;
 $24 = HEAP32[$12>>2]|0;
 $25 = (_luaM_realloc_($L,$23,$24,0)|0);
 HEAP32[$11>>2] = $25;
 HEAP32[$12>>2] = 0;
 $26 = HEAP32[$5>>2]|0;
 $27 = HEAP32[$6>>2]|0;
 $28 = $27 << 1;
 (_luaM_realloc_($L,$26,$28,0)|0);
 $29 = HEAP32[$7>>2]|0;
 $30 = HEAP32[$8>>2]|0;
 $31 = $30 << 4;
 (_luaM_realloc_($L,$29,$31,0)|0);
 $32 = HEAP32[$9>>2]|0;
 $33 = HEAP32[$10>>2]|0;
 $34 = $33 << 4;
 (_luaM_realloc_($L,$32,$34,0)|0);
 $35 = HEAP16[$0>>1]|0;
 $36 = (($35) + -1)<<16>>16;
 HEAP16[$0>>1] = $36;
 STACKTOP = sp;return ($22|0);
}
function _f_parser($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cl$0 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$ud>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 HEAP32[$0>>2] = $2;
 $3 = ($1|0)==(0);
 if ($3) {
  $9 = (_luaZ_fill($0)|0);
  $11 = $9;
 } else {
  $4 = ((($0)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($5)) + 1|0);
  HEAP32[$4>>2] = $6;
  $7 = HEAP8[$5>>0]|0;
  $8 = $7&255;
  $11 = $8;
 }
 $10 = ($11|0)==(27);
 $12 = ((($ud)) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($10) {
  if (!($14)) {
   $15 = (_strchr($13,98)|0);
   $16 = ($15|0)==(0|0);
   if ($16) {
    HEAP32[$vararg_buffer>>2] = 1624;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $13;
    (_luaO_pushfstring($L,1576,$vararg_buffer)|0);
    _luaD_throw($L,3);
    // unreachable;
   }
  }
  $17 = HEAP32[$ud>>2]|0;
  $18 = ((($ud)) + 4|0);
  $19 = ((($ud)) + 56|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (_luaU_undump($L,$17,$18,$20)|0);
  $cl$0 = $21;
  _luaF_initupvals($L,$cl$0);
  STACKTOP = sp;return;
 } else {
  if (!($14)) {
   $22 = (_strchr($13,116)|0);
   $23 = ($22|0)==(0|0);
   if ($23) {
    HEAP32[$vararg_buffer2>>2] = 1632;
    $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
    HEAP32[$vararg_ptr5>>2] = $13;
    (_luaO_pushfstring($L,1576,$vararg_buffer2)|0);
    _luaD_throw($L,3);
    // unreachable;
   }
  }
  $24 = HEAP32[$ud>>2]|0;
  $25 = ((($ud)) + 4|0);
  $26 = ((($ud)) + 16|0);
  $27 = ((($ud)) + 56|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (_luaY_parser($L,$24,$25,$26,$28,$11)|0);
  $cl$0 = $29;
  _luaF_initupvals($L,$cl$0);
  STACKTOP = sp;return;
 }
}
function _luaU_dump($L,$f,$w,$data,$strip) {
 $L = $L|0;
 $f = $f|0;
 $w = $w|0;
 $data = $data|0;
 $strip = $strip|0;
 var $$ph21$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $D = 0, $x$i = 0, $x$i$i = 0, $x$i1$i = 0, $x$i10$i = 0, $x$i12$i = 0, $x$i4$i = 0, $x$i6$i = 0, $x$i8$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i = sp + 43|0;
 $0 = sp + 8|0;
 $1 = sp;
 $x$i12$i = sp + 42|0;
 $x$i10$i = sp + 41|0;
 $x$i8$i = sp + 40|0;
 $x$i6$i = sp + 39|0;
 $x$i4$i = sp + 38|0;
 $x$i1$i = sp + 37|0;
 $x$i$i = sp + 36|0;
 $D = sp + 16|0;
 HEAP32[$D>>2] = $L;
 $2 = ((($D)) + 4|0);
 HEAP32[$2>>2] = $w;
 $3 = ((($D)) + 8|0);
 HEAP32[$3>>2] = $data;
 $4 = ((($D)) + 12|0);
 HEAP32[$4>>2] = $strip;
 $5 = ((($D)) + 16|0);
 $6 = (FUNCTION_TABLE_iiiii[$w & 15]($L,4232,4,$data)|0);
 HEAP32[$5>>2] = $6;
 HEAP8[$x$i$i>>0] = 83;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (FUNCTION_TABLE_iiiii[$w & 15]($L,$x$i$i,1,$data)|0);
  HEAP32[$5>>2] = $8;
  HEAP8[$x$i1$i>>0] = 0;
  $9 = ($8|0)==(0);
  if ($9) {
   $10 = HEAP32[$2>>2]|0;
   $11 = HEAP32[$D>>2]|0;
   $12 = HEAP32[$3>>2]|0;
   $13 = (FUNCTION_TABLE_iiiii[$10 & 15]($11,$x$i1$i,1,$12)|0);
   HEAP32[$5>>2] = $13;
   $14 = ($13|0)==(0);
   if ($14) {
    $15 = HEAP32[$2>>2]|0;
    $16 = HEAP32[$D>>2]|0;
    $17 = HEAP32[$3>>2]|0;
    $18 = (FUNCTION_TABLE_iiiii[$15 & 15]($16,4296,6,$17)|0);
    HEAP32[$5>>2] = $18;
    HEAP8[$x$i4$i>>0] = 4;
    $19 = ($18|0)==(0);
    if ($19) {
     $20 = HEAP32[$2>>2]|0;
     $21 = HEAP32[$D>>2]|0;
     $22 = HEAP32[$3>>2]|0;
     $23 = (FUNCTION_TABLE_iiiii[$20 & 15]($21,$x$i4$i,1,$22)|0);
     HEAP32[$5>>2] = $23;
     HEAP8[$x$i6$i>>0] = 4;
     $24 = ($23|0)==(0);
     if ($24) {
      $25 = HEAP32[$2>>2]|0;
      $26 = HEAP32[$D>>2]|0;
      $27 = HEAP32[$3>>2]|0;
      $28 = (FUNCTION_TABLE_iiiii[$25 & 15]($26,$x$i6$i,1,$27)|0);
      HEAP32[$5>>2] = $28;
      HEAP8[$x$i8$i>>0] = 4;
      $29 = ($28|0)==(0);
      if ($29) {
       $30 = HEAP32[$2>>2]|0;
       $31 = HEAP32[$D>>2]|0;
       $32 = HEAP32[$3>>2]|0;
       $33 = (FUNCTION_TABLE_iiiii[$30 & 15]($31,$x$i8$i,1,$32)|0);
       HEAP32[$5>>2] = $33;
       HEAP8[$x$i10$i>>0] = 8;
       $34 = ($33|0)==(0);
       if ($34) {
        $35 = HEAP32[$2>>2]|0;
        $36 = HEAP32[$D>>2]|0;
        $37 = HEAP32[$3>>2]|0;
        $38 = (FUNCTION_TABLE_iiiii[$35 & 15]($36,$x$i10$i,1,$37)|0);
        HEAP32[$5>>2] = $38;
        HEAP8[$x$i12$i>>0] = 8;
        $39 = ($38|0)==(0);
        if ($39) {
         $44 = HEAP32[$2>>2]|0;
         $45 = HEAP32[$D>>2]|0;
         $46 = HEAP32[$3>>2]|0;
         $47 = (FUNCTION_TABLE_iiiii[$44 & 15]($45,$x$i12$i,1,$46)|0);
         HEAP32[$5>>2] = $47;
         $48 = $1;
         $49 = $48;
         HEAP32[$49>>2] = 22136;
         $50 = (($48) + 4)|0;
         $51 = $50;
         HEAP32[$51>>2] = 0;
         $52 = ($47|0)==(0);
         if ($52) {
          $53 = HEAP32[$2>>2]|0;
          $54 = HEAP32[$D>>2]|0;
          $55 = HEAP32[$3>>2]|0;
          $56 = (FUNCTION_TABLE_iiiii[$53 & 15]($54,$1,8,$55)|0);
          HEAP32[$5>>2] = $56;
          HEAPF64[$0>>3] = 370.5;
          $57 = ($56|0)==(0);
          if ($57) {
           $58 = HEAP32[$2>>2]|0;
           $59 = HEAP32[$D>>2]|0;
           $60 = HEAP32[$3>>2]|0;
           $61 = (FUNCTION_TABLE_iiiii[$58 & 15]($59,$0,8,$60)|0);
           HEAP32[$5>>2] = $61;
           $66 = $61;$80 = $0;
          } else {
           $66 = $56;$80 = $0;
          }
         } else {
          $$ph21$i = $1;$79 = $47;
          label = 18;
         }
        } else {
         $78 = $38;
         label = 16;
        }
       } else {
        $77 = $33;
        label = 14;
       }
      } else {
       $76 = $28;
       label = 12;
      }
     } else {
      $75 = $23;
      label = 10;
     }
    } else {
     $74 = $18;
     label = 8;
    }
   } else {
    $73 = $13;
    label = 6;
   }
  } else {
   $72 = $8;
   label = 4;
  }
 } else {
  HEAP8[$x$i1$i>>0] = 0;
  $72 = $6;
  label = 4;
 }
 if ((label|0) == 4) {
  $73 = $72;
  label = 6;
 }
 if ((label|0) == 6) {
  HEAP8[$x$i4$i>>0] = 4;
  $74 = $73;
  label = 8;
 }
 if ((label|0) == 8) {
  HEAP8[$x$i6$i>>0] = 4;
  $75 = $74;
  label = 10;
 }
 if ((label|0) == 10) {
  HEAP8[$x$i8$i>>0] = 4;
  $76 = $75;
  label = 12;
 }
 if ((label|0) == 12) {
  HEAP8[$x$i10$i>>0] = 8;
  $77 = $76;
  label = 14;
 }
 if ((label|0) == 14) {
  HEAP8[$x$i12$i>>0] = 8;
  $78 = $77;
  label = 16;
 }
 if ((label|0) == 16) {
  $40 = $1;
  $41 = $40;
  HEAP32[$41>>2] = 22136;
  $42 = (($40) + 4)|0;
  $43 = $42;
  HEAP32[$43>>2] = 0;
  $$ph21$i = $1;$79 = $78;
  label = 18;
 }
 if ((label|0) == 18) {
  HEAPF64[$0>>3] = 370.5;
  $66 = $79;$80 = $0;
 }
 $62 = ((($f)) + 12|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = $63&255;
 HEAP8[$x$i>>0] = $64;
 $65 = ($66|0)==(0);
 if (!($65)) {
  _DumpFunction($f,0,$D);
  $71 = HEAP32[$5>>2]|0;
  STACKTOP = sp;return ($71|0);
 }
 $67 = HEAP32[$2>>2]|0;
 $68 = HEAP32[$D>>2]|0;
 $69 = HEAP32[$3>>2]|0;
 $70 = (FUNCTION_TABLE_iiiii[$67 & 15]($68,$x$i,1,$69)|0);
 HEAP32[$5>>2] = $70;
 _DumpFunction($f,0,$D);
 $71 = HEAP32[$5>>2]|0;
 STACKTOP = sp;return ($71|0);
}
function _DumpFunction($f,$psource,$D) {
 $f = $f|0;
 $psource = $psource|0;
 $D = $D|0;
 var $$ph50 = 0, $$pr$i = 0, $$pr$i22 = 0, $$pr30$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i23 = 0, $$pre$i1 = 0, $$pre$i10$i = 0, $$pre$i20 = 0, $$pre$i31 = 0, $$pre$phi49Z2D = 0, $$pre$phiZ2D = 0, $$pre$pre$phiZZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0.0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i26 = 0, $exitcond$i33 = 0, $exitcond35$i = 0, $i$0$i48 = 0, $i$012$i = 0, $i$03$i = 0, $i$032$i = 0, $i$131$i = 0, $size$i = 0, $size$i$i = 0, $size$i$i16 = 0, $size$i9$i = 0, $x$i = 0, $x$i$i = 0, $x$i$i17 = 0, $x$i$i28 = 0, $x$i1$i = 0;
 var $x$i1$i27 = 0, $x$i10 = 0, $x$i15$i = 0, $x$i18$i = 0, $x$i21$i = 0, $x$i24$i = 0, $x$i27$i = 0, $x$i3$i = 0, $x$i36 = 0, $x$i39 = 0, $x$i42 = 0, $x$i45 = 0, $x$i6$i = 0, $x$i7 = 0, $x$i9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i45 = sp + 95|0;
 $x$i42 = sp + 94|0;
 $x$i39 = sp + 93|0;
 $x$i36 = sp + 92|0;
 $0 = sp + 72|0;
 $x$i1$i27 = sp + 91|0;
 $x$i$i28 = sp + 90|0;
 $1 = sp + 68|0;
 $x$i9$i = sp + 89|0;
 $x$i6$i = sp + 88|0;
 $x$i3$i = sp + 87|0;
 $size$i$i16 = sp + 64|0;
 $2 = sp + 8|0;
 $3 = sp;
 $x$i1$i = sp + 86|0;
 $x$i$i17 = sp + 85|0;
 $4 = sp + 60|0;
 $5 = sp + 56|0;
 $x$i10 = sp + 84|0;
 $x$i7 = sp + 83|0;
 $x$i = sp + 82|0;
 $6 = sp + 52|0;
 $7 = sp + 48|0;
 $size$i = sp + 44|0;
 $x$i27$i = sp + 81|0;
 $x$i24$i = sp + 80|0;
 $x$i21$i = sp + 79|0;
 $x$i18$i = sp + 78|0;
 $x$i15$i = sp + 77|0;
 $x$i$i = sp + 76|0;
 $size$i9$i = sp + 40|0;
 $8 = sp + 36|0;
 $9 = sp + 32|0;
 $10 = sp + 28|0;
 $size$i$i = sp + 24|0;
 $11 = sp + 20|0;
 $12 = sp + 16|0;
 $13 = ((($D)) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  $16 = ((($f)) + 72|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==($psource|0);
  if ($18) {
   label = 3;
  } else {
   $28 = ($17|0)==(0|0);
   do {
    if ($28) {
     HEAP8[$x$i39>>0] = 0;
     $29 = ((($D)) + 16|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0);
     if ($31) {
      $32 = ((($D)) + 4|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = HEAP32[$D>>2]|0;
      $35 = ((($D)) + 8|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (FUNCTION_TABLE_iiiii[$33 & 15]($34,$x$i39,1,$36)|0);
      HEAP32[$29>>2] = $37;
      $448 = $37;
     } else {
      $448 = $30;
     }
     $$pre$pre$phiZZ2D = $29;$449 = $448;
    } else {
     $38 = ((($17)) + 12|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($39) + 1)|0;
     HEAP32[$size$i>>2] = $40;
     $41 = ($40>>>0)<(255);
     if ($41) {
      $42 = $40&255;
      HEAP8[$x$i42>>0] = $42;
      $43 = ((($D)) + 16|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==(0);
      if ($45) {
       $46 = ((($D)) + 4|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = HEAP32[$D>>2]|0;
       $49 = ((($D)) + 8|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = (FUNCTION_TABLE_iiiii[$47 & 15]($48,$x$i42,1,$50)|0);
       HEAP32[$43>>2] = $51;
       $450 = $51;
      } else {
       $450 = $44;
      }
      $$pre$phi49Z2D = $43;$69 = $450;$71 = $40;
     } else {
      HEAP8[$x$i45>>0] = -1;
      $52 = ((($D)) + 16|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = ($53|0)==(0);
      if (!($54)) {
       $$pre$pre$phiZZ2D = $52;$449 = $53;
       break;
      }
      $55 = ((($D)) + 4|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$D>>2]|0;
      $58 = ((($D)) + 8|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = (FUNCTION_TABLE_iiiii[$56 & 15]($57,$x$i45,1,$59)|0);
      HEAP32[$52>>2] = $60;
      $61 = ($60|0)==(0);
      if (!($61)) {
       $$pre$pre$phiZZ2D = $52;$449 = $60;
       break;
      }
      $62 = ((($D)) + 4|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = HEAP32[$D>>2]|0;
      $65 = ((($D)) + 8|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = (FUNCTION_TABLE_iiiii[$63 & 15]($64,$size$i,4,$66)|0);
      HEAP32[$52>>2] = $67;
      $$pre$i1 = HEAP32[$size$i>>2]|0;
      $$pre$phi49Z2D = $52;$69 = $67;$71 = $$pre$i1;
     }
     $68 = ($69|0)==(0);
     if ($68) {
      $70 = (($71) + -1)|0;
      $72 = ((($17)) + 24|0);
      $73 = ((($D)) + 4|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = HEAP32[$D>>2]|0;
      $76 = ((($D)) + 8|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (FUNCTION_TABLE_iiiii[$74 & 15]($75,$72,$70,$77)|0);
      HEAP32[$$pre$phi49Z2D>>2] = $78;
      $$pre$pre$phiZZ2D = $$pre$phi49Z2D;$449 = $78;
     } else {
      $$pre$pre$phiZZ2D = $$pre$phi49Z2D;$449 = $69;
     }
    }
   } while(0);
   $$pre$phiZ2D = $$pre$pre$phiZZ2D;$82 = $449;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  HEAP8[$x$i36>>0] = 0;
  $19 = ((($D)) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   $22 = ((($D)) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$D>>2]|0;
   $25 = ((($D)) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (FUNCTION_TABLE_iiiii[$23 & 15]($24,$x$i36,1,$26)|0);
   HEAP32[$19>>2] = $27;
   $447 = $27;
  } else {
   $447 = $20;
  }
  $$pre$phiZ2D = $19;$82 = $447;
 }
 $79 = ((($f)) + 36|0);
 $80 = HEAP32[$79>>2]|0;
 HEAP32[$7>>2] = $80;
 $81 = ($82|0)==(0);
 if ($81) {
  $83 = ((($D)) + 4|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = HEAP32[$D>>2]|0;
  $86 = ((($D)) + 8|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (FUNCTION_TABLE_iiiii[$84 & 15]($85,$7,4,$87)|0);
  HEAP32[$$pre$phiZ2D>>2] = $88;
  $92 = $88;
 } else {
  $92 = $82;
 }
 $89 = ((($f)) + 40|0);
 $90 = HEAP32[$89>>2]|0;
 HEAP32[$6>>2] = $90;
 $91 = ($92|0)==(0);
 if ($91) {
  $93 = ((($D)) + 4|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = HEAP32[$D>>2]|0;
  $96 = ((($D)) + 8|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (FUNCTION_TABLE_iiiii[$94 & 15]($95,$6,4,$97)|0);
  HEAP32[$$pre$phiZ2D>>2] = $98;
  $102 = $98;
 } else {
  $102 = $92;
 }
 $99 = ((($f)) + 6|0);
 $100 = HEAP8[$99>>0]|0;
 HEAP8[$x$i>>0] = $100;
 $101 = ($102|0)==(0);
 if ($101) {
  $103 = ((($D)) + 4|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = HEAP32[$D>>2]|0;
  $106 = ((($D)) + 8|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (FUNCTION_TABLE_iiiii[$104 & 15]($105,$x$i,1,$107)|0);
  HEAP32[$$pre$phiZ2D>>2] = $108;
  $112 = $108;
 } else {
  $112 = $102;
 }
 $109 = ((($f)) + 7|0);
 $110 = HEAP8[$109>>0]|0;
 HEAP8[$x$i7>>0] = $110;
 $111 = ($112|0)==(0);
 if ($111) {
  $113 = ((($D)) + 4|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = HEAP32[$D>>2]|0;
  $116 = ((($D)) + 8|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = (FUNCTION_TABLE_iiiii[$114 & 15]($115,$x$i7,1,$117)|0);
  HEAP32[$$pre$phiZ2D>>2] = $118;
  $122 = $118;
 } else {
  $122 = $112;
 }
 $119 = ((($f)) + 8|0);
 $120 = HEAP8[$119>>0]|0;
 HEAP8[$x$i10>>0] = $120;
 $121 = ($122|0)==(0);
 if ($121) {
  $123 = ((($D)) + 4|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = HEAP32[$D>>2]|0;
  $126 = ((($D)) + 8|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = (FUNCTION_TABLE_iiiii[$124 & 15]($125,$x$i10,1,$127)|0);
  HEAP32[$$pre$phiZ2D>>2] = $128;
  $132 = $128;
 } else {
  $132 = $122;
 }
 $129 = ((($f)) + 20|0);
 $130 = HEAP32[$129>>2]|0;
 HEAP32[$5>>2] = $130;
 $131 = ($132|0)==(0);
 if ($131) {
  $133 = ((($D)) + 4|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = HEAP32[$D>>2]|0;
  $136 = ((($D)) + 8|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = (FUNCTION_TABLE_iiiii[$134 & 15]($135,$5,4,$137)|0);
  HEAP32[$$pre$phiZ2D>>2] = $138;
  $139 = ($138|0)==(0);
  if ($139) {
   $142 = HEAP32[$129>>2]|0;
   $143 = $142 << 2;
   $144 = ((($f)) + 48|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = HEAP32[$133>>2]|0;
   $147 = HEAP32[$D>>2]|0;
   $148 = HEAP32[$136>>2]|0;
   $149 = (FUNCTION_TABLE_iiiii[$146 & 15]($147,$145,$143,$148)|0);
   HEAP32[$$pre$phiZ2D>>2] = $149;
   $150 = ((($f)) + 16|0);
   $151 = HEAP32[$150>>2]|0;
   HEAP32[$4>>2] = $151;
   $152 = ($149|0)==(0);
   if ($152) {
    $153 = ((($D)) + 4|0);
    $154 = HEAP32[$153>>2]|0;
    $155 = HEAP32[$D>>2]|0;
    $156 = ((($D)) + 8|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = (FUNCTION_TABLE_iiiii[$154 & 15]($155,$4,4,$157)|0);
    HEAP32[$$pre$phiZ2D>>2] = $158;
    $160 = $151;$451 = $4;$452 = $158;
   } else {
    $160 = $151;$451 = $4;$452 = $149;
   }
  } else {
   $$ph50 = $138;
   label = 34;
  }
 } else {
  $$ph50 = $132;
  label = 34;
 }
 if ((label|0) == 34) {
  $140 = ((($f)) + 16|0);
  $141 = HEAP32[$140>>2]|0;
  HEAP32[$4>>2] = $141;
  $160 = $141;$451 = $4;$452 = $$ph50;
 }
 $159 = ($160|0)>(0);
 L52: do {
  if ($159) {
   $161 = ((($f)) + 44|0);
   $162 = ((($D)) + 4|0);
   $163 = ((($D)) + 8|0);
   $171 = $452;$i$012$i = 0;
   while(1) {
    $164 = HEAP32[$161>>2]|0;
    $165 = (($164) + ($i$012$i<<4)|0);
    $166 = (((($164) + ($i$012$i<<4)|0)) + 8|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = $167 & 63;
    $169 = $168&255;
    HEAP8[$x$i$i17>>0] = $169;
    $170 = ($171|0)==(0);
    if ($170) {
     $172 = HEAP32[$162>>2]|0;
     $173 = HEAP32[$D>>2]|0;
     $174 = HEAP32[$163>>2]|0;
     $175 = (FUNCTION_TABLE_iiiii[$172 & 15]($173,$x$i$i17,1,$174)|0);
     HEAP32[$$pre$phiZ2D>>2] = $175;
     $$pre$i20 = HEAP32[$166>>2]|0;
     $177 = $$pre$i20;$181 = $175;
    } else {
     $177 = $167;$181 = $171;
    }
    $176 = $177 & 63;
    switch ($176|0) {
    case 19:  {
     $192 = $165;
     $193 = $192;
     $194 = HEAP32[$193>>2]|0;
     $195 = (($192) + 4)|0;
     $196 = $195;
     $197 = HEAP32[$196>>2]|0;
     $198 = $2;
     $199 = $198;
     HEAP32[$199>>2] = $194;
     $200 = (($198) + 4)|0;
     $201 = $200;
     HEAP32[$201>>2] = $197;
     $202 = ($181|0)==(0);
     if ($202) {
      $203 = HEAP32[$162>>2]|0;
      $204 = HEAP32[$D>>2]|0;
      $205 = HEAP32[$163>>2]|0;
      $206 = (FUNCTION_TABLE_iiiii[$203 & 15]($204,$2,8,$205)|0);
      HEAP32[$$pre$phiZ2D>>2] = $206;
      $456 = $206;
     } else {
      $456 = $181;
     }
     $453 = $456;
     break;
    }
    case 4: case 20:  {
     $207 = HEAP32[$165>>2]|0;
     $208 = ($207|0)==(0|0);
     do {
      if ($208) {
       HEAP8[$x$i3$i>>0] = 0;
       $209 = ($181|0)==(0);
       if ($209) {
        $210 = HEAP32[$162>>2]|0;
        $211 = HEAP32[$D>>2]|0;
        $212 = HEAP32[$163>>2]|0;
        $213 = (FUNCTION_TABLE_iiiii[$210 & 15]($211,$x$i3$i,1,$212)|0);
        HEAP32[$$pre$phiZ2D>>2] = $213;
        $457 = $213;
       } else {
        $457 = $181;
       }
       $458 = $457;
      } else {
       $214 = ((($207)) + 12|0);
       $215 = HEAP32[$214>>2]|0;
       $216 = (($215) + 1)|0;
       HEAP32[$size$i$i16>>2] = $216;
       $217 = ($216>>>0)<(255);
       if ($217) {
        $218 = $216&255;
        HEAP8[$x$i6$i>>0] = $218;
        $219 = ($181|0)==(0);
        if ($219) {
         $220 = HEAP32[$162>>2]|0;
         $221 = HEAP32[$D>>2]|0;
         $222 = HEAP32[$163>>2]|0;
         $223 = (FUNCTION_TABLE_iiiii[$220 & 15]($221,$x$i6$i,1,$222)|0);
         HEAP32[$$pre$phiZ2D>>2] = $223;
         $$pr$i22 = $223;
        } else {
         $$pr$i22 = $181;
        }
        $235 = $$pr$i22;$237 = $216;
       } else {
        HEAP8[$x$i9$i>>0] = -1;
        $224 = ($181|0)==(0);
        if (!($224)) {
         $458 = $181;
         break;
        }
        $225 = HEAP32[$162>>2]|0;
        $226 = HEAP32[$D>>2]|0;
        $227 = HEAP32[$163>>2]|0;
        $228 = (FUNCTION_TABLE_iiiii[$225 & 15]($226,$x$i9$i,1,$227)|0);
        HEAP32[$$pre$phiZ2D>>2] = $228;
        $229 = ($228|0)==(0);
        if (!($229)) {
         $458 = $228;
         break;
        }
        $230 = HEAP32[$162>>2]|0;
        $231 = HEAP32[$D>>2]|0;
        $232 = HEAP32[$163>>2]|0;
        $233 = (FUNCTION_TABLE_iiiii[$230 & 15]($231,$size$i$i16,4,$232)|0);
        HEAP32[$$pre$phiZ2D>>2] = $233;
        $$pre$i$i23 = HEAP32[$size$i$i16>>2]|0;
        $235 = $233;$237 = $$pre$i$i23;
       }
       $234 = ($235|0)==(0);
       if ($234) {
        $236 = (($237) + -1)|0;
        $238 = ((($207)) + 24|0);
        $239 = HEAP32[$162>>2]|0;
        $240 = HEAP32[$D>>2]|0;
        $241 = HEAP32[$163>>2]|0;
        $242 = (FUNCTION_TABLE_iiiii[$239 & 15]($240,$238,$236,$241)|0);
        HEAP32[$$pre$phiZ2D>>2] = $242;
        $458 = $242;
       } else {
        $458 = $235;
       }
      }
     } while(0);
     $453 = $458;
     break;
    }
    case 1:  {
     $178 = HEAP32[$165>>2]|0;
     $179 = $178&255;
     HEAP8[$x$i1$i>>0] = $179;
     $180 = ($181|0)==(0);
     if ($180) {
      $182 = HEAP32[$162>>2]|0;
      $183 = HEAP32[$D>>2]|0;
      $184 = HEAP32[$163>>2]|0;
      $185 = (FUNCTION_TABLE_iiiii[$182 & 15]($183,$x$i1$i,1,$184)|0);
      HEAP32[$$pre$phiZ2D>>2] = $185;
      $454 = $185;
     } else {
      $454 = $181;
     }
     $453 = $454;
     break;
    }
    case 3:  {
     $186 = +HEAPF64[$165>>3];
     HEAPF64[$3>>3] = $186;
     $187 = ($181|0)==(0);
     if ($187) {
      $188 = HEAP32[$162>>2]|0;
      $189 = HEAP32[$D>>2]|0;
      $190 = HEAP32[$163>>2]|0;
      $191 = (FUNCTION_TABLE_iiiii[$188 & 15]($189,$3,8,$190)|0);
      HEAP32[$$pre$phiZ2D>>2] = $191;
      $455 = $191;
     } else {
      $455 = $181;
     }
     $453 = $455;
     break;
    }
    default: {
     $453 = $181;
    }
    }
    $243 = (($i$012$i) + 1)|0;
    $exitcond$i26 = ($243|0)==($160|0);
    if ($exitcond$i26) {
     $247 = $453;
     break L52;
    } else {
     $171 = $453;$i$012$i = $243;
    }
   }
  } else {
   $247 = $452;
  }
 } while(0);
 $244 = ((($f)) + 12|0);
 $245 = HEAP32[$244>>2]|0;
 HEAP32[$1>>2] = $245;
 $246 = ($247|0)==(0);
 if ($246) {
  $248 = ((($D)) + 4|0);
  $249 = HEAP32[$248>>2]|0;
  $250 = HEAP32[$D>>2]|0;
  $251 = ((($D)) + 8|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = (FUNCTION_TABLE_iiiii[$249 & 15]($250,$1,4,$252)|0);
  HEAP32[$$pre$phiZ2D>>2] = $253;
  $459 = $253;
 } else {
  $459 = $247;
 }
 $254 = ($245|0)>(0);
 if ($254) {
  $255 = ((($f)) + 64|0);
  $256 = ((($D)) + 4|0);
  $257 = ((($D)) + 8|0);
  $262 = $459;$i$03$i = 0;
  while(1) {
   $258 = HEAP32[$255>>2]|0;
   $259 = (((($258) + ($i$03$i<<3)|0)) + 4|0);
   $260 = HEAP8[$259>>0]|0;
   HEAP8[$x$i$i28>>0] = $260;
   $261 = ($262|0)==(0);
   if ($261) {
    $263 = HEAP32[$256>>2]|0;
    $264 = HEAP32[$D>>2]|0;
    $265 = HEAP32[$257>>2]|0;
    $266 = (FUNCTION_TABLE_iiiii[$263 & 15]($264,$x$i$i28,1,$265)|0);
    HEAP32[$$pre$phiZ2D>>2] = $266;
    $$pre$i31 = HEAP32[$255>>2]|0;
    $268 = $$pre$i31;$271 = $266;
   } else {
    $268 = $258;$271 = $262;
   }
   $267 = (((($268) + ($i$03$i<<3)|0)) + 5|0);
   $269 = HEAP8[$267>>0]|0;
   HEAP8[$x$i1$i27>>0] = $269;
   $270 = ($271|0)==(0);
   if ($270) {
    $272 = HEAP32[$256>>2]|0;
    $273 = HEAP32[$D>>2]|0;
    $274 = HEAP32[$257>>2]|0;
    $275 = (FUNCTION_TABLE_iiiii[$272 & 15]($273,$x$i1$i27,1,$274)|0);
    HEAP32[$$pre$phiZ2D>>2] = $275;
    $460 = $275;
   } else {
    $460 = $271;
   }
   $276 = (($i$03$i) + 1)|0;
   $exitcond$i33 = ($276|0)==($245|0);
   if ($exitcond$i33) {
    $280 = $460;
    break;
   } else {
    $262 = $460;$i$03$i = $276;
   }
  }
 } else {
  $280 = $459;
 }
 $277 = ((($f)) + 28|0);
 $278 = HEAP32[$277>>2]|0;
 HEAP32[$0>>2] = $278;
 $279 = ($280|0)==(0);
 if ($279) {
  $281 = ((($D)) + 4|0);
  $282 = HEAP32[$281>>2]|0;
  $283 = HEAP32[$D>>2]|0;
  $284 = ((($D)) + 8|0);
  $285 = HEAP32[$284>>2]|0;
  $286 = (FUNCTION_TABLE_iiiii[$282 & 15]($283,$0,4,$285)|0);
  HEAP32[$$pre$phiZ2D>>2] = $286;
 }
 $287 = ($278|0)>(0);
 if ($287) {
  $288 = ((($f)) + 52|0);
  $289 = ((($f)) + 72|0);
  $i$0$i48 = 0;
  while(1) {
   $290 = HEAP32[$288>>2]|0;
   $291 = (($290) + ($i$0$i48<<2)|0);
   $292 = HEAP32[$291>>2]|0;
   $293 = HEAP32[$289>>2]|0;
   _DumpFunction($292,$293,$D);
   $294 = (($i$0$i48) + 1)|0;
   $exitcond = ($294|0)==($278|0);
   if ($exitcond) {
    break;
   } else {
    $i$0$i48 = $294;
   }
  }
 }
 $295 = HEAP32[$13>>2]|0;
 $296 = ($295|0)==(0);
 if ($296) {
  $297 = ((($f)) + 24|0);
  $298 = HEAP32[$297>>2]|0;
  $299 = $298;
 } else {
  $299 = 0;
 }
 HEAP32[$12>>2] = $299;
 $300 = HEAP32[$$pre$phiZ2D>>2]|0;
 $301 = ($300|0)==(0);
 if ($301) {
  $302 = ((($D)) + 4|0);
  $303 = HEAP32[$302>>2]|0;
  $304 = HEAP32[$D>>2]|0;
  $305 = ((($D)) + 8|0);
  $306 = HEAP32[$305>>2]|0;
  $307 = (FUNCTION_TABLE_iiiii[$303 & 15]($304,$12,4,$306)|0);
  HEAP32[$$pre$phiZ2D>>2] = $307;
  $308 = ($307|0)==(0);
  if ($308) {
   $309 = $299 << 2;
   $310 = ((($f)) + 56|0);
   $311 = HEAP32[$310>>2]|0;
   $312 = HEAP32[$302>>2]|0;
   $313 = HEAP32[$D>>2]|0;
   $314 = HEAP32[$305>>2]|0;
   $315 = (FUNCTION_TABLE_iiiii[$312 & 15]($313,$311,$309,$314)|0);
   HEAP32[$$pre$phiZ2D>>2] = $315;
   $322 = $315;
  } else {
   $322 = $307;
  }
 } else {
  $322 = $300;
 }
 $316 = HEAP32[$13>>2]|0;
 $317 = ($316|0)==(0);
 if ($317) {
  $318 = ((($f)) + 32|0);
  $319 = HEAP32[$318>>2]|0;
  $320 = $319;
 } else {
  $320 = 0;
 }
 HEAP32[$11>>2] = $320;
 $321 = ($322|0)==(0);
 if ($321) {
  $323 = ((($D)) + 4|0);
  $324 = HEAP32[$323>>2]|0;
  $325 = HEAP32[$D>>2]|0;
  $326 = ((($D)) + 8|0);
  $327 = HEAP32[$326>>2]|0;
  $328 = (FUNCTION_TABLE_iiiii[$324 & 15]($325,$11,4,$327)|0);
  HEAP32[$$pre$phiZ2D>>2] = $328;
  $461 = $328;
 } else {
  $461 = $322;
 }
 $329 = ($320|0)>(0);
 if ($329) {
  $330 = ((($f)) + 60|0);
  $331 = ((($D)) + 4|0);
  $332 = ((($D)) + 8|0);
  $338 = $461;$i$032$i = 0;
  while(1) {
   $333 = HEAP32[$330>>2]|0;
   $334 = (($333) + (($i$032$i*12)|0)|0);
   $335 = HEAP32[$334>>2]|0;
   $336 = ($335|0)==(0|0);
   do {
    if ($336) {
     HEAP8[$x$i$i>>0] = 0;
     $337 = ($338|0)==(0);
     if ($337) {
      $339 = HEAP32[$331>>2]|0;
      $340 = HEAP32[$D>>2]|0;
      $341 = HEAP32[$332>>2]|0;
      $342 = (FUNCTION_TABLE_iiiii[$339 & 15]($340,$x$i$i,1,$341)|0);
      HEAP32[$$pre$phiZ2D>>2] = $342;
      $462 = $342;
     } else {
      $462 = $338;
     }
     $376 = $462;
    } else {
     $343 = ((($335)) + 12|0);
     $344 = HEAP32[$343>>2]|0;
     $345 = (($344) + 1)|0;
     HEAP32[$size$i$i>>2] = $345;
     $346 = ($345>>>0)<(255);
     if ($346) {
      $347 = $345&255;
      HEAP8[$x$i15$i>>0] = $347;
      $348 = ($338|0)==(0);
      if ($348) {
       $349 = HEAP32[$331>>2]|0;
       $350 = HEAP32[$D>>2]|0;
       $351 = HEAP32[$332>>2]|0;
       $352 = (FUNCTION_TABLE_iiiii[$349 & 15]($350,$x$i15$i,1,$351)|0);
       HEAP32[$$pre$phiZ2D>>2] = $352;
       $$pr$i = $352;
      } else {
       $$pr$i = $338;
      }
      $364 = $$pr$i;$366 = $345;
     } else {
      HEAP8[$x$i18$i>>0] = -1;
      $353 = ($338|0)==(0);
      if (!($353)) {
       $376 = $338;
       break;
      }
      $354 = HEAP32[$331>>2]|0;
      $355 = HEAP32[$D>>2]|0;
      $356 = HEAP32[$332>>2]|0;
      $357 = (FUNCTION_TABLE_iiiii[$354 & 15]($355,$x$i18$i,1,$356)|0);
      HEAP32[$$pre$phiZ2D>>2] = $357;
      $358 = ($357|0)==(0);
      if (!($358)) {
       $376 = $357;
       break;
      }
      $359 = HEAP32[$331>>2]|0;
      $360 = HEAP32[$D>>2]|0;
      $361 = HEAP32[$332>>2]|0;
      $362 = (FUNCTION_TABLE_iiiii[$359 & 15]($360,$size$i$i,4,$361)|0);
      HEAP32[$$pre$phiZ2D>>2] = $362;
      $$pre$i$i = HEAP32[$size$i$i>>2]|0;
      $364 = $362;$366 = $$pre$i$i;
     }
     $363 = ($364|0)==(0);
     if (!($363)) {
      $376 = $364;
      break;
     }
     $365 = (($366) + -1)|0;
     $367 = ((($335)) + 24|0);
     $368 = HEAP32[$331>>2]|0;
     $369 = HEAP32[$D>>2]|0;
     $370 = HEAP32[$332>>2]|0;
     $371 = (FUNCTION_TABLE_iiiii[$368 & 15]($369,$367,$365,$370)|0);
     HEAP32[$$pre$phiZ2D>>2] = $371;
     $376 = $371;
    }
   } while(0);
   $372 = HEAP32[$330>>2]|0;
   $373 = (((($372) + (($i$032$i*12)|0)|0)) + 4|0);
   $374 = HEAP32[$373>>2]|0;
   HEAP32[$10>>2] = $374;
   $375 = ($376|0)==(0);
   if ($375) {
    $377 = HEAP32[$331>>2]|0;
    $378 = HEAP32[$D>>2]|0;
    $379 = HEAP32[$332>>2]|0;
    $380 = (FUNCTION_TABLE_iiiii[$377 & 15]($378,$10,4,$379)|0);
    HEAP32[$$pre$phiZ2D>>2] = $380;
    $$pre$i = HEAP32[$330>>2]|0;
    $382 = $$pre$i;$385 = $380;
   } else {
    $382 = $372;$385 = $376;
   }
   $381 = (((($382) + (($i$032$i*12)|0)|0)) + 8|0);
   $383 = HEAP32[$381>>2]|0;
   HEAP32[$9>>2] = $383;
   $384 = ($385|0)==(0);
   if ($384) {
    $386 = HEAP32[$331>>2]|0;
    $387 = HEAP32[$D>>2]|0;
    $388 = HEAP32[$332>>2]|0;
    $389 = (FUNCTION_TABLE_iiiii[$386 & 15]($387,$9,4,$388)|0);
    HEAP32[$$pre$phiZ2D>>2] = $389;
    $463 = $389;
   } else {
    $463 = $385;
   }
   $390 = (($i$032$i) + 1)|0;
   $exitcond35$i = ($390|0)==($320|0);
   if ($exitcond35$i) {
    $396 = $463;
    break;
   } else {
    $338 = $463;$i$032$i = $390;
   }
  }
 } else {
  $396 = $461;
 }
 $391 = HEAP32[$13>>2]|0;
 $392 = ($391|0)==(0);
 if ($392) {
  $393 = HEAP32[$244>>2]|0;
  $394 = $393;
 } else {
  $394 = 0;
 }
 HEAP32[$8>>2] = $394;
 $395 = ($396|0)==(0);
 if ($395) {
  $397 = ((($D)) + 4|0);
  $398 = HEAP32[$397>>2]|0;
  $399 = HEAP32[$D>>2]|0;
  $400 = ((($D)) + 8|0);
  $401 = HEAP32[$400>>2]|0;
  $402 = (FUNCTION_TABLE_iiiii[$398 & 15]($399,$8,4,$401)|0);
  HEAP32[$$pre$phiZ2D>>2] = $402;
  $464 = $402;
 } else {
  $464 = $396;
 }
 $403 = ($394|0)>(0);
 if (!($403)) {
  STACKTOP = sp;return;
 }
 $404 = ((($f)) + 64|0);
 $405 = ((($D)) + 4|0);
 $406 = ((($D)) + 8|0);
 $412 = $464;$i$131$i = 0;
 while(1) {
  $407 = HEAP32[$404>>2]|0;
  $408 = (($407) + ($i$131$i<<3)|0);
  $409 = HEAP32[$408>>2]|0;
  $410 = ($409|0)==(0|0);
  do {
   if ($410) {
    HEAP8[$x$i21$i>>0] = 0;
    $411 = ($412|0)==(0);
    if ($411) {
     $413 = HEAP32[$405>>2]|0;
     $414 = HEAP32[$D>>2]|0;
     $415 = HEAP32[$406>>2]|0;
     $416 = (FUNCTION_TABLE_iiiii[$413 & 15]($414,$x$i21$i,1,$415)|0);
     HEAP32[$$pre$phiZ2D>>2] = $416;
     $465 = $416;
    } else {
     $465 = $412;
    }
    $466 = $465;
   } else {
    $417 = ((($409)) + 12|0);
    $418 = HEAP32[$417>>2]|0;
    $419 = (($418) + 1)|0;
    HEAP32[$size$i9$i>>2] = $419;
    $420 = ($419>>>0)<(255);
    if ($420) {
     $421 = $419&255;
     HEAP8[$x$i24$i>>0] = $421;
     $422 = ($412|0)==(0);
     if ($422) {
      $423 = HEAP32[$405>>2]|0;
      $424 = HEAP32[$D>>2]|0;
      $425 = HEAP32[$406>>2]|0;
      $426 = (FUNCTION_TABLE_iiiii[$423 & 15]($424,$x$i24$i,1,$425)|0);
      HEAP32[$$pre$phiZ2D>>2] = $426;
      $$pr30$i = $426;
     } else {
      $$pr30$i = $412;
     }
     $438 = $$pr30$i;$440 = $419;
    } else {
     HEAP8[$x$i27$i>>0] = -1;
     $427 = ($412|0)==(0);
     if (!($427)) {
      $466 = $412;
      break;
     }
     $428 = HEAP32[$405>>2]|0;
     $429 = HEAP32[$D>>2]|0;
     $430 = HEAP32[$406>>2]|0;
     $431 = (FUNCTION_TABLE_iiiii[$428 & 15]($429,$x$i27$i,1,$430)|0);
     HEAP32[$$pre$phiZ2D>>2] = $431;
     $432 = ($431|0)==(0);
     if (!($432)) {
      $466 = $431;
      break;
     }
     $433 = HEAP32[$405>>2]|0;
     $434 = HEAP32[$D>>2]|0;
     $435 = HEAP32[$406>>2]|0;
     $436 = (FUNCTION_TABLE_iiiii[$433 & 15]($434,$size$i9$i,4,$435)|0);
     HEAP32[$$pre$phiZ2D>>2] = $436;
     $$pre$i10$i = HEAP32[$size$i9$i>>2]|0;
     $438 = $436;$440 = $$pre$i10$i;
    }
    $437 = ($438|0)==(0);
    if (!($437)) {
     $466 = $438;
     break;
    }
    $439 = (($440) + -1)|0;
    $441 = ((($409)) + 24|0);
    $442 = HEAP32[$405>>2]|0;
    $443 = HEAP32[$D>>2]|0;
    $444 = HEAP32[$406>>2]|0;
    $445 = (FUNCTION_TABLE_iiiii[$442 & 15]($443,$441,$439,$444)|0);
    HEAP32[$$pre$phiZ2D>>2] = $445;
    $466 = $445;
   }
  } while(0);
  $446 = (($i$131$i) + 1)|0;
  $exitcond$i = ($446|0)==($394|0);
  if ($exitcond$i) {
   break;
  } else {
   $412 = $466;$i$131$i = $446;
  }
 }
 STACKTOP = sp;return;
}
function _luaF_newCclosure($L,$n) {
 $L = $L|0;
 $n = $n|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $n << 4;
 $1 = (($0) + 16)|0;
 $2 = (_luaC_newobj($L,38,$1)|0);
 $3 = $n&255;
 $4 = ((($2)) + 6|0);
 HEAP8[$4>>0] = $3;
 return ($2|0);
}
function _luaF_newLclosure($L,$n) {
 $L = $L|0;
 $n = $n|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $n << 2;
 $1 = (($0) + 16)|0;
 $2 = (_luaC_newobj($L,6,$1)|0);
 $3 = ((($2)) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = $n&255;
 $5 = ((($2)) + 6|0);
 HEAP8[$5>>0] = $4;
 $6 = ($n|0)==(0);
 if ($6) {
  return ($2|0);
 }
 $7 = ((($2)) + 16|0);
 $$in = $n;
 while(1) {
  $8 = (($$in) + -1)|0;
  $9 = (($7) + ($8<<2)|0);
  HEAP32[$9>>2] = 0;
  $10 = ($8|0)==(0);
  if ($10) {
   break;
  } else {
   $$in = $8;
  }
 }
 return ($2|0);
}
function _luaF_initupvals($L,$cl) {
 $L = $L|0;
 $cl = $cl|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($cl)) + 6|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $3 = (_luaM_realloc_($L,0,0,24)|0);
  $4 = ((($3)) + 4|0);
  HEAP32[$4>>2] = 1;
  $5 = ((($3)) + 8|0);
  HEAP32[$3>>2] = $5;
  $6 = ((($3)) + 16|0);
  HEAP32[$6>>2] = 0;
  $7 = (((($cl)) + 16|0) + ($i$01<<2)|0);
  HEAP32[$7>>2] = $3;
  $8 = (($i$01) + 1)|0;
  $9 = HEAP8[$0>>0]|0;
  $10 = $9&255;
  $11 = ($8|0)<($10|0);
  if ($11) {
   $i$01 = $8;
  } else {
   break;
  }
 }
 return;
}
function _luaF_findupval($L,$level) {
 $L = $L|0;
 $level = $level|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $pp$0$lcssa = 0, $pp$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if ($2) {
   $pp$0$lcssa = $0;
  } else {
   $4 = $1;$pp$03 = $0;
   while(1) {
    $3 = HEAP32[$4>>2]|0;
    $5 = ($3>>>0)<($level>>>0);
    if ($5) {
     $pp$0$lcssa = $pp$03;
     break L1;
    }
    $6 = ($3|0)==($level|0);
    if ($6) {
     $$0 = $4;
     break;
    }
    $7 = ((($4)) + 8|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0|0);
    if ($9) {
     $pp$0$lcssa = $7;
     break L1;
    } else {
     $4 = $8;$pp$03 = $7;
    }
   }
   return ($$0|0);
  }
 } while(0);
 $10 = (_luaM_realloc_($L,0,0,24)|0);
 $11 = ((($10)) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = HEAP32[$pp$0$lcssa>>2]|0;
 $13 = ((($10)) + 8|0);
 HEAP32[$13>>2] = $12;
 $14 = ((($10)) + 12|0);
 HEAP32[$14>>2] = 1;
 HEAP32[$pp$0$lcssa>>2] = $10;
 HEAP32[$10>>2] = $level;
 $15 = ((($L)) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==($L|0);
 if (!($17)) {
  $$0 = $10;
  return ($$0|0);
 }
 $18 = ((($L)) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($19)) + 104|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$15>>2] = $21;
 HEAP32[$20>>2] = $L;
 $$0 = $10;
 return ($$0|0);
}
function _luaF_close($L,$level) {
 $L = $L|0;
 $level = $level|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $4 = $1;
 while(1) {
  $3 = HEAP32[$4>>2]|0;
  $5 = ($3>>>0)<($level>>>0);
  if ($5) {
   label = 9;
   break;
  }
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$0>>2] = $7;
  $8 = ((($4)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0);
  if ($10) {
   (_luaM_realloc_($L,$4,24,0)|0);
  } else {
   ;HEAP32[$6>>2]=HEAP32[$3>>2]|0;HEAP32[$6+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$3+12>>2]|0;
   HEAP32[$4>>2] = $6;
   $11 = ((($4)) + 16|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = $12 & 64;
   $14 = ($13|0)==(0);
   if (!($14)) {
    _luaC_upvalbarrier_($L,$4);
   }
  }
  $15 = HEAP32[$0>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   label = 9;
   break;
  } else {
   $4 = $15;
  }
 }
 if ((label|0) == 9) {
  return;
 }
}
function _luaF_newproto($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaC_newobj($L,9,80)|0);
 $1 = ((($0)) + 44|0);
 $2 = ((($0)) + 68|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 64|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 12|0);
 $5 = ((($0)) + 6|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAP8[$5>>0] = 0;
 $6 = ((($0)) + 7|0);
 HEAP8[$6>>0] = 0;
 $7 = ((($0)) + 8|0);
 HEAP8[$7>>0] = 0;
 $8 = ((($0)) + 60|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 32|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 36|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 40|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 72|0);
 HEAP32[$12>>2] = 0;
 return ($0|0);
}
function _luaF_freeproto($L,$f) {
 $L = $L|0;
 $f = $f|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($f)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 2;
 (_luaM_realloc_($L,$1,$4,0)|0);
 $5 = ((($f)) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($f)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 2;
 (_luaM_realloc_($L,$6,$9,0)|0);
 $10 = ((($f)) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($f)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 4;
 (_luaM_realloc_($L,$11,$14,0)|0);
 $15 = ((($f)) + 56|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($f)) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 << 2;
 (_luaM_realloc_($L,$16,$19,0)|0);
 $20 = ((($f)) + 60|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($f)) + 32|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23*12)|0;
 (_luaM_realloc_($L,$21,$24,0)|0);
 $25 = ((($f)) + 64|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($f)) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28 << 3;
 (_luaM_realloc_($L,$26,$29,0)|0);
 (_luaM_realloc_($L,$f,80,0)|0);
 return;
}
function _luaF_getlocalname($f,$local_number,$pc) {
 $f = $f|0;
 $local_number = $local_number|0;
 $pc = $pc|0;
 var $$0 = 0, $$013 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$04 = 0, $i$04$lcssa11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($f)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $$013 = $local_number;$i$04 = 0;
 while(1) {
  $5 = (((($4) + (($i$04*12)|0)|0)) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>($pc|0);
  if ($7) {
   $$0 = 0;
   label = 8;
   break;
  }
  $8 = (((($4) + (($i$04*12)|0)|0)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)>($pc|0);
  if ($10) {
   $11 = (($$013) + -1)|0;
   $12 = ($11|0)==(0);
   if ($12) {
    $i$04$lcssa11 = $i$04;
    label = 6;
    break;
   } else {
    $$1 = $11;
   }
  } else {
   $$1 = $$013;
  }
  $16 = (($i$04) + 1)|0;
  $17 = ($16|0)<($1|0);
  if ($17) {
   $$013 = $$1;$i$04 = $16;
  } else {
   $$0 = 0;
   label = 8;
   break;
  }
 }
 if ((label|0) == 6) {
  $13 = (($4) + (($i$04$lcssa11*12)|0)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($14)) + 24|0);
  $$0 = $15;
  return ($$0|0);
 }
 else if ((label|0) == 8) {
  return ($$0|0);
 }
 return (0)|0;
}
function _luaC_barrier_($L,$o,$v) {
 $L = $L|0;
 $o = $o|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 61|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3&255)<(2);
 if ($4) {
  _reallymarkobject($1,$v);
  return;
 } else {
  $5 = ((($o)) + 5|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6&255;
  $8 = $7 & 248;
  $9 = ((($1)) + 60|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = $11 & 3;
  $13 = $12 | $8;
  $14 = $13&255;
  HEAP8[$5>>0] = $14;
  return;
 }
}
function _luaC_barrierback_($L,$t) {
 $L = $L|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($t)) + 5|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 & 251;
 $6 = $5&255;
 HEAP8[$2>>0] = $6;
 $7 = ((($1)) + 80|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($t)) + 28|0);
 HEAP32[$9>>2] = $8;
 HEAP32[$7>>2] = $t;
 return;
}
function _luaC_upvalbarrier_($L,$uv) {
 $L = $L|0;
 $uv = $uv|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$uv>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 61|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5&255)<(2);
 $7 = ($3|0)!=(0|0);
 $or$cond = $7 & $6;
 if (!($or$cond)) {
  return;
 }
 $8 = ((($3)) + 5|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 3;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  return;
 }
 _reallymarkobject($1,$3);
 return;
}
function _luaC_fix($L,$o) {
 $L = $L|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($o)) + 5|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 & 252;
 $6 = $5&255;
 HEAP8[$2>>0] = $6;
 $7 = HEAP32[$o>>2]|0;
 $8 = ((($1)) + 64|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($1)) + 100|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$o>>2] = $10;
 HEAP32[$9>>2] = $o;
 return;
}
function _luaC_newobj($L,$tt,$sz) {
 $L = $L|0;
 $tt = $tt|0;
 $sz = $sz|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $tt & 15;
 $3 = (_luaM_realloc_($L,0,$2,$sz)|0);
 $4 = ((($1)) + 60|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 & 3;
 $8 = $7&255;
 $9 = ((($3)) + 5|0);
 HEAP8[$9>>0] = $8;
 $10 = $tt&255;
 $11 = ((($3)) + 4|0);
 HEAP8[$11>>0] = $10;
 $12 = ((($1)) + 64|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$3>>2] = $13;
 HEAP32[$12>>2] = $3;
 return ($3|0);
}
function _luaC_freeallobjects($L) {
 $L = $L|0;
 var $$0$i$i = 0, $$0$i$i$lcssa = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $lastnext$03$us$us$i = 0, $lastnext$03$us$us$i$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 96|0);
 $$0$i$i = $2;
 while(1) {
  $3 = HEAP32[$$0$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $$0$i$i$lcssa = $$0$i$i;
   break;
  } else {
   $$0$i$i = $3;
  }
 }
 $5 = ((($1)) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $14 = $1;
 } else {
  $9 = $6;$lastnext$03$us$us$i = $$0$i$i$lcssa;
  while(1) {
   $8 = HEAP32[$9>>2]|0;
   HEAP32[$5>>2] = $8;
   $10 = HEAP32[$lastnext$03$us$us$i>>2]|0;
   HEAP32[$9>>2] = $10;
   HEAP32[$lastnext$03$us$us$i>>2] = $9;
   $11 = HEAP32[$5>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    break;
   } else {
    $lastnext$03$us$us$i$phi = $9;$9 = $11;$lastnext$03$us$us$i = $lastnext$03$us$us$i$phi;
   }
  }
  $$pre = HEAP32[$0>>2]|0;
  $14 = $$pre;
 }
 $13 = ((($14)) + 96|0);
 $15 = HEAP32[$13>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  while(1) {
   _GCTM($L,0);
   $17 = HEAP32[$13>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
  }
 }
 $19 = ((($1)) + 60|0);
 HEAP8[$19>>0] = 3;
 $20 = ((($1)) + 62|0);
 HEAP8[$20>>0] = 0;
 (_sweeplist($L,$5,-1)|0);
 $21 = ((($1)) + 64|0);
 (_sweeplist($L,$21,-1)|0);
 $22 = ((($1)) + 100|0);
 (_sweeplist($L,$22,-1)|0);
 return;
}
function _luaC_step($L) {
 $L = $L|0;
 var $$$i = 0, $$$neg$i = 0, $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$lcssa = 0, $$op$i = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $debt$0 = 0, $i$04$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $$idx = ((($1)) + 12|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $$idx1 = ((($1)) + 128|0);
 $$idx1$val = HEAP32[$$idx1>>2]|0;
 $2 = (($$idx$val|0) / 200)&-1;
 $3 = (($2) + 1)|0;
 $4 = ((($1)) + 63|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  _luaE_setdebt($1,-20000);
  return;
 }
 $7 = (2147483647 / ($$idx1$val|0))&-1;
 $8 = ($3|0)<($7|0);
 $9 = Math_imul($3, $$idx1$val)|0;
 $$$i = $8 ? $9 : 2147483647;
 $10 = ((($1)) + 61|0);
 $debt$0 = $$$i;
 while(1) {
  $11 = (_singlestep($L)|0);
  $12 = (($debt$0) - ($11))|0;
  $13 = ($12|0)>(-2000);
  $14 = HEAP8[$10>>0]|0;
  $15 = ($14<<24>>24)==(7);
  if (!($13)) {
   label = 6;
   break;
  }
  if ($15) {
   break;
  } else {
   $debt$0 = $12;
  }
 }
 if ((label|0) == 6) {
  if (!($15)) {
   $29 = HEAP32[$$idx1>>2]|0;
   $30 = (($12|0) / ($29|0))&-1;
   $31 = ($30*200)|0;
   _luaE_setdebt($1,$31);
   $32 = HEAP32[$0>>2]|0;
   $33 = ((($32)) + 96|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   $$pre6 = ((($32)) + 120|0);
   L11: do {
    if ($35) {
     $42 = 0;
    } else {
     $i$04$i = 0;
     while(1) {
      $36 = HEAP32[$$pre6>>2]|0;
      $37 = ($i$04$i>>>0)<($36>>>0);
      if (!($37)) {
       $$lcssa = $36;
       break;
      }
      _GCTM($L,1);
      $38 = (($i$04$i) + 1)|0;
      $39 = HEAP32[$33>>2]|0;
      $40 = ($39|0)==(0|0);
      if ($40) {
       $42 = 0;
       break L11;
      } else {
       $i$04$i = $38;
      }
     }
     $41 = $$lcssa << 1;
     $42 = $41;
    }
   } while(0);
   HEAP32[$$pre6>>2] = $42;
   return;
  }
 }
 $16 = ((($1)) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17>>>0) / 100)&-1;
 $19 = ((($1)) + 124|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (2147483647 / ($18>>>0))&-1;
 $22 = ($20|0)<($21|0);
 $23 = ((($1)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$$idx>>2]|0;
 $26 = (($25) + ($24))|0;
 $27 = (0 - ($18))|0;
 $$op$i = Math_imul($20, $27)|0;
 $$$neg$i = $22 ? $$op$i : -2147483647;
 $28 = (($26) + ($$$neg$i))|0;
 _luaE_setdebt($1,$28);
 return;
}
function _luaC_fullgc($L,$isemergency) {
 $L = $L|0;
 $isemergency = $isemergency|0;
 var $$$neg$i = 0, $$lcssa = 0, $$op$i = 0, $$phi$trans$insert = 0, $$phi$trans$insert12 = 0, $$phi$trans$insert15 = 0, $$phi$trans$insert9 = 0, $$pn = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $$pre16 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($isemergency|0)==(0);
 if (!($2)) {
  $3 = ((($1)) + 62|0);
  HEAP8[$3>>0] = 1;
 }
 $4 = ((($1)) + 61|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5&255)<(2);
 if ($6) {
  HEAP8[$4>>0] = 2;
  $7 = ((($1)) + 64|0);
  while(1) {
   $8 = (_sweeplist($L,$7,1)|0);
   $9 = ($8|0)==($7|0);
   if (!($9)) {
    $$lcssa = $8;
    break;
   }
  }
  $10 = ((($1)) + 68|0);
  HEAP32[$10>>2] = $$lcssa;
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = ((($$pre)) + 61|0);
  $$pre7 = HEAP8[$$phi$trans$insert>>0]|0;
  $12 = $$pre;$14 = $$pre7;
 } else {
  $12 = $1;$14 = $5;
 }
 $11 = ((($12)) + 61|0);
 $13 = ($14<<24>>24)==(7);
 if ($13) {
  $18 = $12;$20 = 7;
 } else {
  while(1) {
   (_singlestep($L)|0);
   $15 = HEAP8[$11>>0]|0;
   $16 = ($15<<24>>24)==(7);
   if ($16) {
    break;
   }
  }
  $$pre8 = HEAP32[$0>>2]|0;
  $$phi$trans$insert9 = ((($$pre8)) + 61|0);
  $$pre10 = HEAP8[$$phi$trans$insert9>>0]|0;
  $18 = $$pre8;$20 = $$pre10;
 }
 $17 = ((($18)) + 61|0);
 $19 = $20&255;
 $21 = 1 << $19;
 $22 = $21 & -129;
 $23 = ($22|0)==(0);
 if ($23) {
  while(1) {
   (_singlestep($L)|0);
   $24 = HEAP8[$17>>0]|0;
   $25 = $24&255;
   $26 = 1 << $25;
   $27 = $26 & -129;
   $28 = ($27|0)==(0);
   if (!($28)) {
    break;
   }
  }
  $$pre11 = HEAP32[$0>>2]|0;
  $$phi$trans$insert12 = ((($$pre11)) + 61|0);
  $$pre13 = HEAP8[$$phi$trans$insert12>>0]|0;
  $30 = $$pre11;$32 = $$pre13;
 } else {
  $30 = $18;$32 = $20;
 }
 $29 = ((($30)) + 61|0);
 $31 = ($32<<24>>24)==(6);
 if ($31) {
  $$pn = $30;
  label = 16;
 } else {
  while(1) {
   (_singlestep($L)|0);
   $33 = HEAP8[$29>>0]|0;
   $34 = ($33<<24>>24)==(6);
   if ($34) {
    break;
   }
  }
  $$pre14 = HEAP32[$0>>2]|0;
  $$phi$trans$insert15 = ((($$pre14)) + 61|0);
  $$pre16 = HEAP8[$$phi$trans$insert15>>0]|0;
  $phitmp = ($$pre16<<24>>24)==(7);
  if (!($phitmp)) {
   $$pn = $$pre14;
   label = 16;
  }
 }
 if ((label|0) == 16) {
  $35 = ((($$pn)) + 61|0);
  while(1) {
   (_singlestep($L)|0);
   $36 = HEAP8[$35>>0]|0;
   $37 = ($36<<24>>24)==(7);
   if ($37) {
    break;
   }
  }
 }
 $38 = ((($1)) + 62|0);
 HEAP8[$38>>0] = 0;
 $39 = ((($1)) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40>>>0) / 100)&-1;
 $42 = ((($1)) + 124|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (2147483647 / ($41>>>0))&-1;
 $45 = ($43|0)<($44|0);
 $46 = ((($1)) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($1)) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + ($47))|0;
 $51 = (0 - ($41))|0;
 $$op$i = Math_imul($43, $51)|0;
 $$$neg$i = $45 ? $$op$i : -2147483647;
 $52 = (($50) + ($$$neg$i))|0;
 _luaE_setdebt($1,$52);
 return;
}
function _reallymarkobject($g,$o) {
 $g = $g|0;
 $o = $o|0;
 var $$0 = 0, $$0$lcssa81 = 0, $$0$lcssa82 = 0, $$0$lcssa83 = 0, $$0$lcssa84 = 0, $$0$lcssa85 = 0, $$0$lcssa86 = 0, $$lcssa87 = 0, $$lcssa93 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre26 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($g)) + 16|0);
 $$phi$trans$insert = ((($o)) + 5|0);
 $$pre = HEAP8[$$phi$trans$insert>>0]|0;
 $$0 = $o;$3 = $$pre;
 L1: while(1) {
  $1 = ((($$0)) + 5|0);
  $2 = $3&255;
  $4 = $2 & 252;
  $5 = $4&255;
  HEAP8[$1>>0] = $5;
  $6 = ((($$0)) + 4|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7&255;
  switch ($8|0) {
  case 20: case 4:  {
   $$0$lcssa81 = $$0;$$lcssa87 = $1;$$lcssa93 = $4;
   label = 3;
   break L1;
   break;
  }
  case 38:  {
   $$0$lcssa83 = $$0;
   label = 10;
   break L1;
   break;
  }
  case 8:  {
   $$0$lcssa85 = $$0;
   label = 12;
   break L1;
   break;
  }
  case 6:  {
   $$0$lcssa82 = $$0;
   label = 9;
   break L1;
   break;
  }
  case 7:  {
   break;
  }
  case 9:  {
   $$0$lcssa86 = $$0;
   label = 13;
   break L1;
   break;
  }
  case 5:  {
   $$0$lcssa84 = $$0;
   label = 11;
   break L1;
   break;
  }
  default: {
   label = 14;
   break L1;
  }
  }
  $16 = ((($$0)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $24 = $5;
  } else {
   $19 = ((($17)) + 5|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = $20 & 3;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    $24 = $5;
   } else {
    _reallymarkobject($g,$17);
    $$pre26 = HEAP8[$1>>0]|0;
    $24 = $$pre26;
   }
  }
  $23 = $24&255;
  $25 = $23 | 4;
  $26 = $25&255;
  HEAP8[$1>>0] = $26;
  $27 = ((($$0)) + 12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 24)|0;
  $30 = HEAP32[$0>>2]|0;
  $31 = (($29) + ($30))|0;
  HEAP32[$0>>2] = $31;
  $32 = ((($$0)) + 16|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($$0)) + 6|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35 & 64;
  $37 = ($36<<24>>24)==(0);
  if ($37) {
   label = 14;
   break;
  }
  $38 = ((($33)) + 5|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39 & 3;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   label = 14;
   break;
  } else {
   $$0 = $33;$3 = $39;
  }
 }
 if ((label|0) == 3) {
  $9 = $$lcssa93 | 4;
  $10 = $9&255;
  HEAP8[$$lcssa87>>0] = $10;
  $11 = ((($$0$lcssa81)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 25)|0;
  $14 = HEAP32[$0>>2]|0;
  $15 = (($13) + ($14))|0;
  HEAP32[$0>>2] = $15;
  return;
 }
 else if ((label|0) == 9) {
  $42 = ((($g)) + 76|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ((($$0$lcssa82)) + 8|0);
  HEAP32[$44>>2] = $43;
  HEAP32[$42>>2] = $$0$lcssa82;
  return;
 }
 else if ((label|0) == 10) {
  $45 = ((($g)) + 76|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($$0$lcssa83)) + 8|0);
  HEAP32[$47>>2] = $46;
  HEAP32[$45>>2] = $$0$lcssa83;
  return;
 }
 else if ((label|0) == 11) {
  $48 = ((($g)) + 76|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ((($$0$lcssa84)) + 28|0);
  HEAP32[$50>>2] = $49;
  HEAP32[$48>>2] = $$0$lcssa84;
  return;
 }
 else if ((label|0) == 12) {
  $51 = ((($g)) + 76|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ((($$0$lcssa85)) + 36|0);
  HEAP32[$53>>2] = $52;
  HEAP32[$51>>2] = $$0$lcssa85;
  return;
 }
 else if ((label|0) == 13) {
  $54 = ((($g)) + 76|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ((($$0$lcssa86)) + 76|0);
  HEAP32[$56>>2] = $55;
  HEAP32[$54>>2] = $$0$lcssa86;
  return;
 }
 else if ((label|0) == 14) {
  return;
 }
}
function _sweeplist($L,$p,$count) {
 $L = $L|0;
 $p = $p|0;
 $count = $count|0;
 var $$0$be = 0, $$0$lcssa = 0, $$07 = 0, $$1 = 0, $$15 = 0, $$18 = 0, $$lcssa$i$i = 0, $$lcssa3 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $not$ = 0, $not$26 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 60|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 ^ 3;
 $6 = $4 & 3;
 $7 = HEAP32[$p>>2]|0;
 $8 = ($7|0)==(0|0);
 $9 = ($count|0)!=(0);
 $not$26 = $8 ^ 1;
 $10 = $9 & $not$26;
 if (!($10)) {
  $$0$lcssa = $p;$$lcssa3 = $8;
  $61 = $$lcssa3 ? 0 : $$0$lcssa;
  return ($61|0);
 }
 $$15 = (($count) + -1)|0;
 $$07 = $p;$$18 = $$15;$12 = $7;
 while(1) {
  $11 = ((($12)) + 5|0);
  $13 = HEAP8[$11>>0]|0;
  $14 = $13&255;
  $15 = $14 ^ 3;
  $16 = $15 & $5;
  $17 = ($16|0)==(0);
  L6: do {
   if ($17) {
    $18 = HEAP32[$12>>2]|0;
    HEAP32[$$07>>2] = $18;
    $19 = ((($12)) + 4|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20&255;
    switch ($21|0) {
    case 5:  {
     _luaH_free($L,$12);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 9:  {
     _luaF_freeproto($L,$12);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 20:  {
     break;
    }
    case 6:  {
     $22 = ((($12)) + 6|0);
     $23 = HEAP8[$22>>0]|0;
     $24 = $23&255;
     $25 = ($23<<24>>24)==(0);
     if ($25) {
      $$lcssa$i$i = $24;
     } else {
      $62 = $23;$i$01$i$i = 0;
      while(1) {
       $26 = (((($12)) + 16|0) + ($i$01$i$i<<2)|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ($27|0)==(0|0);
       if ($28) {
        $38 = $62;
       } else {
        $29 = ((($27)) + 4|0);
        $30 = HEAP32[$29>>2]|0;
        $31 = (($30) + -1)|0;
        HEAP32[$29>>2] = $31;
        $32 = ($31|0)==(0);
        if ($32) {
         $33 = HEAP32[$27>>2]|0;
         $34 = ((($27)) + 8|0);
         $35 = ($33|0)==($34|0);
         if ($35) {
          (_luaM_realloc_($L,$27,24,0)|0);
          $$pre$i$i = HEAP8[$22>>0]|0;
          $38 = $$pre$i$i;
         } else {
          $38 = $62;
         }
        } else {
         $38 = $62;
        }
       }
       $36 = (($i$01$i$i) + 1)|0;
       $37 = $38&255;
       $39 = ($36|0)<($37|0);
       if ($39) {
        $62 = $38;$i$01$i$i = $36;
       } else {
        $$lcssa$i$i = $37;
        break;
       }
      }
     }
     $40 = $$lcssa$i$i << 2;
     $41 = (($40) + 16)|0;
     (_luaM_realloc_($L,$12,$41,0)|0);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 38:  {
     $42 = ((($12)) + 6|0);
     $43 = HEAP8[$42>>0]|0;
     $44 = $43&255;
     $45 = $44 << 4;
     $46 = (($45) + 16)|0;
     (_luaM_realloc_($L,$12,$46,0)|0);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 8:  {
     _luaE_freethread($L,$12);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 4:  {
     _luaS_remove($L,$12);
     break;
    }
    case 7:  {
     $47 = ((($12)) + 12|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (($48) + 24)|0;
     (_luaM_realloc_($L,$12,$49,0)|0);
     $$0$be = $$07;
     break L6;
     break;
    }
    default: {
     $$0$be = $$07;
     break L6;
    }
    }
    $50 = ((($12)) + 12|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($51) + 25)|0;
    (_luaM_realloc_($L,$12,$52,0)|0);
    $$0$be = $$07;
   } else {
    $53 = $14 & 248;
    $54 = $53 | $6;
    $55 = $54&255;
    HEAP8[$11>>0] = $55;
    $$0$be = $12;
   }
  } while(0);
  $56 = HEAP32[$$0$be>>2]|0;
  $57 = ($56|0)==(0|0);
  $58 = ($$18|0)!=(0);
  $not$ = $57 ^ 1;
  $59 = $not$ << 31 >> 31;
  $$1 = (($59) + ($$18))|0;
  $60 = $58 & $not$;
  if ($60) {
   $$07 = $$0$be;$$18 = $$1;$12 = $56;
  } else {
   $$0$lcssa = $$0$be;$$lcssa3 = $57;
   break;
  }
 }
 $61 = $$lcssa3 ? 0 : $$0$lcssa;
 return ($61|0);
}
function _GCTM($L,$propagateerrors) {
 $L = $L|0;
 $propagateerrors = $propagateerrors|0;
 var $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, $status$0 = 0, $v = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 16|0;
 $v = sp;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $4;
 $5 = ((($1)) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$3>>2] = $6;
 HEAP32[$5>>2] = $3;
 $7 = ((($3)) + 5|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 & 247;
 $11 = $10&255;
 HEAP8[$7>>0] = $11;
 $12 = ((($1)) + 61|0);
 $13 = HEAP8[$12>>0]|0;
 $$off$i = (($13) + -2)<<24>>24;
 $14 = ($$off$i&255)<(4);
 if ($14) {
  $15 = $9 & 240;
  $16 = ((($1)) + 60|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $18 & 3;
  $20 = $19 | $15;
  $21 = $20&255;
  HEAP8[$7>>0] = $21;
 }
 HEAP32[$v>>2] = $3;
 $22 = ((($3)) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 | 64;
 $26 = ((($v)) + 8|0);
 HEAP32[$26>>2] = $25;
 $27 = (_luaT_gettmbyobj($L,$v,2)|0);
 $28 = ($27|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = ((($27)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 15;
 $32 = ($31|0)==(6);
 if (!($32)) {
  STACKTOP = sp;return;
 }
 $33 = ((($L)) + 109|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ((($1)) + 63|0);
 $36 = HEAP8[$35>>0]|0;
 HEAP8[$33>>0] = 0;
 HEAP8[$35>>0] = 0;
 $37 = ((($L)) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 ;HEAP32[$38>>2]=HEAP32[$27>>2]|0;HEAP32[$38+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$27+12>>2]|0;
 $39 = HEAP32[$37>>2]|0;
 $40 = ((($39)) + 16|0);
 ;HEAP32[$40>>2]=HEAP32[$v>>2]|0;HEAP32[$40+4>>2]=HEAP32[$v+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$v+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$v+12>>2]|0;
 $41 = HEAP32[$37>>2]|0;
 $42 = ((($41)) + 32|0);
 HEAP32[$37>>2] = $42;
 $43 = ((($L)) + 28|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $41;
 $46 = $44;
 $47 = (($45) - ($46))|0;
 $48 = (_luaD_pcall($L,8,0,$47,0)|0);
 HEAP8[$33>>0] = $34;
 HEAP8[$35>>0] = $36;
 $49 = ($48|0)!=(0);
 $50 = ($propagateerrors|0)!=(0);
 $or$cond = $50 & $49;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $51 = ($48|0)==(2);
 if (!($51)) {
  $status$0 = $48;
  _luaD_throw($L,$status$0);
  // unreachable;
 }
 $52 = HEAP32[$37>>2]|0;
 $53 = ((($52)) + -8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54 & 15;
 $56 = ($55|0)==(4);
 if ($56) {
  $57 = ((($52)) + -16|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58)) + 24|0);
  $60 = $59;
 } else {
  $60 = 1640;
 }
 HEAP32[$vararg_buffer>>2] = $60;
 (_luaO_pushfstring($L,1656,$vararg_buffer)|0);
 $status$0 = 5;
 _luaD_throw($L,$status$0);
 // unreachable;
}
function _singlestep($L) {
 $L = $L|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$lcssa = 0, $$02$i$i = 0, $$02$i16$i = 0, $$lcssa = 0, $$lcssa81 = 0, $$lcssa82 = 0, $$lcssa84 = 0, $$lcssa86 = 0, $$lcssa87 = 0, $$lcssa90 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $changed$0$ph$i$i = 0, $changed$0$ph$i$i$lcssa = 0, $changed$0$ph$i7$i = 0, $changed$0$ph$i7$i$lcssa = 0, $i$0$i$i = 0, $i$02$i = 0, $i$04$i = 0, $i$04$i$lcssa = 0, $lastnext$0$ph5$i$i = 0, $lastnext$03$i$i = 0, $lastnext$03$i$i$lcssa = 0, $lastnext$03$i$i$phi = 0, $n$01$i$i = 0, $n$01$i18$i = 0, $next$0$i$i = 0, $next$0$i10$i = 0, $next$0$ph$i$i = 0, $next$0$ph$i8$i = 0;
 var $o$0$i$i = 0, $o$0$i$i4 = 0, $o$01$i$i = 0, $o$01$i$i2 = 0, $o$02$i$i = 0, $o$02$i$i3 = 0, $p$0$ph4$i$i = 0, $p$0$ph5$i$i = 0, $uv$0$i$i = 0, $uv$02$i$i = 0, $uv$03$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 61|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 switch ($4|0) {
 case 1:  {
  $40 = ((($1)) + 76|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if ($42) {
   $46 = $1;
  } else {
   while(1) {
    _propagatemark($1);
    $43 = HEAP32[$40>>2]|0;
    $44 = ($43|0)==(0|0);
    if ($44) {
     break;
    }
   }
   $$pre = HEAP32[$0>>2]|0;
   $46 = $$pre;
  }
  $45 = ((($46)) + 80|0);
  $47 = HEAP32[$45>>2]|0;
  $48 = ((($46)) + 61|0);
  HEAP8[$48>>0] = 8;
  $49 = ((($46)) + 16|0);
  HEAP32[$49>>2] = 0;
  $50 = ((($L)) + 5|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51 & 3;
  $53 = ($52<<24>>24)==(0);
  if (!($53)) {
   _reallymarkobject($46,$L);
  }
  $54 = ((($46)) + 48|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = $55 & 64;
  $57 = ($56|0)==(0);
  if (!($57)) {
   $58 = ((($46)) + 40|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ((($59)) + 5|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61 & 3;
   $63 = ($62<<24>>24)==(0);
   if (!($63)) {
    _reallymarkobject($46,$59);
   }
  }
  _markmt($46);
  $64 = ((($46)) + 104|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  L15: do {
   if (!($66)) {
    $347 = $65;$p$0$ph5$i$i = $64;
    while(1) {
     $70 = $347;
     while(1) {
      $69 = ((($70)) + 5|0);
      $71 = HEAP8[$69>>0]|0;
      $72 = $71 & 7;
      $73 = ($72<<24>>24)==(0);
      $74 = ((($70)) + 32|0);
      if ($73) {
       $75 = HEAP32[$74>>2]|0;
       $76 = ($75|0)==(0|0);
       if (!($76)) {
        $$lcssa87 = $70;
        break;
       }
      }
      $80 = ((($70)) + 40|0);
      $81 = HEAP32[$80>>2]|0;
      HEAP32[$p$0$ph5$i$i>>2] = $81;
      HEAP32[$80>>2] = $70;
      $uv$02$i$i = HEAP32[$74>>2]|0;
      $82 = ($uv$02$i$i|0)==(0|0);
      if (!($82)) {
       $uv$03$i$i = $uv$02$i$i;
       while(1) {
        $83 = ((($uv$03$i$i)) + 8|0);
        $84 = ((($83)) + 4|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = ($85|0)==(0);
        if (!($86)) {
         $87 = HEAP32[$uv$03$i$i>>2]|0;
         $88 = ((($87)) + 8|0);
         $89 = HEAP32[$88>>2]|0;
         $90 = $89 & 64;
         $91 = ($90|0)==(0);
         if (!($91)) {
          $92 = HEAP32[$87>>2]|0;
          $93 = ((($92)) + 5|0);
          $94 = HEAP8[$93>>0]|0;
          $95 = $94 & 3;
          $96 = ($95<<24>>24)==(0);
          if (!($96)) {
           _reallymarkobject($46,$92);
          }
         }
         HEAP32[$84>>2] = 0;
        }
        $uv$0$i$i = HEAP32[$83>>2]|0;
        $97 = ($uv$0$i$i|0)==(0|0);
        if ($97) {
         break;
        } else {
         $uv$03$i$i = $uv$0$i$i;
        }
       }
      }
      $67 = HEAP32[$p$0$ph5$i$i>>2]|0;
      $68 = ($67|0)==(0|0);
      if ($68) {
       break L15;
      } else {
       $70 = $67;
      }
     }
     $77 = ((($$lcssa87)) + 40|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ($78|0)==(0|0);
     if ($79) {
      break;
     } else {
      $347 = $78;$p$0$ph5$i$i = $77;
     }
    }
   }
  } while(0);
  $98 = ((($46)) + 76|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = ($99|0)==(0|0);
  if (!($100)) {
   while(1) {
    _propagatemark($46);
    $101 = HEAP32[$98>>2]|0;
    $102 = ($101|0)==(0|0);
    if ($102) {
     break;
    }
   }
  }
  $103 = HEAP32[$49>>2]|0;
  HEAP32[$98>>2] = $47;
  $104 = ($47|0)==(0);
  if (!($104)) {
   while(1) {
    _propagatemark($46);
    $105 = HEAP32[$98>>2]|0;
    $106 = ($105|0)==(0|0);
    if ($106) {
     break;
    }
   }
  }
  HEAP32[$49>>2] = 0;
  $107 = ((($46)) + 88|0);
  while(1) {
   $108 = HEAP32[$107>>2]|0;
   HEAP32[$107>>2] = 0;
   $changed$0$ph$i$i = 0;$next$0$ph$i$i = $108;
   L46: while(1) {
    $next$0$i$i = $next$0$ph$i$i;
    while(1) {
     $109 = ($next$0$i$i|0)==(0|0);
     if ($109) {
      $changed$0$ph$i$i$lcssa = $changed$0$ph$i$i;
      break L46;
     }
     $110 = ((($next$0$i$i)) + 28|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = (_traverseephemeron($46,$next$0$i$i)|0);
     $113 = ($112|0)==(0);
     if ($113) {
      $next$0$i$i = $111;
     } else {
      $$lcssa86 = $111;
      break;
     }
    }
    $114 = HEAP32[$98>>2]|0;
    $115 = ($114|0)==(0|0);
    if ($115) {
     $changed$0$ph$i$i = 1;$next$0$ph$i$i = $$lcssa86;
     continue;
    }
    while(1) {
     _propagatemark($46);
     $116 = HEAP32[$98>>2]|0;
     $117 = ($116|0)==(0|0);
     if ($117) {
      $changed$0$ph$i$i = 1;$next$0$ph$i$i = $$lcssa86;
      continue L46;
     }
    }
   }
   $118 = ($changed$0$ph$i$i$lcssa|0)==(0);
   if ($118) {
    break;
   }
  }
  $119 = ((($46)) + 84|0);
  $120 = HEAP32[$119>>2]|0;
  _clearvalues($46,$120,0);
  $121 = ((($46)) + 92|0);
  $122 = HEAP32[$121>>2]|0;
  _clearvalues($46,$122,0);
  $123 = HEAP32[$119>>2]|0;
  $124 = HEAP32[$121>>2]|0;
  $125 = HEAP32[$49>>2]|0;
  $126 = ((($46)) + 96|0);
  $$0$i$i$i = $126;
  while(1) {
   $127 = HEAP32[$$0$i$i$i>>2]|0;
   $128 = ($127|0)==(0|0);
   if ($128) {
    $$0$i$i$i$lcssa = $$0$i$i$i;
    break;
   } else {
    $$0$i$i$i = $127;
   }
  }
  $129 = (($125) + ($103))|0;
  $130 = ((($46)) + 72|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = ($131|0)==(0|0);
  L59: do {
   if (!($132)) {
    $348 = $131;$lastnext$0$ph5$i$i = $$0$i$i$i$lcssa;$p$0$ph4$i$i = $130;
    while(1) {
     $136 = $348;$lastnext$03$i$i = $lastnext$0$ph5$i$i;
     while(1) {
      $135 = ((($136)) + 5|0);
      $137 = HEAP8[$135>>0]|0;
      $138 = $137 & 3;
      $139 = ($138<<24>>24)==(0);
      if ($139) {
       $$lcssa84 = $136;$lastnext$03$i$i$lcssa = $lastnext$03$i$i;
       break;
      }
      $140 = HEAP32[$136>>2]|0;
      HEAP32[$p$0$ph4$i$i>>2] = $140;
      $141 = HEAP32[$lastnext$03$i$i>>2]|0;
      HEAP32[$136>>2] = $141;
      HEAP32[$lastnext$03$i$i>>2] = $136;
      $142 = HEAP32[$p$0$ph4$i$i>>2]|0;
      $143 = ($142|0)==(0|0);
      if ($143) {
       break L59;
      } else {
       $lastnext$03$i$i$phi = $136;$136 = $142;$lastnext$03$i$i = $lastnext$03$i$i$phi;
      }
     }
     $133 = HEAP32[$$lcssa84>>2]|0;
     $134 = ($133|0)==(0|0);
     if ($134) {
      break;
     } else {
      $348 = $133;$lastnext$0$ph5$i$i = $lastnext$03$i$i$lcssa;$p$0$ph4$i$i = $$lcssa84;
     }
    }
   }
  } while(0);
  $144 = ((($46)) + 120|0);
  HEAP32[$144>>2] = 1;
  $o$01$i$i2 = HEAP32[$126>>2]|0;
  $145 = ($o$01$i$i2|0)==(0|0);
  if (!($145)) {
   $o$02$i$i3 = $o$01$i$i2;
   while(1) {
    $146 = ((($o$02$i$i3)) + 5|0);
    $147 = HEAP8[$146>>0]|0;
    $148 = $147 & 3;
    $149 = ($148<<24>>24)==(0);
    if (!($149)) {
     _reallymarkobject($46,$o$02$i$i3);
    }
    $o$0$i$i4 = HEAP32[$o$02$i$i3>>2]|0;
    $150 = ($o$0$i$i4|0)==(0|0);
    if ($150) {
     break;
    } else {
     $o$02$i$i3 = $o$0$i$i4;
    }
   }
  }
  $151 = HEAP32[$98>>2]|0;
  $152 = ($151|0)==(0|0);
  if (!($152)) {
   while(1) {
    _propagatemark($46);
    $153 = HEAP32[$98>>2]|0;
    $154 = ($153|0)==(0|0);
    if ($154) {
     break;
    }
   }
  }
  HEAP32[$49>>2] = 0;
  while(1) {
   $155 = HEAP32[$107>>2]|0;
   HEAP32[$107>>2] = 0;
   $changed$0$ph$i7$i = 0;$next$0$ph$i8$i = $155;
   L80: while(1) {
    $next$0$i10$i = $next$0$ph$i8$i;
    while(1) {
     $156 = ($next$0$i10$i|0)==(0|0);
     if ($156) {
      $changed$0$ph$i7$i$lcssa = $changed$0$ph$i7$i;
      break L80;
     }
     $157 = ((($next$0$i10$i)) + 28|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = (_traverseephemeron($46,$next$0$i10$i)|0);
     $160 = ($159|0)==(0);
     if ($160) {
      $next$0$i10$i = $158;
     } else {
      $$lcssa82 = $158;
      break;
     }
    }
    $161 = HEAP32[$98>>2]|0;
    $162 = ($161|0)==(0|0);
    if ($162) {
     $changed$0$ph$i7$i = 1;$next$0$ph$i8$i = $$lcssa82;
     continue;
    }
    while(1) {
     _propagatemark($46);
     $163 = HEAP32[$98>>2]|0;
     $164 = ($163|0)==(0|0);
     if ($164) {
      $changed$0$ph$i7$i = 1;$next$0$ph$i8$i = $$lcssa82;
      continue L80;
     }
    }
   }
   $165 = ($changed$0$ph$i7$i$lcssa|0)==(0);
   if ($165) {
    break;
   }
  }
  $166 = HEAP32[$107>>2]|0;
  $167 = ($166|0)==(0|0);
  if (!($167)) {
   $$02$i$i = $166;
   while(1) {
    $168 = ((($$02$i$i)) + 7|0);
    $169 = HEAP8[$168>>0]|0;
    $170 = $169&255;
    $171 = 1 << $170;
    $172 = ((($$02$i$i)) + 16|0);
    $173 = HEAP32[$172>>2]|0;
    $174 = (($173) + ($171<<5)|0);
    $175 = ($169<<24>>24)==(31);
    if (!($175)) {
     $n$01$i$i = $173;
     while(1) {
      $176 = ((($n$01$i$i)) + 8|0);
      $177 = HEAP32[$176>>2]|0;
      $178 = ($177|0)==(0);
      do {
       if (!($178)) {
        $179 = ((($n$01$i$i)) + 24|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = $180 & 64;
        $182 = ($181|0)==(0);
        if (!($182)) {
         $183 = ((($n$01$i$i)) + 16|0);
         $184 = $180 & 15;
         $185 = ($184|0)==(4);
         $186 = HEAP32[$183>>2]|0;
         if (!($185)) {
          $192 = ((($186)) + 5|0);
          $193 = HEAP8[$192>>0]|0;
          $194 = $193 & 3;
          $195 = ($194<<24>>24)==(0);
          if ($195) {
           break;
          }
          HEAP32[$176>>2] = 0;
          HEAP32[$179>>2] = 10;
          break;
         }
         $187 = ($186|0)==(0|0);
         if ($187) {
          break;
         }
         $188 = ((($186)) + 5|0);
         $189 = HEAP8[$188>>0]|0;
         $190 = $189 & 3;
         $191 = ($190<<24>>24)==(0);
         if ($191) {
          break;
         }
         _reallymarkobject($46,$186);
        }
       }
      } while(0);
      $196 = ((($n$01$i$i)) + 32|0);
      $197 = ($196>>>0)<($174>>>0);
      if ($197) {
       $n$01$i$i = $196;
      } else {
       break;
      }
     }
    }
    $198 = ((($$02$i$i)) + 28|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = ($199|0)==(0|0);
    if ($200) {
     break;
    } else {
     $$02$i$i = $199;
    }
   }
  }
  $201 = HEAP32[$121>>2]|0;
  $202 = ($201|0)==(0|0);
  if (!($202)) {
   $$02$i16$i = $201;
   while(1) {
    $203 = ((($$02$i16$i)) + 7|0);
    $204 = HEAP8[$203>>0]|0;
    $205 = $204&255;
    $206 = 1 << $205;
    $207 = ((($$02$i16$i)) + 16|0);
    $208 = HEAP32[$207>>2]|0;
    $209 = (($208) + ($206<<5)|0);
    $210 = ($204<<24>>24)==(31);
    if (!($210)) {
     $n$01$i18$i = $208;
     while(1) {
      $211 = ((($n$01$i18$i)) + 8|0);
      $212 = HEAP32[$211>>2]|0;
      $213 = ($212|0)==(0);
      do {
       if (!($213)) {
        $214 = ((($n$01$i18$i)) + 24|0);
        $215 = HEAP32[$214>>2]|0;
        $216 = $215 & 64;
        $217 = ($216|0)==(0);
        if (!($217)) {
         $218 = ((($n$01$i18$i)) + 16|0);
         $219 = $215 & 15;
         $220 = ($219|0)==(4);
         $221 = HEAP32[$218>>2]|0;
         if (!($220)) {
          $227 = ((($221)) + 5|0);
          $228 = HEAP8[$227>>0]|0;
          $229 = $228 & 3;
          $230 = ($229<<24>>24)==(0);
          if ($230) {
           break;
          }
          HEAP32[$211>>2] = 0;
          HEAP32[$214>>2] = 10;
          break;
         }
         $222 = ($221|0)==(0|0);
         if ($222) {
          break;
         }
         $223 = ((($221)) + 5|0);
         $224 = HEAP8[$223>>0]|0;
         $225 = $224 & 3;
         $226 = ($225<<24>>24)==(0);
         if ($226) {
          break;
         }
         _reallymarkobject($46,$221);
        }
       }
      } while(0);
      $231 = ((($n$01$i18$i)) + 32|0);
      $232 = ($231>>>0)<($209>>>0);
      if ($232) {
       $n$01$i18$i = $231;
      } else {
       break;
      }
     }
    }
    $233 = ((($$02$i16$i)) + 28|0);
    $234 = HEAP32[$233>>2]|0;
    $235 = ($234|0)==(0|0);
    if ($235) {
     break;
    } else {
     $$02$i16$i = $234;
    }
   }
  }
  $236 = HEAP32[$119>>2]|0;
  _clearvalues($46,$236,$123);
  $237 = HEAP32[$121>>2]|0;
  _clearvalues($46,$237,$124);
  $238 = ((($46)) + 60|0);
  $239 = HEAP8[$238>>0]|0;
  $240 = $239&255;
  $241 = $240 ^ 3;
  $242 = $241&255;
  HEAP8[$238>>0] = $242;
  $243 = HEAP32[$49>>2]|0;
  $244 = HEAP32[$0>>2]|0;
  $245 = ((($244)) + 61|0);
  HEAP8[$245>>0] = 2;
  $246 = ((($244)) + 64|0);
  $i$0$i$i = 0;
  while(1) {
   $247 = (($i$0$i$i) + 1)|0;
   $248 = (_sweeplist($L,$246,1)|0);
   $249 = ($248|0)==($246|0);
   if ($249) {
    $i$0$i$i = $247;
   } else {
    $$lcssa = $247;$$lcssa81 = $248;
    break;
   }
  }
  $250 = (($129) + ($243))|0;
  $251 = ((($244)) + 68|0);
  HEAP32[$251>>2] = $$lcssa81;
  $252 = ((($1)) + 8|0);
  $253 = HEAP32[$252>>2]|0;
  $254 = ((($1)) + 12|0);
  $255 = HEAP32[$254>>2]|0;
  $256 = (($255) + ($253))|0;
  $257 = ((($1)) + 20|0);
  HEAP32[$257>>2] = $256;
  $258 = ($$lcssa*6)|0;
  $259 = (($250) + ($258))|0;
  $$0 = $259;
  return ($$0|0);
  break;
 }
 case 3:  {
  $273 = ((($1)) + 96|0);
  $274 = ((($1)) + 68|0);
  $275 = HEAP32[$274>>2]|0;
  $276 = ($275|0)==(0|0);
  if (!($276)) {
   $277 = ((($1)) + 12|0);
   $278 = HEAP32[$277>>2]|0;
   $279 = (_sweeplist($L,$275,83)|0);
   HEAP32[$274>>2] = $279;
   $280 = HEAP32[$277>>2]|0;
   $281 = (($280) - ($278))|0;
   $282 = ((($1)) + 20|0);
   $283 = HEAP32[$282>>2]|0;
   $284 = (($281) + ($283))|0;
   HEAP32[$282>>2] = $284;
   $285 = ($279|0)==(0|0);
   if (!($285)) {
    $$0 = 498;
    return ($$0|0);
   }
  }
  HEAP8[$2>>0] = 4;
  HEAP32[$274>>2] = $273;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 case 7:  {
  $5 = ((($1)) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 << 2;
  $8 = ((($1)) + 16|0);
  HEAP32[$8>>2] = $7;
  $9 = ((($1)) + 76|0);
  $10 = ((($1)) + 136|0);
  ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = ((($11)) + 5|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14 & 3;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    _reallymarkobject($1,$11);
   }
  }
  $17 = ((($1)) + 48|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & 64;
  $20 = ($19|0)==(0);
  if (!($20)) {
   $21 = ((($1)) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($22)) + 5|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24 & 3;
   $26 = ($25<<24>>24)==(0);
   if (!($26)) {
    _reallymarkobject($1,$22);
   }
  }
  _markmt($1);
  $27 = ((($1)) + 96|0);
  $o$01$i$i = HEAP32[$27>>2]|0;
  $28 = ($o$01$i$i|0)==(0|0);
  if (!($28)) {
   $o$02$i$i = $o$01$i$i;
   while(1) {
    $29 = ((($o$02$i$i)) + 5|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = $30 & 3;
    $32 = ($31<<24>>24)==(0);
    if (!($32)) {
     _reallymarkobject($1,$o$02$i$i);
    }
    $o$0$i$i = HEAP32[$o$02$i$i>>2]|0;
    $33 = ($o$0$i$i|0)==(0|0);
    if ($33) {
     break;
    } else {
     $o$02$i$i = $o$0$i$i;
    }
   }
  }
  HEAP8[$2>>0] = 0;
  $34 = HEAP32[$8>>2]|0;
  $$0 = $34;
  return ($$0|0);
  break;
 }
 case 0:  {
  $35 = ((($1)) + 16|0);
  HEAP32[$35>>2] = 0;
  _propagatemark($1);
  $36 = ((($1)) + 76|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   HEAP8[$2>>0] = 1;
  }
  $39 = HEAP32[$35>>2]|0;
  $$0 = $39;
  return ($$0|0);
  break;
 }
 case 2:  {
  $260 = ((($1)) + 72|0);
  $261 = ((($1)) + 68|0);
  $262 = HEAP32[$261>>2]|0;
  $263 = ($262|0)==(0|0);
  if (!($263)) {
   $264 = ((($1)) + 12|0);
   $265 = HEAP32[$264>>2]|0;
   $266 = (_sweeplist($L,$262,83)|0);
   HEAP32[$261>>2] = $266;
   $267 = HEAP32[$264>>2]|0;
   $268 = (($267) - ($265))|0;
   $269 = ((($1)) + 20|0);
   $270 = HEAP32[$269>>2]|0;
   $271 = (($268) + ($270))|0;
   HEAP32[$269>>2] = $271;
   $272 = ($266|0)==(0|0);
   if (!($272)) {
    $$0 = 498;
    return ($$0|0);
   }
  }
  HEAP8[$2>>0] = 3;
  HEAP32[$261>>2] = $260;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 case 6:  {
  $332 = ((($1)) + 96|0);
  $333 = HEAP32[$332>>2]|0;
  $334 = ($333|0)==(0|0);
  if (!($334)) {
   $335 = ((($1)) + 62|0);
   $336 = HEAP8[$335>>0]|0;
   $337 = ($336<<24>>24)==(1);
   if (!($337)) {
    $338 = ((($1)) + 120|0);
    $i$04$i = 0;
    while(1) {
     $339 = HEAP32[$338>>2]|0;
     $340 = ($i$04$i>>>0)<($339>>>0);
     if (!($340)) {
      $$lcssa90 = $339;$i$04$i$lcssa = $i$04$i;
      label = 116;
      break;
     }
     _GCTM($L,1);
     $341 = (($i$04$i) + 1)|0;
     $342 = HEAP32[$332>>2]|0;
     $343 = ($342|0)==(0|0);
     if ($343) {
      $345 = 0;$i$02$i = $341;
      break;
     } else {
      $i$04$i = $341;
     }
    }
    if ((label|0) == 116) {
     $344 = $$lcssa90 << 1;
     $345 = $344;$i$02$i = $i$04$i$lcssa;
    }
    HEAP32[$338>>2] = $345;
    $346 = ($i$02$i*6)|0;
    $$0 = $346;
    return ($$0|0);
   }
  }
  HEAP8[$2>>0] = 7;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 case 4:  {
  $286 = ((($1)) + 68|0);
  $287 = HEAP32[$286>>2]|0;
  $288 = ($287|0)==(0|0);
  if (!($288)) {
   $289 = ((($1)) + 12|0);
   $290 = HEAP32[$289>>2]|0;
   $291 = (_sweeplist($L,$287,83)|0);
   HEAP32[$286>>2] = $291;
   $292 = HEAP32[$289>>2]|0;
   $293 = (($292) - ($290))|0;
   $294 = ((($1)) + 20|0);
   $295 = HEAP32[$294>>2]|0;
   $296 = (($293) + ($295))|0;
   HEAP32[$294>>2] = $296;
   $297 = ($291|0)==(0|0);
   if (!($297)) {
    $$0 = 498;
    return ($$0|0);
   }
  }
  HEAP8[$2>>0] = 5;
  HEAP32[$286>>2] = 0;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 case 5:  {
  $298 = ((($1)) + 136|0);
  $299 = HEAP32[$298>>2]|0;
  $300 = ((($299)) + 5|0);
  $301 = HEAP8[$300>>0]|0;
  $302 = $301&255;
  $303 = $302 & 248;
  $304 = ((($1)) + 60|0);
  $305 = HEAP8[$304>>0]|0;
  $306 = $305&255;
  $307 = $306 & 3;
  $308 = $307 | $303;
  $309 = $308&255;
  HEAP8[$300>>0] = $309;
  $310 = ((($1)) + 62|0);
  $311 = HEAP8[$310>>0]|0;
  $312 = ($311<<24>>24)==(1);
  if (!($312)) {
   $313 = ((($1)) + 12|0);
   $314 = HEAP32[$313>>2]|0;
   $315 = ((($1)) + 108|0);
   $316 = HEAP32[$315>>2]|0;
   $317 = ((($1)) + 116|0);
   $318 = HEAP32[$317>>2]|0;
   $319 = (_luaM_realloc_($L,$316,$318,0)|0);
   HEAP32[$315>>2] = $319;
   HEAP32[$317>>2] = 0;
   $320 = ((($1)) + 28|0);
   $321 = HEAP32[$320>>2]|0;
   $322 = ((($1)) + 32|0);
   $323 = HEAP32[$322>>2]|0;
   $324 = (($323|0) / 4)&-1;
   $325 = ($321|0)<($324|0);
   if ($325) {
    $326 = (($323|0) / 2)&-1;
    _luaS_resize($L,$326);
   }
   $327 = HEAP32[$313>>2]|0;
   $328 = (($327) - ($314))|0;
   $329 = ((($1)) + 20|0);
   $330 = HEAP32[$329>>2]|0;
   $331 = (($328) + ($330))|0;
   HEAP32[$329>>2] = $331;
  }
  HEAP8[$2>>0] = 6;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 default: {
  $$0 = 0;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function _markmt($g) {
 $g = $g|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($g)) + 244|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 5|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4 & 3;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   _reallymarkobject($g,$1);
  }
 }
 $7 = ((($g)) + 248|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 5|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 & 3;
  $13 = ($12<<24>>24)==(0);
  if (!($13)) {
   _reallymarkobject($g,$8);
  }
 }
 $14 = ((($g)) + 252|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $17 = ((($15)) + 5|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18 & 3;
  $20 = ($19<<24>>24)==(0);
  if (!($20)) {
   _reallymarkobject($g,$15);
  }
 }
 $21 = ((($g)) + 256|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = ((($22)) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25 & 3;
  $27 = ($26<<24>>24)==(0);
  if (!($27)) {
   _reallymarkobject($g,$22);
  }
 }
 $28 = ((($g)) + 260|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = ((($29)) + 5|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = $32 & 3;
  $34 = ($33<<24>>24)==(0);
  if (!($34)) {
   _reallymarkobject($g,$29);
  }
 }
 $35 = ((($g)) + 264|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  $38 = ((($36)) + 5|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39 & 3;
  $41 = ($40<<24>>24)==(0);
  if (!($41)) {
   _reallymarkobject($g,$36);
  }
 }
 $42 = ((($g)) + 268|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = ((($43)) + 5|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46 & 3;
  $48 = ($47<<24>>24)==(0);
  if (!($48)) {
   _reallymarkobject($g,$43);
  }
 }
 $49 = ((($g)) + 272|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if (!($51)) {
  $52 = ((($50)) + 5|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = $53 & 3;
  $55 = ($54<<24>>24)==(0);
  if (!($55)) {
   _reallymarkobject($g,$50);
  }
 }
 $56 = ((($g)) + 276|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 if ($58) {
  return;
 }
 $59 = ((($57)) + 5|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = $60 & 3;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  return;
 }
 _reallymarkobject($g,$57);
 return;
}
function _propagatemark($g) {
 $g = $g|0;
 var $$0$i$i$i = 0, $$lcssa$i = 0, $$lcssa$i12 = 0, $$lcssa$i4 = 0, $$lcssa35 = 0, $$ph8$i = 0, $$ph9$i = 0, $$pr$pre$i = 0, $$pr7$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i3 = 0, $$pre$i6 = 0, $$pre$i8 = 0, $$pre20$i = 0, $$pre21$i = 0, $$pre22$i = 0, $$pre23$i = 0, $$pre7$i$i = 0, $$pre8$i$i = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $hasclears$0$$i$i = 0, $hasclears$0$lcssa$i$i = 0, $hasclears$03$i$i = 0, $hasclears$1$i$i = 0, $i$01$i = 0, $i$01$i1 = 0, $i$016$i = 0, $i$03$i$i = 0, $i$113$i = 0, $i$210$i = 0, $i$39$i = 0, $n$01$i$i = 0, $n$01$i1$i = 0, $not$$i$i = 0, $o$0$lcssa$i = 0, $o$02$i = 0, $o$11$i = 0, $size$0 = 0;
 var $tmp$i = 0, $tmp1$i = 0, $tmp2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($g)) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 5|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 | 4;
 $6 = $5&255;
 HEAP8[$2>>0] = $6;
 $7 = ((($1)) + 4|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 switch ($9|0) {
 case 5:  {
  $10 = ((($1)) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$0>>2] = $11;
  $12 = ((($1)) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  do {
   if ($14) {
    label = 35;
   } else {
    $15 = ((($13)) + 6|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = $16 & 8;
    $18 = ($17<<24>>24)==(0);
    if ($18) {
     $19 = ((($g)) + 160|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (_luaT_gettm($13,3,$20)|0);
     $$pr$pre$i = HEAP32[$12>>2]|0;
     $22 = ($$pr$pre$i|0)==(0|0);
     if ($22) {
      $$ph9$i = $21;
     } else {
      $$ph8$i = $21;$$pr7$i = $$pr$pre$i;
      label = 5;
     }
    } else {
     $$ph8$i = 0;$$pr7$i = $13;
     label = 5;
    }
    if ((label|0) == 5) {
     $23 = ((($$pr7$i)) + 5|0);
     $24 = HEAP8[$23>>0]|0;
     $25 = $24 & 3;
     $26 = ($25<<24>>24)==(0);
     if ($26) {
      $$ph9$i = $$ph8$i;
     } else {
      _reallymarkobject($g,$$pr7$i);
      $$ph9$i = $$ph8$i;
     }
    }
    $27 = ($$ph9$i|0)==(0|0);
    if ($27) {
     label = 35;
    } else {
     $28 = ((($$ph9$i)) + 8|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = $29 & 15;
     $31 = ($30|0)==(4);
     if ($31) {
      $32 = HEAP32[$$ph9$i>>2]|0;
      $33 = ((($32)) + 24|0);
      $34 = (_strchr($33,107)|0);
      $35 = (_strchr($33,118)|0);
      $36 = ($34|0)!=(0|0);
      $37 = ($35|0)!=(0|0);
      $38 = $36 | $37;
      if ($38) {
       $39 = HEAP8[$2>>0]|0;
       $40 = $39&255;
       $41 = $40 & 251;
       $42 = $41&255;
       HEAP8[$2>>0] = $42;
       if ($36) {
        if ($37) {
         $100 = ((($g)) + 92|0);
         $101 = HEAP32[$100>>2]|0;
         HEAP32[$10>>2] = $101;
         HEAP32[$100>>2] = $1;
         break;
        } else {
         (_traverseephemeron($g,$1)|0);
         break;
        }
       }
       $43 = ((($1)) + 7|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = $44&255;
       $46 = 1 << $45;
       $47 = ((($1)) + 16|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = (($48) + ($46<<5)|0);
       $50 = ((($1)) + 8|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = ($51|0)!=(0);
       $53 = $52&1;
       $54 = ($44<<24>>24)==(31);
       if ($54) {
        $hasclears$0$lcssa$i$i = $53;
       } else {
        $hasclears$03$i$i = $53;$n$01$i$i = $48;
        while(1) {
         $55 = ((($n$01$i$i)) + 8|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($56|0)==(0);
         $58 = ((($n$01$i$i)) + 24|0);
         $59 = HEAP32[$58>>2]|0;
         $60 = $59 & 64;
         $61 = ($60|0)==(0);
         if ($57) {
          if ($61) {
           $hasclears$1$i$i = $hasclears$03$i$i;
          } else {
           $62 = ((($n$01$i$i)) + 16|0);
           $63 = HEAP32[$62>>2]|0;
           $64 = ((($63)) + 5|0);
           $65 = HEAP8[$64>>0]|0;
           $66 = $65 & 3;
           $67 = ($66<<24>>24)==(0);
           if ($67) {
            $hasclears$1$i$i = $hasclears$03$i$i;
           } else {
            HEAP32[$58>>2] = 10;
            $hasclears$1$i$i = $hasclears$03$i$i;
           }
          }
         } else {
          if (!($61)) {
           $68 = ((($n$01$i$i)) + 16|0);
           $69 = HEAP32[$68>>2]|0;
           $70 = ((($69)) + 5|0);
           $71 = HEAP8[$70>>0]|0;
           $72 = $71 & 3;
           $73 = ($72<<24>>24)==(0);
           if (!($73)) {
            _reallymarkobject($g,$69);
           }
          }
          $74 = ($hasclears$03$i$i|0)==(0);
          if ($74) {
           $75 = HEAP32[$55>>2]|0;
           $76 = $75 & 64;
           $77 = ($76|0)==(0);
           do {
            if ($77) {
             $$0$i$i$i = 0;
            } else {
             $78 = $75 & 15;
             $79 = ($78|0)==(4);
             $80 = HEAP32[$n$01$i$i>>2]|0;
             if (!($79)) {
              $86 = ((($80)) + 5|0);
              $87 = HEAP8[$86>>0]|0;
              $88 = $87&255;
              $89 = $88 & 3;
              $$0$i$i$i = $89;
              break;
             }
             $81 = ($80|0)==(0|0);
             if ($81) {
              $$0$i$i$i = 0;
             } else {
              $82 = ((($80)) + 5|0);
              $83 = HEAP8[$82>>0]|0;
              $84 = $83 & 3;
              $85 = ($84<<24>>24)==(0);
              if ($85) {
               $$0$i$i$i = 0;
              } else {
               _reallymarkobject($g,$80);
               $$0$i$i$i = 0;
              }
             }
            }
           } while(0);
           $not$$i$i = ($$0$i$i$i|0)!=(0);
           $hasclears$0$$i$i = $not$$i$i&1;
           $hasclears$1$i$i = $hasclears$0$$i$i;
          } else {
           $hasclears$1$i$i = $hasclears$03$i$i;
          }
         }
         $90 = ((($n$01$i$i)) + 32|0);
         $91 = ($90>>>0)<($49>>>0);
         if ($91) {
          $hasclears$03$i$i = $hasclears$1$i$i;$n$01$i$i = $90;
         } else {
          $hasclears$0$lcssa$i$i = $hasclears$1$i$i;
          break;
         }
        }
       }
       $92 = ((($g)) + 61|0);
       $93 = HEAP8[$92>>0]|0;
       $94 = ($93<<24>>24)==(0);
       if ($94) {
        $95 = ((($g)) + 80|0);
        $96 = HEAP32[$95>>2]|0;
        HEAP32[$10>>2] = $96;
        HEAP32[$95>>2] = $1;
        break;
       }
       $97 = ($hasclears$0$lcssa$i$i|0)==(0);
       if (!($97)) {
        $98 = ((($g)) + 84|0);
        $99 = HEAP32[$98>>2]|0;
        HEAP32[$10>>2] = $99;
        HEAP32[$98>>2] = $1;
       }
      } else {
       label = 35;
      }
     } else {
      label = 35;
     }
    }
   }
  } while(0);
  if ((label|0) == 35) {
   $102 = ((($1)) + 7|0);
   $103 = HEAP8[$102>>0]|0;
   $104 = $103&255;
   $105 = 1 << $104;
   $106 = ((($1)) + 16|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (($107) + ($105<<5)|0);
   $109 = ((($1)) + 8|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ($110|0)==(0);
   if ($111) {
    $128 = $107;
   } else {
    $112 = ((($1)) + 12|0);
    $373 = $110;$i$03$i$i = 0;
    while(1) {
     $113 = HEAP32[$112>>2]|0;
     $114 = (((($113) + ($i$03$i$i<<4)|0)) + 8|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = $115 & 64;
     $117 = ($116|0)==(0);
     if ($117) {
      $126 = $373;
     } else {
      $118 = (($113) + ($i$03$i$i<<4)|0);
      $119 = HEAP32[$118>>2]|0;
      $120 = ((($119)) + 5|0);
      $121 = HEAP8[$120>>0]|0;
      $122 = $121 & 3;
      $123 = ($122<<24>>24)==(0);
      if ($123) {
       $126 = $373;
      } else {
       _reallymarkobject($g,$119);
       $$pre$i$i = HEAP32[$109>>2]|0;
       $126 = $$pre$i$i;
      }
     }
     $124 = (($i$03$i$i) + 1)|0;
     $125 = ($124>>>0)<($126>>>0);
     if ($125) {
      $373 = $126;$i$03$i$i = $124;
     } else {
      break;
     }
    }
    $$pre7$i$i = HEAP32[$106>>2]|0;
    $128 = $$pre7$i$i;
   }
   $127 = ($128>>>0)<($108>>>0);
   if ($127) {
    $n$01$i1$i = $128;
    while(1) {
     $129 = ((($n$01$i1$i)) + 8|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ($130|0)==(0);
     $132 = ((($n$01$i1$i)) + 24|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = $133 & 64;
     $135 = ($134|0)==(0);
     if ($131) {
      if (!($135)) {
       $136 = ((($n$01$i1$i)) + 16|0);
       $137 = HEAP32[$136>>2]|0;
       $138 = ((($137)) + 5|0);
       $139 = HEAP8[$138>>0]|0;
       $140 = $139 & 3;
       $141 = ($140<<24>>24)==(0);
       if (!($141)) {
        HEAP32[$132>>2] = 10;
       }
      }
     } else {
      if ($135) {
       $149 = $130;
      } else {
       $142 = ((($n$01$i1$i)) + 16|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = ((($143)) + 5|0);
       $145 = HEAP8[$144>>0]|0;
       $146 = $145 & 3;
       $147 = ($146<<24>>24)==(0);
       if ($147) {
        $149 = $130;
       } else {
        _reallymarkobject($g,$143);
        $$pre8$i$i = HEAP32[$129>>2]|0;
        $149 = $$pre8$i$i;
       }
      }
      $148 = $149 & 64;
      $150 = ($148|0)==(0);
      if (!($150)) {
       $151 = HEAP32[$n$01$i1$i>>2]|0;
       $152 = ((($151)) + 5|0);
       $153 = HEAP8[$152>>0]|0;
       $154 = $153 & 3;
       $155 = ($154<<24>>24)==(0);
       if (!($155)) {
        _reallymarkobject($g,$151);
       }
      }
     }
     $156 = ((($n$01$i1$i)) + 32|0);
     $157 = ($156>>>0)<($108>>>0);
     if ($157) {
      $n$01$i1$i = $156;
     } else {
      break;
     }
    }
   }
  }
  $158 = ((($1)) + 8|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = $159 << 4;
  $161 = (($160) + 32)|0;
  $162 = ((($1)) + 7|0);
  $163 = HEAP8[$162>>0]|0;
  $164 = $163&255;
  $165 = 32 << $164;
  $166 = (($161) + ($165))|0;
  $size$0 = $166;
  break;
 }
 case 6:  {
  $167 = ((($1)) + 8|0);
  $168 = HEAP32[$167>>2]|0;
  HEAP32[$0>>2] = $168;
  $169 = ((($1)) + 12|0);
  $170 = HEAP32[$169>>2]|0;
  $171 = ($170|0)==(0|0);
  if (!($171)) {
   $172 = ((($170)) + 5|0);
   $173 = HEAP8[$172>>0]|0;
   $174 = $173 & 3;
   $175 = ($174<<24>>24)==(0);
   if (!($175)) {
    _reallymarkobject($g,$170);
   }
  }
  $176 = ((($1)) + 6|0);
  $177 = HEAP8[$176>>0]|0;
  $178 = $177&255;
  $179 = ($177<<24>>24)==(0);
  if ($179) {
   $$lcssa$i = $178;
  } else {
   $180 = ((($g)) + 61|0);
   $374 = $177;$i$01$i = 0;
   while(1) {
    $181 = (((($1)) + 16|0) + ($i$01$i<<2)|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = ($182|0)==(0|0);
    do {
     if ($183) {
      $201 = $374;
     } else {
      $184 = HEAP32[$182>>2]|0;
      $185 = ((($182)) + 8|0);
      $186 = ($184|0)==($185|0);
      if (!($186)) {
       $187 = HEAP8[$180>>0]|0;
       $188 = ($187<<24>>24)==(8);
       if (!($188)) {
        $189 = ((($185)) + 4|0);
        HEAP32[$189>>2] = 1;
        $201 = $374;
        break;
       }
      }
      $190 = ((($184)) + 8|0);
      $191 = HEAP32[$190>>2]|0;
      $192 = $191 & 64;
      $193 = ($192|0)==(0);
      if ($193) {
       $201 = $374;
      } else {
       $194 = HEAP32[$184>>2]|0;
       $195 = ((($194)) + 5|0);
       $196 = HEAP8[$195>>0]|0;
       $197 = $196 & 3;
       $198 = ($197<<24>>24)==(0);
       if ($198) {
        $201 = $374;
       } else {
        _reallymarkobject($g,$194);
        $$pre$i = HEAP8[$176>>0]|0;
        $201 = $$pre$i;
       }
      }
     }
    } while(0);
    $199 = (($i$01$i) + 1)|0;
    $200 = $201&255;
    $202 = ($199|0)<($200|0);
    if ($202) {
     $374 = $201;$i$01$i = $199;
    } else {
     $$lcssa$i = $200;
     break;
    }
   }
  }
  $203 = $$lcssa$i << 2;
  $204 = (($203) + 16)|0;
  $size$0 = $204;
  break;
 }
 case 8:  {
  $227 = ((($1)) + 36|0);
  $228 = HEAP32[$227>>2]|0;
  HEAP32[$0>>2] = $228;
  $229 = ((($g)) + 80|0);
  $230 = HEAP32[$229>>2]|0;
  HEAP32[$227>>2] = $230;
  HEAP32[$229>>2] = $1;
  $231 = $4 & 251;
  $232 = $231&255;
  HEAP8[$2>>0] = $232;
  $233 = ((($1)) + 28|0);
  $234 = HEAP32[$233>>2]|0;
  $235 = ($234|0)==(0|0);
  if ($235) {
   $size$0 = 1;
  } else {
   $236 = ((($1)) + 8|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = ($234>>>0)<($237>>>0);
   if ($238) {
    $376 = $237;$o$02$i = $234;
    while(1) {
     $239 = ((($o$02$i)) + 8|0);
     $240 = HEAP32[$239>>2]|0;
     $241 = $240 & 64;
     $242 = ($241|0)==(0);
     if ($242) {
      $250 = $376;
     } else {
      $243 = HEAP32[$o$02$i>>2]|0;
      $244 = ((($243)) + 5|0);
      $245 = HEAP8[$244>>0]|0;
      $246 = $245 & 3;
      $247 = ($246<<24>>24)==(0);
      if ($247) {
       $250 = $376;
      } else {
       _reallymarkobject($g,$243);
       $$pre$i6 = HEAP32[$236>>2]|0;
       $250 = $$pre$i6;
      }
     }
     $248 = ((($o$02$i)) + 16|0);
     $249 = ($248>>>0)<($250>>>0);
     if ($249) {
      $376 = $250;$o$02$i = $248;
     } else {
      $o$0$lcssa$i = $248;
      break;
     }
    }
   } else {
    $o$0$lcssa$i = $234;
   }
   $251 = ((($g)) + 61|0);
   $252 = HEAP8[$251>>0]|0;
   $253 = ($252<<24>>24)==(8);
   if ($253) {
    $254 = HEAP32[$233>>2]|0;
    $255 = ((($1)) + 92|0);
    $256 = HEAP32[$255>>2]|0;
    $257 = (($254) + ($256<<4)|0);
    $258 = ($o$0$lcssa$i>>>0)<($257>>>0);
    if ($258) {
     $o$11$i = $o$0$lcssa$i;
     while(1) {
      $259 = ((($o$11$i)) + 8|0);
      HEAP32[$259>>2] = 0;
      $260 = ((($o$11$i)) + 16|0);
      $261 = ($260>>>0)<($257>>>0);
      if ($261) {
       $o$11$i = $260;
      } else {
       break;
      }
     }
    }
    $262 = ((($1)) + 40|0);
    $263 = HEAP32[$262>>2]|0;
    $264 = ($263|0)==($1|0);
    if ($264) {
     $265 = ((($1)) + 32|0);
     $266 = HEAP32[$265>>2]|0;
     $267 = ($266|0)==(0|0);
     if (!($267)) {
      $268 = ((($g)) + 104|0);
      $269 = HEAP32[$268>>2]|0;
      HEAP32[$262>>2] = $269;
      HEAP32[$268>>2] = $1;
     }
    }
   } else {
    $270 = ((($g)) + 62|0);
    $271 = HEAP8[$270>>0]|0;
    $272 = ($271<<24>>24)==(1);
    if (!($272)) {
     _luaD_shrinkstack($1);
    }
   }
   $273 = ((($1)) + 92|0);
   $274 = HEAP32[$273>>2]|0;
   $275 = $274 << 4;
   $276 = (($275) + 112)|0;
   $size$0 = $276;
  }
  break;
 }
 case 38:  {
  $205 = ((($1)) + 8|0);
  $206 = HEAP32[$205>>2]|0;
  HEAP32[$0>>2] = $206;
  $207 = ((($1)) + 6|0);
  $208 = HEAP8[$207>>0]|0;
  $209 = $208&255;
  $210 = ($208<<24>>24)==(0);
  if ($210) {
   $$lcssa$i4 = $209;
  } else {
   $375 = $208;$i$01$i1 = 0;
   while(1) {
    $211 = (((((($1)) + 16|0) + ($i$01$i1<<4)|0)) + 8|0);
    $212 = HEAP32[$211>>2]|0;
    $213 = $212 & 64;
    $214 = ($213|0)==(0);
    if ($214) {
     $223 = $375;
    } else {
     $215 = (((($1)) + 16|0) + ($i$01$i1<<4)|0);
     $216 = HEAP32[$215>>2]|0;
     $217 = ((($216)) + 5|0);
     $218 = HEAP8[$217>>0]|0;
     $219 = $218 & 3;
     $220 = ($219<<24>>24)==(0);
     if ($220) {
      $223 = $375;
     } else {
      _reallymarkobject($g,$216);
      $$pre$i3 = HEAP8[$207>>0]|0;
      $223 = $$pre$i3;
     }
    }
    $221 = (($i$01$i1) + 1)|0;
    $222 = $223&255;
    $224 = ($221|0)<($222|0);
    if ($224) {
     $375 = $223;$i$01$i1 = $221;
    } else {
     $$lcssa$i4 = $222;
     break;
    }
   }
  }
  $225 = $$lcssa$i4 << 4;
  $226 = (($225) + 16)|0;
  $size$0 = $226;
  break;
 }
 case 9:  {
  $277 = ((($1)) + 76|0);
  $278 = HEAP32[$277>>2]|0;
  HEAP32[$0>>2] = $278;
  $279 = ((($1)) + 68|0);
  $280 = HEAP32[$279>>2]|0;
  $281 = ($280|0)==(0|0);
  if (!($281)) {
   $282 = ((($280)) + 5|0);
   $283 = HEAP8[$282>>0]|0;
   $284 = $283 & 3;
   $285 = ($284<<24>>24)==(0);
   if (!($285)) {
    HEAP32[$279>>2] = 0;
   }
  }
  $286 = ((($1)) + 72|0);
  $287 = HEAP32[$286>>2]|0;
  $288 = ($287|0)==(0|0);
  if (!($288)) {
   $289 = ((($287)) + 5|0);
   $290 = HEAP8[$289>>0]|0;
   $291 = $290 & 3;
   $292 = ($291<<24>>24)==(0);
   if (!($292)) {
    _reallymarkobject($g,$287);
   }
  }
  $293 = ((($1)) + 16|0);
  $294 = HEAP32[$293>>2]|0;
  $295 = ($294|0)>(0);
  if ($295) {
   $296 = ((($1)) + 44|0);
   $377 = $294;$i$016$i = 0;
   while(1) {
    $301 = HEAP32[$296>>2]|0;
    $302 = (((($301) + ($i$016$i<<4)|0)) + 8|0);
    $303 = HEAP32[$302>>2]|0;
    $304 = $303 & 64;
    $305 = ($304|0)==(0);
    if ($305) {
     $314 = $377;
    } else {
     $306 = (($301) + ($i$016$i<<4)|0);
     $307 = HEAP32[$306>>2]|0;
     $308 = ((($307)) + 5|0);
     $309 = HEAP8[$308>>0]|0;
     $310 = $309 & 3;
     $311 = ($310<<24>>24)==(0);
     if ($311) {
      $314 = $377;
     } else {
      _reallymarkobject($g,$307);
      $$pre$i8 = HEAP32[$293>>2]|0;
      $314 = $$pre$i8;
     }
    }
    $312 = (($i$016$i) + 1)|0;
    $313 = ($312|0)<($314|0);
    if ($313) {
     $377 = $314;$i$016$i = $312;
    } else {
     break;
    }
   }
  }
  $297 = ((($1)) + 12|0);
  $298 = HEAP32[$297>>2]|0;
  $299 = ($298|0)>(0);
  if ($299) {
   $300 = ((($1)) + 64|0);
   $378 = $298;$i$113$i = 0;
   while(1) {
    $319 = HEAP32[$300>>2]|0;
    $320 = (($319) + ($i$113$i<<3)|0);
    $321 = HEAP32[$320>>2]|0;
    $322 = ($321|0)==(0|0);
    if ($322) {
     $329 = $378;
    } else {
     $323 = ((($321)) + 5|0);
     $324 = HEAP8[$323>>0]|0;
     $325 = $324 & 3;
     $326 = ($325<<24>>24)==(0);
     if ($326) {
      $329 = $378;
     } else {
      _reallymarkobject($g,$321);
      $$pre20$i = HEAP32[$297>>2]|0;
      $329 = $$pre20$i;
     }
    }
    $327 = (($i$113$i) + 1)|0;
    $328 = ($327|0)<($329|0);
    if ($328) {
     $378 = $329;$i$113$i = $327;
    } else {
     break;
    }
   }
  }
  $315 = ((($1)) + 28|0);
  $316 = HEAP32[$315>>2]|0;
  $317 = ($316|0)>(0);
  if ($317) {
   $318 = ((($1)) + 52|0);
   $380 = $316;$i$210$i = 0;
   while(1) {
    $334 = HEAP32[$318>>2]|0;
    $335 = (($334) + ($i$210$i<<2)|0);
    $336 = HEAP32[$335>>2]|0;
    $337 = ($336|0)==(0|0);
    if ($337) {
     $344 = $380;
    } else {
     $338 = ((($336)) + 5|0);
     $339 = HEAP8[$338>>0]|0;
     $340 = $339 & 3;
     $341 = ($340<<24>>24)==(0);
     if ($341) {
      $344 = $380;
     } else {
      _reallymarkobject($g,$336);
      $$pre21$i = HEAP32[$315>>2]|0;
      $344 = $$pre21$i;
     }
    }
    $342 = (($i$210$i) + 1)|0;
    $343 = ($342|0)<($344|0);
    if ($343) {
     $380 = $344;$i$210$i = $342;
    } else {
     $379 = $344;
     break;
    }
   }
  } else {
   $379 = $316;
  }
  $330 = ((($1)) + 32|0);
  $331 = HEAP32[$330>>2]|0;
  $332 = ($331|0)>(0);
  if ($332) {
   $333 = ((($1)) + 60|0);
   $381 = $331;$i$39$i = 0;
   while(1) {
    $345 = HEAP32[$333>>2]|0;
    $346 = (($345) + (($i$39$i*12)|0)|0);
    $347 = HEAP32[$346>>2]|0;
    $348 = ($347|0)==(0|0);
    if ($348) {
     $355 = $381;
    } else {
     $349 = ((($347)) + 5|0);
     $350 = HEAP8[$349>>0]|0;
     $351 = $350 & 3;
     $352 = ($351<<24>>24)==(0);
     if ($352) {
      $355 = $381;
     } else {
      _reallymarkobject($g,$347);
      $$pre22$i = HEAP32[$330>>2]|0;
      $355 = $$pre22$i;
     }
    }
    $353 = (($i$39$i) + 1)|0;
    $354 = ($353|0)<($355|0);
    if ($354) {
     $381 = $355;$i$39$i = $353;
    } else {
     $$lcssa35 = $355;
     break;
    }
   }
   $$pre23$i = HEAP32[$315>>2]|0;
   $$lcssa$i12 = $$lcssa35;$365 = $$pre23$i;
  } else {
   $$lcssa$i12 = $331;$365 = $379;
  }
  $356 = ((($1)) + 20|0);
  $357 = HEAP32[$356>>2]|0;
  $358 = HEAP32[$293>>2]|0;
  $359 = $358 << 4;
  $360 = ((($1)) + 24|0);
  $361 = HEAP32[$360>>2]|0;
  $362 = ($$lcssa$i12*12)|0;
  $363 = HEAP32[$297>>2]|0;
  $364 = $363 << 3;
  $tmp$i = (($357) + ($365))|0;
  $tmp1$i = (($tmp$i) + ($361))|0;
  $tmp2$i = $tmp1$i << 2;
  $366 = (($362) + 80)|0;
  $367 = (($366) + ($359))|0;
  $368 = (($367) + ($364))|0;
  $369 = (($368) + ($tmp2$i))|0;
  $size$0 = $369;
  break;
 }
 default: {
  return;
 }
 }
 $370 = ((($g)) + 16|0);
 $371 = HEAP32[$370>>2]|0;
 $372 = (($371) + ($size$0))|0;
 HEAP32[$370>>2] = $372;
 return;
}
function _traverseephemeron($g,$h) {
 $g = $g|0;
 $h = $h|0;
 var $$pre = 0, $$pre17 = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $hasclears$0$lcssa = 0, $hasclears$01 = 0, $hasclears$1 = 0, $hasww$0$ = 0, $hasww$0$lcssa = 0, $hasww$03 = 0, $hasww$1 = 0, $i$012 = 0, $marked$0$lcssa = 0, $marked$011 = 0, $marked$1 = 0, $marked$1$lcssa = 0;
 var $marked$2$lcssa = 0, $marked$27 = 0, $marked$3 = 0, $n$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($h)) + 7|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = 1 << $2;
 $4 = ((($h)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($3<<5)|0);
 $7 = ((($h)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $26 = $5;$marked$0$lcssa = 0;
 } else {
  $10 = ((($h)) + 12|0);
  $84 = $8;$i$012 = 0;$marked$011 = 0;
  while(1) {
   $11 = HEAP32[$10>>2]|0;
   $12 = (((($11) + ($i$012<<4)|0)) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 & 64;
   $15 = ($14|0)==(0);
   if ($15) {
    $24 = $84;$marked$1 = $marked$011;
   } else {
    $16 = (($11) + ($i$012<<4)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ((($17)) + 5|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = $19 & 3;
    $21 = ($20<<24>>24)==(0);
    if ($21) {
     $24 = $84;$marked$1 = $marked$011;
    } else {
     _reallymarkobject($g,$17);
     $$pre = HEAP32[$7>>2]|0;
     $24 = $$pre;$marked$1 = 1;
    }
   }
   $22 = (($i$012) + 1)|0;
   $23 = ($22>>>0)<($24>>>0);
   if ($23) {
    $84 = $24;$i$012 = $22;$marked$011 = $marked$1;
   } else {
    $marked$1$lcssa = $marked$1;
    break;
   }
  }
  $$pre17 = HEAP32[$4>>2]|0;
  $26 = $$pre17;$marked$0$lcssa = $marked$1$lcssa;
 }
 $25 = ($26>>>0)<($6>>>0);
 if ($25) {
  $hasclears$01 = 0;$hasww$03 = 0;$marked$27 = $marked$0$lcssa;$n$05 = $26;
  while(1) {
   $27 = ((($n$05)) + 8|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==(0);
   $30 = ((($n$05)) + 24|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $31 & 64;
   $33 = ($32|0)==(0);
   L14: do {
    if ($29) {
     if ($33) {
      $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
     } else {
      $34 = ((($n$05)) + 16|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ((($35)) + 5|0);
      $37 = HEAP8[$36>>0]|0;
      $38 = $37 & 3;
      $39 = ($38<<24>>24)==(0);
      if ($39) {
       $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
      } else {
       HEAP32[$30>>2] = 10;
       $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
      }
     }
    } else {
     do {
      if ($33) {
       $50 = $28;
       label = 18;
      } else {
       $40 = ((($n$05)) + 16|0);
       $41 = $31 & 15;
       $42 = ($41|0)==(4);
       $43 = HEAP32[$40>>2]|0;
       if ($42) {
        $44 = ($43|0)==(0|0);
        if ($44) {
         $50 = $28;
         label = 18;
         break;
        }
        $45 = ((($43)) + 5|0);
        $46 = HEAP8[$45>>0]|0;
        $47 = $46 & 3;
        $48 = ($47<<24>>24)==(0);
        if ($48) {
         $50 = $28;
         label = 18;
         break;
        }
        _reallymarkobject($g,$43);
        $$pre18 = HEAP32[$27>>2]|0;
        $50 = $$pre18;
        label = 18;
        break;
       }
       $52 = ((($43)) + 5|0);
       $53 = HEAP8[$52>>0]|0;
       $54 = $53 & 3;
       $55 = ($54<<24>>24)==(0);
       $56 = $28 & 64;
       $57 = ($56|0)==(0);
       if ($55) {
        if ($57) {
         $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
         break L14;
        } else {
         break;
        }
       }
       if ($57) {
        $hasclears$1 = 1;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
        break L14;
       }
       $58 = HEAP32[$n$05>>2]|0;
       $59 = ((($58)) + 5|0);
       $60 = HEAP8[$59>>0]|0;
       $61 = $60 & 3;
       $62 = ($61<<24>>24)==(0);
       $hasww$0$ = $62 ? $hasww$03 : 1;
       $hasclears$1 = 1;$hasww$1 = $hasww$0$;$marked$3 = $marked$27;
       break L14;
      }
     } while(0);
     if ((label|0) == 18) {
      label = 0;
      $49 = $50 & 64;
      $51 = ($49|0)==(0);
      if ($51) {
       $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
       break;
      }
     }
     $63 = HEAP32[$n$05>>2]|0;
     $64 = ((($63)) + 5|0);
     $65 = HEAP8[$64>>0]|0;
     $66 = $65 & 3;
     $67 = ($66<<24>>24)==(0);
     if ($67) {
      $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
     } else {
      _reallymarkobject($g,$63);
      $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = 1;
     }
    }
   } while(0);
   $68 = ((($n$05)) + 32|0);
   $69 = ($68>>>0)<($6>>>0);
   if ($69) {
    $hasclears$01 = $hasclears$1;$hasww$03 = $hasww$1;$marked$27 = $marked$3;$n$05 = $68;
   } else {
    $hasclears$0$lcssa = $hasclears$1;$hasww$0$lcssa = $hasww$1;$marked$2$lcssa = $marked$3;
    break;
   }
  }
 } else {
  $hasclears$0$lcssa = 0;$hasww$0$lcssa = 0;$marked$2$lcssa = $marked$0$lcssa;
 }
 $70 = ((($g)) + 61|0);
 $71 = HEAP8[$70>>0]|0;
 $72 = ($71<<24>>24)==(0);
 if ($72) {
  $73 = ((($g)) + 80|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ((($h)) + 28|0);
  HEAP32[$75>>2] = $74;
  HEAP32[$73>>2] = $h;
  return ($marked$2$lcssa|0);
 }
 $76 = ($hasww$0$lcssa|0)==(0);
 if (!($76)) {
  $77 = ((($g)) + 88|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ((($h)) + 28|0);
  HEAP32[$79>>2] = $78;
  HEAP32[$77>>2] = $h;
  return ($marked$2$lcssa|0);
 }
 $80 = ($hasclears$0$lcssa|0)==(0);
 if ($80) {
  return ($marked$2$lcssa|0);
 }
 $81 = ((($g)) + 92|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ((($h)) + 28|0);
 HEAP32[$83>>2] = $82;
 HEAP32[$81>>2] = $h;
 return ($marked$2$lcssa|0);
}
function _clearvalues($g,$l,$f) {
 $g = $g|0;
 $l = $l|0;
 $f = $f|0;
 var $$06 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $n$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($l|0)==($f|0);
 if ($0) {
  return;
 } else {
  $$06 = $l;
 }
 while(1) {
  $1 = ((($$06)) + 7|0);
  $2 = HEAP8[$1>>0]|0;
  $3 = $2&255;
  $4 = 1 << $3;
  $5 = ((($$06)) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($4<<5)|0);
  $8 = ((($$06)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0);
  if ($10) {
   $21 = $6;
  } else {
   $11 = ((($$06)) + 12|0);
   $i$01 = 0;
   while(1) {
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + ($i$01<<4)|0);
    $14 = (_iscleared($g,$13)|0);
    $15 = ($14|0)==(0);
    if (!($15)) {
     $16 = (((($12) + ($i$01<<4)|0)) + 8|0);
     HEAP32[$16>>2] = 0;
    }
    $17 = (($i$01) + 1)|0;
    $18 = HEAP32[$8>>2]|0;
    $19 = ($17>>>0)<($18>>>0);
    if ($19) {
     $i$01 = $17;
    } else {
     break;
    }
   }
   $$pre = HEAP32[$5>>2]|0;
   $21 = $$pre;
  }
  $20 = ($21>>>0)<($7>>>0);
  if ($20) {
   $n$02 = $21;
   while(1) {
    $22 = ((($n$02)) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0);
    if (!($24)) {
     $25 = (_iscleared($g,$n$02)|0);
     $26 = ($25|0)==(0);
     if (!($26)) {
      HEAP32[$22>>2] = 0;
      $27 = ((($n$02)) + 24|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = $28 & 64;
      $30 = ($29|0)==(0);
      if (!($30)) {
       $31 = ((($n$02)) + 16|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = ((($32)) + 5|0);
       $34 = HEAP8[$33>>0]|0;
       $35 = $34 & 3;
       $36 = ($35<<24>>24)==(0);
       if (!($36)) {
        HEAP32[$27>>2] = 10;
       }
      }
     }
    }
    $37 = ((($n$02)) + 32|0);
    $38 = ($37>>>0)<($7>>>0);
    if ($38) {
     $n$02 = $37;
    } else {
     break;
    }
   }
  }
  $39 = ((($$06)) + 28|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==($f|0);
  if ($41) {
   break;
  } else {
   $$06 = $40;
  }
 }
 return;
}
function _iscleared($g,$o) {
 $g = $g|0;
 $o = $o|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($o)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 64;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = $1 & 15;
 $5 = ($4|0)==(4);
 $6 = HEAP32[$o>>2]|0;
 if (!($5)) {
  $12 = ((($6)) + 5|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 & 3;
  $$0 = $15;
  return ($$0|0);
 }
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0 = 0;
  return ($$0|0);
 }
 $8 = ((($6)) + 5|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 3;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $$0 = 0;
  return ($$0|0);
 }
 _reallymarkobject($g,$6);
 $$0 = 0;
 return ($$0|0);
}
function _dothecall($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -32|0);
 _luaD_call($L,$2,0,0);
 return;
}
function _luaM_growaux_($L,$block,$size,$size_elems,$limit,$what) {
 $L = $L|0;
 $block = $block|0;
 $size = $size|0;
 $size_elems = $size_elems|0;
 $limit = $limit|0;
 $what = $what|0;
 var $$ = 0, $$neg$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newblock$0$i = 0, $newsize$0 = 0, $or$cond$i = 0, $osize$op$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[$size>>2]|0;
 $1 = (($limit|0) / 2)&-1;
 $2 = ($0|0)<($1|0);
 if ($2) {
  $4 = $0 << 1;
  $5 = ($4|0)<(4);
  $$ = $5 ? 4 : $4;
  $newsize$0 = $$;
 } else {
  $3 = ($0|0)<($limit|0);
  if ($3) {
   $newsize$0 = $limit;
  } else {
   HEAP32[$vararg_buffer>>2] = $what;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $limit;
   _luaG_runerror($L,1688,$vararg_buffer);
   // unreachable;
  }
 }
 $6 = (($newsize$0) + 1)|0;
 $7 = (4294967295 / ($size_elems>>>0))&-1;
 $8 = ($6>>>0)>($7>>>0);
 if ($8) {
  _luaM_toobig($L);
  // unreachable;
 }
 $9 = Math_imul($0, $size_elems)|0;
 $10 = Math_imul($newsize$0, $size_elems)|0;
 $11 = ((($L)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($block|0)!=(0|0);
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($12)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_iiiii[$14 & 15]($16,$block,$9,$10)|0);
 $18 = ($17|0)==(0|0);
 $19 = ($10|0)!=(0);
 $or$cond$i = $19 & $18;
 if ($or$cond$i) {
  _luaC_fullgc($L,1);
  $20 = HEAP32[$12>>2]|0;
  $21 = HEAP32[$15>>2]|0;
  $22 = (FUNCTION_TABLE_iiiii[$20 & 15]($21,$block,$9,$10)|0);
  $23 = ($22|0)==(0|0);
  if ($23) {
   _luaD_throw($L,4);
   // unreachable;
  } else {
   $newblock$0$i = $22;
  }
 } else {
  $newblock$0$i = $17;
 }
 $24 = ((($12)) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $osize$op$i = (0 - ($9))|0;
 $$neg$i = $13 ? $osize$op$i : 0;
 $26 = (($$neg$i) + ($10))|0;
 $27 = (($26) + ($25))|0;
 HEAP32[$24>>2] = $27;
 HEAP32[$size>>2] = $newsize$0;
 STACKTOP = sp;return ($newblock$0$i|0);
}
function _luaM_toobig($L) {
 $L = $L|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 _luaG_runerror($L,1720,$vararg_buffer);
 // unreachable;
}
function _luaM_realloc_($L,$block,$osize,$nsize) {
 $L = $L|0;
 $block = $block|0;
 $osize = $osize|0;
 $nsize = $nsize|0;
 var $$neg = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newblock$0 = 0, $or$cond = 0;
 var $osize$op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($block|0)!=(0|0);
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$3 & 15]($5,$block,$osize,$nsize)|0);
 $7 = ($6|0)==(0|0);
 $8 = ($nsize|0)!=(0);
 $or$cond = $8 & $7;
 if ($or$cond) {
  _luaC_fullgc($L,1);
  $9 = HEAP32[$1>>2]|0;
  $10 = HEAP32[$4>>2]|0;
  $11 = (FUNCTION_TABLE_iiiii[$9 & 15]($10,$block,$osize,$nsize)|0);
  $12 = ($11|0)==(0|0);
  if ($12) {
   _luaD_throw($L,4);
   // unreachable;
  } else {
   $newblock$0 = $11;
  }
 } else {
  $newblock$0 = $6;
 }
 $13 = ((($1)) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $osize$op = (0 - ($osize))|0;
 $$neg = $2 ? $osize$op : 0;
 $15 = (($$neg) + ($nsize))|0;
 $16 = (($15) + ($14))|0;
 HEAP32[$13>>2] = $16;
 return ($newblock$0|0);
}
function _luaO_int2fb($x) {
 $x = $x|0;
 var $$0$lcssa = 0, $$01 = 0, $$02 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $e$0$lcssa = 0, $e$03 = 0, $phitmp = 0, $phitmp$lcssa = 0, $phitmp5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($x>>>0)<(8);
 if ($0) {
  $$01 = $x;
  return ($$01|0);
 }
 $1 = ($x>>>0)>(15);
 if ($1) {
  $$02 = $x;$e$03 = 1;
  while(1) {
   $2 = (($$02) + 1)|0;
   $3 = $2 >>> 1;
   $phitmp = (($e$03) + 1)|0;
   $4 = ($2>>>0)>(31);
   if ($4) {
    $$02 = $3;$e$03 = $phitmp;
   } else {
    $$lcssa = $3;$phitmp$lcssa = $phitmp;
    break;
   }
  }
  $phitmp5 = $phitmp$lcssa << 3;
  $$0$lcssa = $$lcssa;$e$0$lcssa = $phitmp5;
 } else {
  $$0$lcssa = $x;$e$0$lcssa = 8;
 }
 $5 = (($$0$lcssa) + -8)|0;
 $6 = $e$0$lcssa | $5;
 $$01 = $6;
 return ($$01|0);
}
function _luaO_fb2int($x) {
 $x = $x|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $x >>> 3;
 $1 = $0 & 31;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = $x;
  return ($$0|0);
 }
 $3 = $x & 7;
 $4 = $3 | 8;
 $5 = (($1) + -1)|0;
 $6 = $4 << $5;
 $$0 = $6;
 return ($$0|0);
}
function _luaO_ceillog2($x) {
 $x = $x|0;
 var $$0$lcssa = 0, $$01 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $l$0$lcssa = 0, $l$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($x) + -1)|0;
 $1 = ($0>>>0)>(255);
 if ($1) {
  $$01 = $0;$l$02 = 0;
  while(1) {
   $2 = (($l$02) + 8)|0;
   $3 = $$01 >>> 8;
   $4 = ($$01>>>0)>(65535);
   if ($4) {
    $$01 = $3;$l$02 = $2;
   } else {
    $$0$lcssa = $3;$l$0$lcssa = $2;
    break;
   }
  }
 } else {
  $$0$lcssa = $0;$l$0$lcssa = 0;
 }
 $5 = (1776 + ($$0$lcssa)|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = (($7) + ($l$0$lcssa))|0;
 return ($8|0);
}
function _luaO_arith($L,$op,$p1,$p2,$res) {
 $L = $L|0;
 $op = $op|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $res = $res|0;
 var $$0$i1 = 0.0, $$0$i5 = 0.0, $$pre = 0.0, $$pre10 = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0.0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i1 = 0, $i2 = 0, $m$0$i4 = 0.0, $n1 = 0, $n12 = 0, $n2 = 0, $n23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $i1 = sp + 40|0;
 $i2 = sp + 32|0;
 $n1 = sp + 24|0;
 $n2 = sp + 16|0;
 $n12 = sp + 8|0;
 $n23 = sp;
 L1: do {
  switch ($op|0) {
  case 4: case 5:  {
   $67 = ((($p1)) + 8|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==(3);
   if ($69) {
    $70 = +HEAPF64[$p1>>3];
    HEAPF64[$n1>>3] = $70;
   } else {
    $71 = (_luaV_tonumber_($p1,$n1)|0);
    $72 = ($71|0)==(0);
    if ($72) {
     break L1;
    }
   }
   $73 = ((($p2)) + 8|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(3);
   if ($75) {
    $76 = +HEAPF64[$p2>>3];
    HEAPF64[$n2>>3] = $76;
    $81 = $76;
   } else {
    $77 = (_luaV_tonumber_($p2,$n2)|0);
    $78 = ($77|0)==(0);
    if ($78) {
     break L1;
    }
    $$pre = +HEAPF64[$n2>>3];
    $81 = $$pre;
   }
   $79 = +HEAPF64[$n1>>3];
   if ((($op|0) == 5)) {
    $80 = $79 / $81;
    $$0$i1 = $80;
   } else if ((($op|0) == 4)) {
    $82 = (+Math_pow((+$79),(+$81)));
    $$0$i1 = $82;
   } else {
    $$0$i1 = 0.0;
   }
   HEAPF64[$res>>3] = $$0$i1;
   $83 = ((($res)) + 8|0);
   HEAP32[$83>>2] = 3;
   STACKTOP = sp;return;
   break;
  }
  case 13: case 11: case 10: case 9: case 8: case 7:  {
   $0 = ((($p1)) + 8|0);
   $1 = HEAP32[$0>>2]|0;
   $2 = ($1|0)==(19);
   if ($2) {
    $3 = $p1;
    $4 = $3;
    $5 = HEAP32[$4>>2]|0;
    $6 = (($3) + 4)|0;
    $7 = $6;
    $8 = HEAP32[$7>>2]|0;
    $9 = $i1;
    $10 = $9;
    HEAP32[$10>>2] = $5;
    $11 = (($9) + 4)|0;
    $12 = $11;
    HEAP32[$12>>2] = $8;
   } else {
    $13 = (_luaV_tointeger_($p1,$i1)|0);
    $14 = ($13|0)==(0);
    if ($14) {
     break L1;
    }
   }
   $15 = ((($p2)) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(19);
   if ($17) {
    $18 = $p2;
    $19 = $18;
    $20 = HEAP32[$19>>2]|0;
    $21 = (($18) + 4)|0;
    $22 = $21;
    $23 = HEAP32[$22>>2]|0;
    $24 = $i2;
    $25 = $24;
    HEAP32[$25>>2] = $20;
    $26 = (($24) + 4)|0;
    $27 = $26;
    HEAP32[$27>>2] = $23;
    $43 = $20;$45 = $23;
   } else {
    $28 = (_luaV_tointeger_($p2,$i2)|0);
    $29 = ($28|0)==(0);
    if ($29) {
     break L1;
    }
    $30 = $i2;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $43 = $32;$45 = $35;
   }
   $36 = $i1;
   $37 = $36;
   $38 = HEAP32[$37>>2]|0;
   $39 = (($36) + 4)|0;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   switch ($op|0) {
   case 12:  {
    $56 = (_i64Subtract(0,0,($38|0),($41|0))|0);
    $57 = tempRet0;
    $62 = $56;$65 = $57;
    break;
   }
   case 13:  {
    $58 = $38 ^ -1;
    $59 = $41 ^ -1;
    $62 = $58;$65 = $59;
    break;
   }
   case 7:  {
    $42 = $43 & $38;
    $44 = $45 & $41;
    $62 = $42;$65 = $44;
    break;
   }
   case 11:  {
    $52 = (_i64Subtract(0,0,($43|0),($45|0))|0);
    $53 = tempRet0;
    $54 = (_luaV_shiftl($38,$41,$52,$53)|0);
    $55 = tempRet0;
    $62 = $54;$65 = $55;
    break;
   }
   case 9:  {
    $48 = $43 ^ $38;
    $49 = $45 ^ $41;
    $62 = $48;$65 = $49;
    break;
   }
   case 10:  {
    $50 = (_luaV_shiftl($38,$41,$43,$45)|0);
    $51 = tempRet0;
    $62 = $50;$65 = $51;
    break;
   }
   case 8:  {
    $46 = $43 | $38;
    $47 = $45 | $41;
    $62 = $46;$65 = $47;
    break;
   }
   default: {
    $62 = 0;$65 = 0;
   }
   }
   $60 = $res;
   $61 = $60;
   HEAP32[$61>>2] = $62;
   $63 = (($60) + 4)|0;
   $64 = $63;
   HEAP32[$64>>2] = $65;
   $66 = ((($res)) + 8|0);
   HEAP32[$66>>2] = 19;
   STACKTOP = sp;return;
   break;
  }
  default: {
   $84 = ((($p1)) + 8|0);
   $85 = HEAP32[$84>>2]|0;
   if ((($85|0) == 3)) {
    $122 = +HEAPF64[$p1>>3];
    HEAPF64[$n12>>3] = $122;
   } else if ((($85|0) == 19)) {
    $86 = ((($p2)) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87|0)==(19);
    if ($88) {
     $89 = $p1;
     $90 = $89;
     $91 = HEAP32[$90>>2]|0;
     $92 = (($89) + 4)|0;
     $93 = $92;
     $94 = HEAP32[$93>>2]|0;
     $95 = $p2;
     $96 = $95;
     $97 = HEAP32[$96>>2]|0;
     $98 = (($95) + 4)|0;
     $99 = $98;
     $100 = HEAP32[$99>>2]|0;
     switch ($op|0) {
     case 0:  {
      $101 = (_i64Add(($97|0),($100|0),($91|0),($94|0))|0);
      $102 = tempRet0;
      $117 = $101;$120 = $102;
      break;
     }
     case 1:  {
      $103 = (_i64Subtract(($91|0),($94|0),($97|0),($100|0))|0);
      $104 = tempRet0;
      $117 = $103;$120 = $104;
      break;
     }
     case 2:  {
      $105 = (___muldi3(($97|0),($100|0),($91|0),($94|0))|0);
      $106 = tempRet0;
      $117 = $105;$120 = $106;
      break;
     }
     case 3:  {
      $107 = (_luaV_mod($L,$91,$94,$97,$100)|0);
      $108 = tempRet0;
      $117 = $107;$120 = $108;
      break;
     }
     case 6:  {
      $109 = (_luaV_div($L,$91,$94,$97,$100)|0);
      $110 = tempRet0;
      $117 = $109;$120 = $110;
      break;
     }
     case 12:  {
      $111 = (_i64Subtract(0,0,($91|0),($94|0))|0);
      $112 = tempRet0;
      $117 = $111;$120 = $112;
      break;
     }
     case 13:  {
      $113 = $91 ^ -1;
      $114 = $94 ^ -1;
      $117 = $113;$120 = $114;
      break;
     }
     default: {
      $117 = 0;$120 = 0;
     }
     }
     $115 = $res;
     $116 = $115;
     HEAP32[$116>>2] = $117;
     $118 = (($115) + 4)|0;
     $119 = $118;
     HEAP32[$119>>2] = $120;
     $121 = ((($res)) + 8|0);
     HEAP32[$121>>2] = 19;
     STACKTOP = sp;return;
    } else {
     label = 41;
    }
   } else {
    label = 41;
   }
   if ((label|0) == 41) {
    $123 = (_luaV_tonumber_($p1,$n12)|0);
    $124 = ($123|0)==(0);
    if ($124) {
     break L1;
    }
   }
   $125 = ((($p2)) + 8|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = ($126|0)==(3);
   if ($127) {
    $128 = +HEAPF64[$p2>>3];
    HEAPF64[$n23>>3] = $128;
    $133 = $128;
   } else {
    $129 = (_luaV_tonumber_($p2,$n23)|0);
    $130 = ($129|0)==(0);
    if ($130) {
     break L1;
    }
    $$pre10 = +HEAPF64[$n23>>3];
    $133 = $$pre10;
   }
   $131 = +HEAPF64[$n12>>3];
   switch ($op|0) {
   case 5:  {
    $136 = $131 / $133;
    $$0$i5 = $136;
    break;
   }
   case 4:  {
    $137 = (+Math_pow((+$131),(+$133)));
    $$0$i5 = $137;
    break;
   }
   case 6:  {
    $138 = $131 / $133;
    $139 = (+Math_floor((+$138)));
    $$0$i5 = $139;
    break;
   }
   case 12:  {
    $140 = -$131;
    $$0$i5 = $140;
    break;
   }
   case 3:  {
    $141 = (+_fmod($131,$133));
    $142 = $133 * $141;
    $143 = $142 < 0.0;
    $144 = $133 + $141;
    $m$0$i4 = $143 ? $144 : $141;
    $$0$i5 = $m$0$i4;
    break;
   }
   case 0:  {
    $132 = $131 + $133;
    $$0$i5 = $132;
    break;
   }
   case 1:  {
    $134 = $131 - $133;
    $$0$i5 = $134;
    break;
   }
   case 2:  {
    $135 = $131 * $133;
    $$0$i5 = $135;
    break;
   }
   default: {
    $$0$i5 = 0.0;
   }
   }
   HEAPF64[$res>>3] = $$0$i5;
   $145 = ((($res)) + 8|0);
   HEAP32[$145>>2] = 3;
   STACKTOP = sp;return;
  }
  }
 } while(0);
 $146 = (($op) + 6)|0;
 _luaT_trybinTM($L,$p1,$p2,$res,$146);
 STACKTOP = sp;return;
}
function _luaO_hexavalue($c) {
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + 1)|0;
 $1 = (5048 + ($0)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 & 2;
 $4 = ($3<<24>>24)==(0);
 $5 = (($c) + -48)|0;
 $6 = $c | 32;
 $7 = (($6) + -87)|0;
 $$0 = $4 ? $7 : $5;
 return ($$0|0);
}
function _luaO_str2num($s,$o) {
 $s = $s|0;
 $o = $o|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i2$i = 0, $$lcssa = 0, $$lcssa$i = 0, $$lcssa1$i = 0, $$lcssa67 = 0, $$lcssa7 = 0, $$lcssa77 = 0, $$lcssa78 = 0, $$lcssa8 = 0, $$ph$i = 0, $$ph$i$pn = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0.0;
 var $e$0 = 0, $empty$2$ph$i = 0, $endptr$i = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$not = 0, $storemerge$i = 0, $storemerge$i$lcssa = 0, $storemerge111$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $endptr$i = sp;
 $storemerge$i = $s;
 while(1) {
  $0 = HEAP8[$storemerge$i>>0]|0;
  $1 = $0&255;
  $2 = (($1) + 1)|0;
  $3 = (5048 + ($2)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4 & 8;
  $6 = ($5<<24>>24)==(0);
  $7 = ((($storemerge$i)) + 1|0);
  if ($6) {
   $$lcssa77 = $0;$$lcssa78 = $7;$storemerge$i$lcssa = $storemerge$i;
   break;
  } else {
   $storemerge$i = $7;
  }
 }
 if ((($$lcssa77<<24>>24) == 45)) {
  $$0$i$i = 1;$9 = $$lcssa78;
 } else if ((($$lcssa77<<24>>24) == 43)) {
  $$0$i$i = 0;$9 = $$lcssa78;
 } else {
  $$0$i$i = 0;$9 = $storemerge$i$lcssa;
 }
 $8 = HEAP8[$9>>0]|0;
 $10 = ($8<<24>>24)==(48);
 if ($10) {
  $11 = ((($9)) + 1|0);
  $12 = HEAP8[$11>>0]|0;
  if ((($12<<24>>24) == 88) | (($12<<24>>24) == 120)) {
   $19 = ((($9)) + 2|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = $20&255;
   $22 = (($21) + 1)|0;
   $23 = (5048 + ($22)|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24 & 16;
   $26 = ($25<<24>>24)==(0);
   if ($26) {
    $$ph$i = $19;$125 = $20;$28 = $24;$86 = 0;$87 = 0;$empty$2$ph$i = 1;
   } else {
    $30 = 0;$31 = 0;$35 = $20;$storemerge111$i = $19;
    while(1) {
     $32 = (_bitshift64Shl(($30|0),($31|0),4)|0);
     $33 = tempRet0;
     $34 = $35 << 24 >> 24;
     $36 = (($34) + 1)|0;
     $37 = (5048 + ($36)|0);
     $38 = HEAP8[$37>>0]|0;
     $39 = $38 & 2;
     $40 = ($39<<24>>24)==(0);
     $41 = (($34) + -48)|0;
     $42 = $34 | 32;
     $43 = (($42) + -87)|0;
     $$0$i2$i = $40 ? $43 : $41;
     $44 = ($$0$i2$i|0)<(0);
     $45 = $44 << 31 >> 31;
     $46 = (_i64Add(($$0$i2$i|0),($45|0),($32|0),($33|0))|0);
     $47 = tempRet0;
     $48 = ((($storemerge111$i)) + 1|0);
     $49 = HEAP8[$48>>0]|0;
     $50 = $49&255;
     $51 = (($50) + 1)|0;
     $52 = (5048 + ($51)|0);
     $53 = HEAP8[$52>>0]|0;
     $54 = $53 & 16;
     $55 = ($54<<24>>24)==(0);
     if ($55) {
      $$ph$i = $48;$125 = $49;$28 = $53;$86 = $46;$87 = $47;$empty$2$ph$i = 0;
      break;
     } else {
      $30 = $46;$31 = $47;$35 = $49;$storemerge111$i = $48;
     }
    }
   }
  } else {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  $13 = $8&255;
  $14 = (($13) + 1)|0;
  $15 = (5048 + ($14)|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16 & 2;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $$ph$i = $9;$125 = $8;$28 = $16;$86 = 0;$87 = 0;$empty$2$ph$i = 1;
  } else {
   $56 = 0;$57 = 0;$61 = $8;$69 = $9;
   while(1) {
    $58 = (___muldi3(($56|0),($57|0),10,0)|0);
    $59 = tempRet0;
    $60 = $61 << 24 >> 24;
    $62 = ($60|0)<(0);
    $63 = $62 << 31 >> 31;
    $64 = (_i64Add(($60|0),($63|0),-48,-1)|0);
    $65 = tempRet0;
    $66 = (_i64Add(($64|0),($65|0),($58|0),($59|0))|0);
    $67 = tempRet0;
    $68 = ((($69)) + 1|0);
    $70 = HEAP8[$68>>0]|0;
    $71 = $70&255;
    $72 = (($71) + 1)|0;
    $73 = (5048 + ($72)|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74 & 2;
    $76 = ($75<<24>>24)==(0);
    if ($76) {
     $$ph$i = $68;$125 = $70;$28 = $74;$86 = $66;$87 = $67;$empty$2$ph$i = 0;
     break;
    } else {
     $56 = $66;$57 = $67;$61 = $70;$69 = $68;
    }
   }
  }
 }
 $27 = $28 & 8;
 $29 = ($27<<24>>24)==(0);
 if ($29) {
  $$lcssa7 = $125;$$lcssa8 = $$ph$i;
 } else {
  $$ph$i$pn = $$ph$i;
  while(1) {
   $77 = ((($$ph$i$pn)) + 1|0);
   $$pre$i = HEAP8[$77>>0]|0;
   $78 = $$pre$i&255;
   $79 = (($78) + 1)|0;
   $80 = (5048 + ($79)|0);
   $81 = HEAP8[$80>>0]|0;
   $82 = $81 & 8;
   $83 = ($82<<24>>24)==(0);
   if ($83) {
    $$lcssa7 = $$pre$i;$$lcssa8 = $77;
    break;
   } else {
    $$ph$i$pn = $77;
   }
  }
 }
 $notlhs = ($empty$2$ph$i|0)!=(0);
 $notrhs = ($$lcssa7<<24>>24)!=(0);
 $or$cond$i$not = $notrhs | $notlhs;
 $84 = ($$lcssa8|0)==(0|0);
 $or$cond = $or$cond$i$not | $84;
 do {
  if ($or$cond) {
   $97 = (_strpbrk($s,2032)|0);
   $98 = ($97|0)==(0|0);
   if ($98) {
    $99 = (+_strtod($s,$endptr$i));
    $100 = HEAP32[$endptr$i>>2]|0;
    $101 = ($100|0)==($s|0);
    if (!($101)) {
     $102 = HEAP8[$100>>0]|0;
     $103 = $102&255;
     $104 = (($103) + 1)|0;
     $105 = (5048 + ($104)|0);
     $106 = HEAP8[$105>>0]|0;
     $107 = $106 & 8;
     $108 = ($107<<24>>24)==(0);
     if ($108) {
      $$lcssa$i = $100;$$lcssa1$i = $102;
     } else {
      $110 = $100;
      while(1) {
       $109 = ((($110)) + 1|0);
       $111 = HEAP8[$109>>0]|0;
       $112 = $111&255;
       $113 = (($112) + 1)|0;
       $114 = (5048 + ($113)|0);
       $115 = HEAP8[$114>>0]|0;
       $116 = $115 & 8;
       $117 = ($116<<24>>24)==(0);
       if ($117) {
        $$lcssa = $109;$$lcssa67 = $111;
        break;
       } else {
        $110 = $109;
       }
      }
      HEAP32[$endptr$i>>2] = $$lcssa;
      $$lcssa$i = $$lcssa;$$lcssa1$i = $$lcssa67;
     }
     $118 = ($$lcssa1$i<<24>>24)==(0);
     if ($118) {
      $119 = ($$lcssa$i|0)==(0|0);
      if ($119) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      } else {
       HEAPF64[$o>>3] = $99;
       $120 = ((($o)) + 8|0);
       HEAP32[$120>>2] = 3;
       $e$0 = $$lcssa$i;
       break;
      }
     }
    }
   }
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $85 = ($$0$i$i|0)!=(0);
   $88 = (_i64Subtract(0,0,($86|0),($87|0))|0);
   $89 = tempRet0;
   $90 = $85 ? $88 : $86;
   $91 = $85 ? $89 : $87;
   $92 = $o;
   $93 = $92;
   HEAP32[$93>>2] = $90;
   $94 = (($92) + 4)|0;
   $95 = $94;
   HEAP32[$95>>2] = $91;
   $96 = ((($o)) + 8|0);
   HEAP32[$96>>2] = 19;
   $e$0 = $$lcssa8;
  }
 } while(0);
 $121 = $e$0;
 $122 = $s;
 $123 = (1 - ($122))|0;
 $124 = (($123) + ($121))|0;
 $$0 = $124;
 STACKTOP = sp;return ($$0|0);
}
function _luaO_utf8esc($buff,$x) {
 $buff = $buff|0;
 $x = $x|0;
 var $$0 = 0, $$lcssa = 0, $$lcssa11 = 0, $$lcssa12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $mfb$0 = 0, $n$0 = 0, $n$0$lcssa = 0, $n$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($x>>>0)<(128);
 if ($0) {
  $1 = $x&255;
  $2 = ((($buff)) + 7|0);
  HEAP8[$2>>0] = $1;
  $n$1 = 1;
  return ($n$1|0);
 } else {
  $$0 = $x;$mfb$0 = 63;$n$0 = 1;
 }
 while(1) {
  $3 = $$0 & 63;
  $4 = $3 | 128;
  $5 = $4&255;
  $6 = (($n$0) + 1)|0;
  $7 = (8 - ($n$0))|0;
  $8 = (($buff) + ($7)|0);
  HEAP8[$8>>0] = $5;
  $9 = $$0 >>> 6;
  $10 = $mfb$0 >>> 1;
  $11 = ($9>>>0)>($10>>>0);
  if ($11) {
   $$0 = $9;$mfb$0 = $10;$n$0 = $6;
  } else {
   $$lcssa = $6;$$lcssa11 = $9;$$lcssa12 = $10;$n$0$lcssa = $n$0;
   break;
  }
 }
 $12 = $$lcssa12 << 1;
 $13 = $12 ^ 254;
 $14 = $13 | $$lcssa11;
 $15 = $14&255;
 $16 = (7 - ($n$0$lcssa))|0;
 $17 = (($buff) + ($16)|0);
 HEAP8[$17>>0] = $15;
 $n$1 = $$lcssa;
 return ($n$1|0);
}
function _luaO_tostring($L,$obj) {
 $L = $L|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buff = 0, $len$0 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $buff = sp + 16|0;
 $0 = ((($obj)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(19);
 if ($2) {
  $3 = $obj;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $vararg_buffer;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  $13 = (_sprintf($buff,2040,$vararg_buffer)|0);
  $len$0 = $13;
 } else {
  $14 = +HEAPF64[$obj>>3];
  HEAPF64[$vararg_buffer1>>3] = $14;
  $15 = (_sprintf($buff,2048,$vararg_buffer1)|0);
  $16 = (_strspn($buff,2056)|0);
  $17 = (($buff) + ($16)|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $20 = (($15) + 1)|0;
   $21 = (($buff) + ($15)|0);
   HEAP8[$21>>0] = 46;
   $22 = (($15) + 2)|0;
   $23 = (($buff) + ($20)|0);
   HEAP8[$23>>0] = 48;
   $len$0 = $22;
  } else {
   $len$0 = $15;
  }
 }
 $24 = (_luaS_newlstr($L,$buff,$len$0)|0);
 HEAP32[$obj>>2] = $24;
 $25 = ((($24)) + 4|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = $27 | 64;
 HEAP32[$0>>2] = $28;
 STACKTOP = sp;return;
}
function _luaO_pushvfstring($L,$fmt,$argp) {
 $L = $L|0;
 $fmt = $fmt|0;
 $argp = $argp|0;
 var $$ = 0, $$0$i = 0, $$0$lcssa = 0, $$017 = 0, $$lcssa = 0, $$lcssa13 = 0, $$lcssa53 = 0, $$lcssa54 = 0, $$lcssa55 = 0, $$pre = 0, $$pre28 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0.0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0.0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0.0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0;
 var $arglist_current = 0, $arglist_current14 = 0, $arglist_current2 = 0, $arglist_current23 = 0, $arglist_current32 = 0, $arglist_current38 = 0, $arglist_current5 = 0, $arglist_next = 0, $arglist_next15 = 0, $arglist_next24 = 0, $arglist_next3 = 0, $arglist_next33 = 0, $arglist_next39 = 0, $arglist_next6 = 0, $buff = 0, $buff$i = 0, $buff3 = 0, $buff4 = 0, $expanded = 0, $expanded43 = 0;
 var $expanded45 = 0, $expanded46 = 0, $expanded47 = 0, $expanded49 = 0, $expanded50 = 0, $expanded52 = 0, $expanded53 = 0, $expanded54 = 0, $expanded56 = 0, $expanded57 = 0, $expanded59 = 0, $expanded60 = 0, $expanded61 = 0, $expanded63 = 0, $expanded64 = 0, $expanded66 = 0, $expanded67 = 0, $expanded68 = 0, $expanded70 = 0, $expanded71 = 0;
 var $expanded73 = 0, $expanded74 = 0, $expanded75 = 0, $expanded77 = 0, $expanded78 = 0, $expanded80 = 0, $expanded81 = 0, $expanded82 = 0, $expanded84 = 0, $expanded85 = 0, $expanded87 = 0, $expanded88 = 0, $expanded89 = 0, $len$0$i = 0, $len$0$i2 = 0, $len$0$i5 = 0, $mfb$0$i = 0, $n$0$i = 0, $n$0$i$lcssa = 0, $n$0$lcssa = 0;
 var $n$016 = 0, $n$1$i = 0, $vararg_buffer = 0, $vararg_buffer10 = 0, $vararg_buffer16 = 0, $vararg_buffer19 = 0, $vararg_buffer25 = 0, $vararg_buffer28 = 0, $vararg_buffer34 = 0, $vararg_buffer40 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer40 = sp + 64|0;
 $vararg_buffer34 = sp + 56|0;
 $vararg_buffer28 = sp + 48|0;
 $vararg_buffer25 = sp + 40|0;
 $vararg_buffer19 = sp + 32|0;
 $vararg_buffer16 = sp + 24|0;
 $vararg_buffer10 = sp + 16|0;
 $vararg_buffer7 = sp + 8|0;
 $vararg_buffer = sp;
 $buff$i = sp + 106|0;
 $buff = sp + 104|0;
 $buff3 = sp + 80|0;
 $buff4 = sp + 72|0;
 $0 = (_strchr($fmt,37)|0);
 $1 = ($0|0)==(0|0);
 $2 = ((($L)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($L)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 L1: do {
  if ($1) {
   $$0$lcssa = $fmt;$$lcssa13 = $8;$286 = $5;$n$0$lcssa = 0;
  } else {
   $9 = ((($buff4)) + 7|0);
   $$017 = $fmt;$11 = $8;$13 = $0;$287 = $5;$n$016 = 0;
   L3: while(1) {
    $10 = ($11|0)<(48);
    if ($10) {
     _luaD_growstack($L,2);
     $$pre = HEAP32[$4>>2]|0;
     $17 = $$pre;
    } else {
     $17 = $287;
    }
    $12 = $13;
    $14 = $$017;
    $15 = (($12) - ($14))|0;
    $16 = ((($17)) + 16|0);
    HEAP32[$4>>2] = $16;
    $18 = (_luaS_newlstr($L,$$017,$15)|0);
    HEAP32[$17>>2] = $18;
    $19 = ((($18)) + 4|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20&255;
    $22 = $21 | 64;
    $23 = ((($17)) + 8|0);
    HEAP32[$23>>2] = $22;
    $24 = ((($13)) + 1|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = $25 << 24 >> 24;
    L8: do {
     switch ($26|0) {
     case 100:  {
      $66 = HEAP32[$4>>2]|0;
      $67 = ((($66)) + 16|0);
      HEAP32[$4>>2] = $67;
      $arglist_current5 = HEAP32[$argp>>2]|0;
      $68 = $arglist_current5;
      $69 = ((0) + 4|0);
      $expanded57 = $69;
      $expanded56 = (($expanded57) - 1)|0;
      $70 = (($68) + ($expanded56))|0;
      $71 = ((0) + 4|0);
      $expanded61 = $71;
      $expanded60 = (($expanded61) - 1)|0;
      $expanded59 = $expanded60 ^ -1;
      $72 = $70 & $expanded59;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $arglist_next6 = ((($73)) + 4|0);
      HEAP32[$argp>>2] = $arglist_next6;
      $75 = ($74|0)<(0);
      $76 = $75 << 31 >> 31;
      $77 = $66;
      $78 = $77;
      HEAP32[$78>>2] = $74;
      $79 = (($77) + 4)|0;
      $80 = $79;
      HEAP32[$80>>2] = $76;
      $81 = ((($66)) + 8|0);
      HEAP32[$81>>2] = 19;
      $82 = HEAP32[$4>>2]|0;
      $83 = ((($82)) + -16|0);
      $84 = ((($82)) + -8|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = ($85|0)==(19);
      if ($86) {
       $87 = $83;
       $88 = $87;
       $89 = HEAP32[$88>>2]|0;
       $90 = (($87) + 4)|0;
       $91 = $90;
       $92 = HEAP32[$91>>2]|0;
       $93 = $vararg_buffer7;
       $94 = $93;
       HEAP32[$94>>2] = $89;
       $95 = (($93) + 4)|0;
       $96 = $95;
       HEAP32[$96>>2] = $92;
       $97 = (_sprintf($buff$i,2040,$vararg_buffer7)|0);
       $len$0$i = $97;
      } else {
       $98 = +HEAPF64[$83>>3];
       HEAPF64[$vararg_buffer10>>3] = $98;
       $99 = (_sprintf($buff$i,2048,$vararg_buffer10)|0);
       $100 = (_strspn($buff$i,2056)|0);
       $101 = (($buff$i) + ($100)|0);
       $102 = HEAP8[$101>>0]|0;
       $103 = ($102<<24>>24)==(0);
       if ($103) {
        $104 = (($99) + 1)|0;
        $105 = (($buff$i) + ($99)|0);
        HEAP8[$105>>0] = 46;
        $106 = (($99) + 2)|0;
        $107 = (($buff$i) + ($104)|0);
        HEAP8[$107>>0] = 48;
        $len$0$i = $106;
       } else {
        $len$0$i = $99;
       }
      }
      $108 = (_luaS_newlstr($L,$buff$i,$len$0$i)|0);
      HEAP32[$83>>2] = $108;
      $109 = ((($108)) + 4|0);
      $110 = HEAP8[$109>>0]|0;
      $111 = $110&255;
      $112 = $111 | 64;
      HEAP32[$84>>2] = $112;
      break;
     }
     case 85:  {
      $arglist_current38 = HEAP32[$argp>>2]|0;
      $220 = $arglist_current38;
      $221 = ((0) + 4|0);
      $expanded85 = $221;
      $expanded84 = (($expanded85) - 1)|0;
      $222 = (($220) + ($expanded84))|0;
      $223 = ((0) + 4|0);
      $expanded89 = $223;
      $expanded88 = (($expanded89) - 1)|0;
      $expanded87 = $expanded88 ^ -1;
      $224 = $222 & $expanded87;
      $225 = $224;
      $226 = HEAP32[$225>>2]|0;
      $arglist_next39 = ((($225)) + 4|0);
      HEAP32[$argp>>2] = $arglist_next39;
      $227 = ($226>>>0)<(128);
      if ($227) {
       $228 = $226&255;
       HEAP8[$9>>0] = $228;
       $n$1$i = 1;
      } else {
       $$0$i = $226;$mfb$0$i = 63;$n$0$i = 1;
       while(1) {
        $229 = $$0$i & 63;
        $230 = $229 | 128;
        $231 = $230&255;
        $232 = (($n$0$i) + 1)|0;
        $233 = (8 - ($n$0$i))|0;
        $234 = (($buff4) + ($233)|0);
        HEAP8[$234>>0] = $231;
        $235 = $$0$i >>> 6;
        $236 = $mfb$0$i >>> 1;
        $237 = ($235>>>0)>($236>>>0);
        if ($237) {
         $$0$i = $235;$mfb$0$i = $236;$n$0$i = $232;
        } else {
         $$lcssa = $232;$$lcssa53 = $235;$$lcssa54 = $236;$n$0$i$lcssa = $n$0$i;
         break;
        }
       }
       $238 = $$lcssa54 << 1;
       $239 = $238 ^ 254;
       $240 = $239 | $$lcssa53;
       $241 = $240&255;
       $242 = (7 - ($n$0$i$lcssa))|0;
       $243 = (($buff4) + ($242)|0);
       HEAP8[$243>>0] = $241;
       $n$1$i = $$lcssa;
      }
      $$sum = (8 - ($n$1$i))|0;
      $244 = (($buff4) + ($$sum)|0);
      $245 = HEAP32[$4>>2]|0;
      $246 = ((($245)) + 16|0);
      HEAP32[$4>>2] = $246;
      $247 = (_luaS_newlstr($L,$244,$n$1$i)|0);
      HEAP32[$245>>2] = $247;
      $248 = ((($247)) + 4|0);
      $249 = HEAP8[$248>>0]|0;
      $250 = $249&255;
      $251 = $250 | 64;
      $252 = ((($245)) + 8|0);
      HEAP32[$252>>2] = $251;
      break;
     }
     case 102:  {
      $163 = HEAP32[$4>>2]|0;
      $164 = ((($163)) + 16|0);
      HEAP32[$4>>2] = $164;
      $arglist_current23 = HEAP32[$argp>>2]|0;
      $165 = $arglist_current23;
      $166 = ((0) + 8|0);
      $expanded71 = $166;
      $expanded70 = (($expanded71) - 1)|0;
      $167 = (($165) + ($expanded70))|0;
      $168 = ((0) + 8|0);
      $expanded75 = $168;
      $expanded74 = (($expanded75) - 1)|0;
      $expanded73 = $expanded74 ^ -1;
      $169 = $167 & $expanded73;
      $170 = $169;
      $171 = +HEAPF64[$170>>3];
      $arglist_next24 = ((($170)) + 8|0);
      HEAP32[$argp>>2] = $arglist_next24;
      HEAPF64[$163>>3] = $171;
      $172 = ((($163)) + 8|0);
      HEAP32[$172>>2] = 3;
      $173 = HEAP32[$4>>2]|0;
      $174 = ((($173)) + -16|0);
      $175 = ((($173)) + -8|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = ($176|0)==(19);
      if ($177) {
       $178 = $174;
       $179 = $178;
       $180 = HEAP32[$179>>2]|0;
       $181 = (($178) + 4)|0;
       $182 = $181;
       $183 = HEAP32[$182>>2]|0;
       $184 = $vararg_buffer25;
       $185 = $184;
       HEAP32[$185>>2] = $180;
       $186 = (($184) + 4)|0;
       $187 = $186;
       HEAP32[$187>>2] = $183;
       $188 = (_sprintf($buff$i,2040,$vararg_buffer25)|0);
       $len$0$i5 = $188;
      } else {
       $189 = +HEAPF64[$174>>3];
       HEAPF64[$vararg_buffer28>>3] = $189;
       $190 = (_sprintf($buff$i,2048,$vararg_buffer28)|0);
       $191 = (_strspn($buff$i,2056)|0);
       $192 = (($buff$i) + ($191)|0);
       $193 = HEAP8[$192>>0]|0;
       $194 = ($193<<24>>24)==(0);
       if ($194) {
        $195 = (($190) + 1)|0;
        $196 = (($buff$i) + ($190)|0);
        HEAP8[$196>>0] = 46;
        $197 = (($190) + 2)|0;
        $198 = (($buff$i) + ($195)|0);
        HEAP8[$198>>0] = 48;
        $len$0$i5 = $197;
       } else {
        $len$0$i5 = $190;
       }
      }
      $199 = (_luaS_newlstr($L,$buff$i,$len$0$i5)|0);
      HEAP32[$174>>2] = $199;
      $200 = ((($199)) + 4|0);
      $201 = HEAP8[$200>>0]|0;
      $202 = $201&255;
      $203 = $202 | 64;
      HEAP32[$175>>2] = $203;
      break;
     }
     case 115:  {
      $arglist_current = HEAP32[$argp>>2]|0;
      $27 = $arglist_current;
      $28 = ((0) + 4|0);
      $expanded43 = $28;
      $expanded = (($expanded43) - 1)|0;
      $29 = (($27) + ($expanded))|0;
      $30 = ((0) + 4|0);
      $expanded47 = $30;
      $expanded46 = (($expanded47) - 1)|0;
      $expanded45 = $expanded46 ^ -1;
      $31 = $29 & $expanded45;
      $32 = $31;
      $33 = HEAP32[$32>>2]|0;
      $arglist_next = ((($32)) + 4|0);
      HEAP32[$argp>>2] = $arglist_next;
      $34 = ($33|0)==(0|0);
      $$ = $34 ? 6872 : $33;
      $35 = (_strlen(($$|0))|0);
      $36 = HEAP32[$4>>2]|0;
      $37 = ((($36)) + 16|0);
      HEAP32[$4>>2] = $37;
      $38 = (_luaS_newlstr($L,$$,$35)|0);
      HEAP32[$36>>2] = $38;
      $39 = ((($38)) + 4|0);
      $40 = HEAP8[$39>>0]|0;
      $41 = $40&255;
      $42 = $41 | 64;
      $43 = ((($36)) + 8|0);
      HEAP32[$43>>2] = $42;
      break;
     }
     case 37:  {
      $253 = HEAP32[$4>>2]|0;
      $254 = ((($253)) + 16|0);
      HEAP32[$4>>2] = $254;
      $255 = (_luaS_newlstr($L,2088,1)|0);
      HEAP32[$253>>2] = $255;
      $256 = ((($255)) + 4|0);
      $257 = HEAP8[$256>>0]|0;
      $258 = $257&255;
      $259 = $258 | 64;
      $260 = ((($253)) + 8|0);
      HEAP32[$260>>2] = $259;
      break;
     }
     case 112:  {
      $arglist_current32 = HEAP32[$argp>>2]|0;
      $204 = $arglist_current32;
      $205 = ((0) + 4|0);
      $expanded78 = $205;
      $expanded77 = (($expanded78) - 1)|0;
      $206 = (($204) + ($expanded77))|0;
      $207 = ((0) + 4|0);
      $expanded82 = $207;
      $expanded81 = (($expanded82) - 1)|0;
      $expanded80 = $expanded81 ^ -1;
      $208 = $206 & $expanded80;
      $209 = $208;
      $210 = HEAP32[$209>>2]|0;
      $arglist_next33 = ((($209)) + 4|0);
      HEAP32[$argp>>2] = $arglist_next33;
      HEAP32[$vararg_buffer34>>2] = $210;
      $211 = (_sprintf($buff3,2080,$vararg_buffer34)|0);
      $212 = HEAP32[$4>>2]|0;
      $213 = ((($212)) + 16|0);
      HEAP32[$4>>2] = $213;
      $214 = (_luaS_newlstr($L,$buff3,$211)|0);
      HEAP32[$212>>2] = $214;
      $215 = ((($214)) + 4|0);
      $216 = HEAP8[$215>>0]|0;
      $217 = $216&255;
      $218 = $217 | 64;
      $219 = ((($212)) + 8|0);
      HEAP32[$219>>2] = $218;
      break;
     }
     case 99:  {
      $arglist_current2 = HEAP32[$argp>>2]|0;
      $44 = $arglist_current2;
      $45 = ((0) + 4|0);
      $expanded50 = $45;
      $expanded49 = (($expanded50) - 1)|0;
      $46 = (($44) + ($expanded49))|0;
      $47 = ((0) + 4|0);
      $expanded54 = $47;
      $expanded53 = (($expanded54) - 1)|0;
      $expanded52 = $expanded53 ^ -1;
      $48 = $46 & $expanded52;
      $49 = $48;
      $50 = HEAP32[$49>>2]|0;
      $arglist_next3 = ((($49)) + 4|0);
      HEAP32[$argp>>2] = $arglist_next3;
      $51 = $50&255;
      HEAP8[$buff>>0] = $51;
      $52 = $50 & 255;
      $53 = (($52) + 1)|0;
      $54 = (5048 + ($53)|0);
      $55 = HEAP8[$54>>0]|0;
      $56 = $55 & 4;
      $57 = ($56<<24>>24)==(0);
      if ($57) {
       HEAP32[$vararg_buffer>>2] = $52;
       (_luaO_pushfstring($L,2072,$vararg_buffer)|0);
       break L8;
      } else {
       $58 = HEAP32[$4>>2]|0;
       $59 = ((($58)) + 16|0);
       HEAP32[$4>>2] = $59;
       $60 = (_luaS_newlstr($L,$buff,1)|0);
       HEAP32[$58>>2] = $60;
       $61 = ((($60)) + 4|0);
       $62 = HEAP8[$61>>0]|0;
       $63 = $62&255;
       $64 = $63 | 64;
       $65 = ((($58)) + 8|0);
       HEAP32[$65>>2] = $64;
       break L8;
      }
      break;
     }
     case 73:  {
      $113 = HEAP32[$4>>2]|0;
      $114 = ((($113)) + 16|0);
      HEAP32[$4>>2] = $114;
      $arglist_current14 = HEAP32[$argp>>2]|0;
      $115 = $arglist_current14;
      $116 = ((0) + 8|0);
      $expanded64 = $116;
      $expanded63 = (($expanded64) - 1)|0;
      $117 = (($115) + ($expanded63))|0;
      $118 = ((0) + 8|0);
      $expanded68 = $118;
      $expanded67 = (($expanded68) - 1)|0;
      $expanded66 = $expanded67 ^ -1;
      $119 = $117 & $expanded66;
      $120 = $119;
      $121 = $120;
      $122 = $121;
      $123 = HEAP32[$122>>2]|0;
      $124 = (($121) + 4)|0;
      $125 = $124;
      $126 = HEAP32[$125>>2]|0;
      $arglist_next15 = ((($120)) + 8|0);
      HEAP32[$argp>>2] = $arglist_next15;
      $127 = $113;
      $128 = $127;
      HEAP32[$128>>2] = $123;
      $129 = (($127) + 4)|0;
      $130 = $129;
      HEAP32[$130>>2] = $126;
      $131 = ((($113)) + 8|0);
      HEAP32[$131>>2] = 19;
      $132 = HEAP32[$4>>2]|0;
      $133 = ((($132)) + -16|0);
      $134 = ((($132)) + -8|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = ($135|0)==(19);
      if ($136) {
       $137 = $133;
       $138 = $137;
       $139 = HEAP32[$138>>2]|0;
       $140 = (($137) + 4)|0;
       $141 = $140;
       $142 = HEAP32[$141>>2]|0;
       $143 = $vararg_buffer16;
       $144 = $143;
       HEAP32[$144>>2] = $139;
       $145 = (($143) + 4)|0;
       $146 = $145;
       HEAP32[$146>>2] = $142;
       $147 = (_sprintf($buff$i,2040,$vararg_buffer16)|0);
       $len$0$i2 = $147;
      } else {
       $148 = +HEAPF64[$133>>3];
       HEAPF64[$vararg_buffer19>>3] = $148;
       $149 = (_sprintf($buff$i,2048,$vararg_buffer19)|0);
       $150 = (_strspn($buff$i,2056)|0);
       $151 = (($buff$i) + ($150)|0);
       $152 = HEAP8[$151>>0]|0;
       $153 = ($152<<24>>24)==(0);
       if ($153) {
        $154 = (($149) + 1)|0;
        $155 = (($buff$i) + ($149)|0);
        HEAP8[$155>>0] = 46;
        $156 = (($149) + 2)|0;
        $157 = (($buff$i) + ($154)|0);
        HEAP8[$157>>0] = 48;
        $len$0$i2 = $156;
       } else {
        $len$0$i2 = $149;
       }
      }
      $158 = (_luaS_newlstr($L,$buff$i,$len$0$i2)|0);
      HEAP32[$133>>2] = $158;
      $159 = ((($158)) + 4|0);
      $160 = HEAP8[$159>>0]|0;
      $161 = $160&255;
      $162 = $161 | 64;
      HEAP32[$134>>2] = $162;
      break;
     }
     default: {
      $$lcssa55 = $26;
      break L3;
     }
     }
    } while(0);
    $261 = (($n$016) + 2)|0;
    $262 = ((($13)) + 2|0);
    $263 = (_strchr($262,37)|0);
    $264 = ($263|0)==(0|0);
    $265 = HEAP32[$2>>2]|0;
    $266 = HEAP32[$4>>2]|0;
    $267 = $265;
    $268 = $266;
    $269 = (($267) - ($268))|0;
    if ($264) {
     $$0$lcssa = $262;$$lcssa13 = $269;$286 = $266;$n$0$lcssa = $261;
     break L1;
    } else {
     $$017 = $262;$11 = $269;$13 = $263;$287 = $266;$n$016 = $261;
    }
   }
   HEAP32[$vararg_buffer40>>2] = $$lcssa55;
   _luaG_runerror($L,2096,$vararg_buffer40);
   // unreachable;
  }
 } while(0);
 $270 = ($$lcssa13|0)<(32);
 if ($270) {
  _luaD_growstack($L,1);
  $$pre28 = HEAP32[$4>>2]|0;
  $273 = $$pre28;
 } else {
  $273 = $286;
 }
 $271 = (_strlen(($$0$lcssa|0))|0);
 $272 = ((($273)) + 16|0);
 HEAP32[$4>>2] = $272;
 $274 = (_luaS_newlstr($L,$$0$lcssa,$271)|0);
 HEAP32[$273>>2] = $274;
 $275 = ((($274)) + 4|0);
 $276 = HEAP8[$275>>0]|0;
 $277 = $276&255;
 $278 = $277 | 64;
 $279 = ((($273)) + 8|0);
 HEAP32[$279>>2] = $278;
 $280 = ($n$0$lcssa|0)>(0);
 if (!($280)) {
  $282 = HEAP32[$4>>2]|0;
  $283 = ((($282)) + -16|0);
  $284 = HEAP32[$283>>2]|0;
  $285 = ((($284)) + 24|0);
  STACKTOP = sp;return ($285|0);
 }
 $281 = $n$0$lcssa | 1;
 _luaV_concat($L,$281);
 $282 = HEAP32[$4>>2]|0;
 $283 = ((($282)) + -16|0);
 $284 = HEAP32[$283>>2]|0;
 $285 = ((($284)) + 24|0);
 STACKTOP = sp;return ($285|0);
}
function _luaO_pushfstring($L,$fmt,$varargs) {
 $L = $L|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $argp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $argp = sp;
 HEAP32[$argp>>2] = $varargs;
 $0 = (_luaO_pushvfstring($L,$fmt,$argp)|0);
 STACKTOP = sp;return ($0|0);
}
function _luaO_chunkid($out,$source,$bufflen) {
 $out = $out|0;
 $source = $source|0;
 $bufflen = $bufflen|0;
 var $$0 = 0, $$l$0 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum3$pn = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$0 = 0, $or$cond = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (_strlen(($source|0))|0);
 $1 = HEAP8[$source>>0]|0;
 if ((($1<<24>>24) == 61)) {
  $2 = ($0>>>0)>($bufflen>>>0);
  $3 = ((($source)) + 1|0);
  if ($2) {
   $4 = (($bufflen) + -1)|0;
   _memcpy(($out|0),($3|0),($4|0))|0;
   $5 = (($out) + ($4)|0);
   HEAP8[$5>>0] = 0;
   return;
  } else {
   _memcpy(($out|0),($3|0),($0|0))|0;
   return;
  }
 } else if ((($1<<24>>24) == 64)) {
  $6 = ($0>>>0)>($bufflen>>>0);
  if ($6) {
   ;HEAP8[$out>>0]=HEAP8[6088>>0]|0;HEAP8[$out+1>>0]=HEAP8[6088+1>>0]|0;HEAP8[$out+2>>0]=HEAP8[6088+2>>0]|0;
   $8 = ((($out)) + 3|0);
   $9 = (($bufflen) + -3)|0;
   $10 = (4 - ($bufflen))|0;
   $$sum5 = (($10) + ($0))|0;
   $11 = (($source) + ($$sum5)|0);
   _memcpy(($8|0),($11|0),($9|0))|0;
   return;
  } else {
   $7 = ((($source)) + 1|0);
   _memcpy(($out|0),($7|0),($0|0))|0;
   return;
  }
 } else {
  $12 = (_strchr($source,10)|0);
  dest=$out; src=2144; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $13 = ((($out)) + 9|0);
  $14 = (($bufflen) + -15)|0;
  $15 = ($0>>>0)<($14>>>0);
  $16 = ($12|0)==(0|0);
  $or$cond = $15 & $16;
  if ($or$cond) {
   _memcpy(($13|0),($source|0),($0|0))|0;
   $$sum3 = (($0) + 9)|0;
   $$sum3$pn = $$sum3;
  } else {
   $17 = $12;
   $18 = $source;
   $19 = (($17) - ($18))|0;
   $l$0 = $16 ? $0 : $19;
   $20 = ($l$0>>>0)>($14>>>0);
   $$l$0 = $20 ? $14 : $l$0;
   _memcpy(($13|0),($source|0),($$l$0|0))|0;
   $$sum = (($$l$0) + 9)|0;
   $21 = (($out) + ($$sum)|0);
   ;HEAP8[$21>>0]=HEAP8[6088>>0]|0;HEAP8[$21+1>>0]=HEAP8[6088+1>>0]|0;HEAP8[$21+2>>0]=HEAP8[6088+2>>0]|0;
   $$sum2 = (($$l$0) + 12)|0;
   $$sum3$pn = $$sum2;
  }
  $$0 = (($out) + ($$sum3$pn)|0);
  ;HEAP8[$$0>>0]=HEAP8[2160>>0]|0;HEAP8[$$0+1>>0]=HEAP8[2160+1>>0]|0;HEAP8[$$0+2>>0]=HEAP8[2160+2>>0]|0;
  return;
 }
}
function _luaY_parser($L,$z,$buff,$dyd,$name,$firstchar) {
 $L = $L|0;
 $z = $z|0;
 $buff = $buff|0;
 $dyd = $dyd|0;
 $name = $name|0;
 $firstchar = $firstchar|0;
 var $$pr$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $bl$i = 0, $funcstate = 0, $lexstate = 0, $ls$idx$val$i$i = 0, $v$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $bl$i = sp + 160|0;
 $v$i = sp + 88|0;
 $lexstate = sp;
 $funcstate = sp + 112|0;
 $0 = (_luaF_newLclosure($L,1)|0);
 $1 = ((($L)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$2>>2] = $0;
 $3 = ((($2)) + 8|0);
 HEAP32[$3>>2] = 70;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 16|0);
 HEAP32[$1>>2] = $5;
 $6 = ((($L)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7;
 $9 = $5;
 $10 = (($8) - ($9))|0;
 $11 = ($10|0)<(16);
 if ($11) {
  _luaD_growstack($L,0);
 }
 $12 = (_luaH_new($L)|0);
 $13 = ((($lexstate)) + 64|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$1>>2]|0;
 HEAP32[$14>>2] = $12;
 $15 = ((($14)) + 8|0);
 HEAP32[$15>>2] = 69;
 $16 = HEAP32[$1>>2]|0;
 $17 = ((($16)) + 16|0);
 HEAP32[$1>>2] = $17;
 $18 = HEAP32[$6>>2]|0;
 $19 = $18;
 $20 = $17;
 $21 = (($19) - ($20))|0;
 $22 = ($21|0)<(16);
 if ($22) {
  _luaD_growstack($L,0);
 }
 $23 = (_luaF_newproto($L)|0);
 $24 = ((($0)) + 12|0);
 HEAP32[$24>>2] = $23;
 HEAP32[$funcstate>>2] = $23;
 $25 = (_luaS_new($L,$name)|0);
 $26 = ((($23)) + 72|0);
 HEAP32[$26>>2] = $25;
 $27 = ((($lexstate)) + 60|0);
 HEAP32[$27>>2] = $buff;
 $28 = ((($lexstate)) + 68|0);
 HEAP32[$28>>2] = $dyd;
 $29 = ((($dyd)) + 28|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($dyd)) + 16|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($dyd)) + 4|0);
 HEAP32[$31>>2] = 0;
 _luaX_setinput($L,$lexstate,$z,$25,$firstchar);
 $32 = ((($lexstate)) + 48|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($funcstate)) + 4|0);
 HEAP32[$34>>2] = $33;
 $35 = ((($funcstate)) + 8|0);
 HEAP32[$35>>2] = $lexstate;
 HEAP32[$32>>2] = $funcstate;
 $36 = ((($funcstate)) + 16|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($funcstate)) + 20|0);
 HEAP32[$37>>2] = 0;
 $38 = ((($funcstate)) + 24|0);
 HEAP32[$38>>2] = -1;
 $39 = ((($funcstate)) + 28|0);
 HEAP32[$39>>2] = 0;
 $40 = ((($funcstate)) + 32|0);
 HEAP32[$40>>2] = 0;
 $41 = ((($funcstate)) + 40|0);
 ;HEAP32[$41>>2]=0|0;HEAP8[$41+4>>0]=0|0;
 $42 = HEAP32[$28>>2]|0;
 $43 = ((($42)) + 4|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($funcstate)) + 36|0);
 HEAP32[$45>>2] = $44;
 $46 = ((($funcstate)) + 12|0);
 $47 = ((($lexstate)) + 72|0);
 $48 = HEAP32[$47>>2]|0;
 HEAP32[$26>>2] = $48;
 $49 = ((($23)) + 8|0);
 HEAP8[$49>>0] = 2;
 $50 = ((($bl$i)) + 14|0);
 HEAP8[$50>>0] = 0;
 $51 = ((($bl$i)) + 12|0);
 HEAP8[$51>>0] = 0;
 $52 = ((($42)) + 28|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ((($bl$i)) + 4|0);
 HEAP32[$54>>2] = $53;
 $55 = ((($42)) + 16|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ((($bl$i)) + 8|0);
 HEAP32[$57>>2] = $56;
 $58 = ((($bl$i)) + 13|0);
 HEAP8[$58>>0] = 0;
 HEAP32[$bl$i>>2] = 0;
 HEAP32[$46>>2] = $bl$i;
 $59 = ((($23)) + 7|0);
 HEAP8[$59>>0] = 1;
 $60 = ((($v$i)) + 16|0);
 HEAP32[$60>>2] = -1;
 $61 = ((($v$i)) + 20|0);
 HEAP32[$61>>2] = -1;
 HEAP32[$v$i>>2] = 8;
 $62 = ((($v$i)) + 8|0);
 HEAP32[$62>>2] = 0;
 $63 = ((($lexstate)) + 76|0);
 $64 = HEAP32[$63>>2]|0;
 (_newupvalue($funcstate,$64,$v$i)|0);
 _luaX_next($lexstate);
 $65 = ((($lexstate)) + 16|0);
 L7: while(1) {
  $ls$idx$val$i$i = HEAP32[$65>>2]|0;
  switch ($ls$idx$val$i$i|0) {
  case 277: case 289: case 262: case 261: case 260:  {
   $68 = $ls$idx$val$i$i;
   break L7;
   break;
  }
  default: {
  }
  }
  $66 = ($ls$idx$val$i$i|0)==(274);
  _statement($lexstate);
  if ($66) {
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  $$pr$i = HEAP32[$65>>2]|0;
  $68 = $$pr$i;
 }
 $67 = ($68|0)==(289);
 if ($67) {
  _close_func($lexstate);
  $69 = HEAP32[$1>>2]|0;
  $70 = ((($69)) + -16|0);
  HEAP32[$1>>2] = $70;
  STACKTOP = sp;return ($0|0);
 } else {
  _error_expected($lexstate,289);
  // unreachable;
 }
 return (0)|0;
}
function _newupvalue($fs,$name,$v) {
 $fs = $fs|0;
 $name = $name|0;
 $v = $v|0;
 var $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $oldsize$01 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$fs>>2]|0;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($fs)) + 43|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = (($5) + 1)|0;
 $7 = ($6>>>0)>(255);
 if ($7) {
  $8 = ((($fs)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9)) + 52|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($0)) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  if ($14) {
   $16 = 3080;
   HEAP32[$vararg_buffer1>>2] = 3584;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = 255;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $16;
   $17 = (_luaO_pushfstring($11,3096,$vararg_buffer1)|0);
   $18 = HEAP32[$8>>2]|0;
   _luaX_syntaxerror($18,$17);
   // unreachable;
  }
  HEAP32[$vararg_buffer>>2] = $13;
  $15 = (_luaO_pushfstring($11,3056,$vararg_buffer)|0);
  $16 = $15;
  HEAP32[$vararg_buffer1>>2] = 3584;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = 255;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $16;
  $17 = (_luaO_pushfstring($11,3096,$vararg_buffer1)|0);
  $18 = HEAP32[$8>>2]|0;
  _luaX_syntaxerror($18,$17);
  // unreachable;
 }
 $19 = ($5|0)<($2|0);
 if ($19) {
  $28 = $2;
 } else {
  $20 = ((($fs)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ((($21)) + 52|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($0)) + 64|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (_luaM_growaux_($23,$25,$1,8,255,3584)|0);
  HEAP32[$24>>2] = $26;
  $$pre = HEAP32[$1>>2]|0;
  $28 = $$pre;
 }
 $27 = ($2|0)<($28|0);
 $29 = ((($0)) + 64|0);
 $30 = HEAP32[$29>>2]|0;
 if ($27) {
  $oldsize$01 = $2;
  while(1) {
   $31 = (($oldsize$01) + 1)|0;
   $32 = (($30) + ($oldsize$01<<3)|0);
   HEAP32[$32>>2] = 0;
   $33 = ($31|0)<($28|0);
   if ($33) {
    $oldsize$01 = $31;
   } else {
    break;
   }
  }
 }
 $34 = HEAP32[$v>>2]|0;
 $35 = ($34|0)==(8);
 $36 = $35&1;
 $37 = HEAP8[$3>>0]|0;
 $38 = $37&255;
 $39 = (((($30) + ($38<<3)|0)) + 4|0);
 HEAP8[$39>>0] = $36;
 $40 = ((($v)) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41&255;
 $43 = (((($30) + ($38<<3)|0)) + 5|0);
 HEAP8[$43>>0] = $42;
 $44 = (($30) + ($38<<3)|0);
 HEAP32[$44>>2] = $name;
 $45 = ((($0)) + 5|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = $46 & 4;
 $48 = ($47<<24>>24)==(0);
 if ($48) {
  $58 = $37;
  $57 = (($58) + 1)<<24>>24;
  HEAP8[$3>>0] = $57;
  $59 = $58&255;
  STACKTOP = sp;return ($59|0);
 }
 $49 = ((($name)) + 5|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = $50 & 3;
 $52 = ($51<<24>>24)==(0);
 if ($52) {
  $58 = $37;
  $57 = (($58) + 1)<<24>>24;
  HEAP8[$3>>0] = $57;
  $59 = $58&255;
  STACKTOP = sp;return ($59|0);
 }
 $53 = ((($fs)) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ((($54)) + 52|0);
 $56 = HEAP32[$55>>2]|0;
 _luaC_barrier_($56,$0,$name);
 $$pre3 = HEAP8[$3>>0]|0;
 $58 = $$pre3;
 $57 = (($58) + 1)<<24>>24;
 HEAP8[$3>>0] = $57;
 $59 = $58&255;
 STACKTOP = sp;return ($59|0);
}
function _statement($ls) {
 $ls = $ls|0;
 var $$$i$i = 0, $$$i$i$i = 0, $$01$i$i42 = 0, $$idx$val$i = 0, $$idx$val$i$i = 0, $$idx$val$i$i31 = 0, $$idx$val$idx$i = 0, $$idx$val$idx$i$i = 0, $$idx$val$idx$i$i36 = 0, $$idx$val$idx$val$i = 0, $$idx$val$idx$val$i$i = 0, $$idx$val$idx$val$i$i37 = 0, $$idx1$i = 0, $$idx1$i$i = 0, $$idx1$i$i32 = 0, $$idx1$val$i = 0, $$idx1$val$i$i = 0, $$idx1$val$i$i33 = 0, $$idx1$val$idx$i = 0, $$idx1$val$idx$i$i = 0;
 var $$idx1$val$idx$i$i38 = 0, $$idx1$val$idx$val$i = 0, $$idx1$val$idx$val$i$i = 0, $$idx1$val$idx$val$i$i39 = 0, $$idx1$val$idx$val$idx$val$i = 0, $$idx1$val$idx$val$idx$val$i$i = 0, $$idx1$val$idx$val$idx$val$i$i41 = 0, $$idx2$i = 0, $$idx2$i$i = 0, $$idx2$i$i34 = 0, $$idx2$val$i = 0, $$idx2$val$i$i = 0, $$idx2$val$i$i35 = 0, $$lcssa166 = 0, $$lcssa169 = 0, $$lcssa170 = 0, $$lcssa172 = 0, $$off$i = 0, $$pre = 0, $$pre$i$i = 0;
 var $$pre111 = 0, $$pre112 = 0, $$pre113 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$i = 0, $b$i21 = 0, $bl$i = 0;
 var $bl$i$i = 0, $bl$i$i2 = 0, $bl$i8 = 0, $bl$i9 = 0, $bl1$i = 0, $bl2$i = 0, $e$i = 0, $e$i$i = 0, $e$i48 = 0, $e$i70 = 0, $e$i71 = 0, $e$i72 = 0, $escapelist$i = 0, $first$0$i = 0, $i$0$ph1$i$i = 0, $i$02$i$i = 0, $i$02$i$i$lcssa = 0, $ismethod$0$i$i = 0, $key$i$i$i = 0, $ls$idx = 0;
 var $ls$idx$val = 0, $ls$idx$val$i = 0, $ls$idx$val$i$i = 0, $ls$idx$val$i$i$i = 0, $ls$idx$val$i$i$i20 = 0, $ls$idx$val$i$i$i4 = 0, $ls$idx$val$i$i12 = 0, $ls$idx$val$i$i15 = 0, $ls$idx$val$i29 = 0, $ls$idx$val$i50 = 0, $ls$idx1 = 0, $ls$idx1$val = 0, $ls$idx1$val$i = 0, $ls$idx1$val$i115 = 0, $ls$idx1$val$i116 = 0, $n$0$i$i$lcssa = 0, $n$0$i$i53$lcssa = 0, $n$0$i$i5397 = 0, $n$0$i$i91 = 0, $n$0$i$lcssa = 0;
 var $n$0$i87 = 0, $nret$0$i = 0, $nvars$0$i$i$lcssa = 0, $nvars$0$i$i88 = 0, $nvars$0$i$i88$lcssa165 = 0, $nvars$0$i95 = 0, $or$cond$i = 0, $phitmp = 0, $switch$i = 0, $v$i = 0, $v$i$i = 0, $v$i$i13 = 0, $v$i59 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer16 = 0, $vararg_buffer21 = 0, $vararg_buffer26 = 0, $vararg_buffer31 = 0;
 var $vararg_buffer6 = 0, $vararg_ptr10 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr19 = 0, $vararg_ptr20 = 0, $vararg_ptr24 = 0, $vararg_ptr25 = 0, $vararg_ptr29 = 0, $vararg_ptr30 = 0, $vararg_ptr34 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer31 = sp + 424|0;
 $vararg_buffer26 = sp + 408|0;
 $vararg_buffer21 = sp + 392|0;
 $vararg_buffer16 = sp + 376|0;
 $vararg_buffer11 = sp + 360|0;
 $vararg_buffer6 = sp + 344|0;
 $vararg_buffer1 = sp + 328|0;
 $vararg_buffer = sp + 320|0;
 $e$i72 = sp + 296|0;
 $e$i71 = sp + 272|0;
 $e$i70 = sp + 248|0;
 $v$i59 = sp + 216|0;
 $e$i48 = sp + 192|0;
 $e$i = sp + 168|0;
 $b$i21 = sp + 144|0;
 $key$i$i$i = sp + 120|0;
 $v$i = sp + 96|0;
 $b$i = sp + 72|0;
 $v$i$i13 = sp + 48|0;
 $bl1$i = sp + 536|0;
 $bl2$i = sp + 520|0;
 $e$i$i = sp + 24|0;
 $bl$i9 = sp + 504|0;
 $bl$i8 = sp + 488|0;
 $v$i$i = sp;
 $bl$i$i2 = sp + 472|0;
 $bl$i = sp + 456|0;
 $bl$i$i = sp + 440|0;
 $escapelist$i = sp + 432|0;
 $0 = ((($ls)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $ls$idx = ((($ls)) + 48|0);
 $ls$idx$val = HEAP32[$ls$idx>>2]|0;
 $ls$idx1 = ((($ls)) + 52|0);
 $ls$idx1$val = HEAP32[$ls$idx1>>2]|0;
 $2 = ((($ls$idx1$val)) + 106|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = (($3) + 1)<<16>>16;
 HEAP16[$2>>1] = $4;
 $5 = ($4&65535)>(200);
 if ($5) {
  $6 = ((($ls$idx$val)) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($7)) + 52|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$ls$idx$val>>2]|0;
  $11 = ((($10)) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0);
  if ($13) {
   $15 = 3080;
   HEAP32[$vararg_buffer1>>2] = 3128;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = 200;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $15;
   $16 = (_luaO_pushfstring($9,3096,$vararg_buffer1)|0);
   $17 = HEAP32[$6>>2]|0;
   _luaX_syntaxerror($17,$16);
   // unreachable;
  }
  HEAP32[$vararg_buffer>>2] = $12;
  $14 = (_luaO_pushfstring($9,3056,$vararg_buffer)|0);
  $15 = $14;
  HEAP32[$vararg_buffer1>>2] = 3128;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = 200;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $15;
  $16 = (_luaO_pushfstring($9,3096,$vararg_buffer1)|0);
  $17 = HEAP32[$6>>2]|0;
  _luaX_syntaxerror($17,$16);
  // unreachable;
 }
 $18 = ((($ls)) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 do {
  switch ($19|0) {
  case 278:  {
   _luaX_next($ls);
   $49 = (_luaK_getlabel($ls$idx$val)|0);
   (_subexpr($ls,$v$i$i,0)|0);
   $50 = HEAP32[$v$i$i>>2]|0;
   $51 = ($50|0)==(1);
   if ($51) {
    HEAP32[$v$i$i>>2] = 3;
   }
   $52 = HEAP32[$ls$idx>>2]|0;
   _luaK_goiftrue($52,$v$i$i);
   $53 = ((($v$i$i)) + 20|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ((($bl$i)) + 14|0);
   HEAP8[$55>>0] = 1;
   $56 = ((($ls$idx$val)) + 42|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = ((($bl$i)) + 12|0);
   HEAP8[$58>>0] = $57;
   $59 = ((($ls$idx$val)) + 8|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ((($60)) + 68|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ((($62)) + 28|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ((($bl$i)) + 4|0);
   HEAP32[$65>>2] = $64;
   $66 = ((($62)) + 16|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ((($bl$i)) + 8|0);
   HEAP32[$68>>2] = $67;
   $69 = ((($bl$i)) + 13|0);
   HEAP8[$69>>0] = 0;
   $70 = ((($ls$idx$val)) + 12|0);
   $71 = HEAP32[$70>>2]|0;
   HEAP32[$bl$i>>2] = $71;
   HEAP32[$70>>2] = $bl$i;
   $72 = HEAP32[$18>>2]|0;
   $73 = ($72|0)==(259);
   if (!($73)) {
    _error_expected($ls,259);
    // unreachable;
   }
   _luaX_next($ls);
   $74 = HEAP32[$ls$idx>>2]|0;
   $75 = ((($bl$i$i2)) + 14|0);
   HEAP8[$75>>0] = 0;
   $76 = ((($74)) + 42|0);
   $77 = HEAP8[$76>>0]|0;
   $78 = ((($bl$i$i2)) + 12|0);
   HEAP8[$78>>0] = $77;
   $79 = ((($74)) + 8|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ((($80)) + 68|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ((($82)) + 28|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ((($bl$i$i2)) + 4|0);
   HEAP32[$85>>2] = $84;
   $86 = ((($82)) + 16|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ((($bl$i$i2)) + 8|0);
   HEAP32[$88>>2] = $87;
   $89 = ((($bl$i$i2)) + 13|0);
   HEAP8[$89>>0] = 0;
   $90 = ((($74)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   HEAP32[$bl$i$i2>>2] = $91;
   HEAP32[$90>>2] = $bl$i$i2;
   L16: while(1) {
    $ls$idx$val$i$i$i4 = HEAP32[$18>>2]|0;
    switch ($ls$idx$val$i$i$i4|0) {
    case 277: case 289: case 262: case 261: case 260:  {
     break L16;
     break;
    }
    default: {
    }
    }
    $92 = ($ls$idx$val$i$i$i4|0)==(274);
    _statement($ls);
    if ($92) {
     break;
    }
   }
   _leaveblock($74);
   $93 = (_luaK_jump($ls$idx$val)|0);
   _luaK_patchlist($ls$idx$val,$93,$49);
   $94 = HEAP32[$18>>2]|0;
   $95 = ($94|0)==(262);
   if ($95) {
    _luaX_next($ls);
    _leaveblock($ls$idx$val);
    _luaK_patchtohere($ls$idx$val,$54);
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $96 = HEAP32[$0>>2]|0;
   $97 = ($96|0)==($1|0);
   if ($97) {
    _error_expected($ls,262);
    // unreachable;
   } else {
    $98 = HEAP32[$ls$idx1>>2]|0;
    $99 = (_luaX_token2str($ls,262)|0);
    $100 = (_luaX_token2str($ls,278)|0);
    HEAP32[$vararg_buffer11>>2] = $99;
    $vararg_ptr14 = ((($vararg_buffer11)) + 4|0);
    HEAP32[$vararg_ptr14>>2] = $100;
    $vararg_ptr15 = ((($vararg_buffer11)) + 8|0);
    HEAP32[$vararg_ptr15>>2] = $1;
    $101 = (_luaO_pushfstring($98,3144,$vararg_buffer11)|0);
    _luaX_syntaxerror($ls,$101);
    // unreachable;
   }
   break;
  }
  case 59:  {
   _luaX_next($ls);
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  case 264:  {
   $129 = ((($bl$i9)) + 14|0);
   HEAP8[$129>>0] = 1;
   $130 = ((($ls$idx$val)) + 42|0);
   $131 = HEAP8[$130>>0]|0;
   $132 = ((($bl$i9)) + 12|0);
   HEAP8[$132>>0] = $131;
   $133 = ((($ls$idx$val)) + 8|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = ((($134)) + 68|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = ((($136)) + 28|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ((($bl$i9)) + 4|0);
   HEAP32[$139>>2] = $138;
   $140 = ((($136)) + 16|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = ((($bl$i9)) + 8|0);
   HEAP32[$142>>2] = $141;
   $143 = ((($bl$i9)) + 13|0);
   HEAP8[$143>>0] = 0;
   $144 = ((($ls$idx$val)) + 12|0);
   $145 = HEAP32[$144>>2]|0;
   HEAP32[$bl$i9>>2] = $145;
   HEAP32[$144>>2] = $bl$i9;
   _luaX_next($ls);
   $146 = HEAP32[$18>>2]|0;
   $147 = ($146|0)==(292);
   if (!($147)) {
    _error_expected($ls,292);
    // unreachable;
   }
   $148 = ((($ls)) + 24|0);
   $149 = HEAP32[$148>>2]|0;
   _luaX_next($ls);
   $150 = HEAP32[$18>>2]|0;
   if ((($150|0) == 61)) {
    $151 = HEAP32[$ls$idx>>2]|0;
    $152 = ((($151)) + 44|0);
    $153 = HEAP8[$152>>0]|0;
    $154 = $153&255;
    $155 = (_luaX_newstring($ls,3184,11)|0);
    _new_localvar($ls,$155);
    $156 = (_luaX_newstring($ls,3200,11)|0);
    _new_localvar($ls,$156);
    $157 = (_luaX_newstring($ls,3216,10)|0);
    _new_localvar($ls,$157);
    _new_localvar($ls,$149);
    $158 = HEAP32[$18>>2]|0;
    $159 = ($158|0)==(61);
    if (!($159)) {
     _error_expected($ls,61);
     // unreachable;
    }
    _luaX_next($ls);
    (_subexpr($ls,$e$i70,0)|0);
    $160 = HEAP32[$ls$idx>>2]|0;
    _luaK_exp2nextreg($160,$e$i70);
    $161 = HEAP32[$18>>2]|0;
    $162 = ($161|0)==(44);
    if (!($162)) {
     _error_expected($ls,44);
     // unreachable;
    }
    _luaX_next($ls);
    (_subexpr($ls,$e$i71,0)|0);
    $163 = HEAP32[$ls$idx>>2]|0;
    _luaK_exp2nextreg($163,$e$i71);
    $164 = HEAP32[$18>>2]|0;
    $165 = ($164|0)==(44);
    if ($165) {
     _luaX_next($ls);
     (_subexpr($ls,$e$i72,0)|0);
     $166 = HEAP32[$ls$idx>>2]|0;
     _luaK_exp2nextreg($166,$e$i72);
    } else {
     $167 = HEAP8[$152>>0]|0;
     $168 = $167&255;
     $169 = (_luaK_intK($151,1,0)|0);
     (_luaK_codek($151,$168,$169)|0);
     _luaK_reserveregs($151,1);
    }
    _forbody($ls,$154,$1,1,1);
   } else if ((($150|0) == 268) | (($150|0) == 44)) {
    $170 = HEAP32[$ls$idx>>2]|0;
    $171 = ((($170)) + 44|0);
    $172 = HEAP8[$171>>0]|0;
    $173 = $172&255;
    $174 = (_luaX_newstring($ls,3232,15)|0);
    _new_localvar($ls,$174);
    $175 = (_luaX_newstring($ls,3248,11)|0);
    _new_localvar($ls,$175);
    $176 = (_luaX_newstring($ls,3264,13)|0);
    _new_localvar($ls,$176);
    _new_localvar($ls,$149);
    $177 = HEAP32[$18>>2]|0;
    $178 = ($177|0)==(44);
    do {
     if ($178) {
      $nvars$0$i$i88 = 4;
      while(1) {
       _luaX_next($ls);
       $179 = HEAP32[$18>>2]|0;
       $180 = ($179|0)==(292);
       if (!($180)) {
        label = 52;
        break;
       }
       $181 = HEAP32[$148>>2]|0;
       _luaX_next($ls);
       _new_localvar($ls,$181);
       $182 = (($nvars$0$i$i88) + 1)|0;
       $183 = HEAP32[$18>>2]|0;
       $184 = ($183|0)==(44);
       if ($184) {
        $nvars$0$i$i88 = $182;
       } else {
        $$lcssa166 = $183;$nvars$0$i$i88$lcssa165 = $nvars$0$i$i88;
        label = 54;
        break;
       }
      }
      if ((label|0) == 52) {
       _error_expected($ls,292);
       // unreachable;
      }
      else if ((label|0) == 54) {
       $phitmp = (($nvars$0$i$i88$lcssa165) + -2)|0;
       $186 = $$lcssa166;$nvars$0$i$i$lcssa = $phitmp;
       break;
      }
     } else {
      $186 = $177;$nvars$0$i$i$lcssa = 1;
     }
    } while(0);
    $185 = ($186|0)==(268);
    if (!($185)) {
     _error_expected($ls,268);
     // unreachable;
    }
    _luaX_next($ls);
    $187 = HEAP32[$0>>2]|0;
    (_subexpr($ls,$e$i$i,0)|0);
    $188 = HEAP32[$18>>2]|0;
    $189 = ($188|0)==(44);
    if ($189) {
     $n$0$i87 = 1;
     while(1) {
      _luaX_next($ls);
      $190 = HEAP32[$ls$idx>>2]|0;
      _luaK_exp2nextreg($190,$e$i$i);
      (_subexpr($ls,$e$i$i,0)|0);
      $191 = (($n$0$i87) + 1)|0;
      $192 = HEAP32[$18>>2]|0;
      $193 = ($192|0)==(44);
      if ($193) {
       $n$0$i87 = $191;
      } else {
       $n$0$i$lcssa = $191;
       break;
      }
     }
    } else {
     $n$0$i$lcssa = 1;
    }
    $ls$idx$val$i$i12 = HEAP32[$ls$idx>>2]|0;
    $194 = (3 - ($n$0$i$lcssa))|0;
    $195 = HEAP32[$e$i$i>>2]|0;
    if ((($195|0) == 14) | (($195|0) == 13)) {
     $196 = (($194) + 1)|0;
     $197 = ($196|0)<(0);
     $$$i$i$i = $197 ? 0 : $196;
     _luaK_setreturns($ls$idx$val$i$i12,$e$i$i,$$$i$i$i);
     $198 = ($$$i$i$i|0)>(1);
     if ($198) {
      $199 = (($$$i$i$i) + -1)|0;
      _luaK_reserveregs($ls$idx$val$i$i12,$199);
     }
    } else if ((($195|0) == 0)) {
     label = 63;
    } else {
     _luaK_exp2nextreg($ls$idx$val$i$i12,$e$i$i);
     label = 63;
    }
    if ((label|0) == 63) {
     $200 = ($194|0)>(0);
     if ($200) {
      $201 = ((($ls$idx$val$i$i12)) + 44|0);
      $202 = HEAP8[$201>>0]|0;
      $203 = $202&255;
      _luaK_reserveregs($ls$idx$val$i$i12,$194);
      _luaK_nil($ls$idx$val$i$i12,$203,$194);
     }
    }
    _luaK_checkstack($170,3);
    _forbody($ls,$173,$187,$nvars$0$i$i$lcssa,0);
   } else {
    _luaX_syntaxerror($ls,3280);
    // unreachable;
   }
   $204 = HEAP32[$18>>2]|0;
   $205 = ($204|0)==(262);
   if ($205) {
    _luaX_next($ls);
    _leaveblock($ls$idx$val);
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $206 = HEAP32[$0>>2]|0;
   $207 = ($206|0)==($1|0);
   if ($207) {
    _error_expected($ls,262);
    // unreachable;
   } else {
    $208 = HEAP32[$ls$idx1>>2]|0;
    $209 = (_luaX_token2str($ls,262)|0);
    $210 = (_luaX_token2str($ls,264)|0);
    HEAP32[$vararg_buffer21>>2] = $209;
    $vararg_ptr24 = ((($vararg_buffer21)) + 4|0);
    HEAP32[$vararg_ptr24>>2] = $210;
    $vararg_ptr25 = ((($vararg_buffer21)) + 8|0);
    HEAP32[$vararg_ptr25>>2] = $1;
    $211 = (_luaO_pushfstring($208,3144,$vararg_buffer21)|0);
    _luaX_syntaxerror($ls,$211);
    // unreachable;
   }
   break;
  }
  case 259:  {
   _luaX_next($ls);
   $102 = HEAP32[$ls$idx>>2]|0;
   $103 = ((($bl$i8)) + 14|0);
   HEAP8[$103>>0] = 0;
   $104 = ((($102)) + 42|0);
   $105 = HEAP8[$104>>0]|0;
   $106 = ((($bl$i8)) + 12|0);
   HEAP8[$106>>0] = $105;
   $107 = ((($102)) + 8|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = ((($108)) + 68|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ((($110)) + 28|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = ((($bl$i8)) + 4|0);
   HEAP32[$113>>2] = $112;
   $114 = ((($110)) + 16|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = ((($bl$i8)) + 8|0);
   HEAP32[$116>>2] = $115;
   $117 = ((($bl$i8)) + 13|0);
   HEAP8[$117>>0] = 0;
   $118 = ((($102)) + 12|0);
   $119 = HEAP32[$118>>2]|0;
   HEAP32[$bl$i8>>2] = $119;
   HEAP32[$118>>2] = $bl$i8;
   L79: while(1) {
    $ls$idx$val$i$i = HEAP32[$18>>2]|0;
    switch ($ls$idx$val$i$i|0) {
    case 277: case 289: case 262: case 261: case 260:  {
     break L79;
     break;
    }
    default: {
    }
    }
    $120 = ($ls$idx$val$i$i|0)==(274);
    _statement($ls);
    if ($120) {
     break;
    }
   }
   _leaveblock($102);
   $121 = HEAP32[$18>>2]|0;
   $122 = ($121|0)==(262);
   if ($122) {
    _luaX_next($ls);
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $123 = HEAP32[$0>>2]|0;
   $124 = ($123|0)==($1|0);
   if ($124) {
    _error_expected($ls,262);
    // unreachable;
   } else {
    $125 = HEAP32[$ls$idx1>>2]|0;
    $126 = (_luaX_token2str($ls,262)|0);
    $127 = (_luaX_token2str($ls,259)|0);
    HEAP32[$vararg_buffer16>>2] = $126;
    $vararg_ptr19 = ((($vararg_buffer16)) + 4|0);
    HEAP32[$vararg_ptr19>>2] = $127;
    $vararg_ptr20 = ((($vararg_buffer16)) + 8|0);
    HEAP32[$vararg_ptr20>>2] = $1;
    $128 = (_luaO_pushfstring($125,3144,$vararg_buffer16)|0);
    _luaX_syntaxerror($ls,$128);
    // unreachable;
   }
   break;
  }
  case 267:  {
   HEAP32[$escapelist$i>>2] = -1;
   _test_then_block($ls,$escapelist$i);
   while(1) {
    $20 = HEAP32[$18>>2]|0;
    if ((($20|0) == 260)) {
     label = 10;
     break;
    } else if (!((($20|0) == 261))) {
     $41 = $20;
     break;
    }
    _test_then_block($ls,$escapelist$i);
   }
   if ((label|0) == 10) {
    _luaX_next($ls);
    $21 = HEAP32[$ls$idx>>2]|0;
    $22 = ((($bl$i$i)) + 14|0);
    HEAP8[$22>>0] = 0;
    $23 = ((($21)) + 42|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ((($bl$i$i)) + 12|0);
    HEAP8[$25>>0] = $24;
    $26 = ((($21)) + 8|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ((($27)) + 68|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($29)) + 28|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($bl$i$i)) + 4|0);
    HEAP32[$32>>2] = $31;
    $33 = ((($29)) + 16|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($bl$i$i)) + 8|0);
    HEAP32[$35>>2] = $34;
    $36 = ((($bl$i$i)) + 13|0);
    HEAP8[$36>>0] = 0;
    $37 = ((($21)) + 12|0);
    $38 = HEAP32[$37>>2]|0;
    HEAP32[$bl$i$i>>2] = $38;
    HEAP32[$37>>2] = $bl$i$i;
    L96: while(1) {
     $ls$idx$val$i$i$i = HEAP32[$18>>2]|0;
     switch ($ls$idx$val$i$i$i|0) {
     case 277: case 289: case 262: case 261: case 260:  {
      break L96;
      break;
     }
     default: {
     }
     }
     $39 = ($ls$idx$val$i$i$i|0)==(274);
     _statement($ls);
     if ($39) {
      break;
     }
    }
    _leaveblock($21);
    $$pre113 = HEAP32[$18>>2]|0;
    $41 = $$pre113;
   }
   $40 = ($41|0)==(262);
   if ($40) {
    _luaX_next($ls);
    $48 = HEAP32[$escapelist$i>>2]|0;
    _luaK_patchtohere($ls$idx$val,$48);
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $42 = HEAP32[$0>>2]|0;
   $43 = ($42|0)==($1|0);
   if ($43) {
    _error_expected($ls,262);
    // unreachable;
   } else {
    $44 = HEAP32[$ls$idx1>>2]|0;
    $45 = (_luaX_token2str($ls,262)|0);
    $46 = (_luaX_token2str($ls,267)|0);
    HEAP32[$vararg_buffer6>>2] = $45;
    $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
    HEAP32[$vararg_ptr9>>2] = $46;
    $vararg_ptr10 = ((($vararg_buffer6)) + 8|0);
    HEAP32[$vararg_ptr10>>2] = $1;
    $47 = (_luaO_pushfstring($44,3144,$vararg_buffer6)|0);
    _luaX_syntaxerror($ls,$47);
    // unreachable;
   }
   break;
  }
  case 273:  {
   $212 = (_luaK_getlabel($ls$idx$val)|0);
   $213 = ((($bl1$i)) + 14|0);
   HEAP8[$213>>0] = 1;
   $214 = ((($ls$idx$val)) + 42|0);
   $215 = HEAP8[$214>>0]|0;
   $216 = ((($bl1$i)) + 12|0);
   HEAP8[$216>>0] = $215;
   $217 = ((($ls$idx$val)) + 8|0);
   $218 = HEAP32[$217>>2]|0;
   $219 = ((($218)) + 68|0);
   $220 = HEAP32[$219>>2]|0;
   $221 = ((($220)) + 28|0);
   $222 = HEAP32[$221>>2]|0;
   $223 = ((($bl1$i)) + 4|0);
   HEAP32[$223>>2] = $222;
   $224 = ((($220)) + 16|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = ((($bl1$i)) + 8|0);
   HEAP32[$226>>2] = $225;
   $227 = ((($bl1$i)) + 13|0);
   HEAP8[$227>>0] = 0;
   $228 = ((($ls$idx$val)) + 12|0);
   $229 = HEAP32[$228>>2]|0;
   HEAP32[$bl1$i>>2] = $229;
   $230 = ((($bl2$i)) + 14|0);
   HEAP8[$230>>0] = 0;
   $231 = ((($bl2$i)) + 12|0);
   HEAP8[$231>>0] = $215;
   $232 = ((($bl2$i)) + 4|0);
   HEAP32[$232>>2] = $222;
   $233 = ((($bl2$i)) + 8|0);
   HEAP32[$233>>2] = $225;
   $234 = ((($bl2$i)) + 13|0);
   HEAP8[$234>>0] = 0;
   $235 = $bl1$i;
   HEAP32[$bl2$i>>2] = $235;
   HEAP32[$228>>2] = $bl2$i;
   _luaX_next($ls);
   L109: while(1) {
    $ls$idx$val$i$i15 = HEAP32[$18>>2]|0;
    switch ($ls$idx$val$i$i15|0) {
    case 277: case 289: case 262: case 261: case 260:  {
     $238 = $ls$idx$val$i$i15;
     break L109;
     break;
    }
    default: {
    }
    }
    $236 = ($ls$idx$val$i$i15|0)==(274);
    _statement($ls);
    if ($236) {
     label = 75;
     break;
    }
   }
   if ((label|0) == 75) {
    $$pre112 = HEAP32[$18>>2]|0;
    $238 = $$pre112;
   }
   $237 = ($238|0)==(277);
   if (!($237)) {
    $239 = HEAP32[$0>>2]|0;
    $240 = ($239|0)==($1|0);
    if ($240) {
     _error_expected($ls,277);
     // unreachable;
    } else {
     $241 = HEAP32[$ls$idx1>>2]|0;
     $242 = (_luaX_token2str($ls,277)|0);
     $243 = (_luaX_token2str($ls,273)|0);
     HEAP32[$vararg_buffer26>>2] = $242;
     $vararg_ptr29 = ((($vararg_buffer26)) + 4|0);
     HEAP32[$vararg_ptr29>>2] = $243;
     $vararg_ptr30 = ((($vararg_buffer26)) + 8|0);
     HEAP32[$vararg_ptr30>>2] = $1;
     $244 = (_luaO_pushfstring($241,3144,$vararg_buffer26)|0);
     _luaX_syntaxerror($ls,$244);
     // unreachable;
    }
   }
   _luaX_next($ls);
   (_subexpr($ls,$v$i$i13,0)|0);
   $245 = HEAP32[$v$i$i13>>2]|0;
   $246 = ($245|0)==(1);
   if ($246) {
    HEAP32[$v$i$i13>>2] = 3;
   }
   $247 = HEAP32[$ls$idx>>2]|0;
   _luaK_goiftrue($247,$v$i$i13);
   $248 = ((($v$i$i13)) + 20|0);
   $249 = HEAP32[$248>>2]|0;
   $250 = HEAP8[$234>>0]|0;
   $251 = ($250<<24>>24)==(0);
   if (!($251)) {
    $252 = HEAP8[$231>>0]|0;
    $253 = $252&255;
    _luaK_patchclose($ls$idx$val,$249,$253);
   }
   _leaveblock($ls$idx$val);
   _luaK_patchlist($ls$idx$val,$249,$212);
   _leaveblock($ls$idx$val);
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  case 265:  {
   _luaX_next($ls);
   $254 = HEAP32[$18>>2]|0;
   $255 = ($254|0)==(292);
   if (!($255)) {
    _error_expected($ls,292);
    // unreachable;
   }
   $256 = ((($ls)) + 24|0);
   $257 = HEAP32[$256>>2]|0;
   _luaX_next($ls);
   $258 = HEAP32[$ls$idx>>2]|0;
   $259 = (_singlevaraux($258,$257,$v$i,1)|0);
   $260 = ($259|0)==(0);
   if ($260) {
    $261 = ((($ls)) + 76|0);
    $262 = HEAP32[$261>>2]|0;
    (_singlevaraux($258,$262,$v$i,1)|0);
    $ls$idx$val$i$i$i20 = HEAP32[$ls$idx>>2]|0;
    $263 = (_luaK_stringK($ls$idx$val$i$i$i20,$257)|0);
    $264 = ((($key$i$i$i)) + 16|0);
    HEAP32[$264>>2] = -1;
    $265 = ((($key$i$i$i)) + 20|0);
    HEAP32[$265>>2] = -1;
    HEAP32[$key$i$i$i>>2] = 4;
    $266 = ((($key$i$i$i)) + 8|0);
    HEAP32[$266>>2] = $263;
    _luaK_indexed($258,$v$i,$key$i$i$i);
   }
   while(1) {
    $267 = HEAP32[$18>>2]|0;
    if ((($267|0) == 58)) {
     label = 92;
     break;
    } else if (!((($267|0) == 46))) {
     $ismethod$0$i$i = 0;
     break;
    }
    _fieldsel($ls,$v$i);
   }
   if ((label|0) == 92) {
    _fieldsel($ls,$v$i);
    $ismethod$0$i$i = 1;
   }
   _body($ls,$b$i,$ismethod$0$i$i,$1);
   $268 = HEAP32[$ls$idx>>2]|0;
   _luaK_storevar($268,$v$i,$b$i);
   $269 = HEAP32[$ls$idx>>2]|0;
   _luaK_fixline($269,$1);
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  case 269:  {
   _luaX_next($ls);
   $270 = HEAP32[$18>>2]|0;
   $271 = ($270|0)==(265);
   if ($271) {
    _luaX_next($ls);
    $272 = HEAP32[$ls$idx>>2]|0;
    $273 = HEAP32[$18>>2]|0;
    $274 = ($273|0)==(292);
    if (!($274)) {
     _error_expected($ls,292);
     // unreachable;
    }
    $275 = ((($ls)) + 24|0);
    $276 = HEAP32[$275>>2]|0;
    _luaX_next($ls);
    _new_localvar($ls,$276);
    $ls$idx$val$i = HEAP32[$ls$idx>>2]|0;
    $277 = ((($ls$idx$val$i)) + 42|0);
    $278 = HEAP8[$277>>0]|0;
    $279 = $278&255;
    $280 = (($279) + 1)|0;
    $281 = $280&255;
    HEAP8[$277>>0] = $281;
    $282 = ((($ls$idx$val$i)) + 16|0);
    $283 = HEAP32[$282>>2]|0;
    $284 = $280 & 255;
    $$idx$val$i$i = HEAP32[$ls$idx$val$i>>2]|0;
    $$idx1$i$i = ((($ls$idx$val$i)) + 8|0);
    $$idx1$val$i$i = HEAP32[$$idx1$i$i>>2]|0;
    $$idx2$i$i = ((($ls$idx$val$i)) + 36|0);
    $$idx2$val$i$i = HEAP32[$$idx2$i$i>>2]|0;
    $$idx$val$idx$i$i = ((($$idx$val$i$i)) + 60|0);
    $$idx$val$idx$val$i$i = HEAP32[$$idx$val$idx$i$i>>2]|0;
    $$idx1$val$idx$i$i = ((($$idx1$val$i$i)) + 68|0);
    $$idx1$val$idx$val$i$i = HEAP32[$$idx1$val$idx$i$i>>2]|0;
    $$idx1$val$idx$val$idx$val$i$i = HEAP32[$$idx1$val$idx$val$i$i>>2]|0;
    $285 = (($$idx2$val$i$i) + ($284))|0;
    $286 = (($285) + -1)|0;
    $287 = (($$idx1$val$idx$val$idx$val$i$i) + ($286<<1)|0);
    $288 = HEAP16[$287>>1]|0;
    $289 = $288 << 16 >> 16;
    $290 = (((($$idx$val$idx$val$i$i) + (($289*12)|0)|0)) + 4|0);
    HEAP32[$290>>2] = $283;
    $291 = HEAP32[$0>>2]|0;
    _body($ls,$b$i21,0,$291);
    $292 = ((($272)) + 16|0);
    $293 = HEAP32[$292>>2]|0;
    $294 = ((($b$i21)) + 8|0);
    $295 = HEAP32[$294>>2]|0;
    $$idx$val$i = HEAP32[$272>>2]|0;
    $$idx1$i = ((($272)) + 8|0);
    $$idx1$val$i = HEAP32[$$idx1$i>>2]|0;
    $$idx2$i = ((($272)) + 36|0);
    $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
    $$idx$val$idx$i = ((($$idx$val$i)) + 60|0);
    $$idx$val$idx$val$i = HEAP32[$$idx$val$idx$i>>2]|0;
    $$idx1$val$idx$i = ((($$idx1$val$i)) + 68|0);
    $$idx1$val$idx$val$i = HEAP32[$$idx1$val$idx$i>>2]|0;
    $$idx1$val$idx$val$idx$val$i = HEAP32[$$idx1$val$idx$val$i>>2]|0;
    $296 = (($$idx2$val$i) + ($295))|0;
    $297 = (($$idx1$val$idx$val$idx$val$i) + ($296<<1)|0);
    $298 = HEAP16[$297>>1]|0;
    $299 = $298 << 16 >> 16;
    $300 = (((($$idx$val$idx$val$i) + (($299*12)|0)|0)) + 4|0);
    HEAP32[$300>>2] = $293;
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $301 = ($270|0)==(292);
   if (!($301)) {
    _error_expected($ls,292);
    // unreachable;
   }
   $302 = ((($ls)) + 24|0);
   $nvars$0$i95 = 0;
   while(1) {
    $303 = HEAP32[$302>>2]|0;
    _luaX_next($ls);
    _new_localvar($ls,$303);
    $304 = (($nvars$0$i95) + 1)|0;
    $305 = HEAP32[$18>>2]|0;
    if ((($305|0) == 61)) {
     $$lcssa170 = $304;
     label = 103;
     break;
    } else if (!((($305|0) == 44))) {
     $$lcssa169 = $304;
     label = 105;
     break;
    }
    _luaX_next($ls);
    $306 = HEAP32[$18>>2]|0;
    $307 = ($306|0)==(292);
    if ($307) {
     $nvars$0$i95 = $304;
    } else {
     label = 100;
     break;
    }
   }
   do {
    if ((label|0) == 100) {
     _error_expected($ls,292);
     // unreachable;
    }
    else if ((label|0) == 103) {
     _luaX_next($ls);
     (_subexpr($ls,$e$i,0)|0);
     $308 = HEAP32[$18>>2]|0;
     $309 = ($308|0)==(44);
     if ($309) {
      $n$0$i$i91 = 1;
      while(1) {
       _luaX_next($ls);
       $310 = HEAP32[$ls$idx>>2]|0;
       _luaK_exp2nextreg($310,$e$i);
       (_subexpr($ls,$e$i,0)|0);
       $311 = (($n$0$i$i91) + 1)|0;
       $312 = HEAP32[$18>>2]|0;
       $313 = ($312|0)==(44);
       if ($313) {
        $n$0$i$i91 = $311;
       } else {
        $n$0$i$i$lcssa = $311;
        break;
       }
      }
     } else {
      $n$0$i$i$lcssa = 1;
     }
     $$pre111 = HEAP32[$e$i>>2]|0;
     $ls$idx1$val$i = HEAP32[$ls$idx>>2]|0;
     $314 = (($$lcssa170) - ($n$0$i$i$lcssa))|0;
     if ((($$pre111|0) == 0)) {
      $320 = $314;$471 = $$lcssa170;$ls$idx1$val$i116 = $ls$idx1$val$i;
      label = 110;
      break;
     } else if (!((($$pre111|0) == 14) | (($$pre111|0) == 13))) {
      _luaK_exp2nextreg($ls$idx1$val$i,$e$i);
      $320 = $314;$471 = $$lcssa170;$ls$idx1$val$i116 = $ls$idx1$val$i;
      label = 110;
      break;
     }
     $315 = (($314) + 1)|0;
     $316 = ($315|0)<(0);
     $$$i$i = $316 ? 0 : $315;
     _luaK_setreturns($ls$idx1$val$i,$e$i,$$$i$i);
     $317 = ($$$i$i|0)>(1);
     if ($317) {
      $318 = (($$$i$i) + -1)|0;
      _luaK_reserveregs($ls$idx1$val$i,$318);
      $328 = $$lcssa170;
     } else {
      $328 = $$lcssa170;
     }
    }
    else if ((label|0) == 105) {
     HEAP32[$e$i>>2] = 0;
     $ls$idx1$val$i115 = HEAP32[$ls$idx>>2]|0;
     $320 = $$lcssa169;$471 = $$lcssa169;$ls$idx1$val$i116 = $ls$idx1$val$i115;
     label = 110;
    }
   } while(0);
   if ((label|0) == 110) {
    $319 = ($320|0)>(0);
    if ($319) {
     $321 = ((($ls$idx1$val$i116)) + 44|0);
     $322 = HEAP8[$321>>0]|0;
     $323 = $322&255;
     _luaK_reserveregs($ls$idx1$val$i116,$320);
     _luaK_nil($ls$idx1$val$i116,$323,$320);
     $328 = $471;
    } else {
     $328 = $471;
    }
   }
   $ls$idx$val$i29 = HEAP32[$ls$idx>>2]|0;
   $324 = ((($ls$idx$val$i29)) + 42|0);
   $325 = HEAP8[$324>>0]|0;
   $326 = $325&255;
   $327 = (($326) + ($328))|0;
   $329 = $327&255;
   HEAP8[$324>>0] = $329;
   $330 = ($328|0)==(0);
   if (!($330)) {
    $331 = ((($ls$idx$val$i29)) + 16|0);
    $332 = HEAP32[$331>>2]|0;
    $333 = $327 & 255;
    $$idx$val$i$i31 = HEAP32[$ls$idx$val$i29>>2]|0;
    $$idx1$i$i32 = ((($ls$idx$val$i29)) + 8|0);
    $$idx1$val$i$i33 = HEAP32[$$idx1$i$i32>>2]|0;
    $$idx2$i$i34 = ((($ls$idx$val$i29)) + 36|0);
    $$idx2$val$i$i35 = HEAP32[$$idx2$i$i34>>2]|0;
    $$idx$val$idx$i$i36 = ((($$idx$val$i$i31)) + 60|0);
    $$idx$val$idx$val$i$i37 = HEAP32[$$idx$val$idx$i$i36>>2]|0;
    $$idx1$val$idx$i$i38 = ((($$idx1$val$i$i33)) + 68|0);
    $$idx1$val$idx$val$i$i39 = HEAP32[$$idx1$val$idx$i$i38>>2]|0;
    $$idx1$val$idx$val$idx$val$i$i41 = HEAP32[$$idx1$val$idx$val$i$i39>>2]|0;
    $334 = (($$idx2$val$i$i35) + ($333))|0;
    $$01$i$i42 = $328;
    while(1) {
     $335 = (($334) - ($$01$i$i42))|0;
     $336 = (($$idx1$val$idx$val$idx$val$i$i41) + ($335<<1)|0);
     $337 = HEAP16[$336>>1]|0;
     $338 = $337 << 16 >> 16;
     $339 = (((($$idx$val$idx$val$i$i37) + (($338*12)|0)|0)) + 4|0);
     HEAP32[$339>>2] = $332;
     $340 = (($$01$i$i42) + -1)|0;
     $341 = ($340|0)==(0);
     if ($341) {
      break;
     } else {
      $$01$i$i42 = $340;
     }
    }
   }
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  case 274:  {
   _luaX_next($ls);
   $419 = HEAP32[$ls$idx>>2]|0;
   $ls$idx$val$i50 = HEAP32[$18>>2]|0;
   L179: do {
    switch ($ls$idx$val$i50|0) {
    case 59: case 277: case 289: case 262: case 261: case 260:  {
     $first$0$i = 0;$nret$0$i = 0;
     break;
    }
    default: {
     (_subexpr($ls,$e$i48,0)|0);
     $420 = HEAP32[$18>>2]|0;
     $421 = ($420|0)==(44);
     if ($421) {
      $n$0$i$i5397 = 1;
      while(1) {
       _luaX_next($ls);
       $422 = HEAP32[$ls$idx>>2]|0;
       _luaK_exp2nextreg($422,$e$i48);
       (_subexpr($ls,$e$i48,0)|0);
       $423 = (($n$0$i$i5397) + 1)|0;
       $424 = HEAP32[$18>>2]|0;
       $425 = ($424|0)==(44);
       if ($425) {
        $n$0$i$i5397 = $423;
       } else {
        $n$0$i$i53$lcssa = $423;
        break;
       }
      }
     } else {
      $n$0$i$i53$lcssa = 1;
     }
     $426 = HEAP32[$e$i48>>2]|0;
     $$off$i = (($426) + -13)|0;
     $switch$i = ($$off$i>>>0)<(2);
     if ($switch$i) {
      _luaK_setreturns($419,$e$i48,-1);
      $427 = HEAP32[$e$i48>>2]|0;
      $428 = ($427|0)==(13);
      $429 = ($n$0$i$i53$lcssa|0)==(1);
      $or$cond$i = $429 & $428;
      if ($or$cond$i) {
       $430 = ((($e$i48)) + 8|0);
       $431 = HEAP32[$430>>2]|0;
       $432 = HEAP32[$419>>2]|0;
       $433 = ((($432)) + 48|0);
       $434 = HEAP32[$433>>2]|0;
       $435 = (($434) + ($431<<2)|0);
       $436 = HEAP32[$435>>2]|0;
       $437 = $436 & -64;
       $438 = $437 | 37;
       HEAP32[$435>>2] = $438;
      }
      $439 = ((($419)) + 42|0);
      $440 = HEAP8[$439>>0]|0;
      $441 = $440&255;
      $first$0$i = $441;$nret$0$i = -1;
      break L179;
     } else {
      $442 = ($n$0$i$i53$lcssa|0)==(1);
      if ($442) {
       $443 = (_luaK_exp2anyreg($419,$e$i48)|0);
       $first$0$i = $443;$nret$0$i = 1;
       break L179;
      } else {
       _luaK_exp2nextreg($419,$e$i48);
       $444 = ((($419)) + 42|0);
       $445 = HEAP8[$444>>0]|0;
       $446 = $445&255;
       $first$0$i = $446;$nret$0$i = $n$0$i$i53$lcssa;
       break L179;
      }
     }
    }
    }
   } while(0);
   _luaK_ret($419,$first$0$i,$nret$0$i);
   $447 = HEAP32[$18>>2]|0;
   $448 = ($447|0)==(59);
   if ($448) {
    _luaX_next($ls);
   }
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  case 288:  {
   _luaX_next($ls);
   $342 = HEAP32[$18>>2]|0;
   $343 = ($342|0)==(292);
   if (!($343)) {
    _error_expected($ls,292);
    // unreachable;
   }
   $344 = ((($ls)) + 24|0);
   $345 = HEAP32[$344>>2]|0;
   _luaX_next($ls);
   $346 = HEAP32[$ls$idx>>2]|0;
   $347 = ((($ls)) + 68|0);
   $348 = HEAP32[$347>>2]|0;
   $349 = ((($348)) + 24|0);
   $350 = ((($346)) + 12|0);
   $351 = HEAP32[$350>>2]|0;
   $352 = ((($351)) + 4|0);
   $353 = HEAP32[$352>>2]|0;
   $354 = ((($348)) + 28|0);
   $355 = HEAP32[$354>>2]|0;
   $356 = ($353|0)<($355|0);
   L203: do {
    if ($356) {
     $357 = HEAP32[$349>>2]|0;
     $i$02$i$i = $353;
     while(1) {
      $358 = (($357) + ($i$02$i$i<<4)|0);
      $359 = HEAP32[$358>>2]|0;
      $360 = ($359|0)==($345|0);
      if ($360) {
       $i$02$i$i$lcssa = $i$02$i$i;
       break;
      }
      $370 = (($i$02$i$i) + 1)|0;
      $371 = ($370|0)<($355|0);
      if ($371) {
       $i$02$i$i = $370;
      } else {
       break L203;
      }
     }
     $361 = ((($346)) + 8|0);
     $362 = HEAP32[$361>>2]|0;
     $363 = ((($362)) + 52|0);
     $364 = HEAP32[$363>>2]|0;
     $365 = ((($345)) + 24|0);
     $366 = (((($357) + ($i$02$i$i$lcssa<<4)|0)) + 8|0);
     $367 = HEAP32[$366>>2]|0;
     HEAP32[$vararg_buffer31>>2] = $365;
     $vararg_ptr34 = ((($vararg_buffer31)) + 4|0);
     HEAP32[$vararg_ptr34>>2] = $367;
     $368 = (_luaO_pushfstring($364,3304,$vararg_buffer31)|0);
     $369 = HEAP32[$361>>2]|0;
     _semerror($369,$368);
     // unreachable;
    }
   } while(0);
   $372 = HEAP32[$18>>2]|0;
   $373 = ($372|0)==(288);
   if (!($373)) {
    _error_expected($ls,288);
    // unreachable;
   }
   _luaX_next($ls);
   $374 = ((($346)) + 16|0);
   $375 = HEAP32[$374>>2]|0;
   $376 = HEAP32[$354>>2]|0;
   $377 = (($376) + 1)|0;
   $378 = ((($348)) + 32|0);
   $379 = HEAP32[$378>>2]|0;
   $380 = ($376|0)<($379|0);
   if ($380) {
    $$pre$i$i = HEAP32[$349>>2]|0;
    $385 = $$pre$i$i;
   } else {
    $381 = HEAP32[$ls$idx1>>2]|0;
    $382 = HEAP32[$349>>2]|0;
    $383 = (_luaM_growaux_($381,$382,$378,16,32767,2880)|0);
    HEAP32[$349>>2] = $383;
    $385 = $383;
   }
   $384 = (($385) + ($376<<4)|0);
   HEAP32[$384>>2] = $345;
   $386 = (((($385) + ($376<<4)|0)) + 8|0);
   HEAP32[$386>>2] = $1;
   $387 = HEAP32[$ls$idx>>2]|0;
   $388 = ((($387)) + 42|0);
   $389 = HEAP8[$388>>0]|0;
   $390 = (((($385) + ($376<<4)|0)) + 12|0);
   HEAP8[$390>>0] = $389;
   $391 = (((($385) + ($376<<4)|0)) + 4|0);
   HEAP32[$391>>2] = $375;
   HEAP32[$354>>2] = $377;
   L217: while(1) {
    $392 = HEAP32[$18>>2]|0;
    switch ($392|0) {
    case 288: case 59:  {
     break;
    }
    case 289: case 262: case 261: case 260:  {
     label = 132;
     break L217;
     break;
    }
    default: {
     label = 131;
     break L217;
    }
    }
    _statement($ls);
   }
   if ((label|0) == 131) {
    $$pre = HEAP32[$349>>2]|0;
    $399 = $$pre;
   }
   else if ((label|0) == 132) {
    $393 = HEAP32[$350>>2]|0;
    $394 = ((($393)) + 12|0);
    $395 = HEAP8[$394>>0]|0;
    $396 = HEAP32[$349>>2]|0;
    $397 = (((($396) + ($376<<4)|0)) + 12|0);
    HEAP8[$397>>0] = $395;
    $399 = $396;
   }
   $398 = (($399) + ($376<<4)|0);
   $400 = HEAP32[$347>>2]|0;
   $401 = HEAP32[$ls$idx>>2]|0;
   $402 = ((($401)) + 12|0);
   $403 = HEAP32[$402>>2]|0;
   $404 = ((($403)) + 8|0);
   $405 = HEAP32[$404>>2]|0;
   $406 = ((($400)) + 16|0);
   $407 = HEAP32[$406>>2]|0;
   $408 = ($405|0)<($407|0);
   if (!($408)) {
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $409 = ((($400)) + 12|0);
   $472 = $407;$i$0$ph1$i$i = $405;
   L227: while(1) {
    $473 = $472;
    while(1) {
     $410 = HEAP32[$409>>2]|0;
     $411 = (($410) + ($i$0$ph1$i$i<<4)|0);
     $412 = HEAP32[$411>>2]|0;
     $413 = HEAP32[$398>>2]|0;
     $414 = ($412|0)==($413|0);
     if (!($414)) {
      $$lcssa172 = $473;
      break;
     }
     _closegoto($ls,$i$0$ph1$i$i,$398);
     $415 = HEAP32[$406>>2]|0;
     $416 = ($i$0$ph1$i$i|0)<($415|0);
     if ($416) {
      $473 = $415;
     } else {
      label = 159;
      break L227;
     }
    }
    $417 = (($i$0$ph1$i$i) + 1)|0;
    $418 = ($417|0)<($$lcssa172|0);
    if ($418) {
     $472 = $$lcssa172;$i$0$ph1$i$i = $417;
    } else {
     label = 159;
     break;
    }
   }
   if ((label|0) == 159) {
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   break;
  }
  case 266: case 258:  {
   $449 = (_luaK_jump($ls$idx$val)|0);
   _gotostat($ls,$449);
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  default: {
   $450 = ((($v$i59)) + 8|0);
   _suffixedexp($ls,$450);
   $451 = HEAP32[$18>>2]|0;
   do {
    if ((($451|0) == 44) | (($451|0) == 61)) {
     HEAP32[$v$i59>>2] = 0;
     _assignment($ls,$v$i59,1);
    } else {
     $452 = HEAP32[$450>>2]|0;
     $453 = ($452|0)==(13);
     if ($453) {
      $454 = ((($v$i59)) + 16|0);
      $455 = HEAP32[$454>>2]|0;
      $456 = HEAP32[$ls$idx$val>>2]|0;
      $457 = ((($456)) + 48|0);
      $458 = HEAP32[$457>>2]|0;
      $459 = (($458) + ($455<<2)|0);
      $460 = HEAP32[$459>>2]|0;
      $461 = $460 & -8372225;
      $462 = $461 | 16384;
      HEAP32[$459>>2] = $462;
      break;
     } else {
      _luaX_syntaxerror($ls,3344);
      // unreachable;
     }
    }
   } while(0);
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
  }
  }
 } while(0);
}
function _error_expected($ls,$token) {
 $ls = $ls|0;
 $token = $token|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($ls)) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaX_token2str($ls,$token)|0);
 HEAP32[$vararg_buffer>>2] = $2;
 $3 = (_luaO_pushfstring($1,3040,$vararg_buffer)|0);
 _luaX_syntaxerror($ls,$3);
 // unreachable;
}
function _close_func($ls) {
 $ls = $ls|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 _luaK_ret($3,0,0);
 _leaveblock($3);
 $5 = ((($3)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  _luaM_toobig($1);
  // unreachable;
 }
 $9 = ((($4)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($4)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 << 2;
 $14 = $6 << 2;
 $15 = (_luaM_realloc_($1,$10,$13,$14)|0);
 HEAP32[$9>>2] = $15;
 $16 = HEAP32[$5>>2]|0;
 HEAP32[$11>>2] = $16;
 $17 = (($16) + 1)|0;
 $18 = ($17>>>0)>(1073741823);
 if ($18) {
  _luaM_toobig($1);
  // unreachable;
 }
 $19 = ((($4)) + 56|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($4)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 2;
 $24 = $16 << 2;
 $25 = (_luaM_realloc_($1,$20,$23,$24)|0);
 HEAP32[$19>>2] = $25;
 $26 = HEAP32[$5>>2]|0;
 HEAP32[$21>>2] = $26;
 $27 = ((($3)) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 $30 = ($29>>>0)>(268435455);
 if ($30) {
  _luaM_toobig($1);
  // unreachable;
 }
 $31 = ((($4)) + 44|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($4)) + 16|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 << 4;
 $36 = $28 << 4;
 $37 = (_luaM_realloc_($1,$32,$35,$36)|0);
 HEAP32[$31>>2] = $37;
 $38 = HEAP32[$27>>2]|0;
 HEAP32[$33>>2] = $38;
 $39 = ((($3)) + 32|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 1)|0;
 $42 = ($41>>>0)>(1073741823);
 if ($42) {
  _luaM_toobig($1);
  // unreachable;
 }
 $43 = ((($4)) + 52|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($4)) + 28|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $46 << 2;
 $48 = $40 << 2;
 $49 = (_luaM_realloc_($1,$44,$47,$48)|0);
 HEAP32[$43>>2] = $49;
 $50 = HEAP32[$39>>2]|0;
 HEAP32[$45>>2] = $50;
 $51 = ((($4)) + 60|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ((($4)) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54*12)|0;
 $56 = ((($3)) + 40|0);
 $57 = HEAP16[$56>>1]|0;
 $58 = $57 << 16 >> 16;
 $59 = ($58*12)|0;
 $60 = (_luaM_realloc_($1,$52,$55,$59)|0);
 HEAP32[$51>>2] = $60;
 $61 = HEAP16[$56>>1]|0;
 $62 = $61 << 16 >> 16;
 HEAP32[$53>>2] = $62;
 $63 = ((($4)) + 64|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ((($4)) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $66 << 3;
 $68 = ((($3)) + 43|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = $69&255;
 $71 = $70 << 3;
 $72 = (_luaM_realloc_($1,$64,$67,$71)|0);
 HEAP32[$63>>2] = $72;
 $73 = HEAP8[$68>>0]|0;
 $74 = $73&255;
 HEAP32[$65>>2] = $74;
 $75 = ((($3)) + 4|0);
 $76 = HEAP32[$75>>2]|0;
 HEAP32[$2>>2] = $76;
 $77 = ((($1)) + 12|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ((($78)) + 12|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)>(0);
 if (!($81)) {
  return;
 }
 _luaC_step($1);
 return;
}
function _leaveblock($fs) {
 $fs = $fs|0;
 var $$0$i$i = 0, $$i$0$i = 0, $$lcssa = 0, $$lcssa33 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i2 = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $fs$idx$val$i = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$val$i = 0, $fs$idx1$val$idx$val$idx$val$i = 0, $fs$idx2$i = 0, $fs$idx2$val$i = 0, $i$0$ph1$i$i = 0, $i$03$i = 0, $i$04$i$i = 0, $i$04$i$i$lcssa = 0, $indvars$iv = 0, $indvars$iv$next = 0, $phitmp$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($fs)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($fs)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 13|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   $9 = (_luaK_jump($fs)|0);
   $10 = ((($1)) + 12|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = $11&255;
   _luaK_patchclose($fs,$9,$12);
   _luaK_patchtohere($fs,$9);
  }
 }
 $13 = ((($1)) + 14|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 L5: do {
  if (!($15)) {
   $16 = ((($3)) + 52|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (_luaS_new($17,5896)|0);
   $19 = ((($3)) + 68|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ((($20)) + 24|0);
   $22 = ((($3)) + 48|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($23)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($20)) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 1)|0;
   $29 = ((($20)) + 32|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($27|0)<($30|0);
   if ($31) {
    $$pre$i$i = HEAP32[$21>>2]|0;
    $36 = $$pre$i$i;$39 = $23;$44 = $20;
   } else {
    $32 = HEAP32[$16>>2]|0;
    $33 = HEAP32[$21>>2]|0;
    $34 = (_luaM_growaux_($32,$33,$29,16,32767,2880)|0);
    HEAP32[$21>>2] = $34;
    $$pre$i = HEAP32[$22>>2]|0;
    $$pre4$i = HEAP32[$19>>2]|0;
    $36 = $34;$39 = $$pre$i;$44 = $$pre4$i;
   }
   $35 = (($36) + ($27<<4)|0);
   HEAP32[$35>>2] = $18;
   $37 = (((($36) + ($27<<4)|0)) + 8|0);
   HEAP32[$37>>2] = 0;
   $38 = ((($39)) + 42|0);
   $40 = HEAP8[$38>>0]|0;
   $41 = (((($36) + ($27<<4)|0)) + 12|0);
   HEAP8[$41>>0] = $40;
   $42 = (((($36) + ($27<<4)|0)) + 4|0);
   HEAP32[$42>>2] = $25;
   HEAP32[$26>>2] = $28;
   $43 = ((($44)) + 24|0);
   $45 = HEAP32[$43>>2]|0;
   $46 = (($45) + ($27<<4)|0);
   $47 = ((($39)) + 12|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ((($48)) + 8|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ((($44)) + 16|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($50|0)<($52|0);
   if ($53) {
    $54 = ((($44)) + 12|0);
    $169 = $52;$i$0$ph1$i$i = $50;
    while(1) {
     $170 = $169;
     while(1) {
      $55 = HEAP32[$54>>2]|0;
      $56 = (($55) + ($i$0$ph1$i$i<<4)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = HEAP32[$46>>2]|0;
      $59 = ($57|0)==($58|0);
      if (!($59)) {
       $$lcssa33 = $170;
       break;
      }
      _closegoto($3,$i$0$ph1$i$i,$46);
      $60 = HEAP32[$51>>2]|0;
      $61 = ($i$0$ph1$i$i|0)<($60|0);
      if ($61) {
       $170 = $60;
      } else {
       break L5;
      }
     }
     $62 = (($i$0$ph1$i$i) + 1)|0;
     $63 = ($62|0)<($$lcssa33|0);
     if ($63) {
      $169 = $$lcssa33;$i$0$ph1$i$i = $62;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 $64 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $64;
 $65 = ((($1)) + 12|0);
 $66 = HEAP8[$65>>0]|0;
 $67 = $66&255;
 $68 = ((($fs)) + 42|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = $69&255;
 $71 = HEAP32[$2>>2]|0;
 $72 = ((($71)) + 68|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ((($73)) + 4|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($67) - ($70))|0;
 $77 = (($76) + ($75))|0;
 HEAP32[$74>>2] = $77;
 $78 = ($66&255)<($69&255);
 if ($78) {
  $79 = ((($fs)) + 16|0);
  $80 = HEAP32[$79>>2]|0;
  $fs$idx$val$i = HEAP32[$fs>>2]|0;
  $fs$idx2$i = ((($fs)) + 36|0);
  $fs$idx2$val$i = HEAP32[$fs$idx2$i>>2]|0;
  $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 60|0);
  $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
  $fs$idx1$val$idx$val$idx$val$i = HEAP32[$73>>2]|0;
  $indvars$iv = $70;
  while(1) {
   $81 = $indvars$iv&255;
   $82 = (($81) + -1)<<24>>24;
   $83 = $82&255;
   $84 = (($83) + ($fs$idx2$val$i))|0;
   $85 = (($fs$idx1$val$idx$val$idx$val$i) + ($84<<1)|0);
   $86 = HEAP16[$85>>1]|0;
   $87 = $86 << 16 >> 16;
   $88 = (((($fs$idx$val$idx$val$i) + (($87*12)|0)|0)) + 8|0);
   HEAP32[$88>>2] = $80;
   $89 = ($82&255)>($66&255);
   $indvars$iv$next = (($indvars$iv) + -1)|0;
   if ($89) {
    $indvars$iv = $indvars$iv$next;
   } else {
    break;
   }
  }
  HEAP8[$68>>0] = $66;
  $91 = $66;
 } else {
  $91 = $69;
 }
 $90 = ((($fs)) + 44|0);
 HEAP8[$90>>0] = $91;
 $92 = ((($1)) + 4|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ((($3)) + 68|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ((($95)) + 28|0);
 HEAP32[$96>>2] = $93;
 $97 = ($64|0)==(0);
 $98 = ((($1)) + 8|0);
 $99 = HEAP32[$98>>2]|0;
 if ($97) {
  $149 = ((($95)) + 16|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = ($99|0)<($150|0);
  if (!($151)) {
   STACKTOP = sp;return;
  }
  $152 = ((($95)) + 12|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = (($153) + ($99<<4)|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = ((($155)) + 4|0);
  $157 = HEAP8[$156>>0]|0;
  $158 = ($157<<24>>24)==(4);
  if (!($158)) {
   $167 = 2936;
   $162 = ((($3)) + 52|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ((($155)) + 24|0);
   $165 = (((($153) + ($99<<4)|0)) + 8|0);
   $166 = HEAP32[$165>>2]|0;
   HEAP32[$vararg_buffer>>2] = $164;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $166;
   $168 = (_luaO_pushfstring($163,$167,$vararg_buffer)|0);
   _semerror($3,$168);
   // unreachable;
  }
  $159 = ((($155)) + 6|0);
  $160 = HEAP8[$159>>0]|0;
  $161 = ($160<<24>>24)!=(0);
  $phitmp$i = $161 ? 2896 : 2936;
  $167 = $phitmp$i;
  $162 = ((($3)) + 52|0);
  $163 = HEAP32[$162>>2]|0;
  $164 = ((($155)) + 24|0);
  $165 = (((($153) + ($99<<4)|0)) + 8|0);
  $166 = HEAP32[$165>>2]|0;
  HEAP32[$vararg_buffer>>2] = $164;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $166;
  $168 = (_luaO_pushfstring($163,$167,$vararg_buffer)|0);
  _semerror($3,$168);
  // unreachable;
 }
 $100 = ((($73)) + 16|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($99|0)<($101|0);
 if (!($102)) {
  STACKTOP = sp;return;
 }
 $103 = ((($73)) + 12|0);
 $104 = ((($1)) + 13|0);
 $109 = $66;$i$03$i = $99;
 while(1) {
  $105 = HEAP32[$103>>2]|0;
  $106 = (((($105) + ($i$03$i<<4)|0)) + 12|0);
  $107 = HEAP8[$106>>0]|0;
  $108 = $109&255;
  $110 = ($107&255)>($109&255);
  if ($110) {
   $111 = HEAP8[$104>>0]|0;
   $112 = ($111<<24>>24)==(0);
   if ($112) {
    $115 = $109;
   } else {
    $113 = (((($105) + ($i$03$i<<4)|0)) + 4|0);
    $114 = HEAP32[$113>>2]|0;
    _luaK_patchclose($fs,$114,$108);
    $$pre$i2 = HEAP8[$65>>0]|0;
    $115 = $$pre$i2;
   }
   HEAP8[$106>>0] = $115;
  }
  $116 = HEAP32[$2>>2]|0;
  $117 = ((($116)) + 48|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = ((($118)) + 12|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = ((($116)) + 68|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = ((($122)) + 12|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ((($120)) + 4|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ((($122)) + 28|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ($126|0)<($128|0);
  L46: do {
   if ($129) {
    $130 = ((($122)) + 24|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($124) + ($i$03$i<<4)|0);
    $133 = HEAP32[$132>>2]|0;
    $i$04$i$i = $126;
    while(1) {
     $134 = (($131) + ($i$04$i$i<<4)|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ($135|0)==($133|0);
     if ($136) {
      $$lcssa = $134;$i$04$i$i$lcssa = $i$04$i$i;
      break;
     }
     $145 = (($i$04$i$i) + 1)|0;
     $146 = ($145|0)<($128|0);
     if ($146) {
      $i$04$i$i = $145;
     } else {
      $$0$i$i = 1;
      break L46;
     }
    }
    $137 = (((($124) + ($i$03$i<<4)|0)) + 12|0);
    $138 = HEAP8[$137>>0]|0;
    $139 = (((($131) + ($i$04$i$i$lcssa<<4)|0)) + 12|0);
    $140 = HEAP8[$139>>0]|0;
    $141 = ($138&255)>($140&255);
    if ($141) {
     $142 = (((($124) + ($i$03$i<<4)|0)) + 4|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = $140&255;
     _luaK_patchclose($118,$143,$144);
    }
    _closegoto($116,$i$03$i,$$lcssa);
    $$0$i$i = 0;
   } else {
    $$0$i$i = 1;
   }
  } while(0);
  $$i$0$i = (($$0$i$i) + ($i$03$i))|0;
  $147 = HEAP32[$100>>2]|0;
  $148 = ($$i$0$i|0)<($147|0);
  if (!($148)) {
   break;
  }
  $$pre = HEAP8[$65>>0]|0;
  $109 = $$pre;$i$03$i = $$i$0$i;
 }
 STACKTOP = sp;return;
}
function _closegoto($ls,$g,$label) {
 $ls = $ls|0;
 $g = $g|0;
 $label = $label|0;
 var $$idx$val = 0, $$idx$val$idx = 0, $$idx$val$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$idx1$val$idx = 0, $$idx1$val$idx$val = 0, $$idx1$val$idx$val$idx$val = 0, $$idx2 = 0, $$idx2$val = 0, $$lcssa3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (((($5) + ($g<<4)|0)) + 12|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ((($label)) + 12|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($7&255)<($9&255);
 if ($10) {
  $11 = (($5) + ($g<<4)|0);
  $12 = $7&255;
  $$idx$val = HEAP32[$1>>2]|0;
  $$idx1 = ((($1)) + 8|0);
  $$idx1$val = HEAP32[$$idx1>>2]|0;
  $$idx2 = ((($1)) + 36|0);
  $$idx2$val = HEAP32[$$idx2>>2]|0;
  $$idx$val$idx = ((($$idx$val)) + 60|0);
  $$idx$val$idx$val = HEAP32[$$idx$val$idx>>2]|0;
  $$idx1$val$idx = ((($$idx1$val)) + 68|0);
  $$idx1$val$idx$val = HEAP32[$$idx1$val$idx>>2]|0;
  $$idx1$val$idx$val$idx$val = HEAP32[$$idx1$val$idx$val>>2]|0;
  $13 = (($$idx2$val) + ($12))|0;
  $14 = (($$idx1$val$idx$val$idx$val) + ($13<<1)|0);
  $15 = HEAP16[$14>>1]|0;
  $16 = $15 << 16 >> 16;
  $17 = (($$idx$val$idx$val) + (($16*12)|0)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($ls)) + 52|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$11>>2]|0;
  $22 = ((($21)) + 24|0);
  $23 = (((($5) + ($g<<4)|0)) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($18)) + 24|0);
  HEAP32[$vararg_buffer>>2] = $22;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $24;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $25;
  $26 = (_luaO_pushfstring($20,2984,$vararg_buffer)|0);
  _semerror($ls,$26);
  // unreachable;
 }
 $27 = (((($5) + ($g<<4)|0)) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($label)) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 _luaK_patchlist($1,$28,$30);
 $31 = ((($3)) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + -1)|0;
 $34 = ($33|0)>($g|0);
 if ($34) {
  $i$04 = $g;
 } else {
  $$lcssa3 = $33;
  HEAP32[$31>>2] = $$lcssa3;
  STACKTOP = sp;return;
 }
 while(1) {
  $35 = HEAP32[$4>>2]|0;
  $36 = (($35) + ($i$04<<4)|0);
  $37 = (($i$04) + 1)|0;
  $38 = (($35) + ($37<<4)|0);
  ;HEAP32[$36>>2]=HEAP32[$38>>2]|0;HEAP32[$36+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$38+12>>2]|0;
  $39 = HEAP32[$31>>2]|0;
  $40 = (($39) + -1)|0;
  $41 = ($37|0)<($40|0);
  if ($41) {
   $i$04 = $37;
  } else {
   $$lcssa3 = $40;
   break;
  }
 }
 HEAP32[$31>>2] = $$lcssa3;
 STACKTOP = sp;return;
}
function _semerror($ls,$msg) {
 $ls = $ls|0;
 $msg = $msg|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 16|0);
 HEAP32[$0>>2] = 0;
 _luaX_syntaxerror($ls,$msg);
 // unreachable;
}
function _test_then_block($ls,$escapelist) {
 $ls = $ls|0;
 $escapelist = $escapelist|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bl = 0, $jf$0 = 0, $ls$idx$val$i = 0, $switch = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $bl = sp + 24|0;
 $v = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 _luaX_next($ls);
 (_subexpr($ls,$v,0)|0);
 $2 = ((($ls)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(275);
 if (!($4)) {
  _error_expected($ls,275);
  // unreachable;
 }
 _luaX_next($ls);
 $5 = HEAP32[$2>>2]|0;
 do {
  if ((($5|0) == 258) | (($5|0) == 266)) {
   $6 = HEAP32[$0>>2]|0;
   _luaK_goiffalse($6,$v);
   $7 = ((($bl)) + 14|0);
   HEAP8[$7>>0] = 0;
   $8 = ((($1)) + 42|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ((($bl)) + 12|0);
   HEAP8[$10>>0] = $9;
   $11 = ((($1)) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ((($12)) + 68|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ((($14)) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($bl)) + 4|0);
   HEAP32[$17>>2] = $16;
   $18 = ((($14)) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($bl)) + 8|0);
   HEAP32[$20>>2] = $19;
   $21 = ((($bl)) + 13|0);
   HEAP8[$21>>0] = 0;
   $22 = ((($1)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   HEAP32[$bl>>2] = $23;
   HEAP32[$22>>2] = $bl;
   $24 = ((($v)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   _gotostat($ls,$25);
   L6: while(1) {
    $26 = HEAP32[$2>>2]|0;
    switch ($26|0) {
    case 288: case 59:  {
     break;
    }
    case 289: case 262: case 261: case 260:  {
     break L6;
     break;
    }
    default: {
     label = 8;
     break L6;
    }
    }
    _statement($ls);
   }
   if ((label|0) == 8) {
    $27 = (_luaK_jump($1)|0);
    $jf$0 = $27;
    break;
   }
   _leaveblock($1);
   STACKTOP = sp;return;
  } else {
   $28 = HEAP32[$0>>2]|0;
   _luaK_goiftrue($28,$v);
   $29 = ((($bl)) + 14|0);
   HEAP8[$29>>0] = 0;
   $30 = ((($1)) + 42|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ((($bl)) + 12|0);
   HEAP8[$32>>0] = $31;
   $33 = ((($1)) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34)) + 68|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36)) + 28|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($bl)) + 4|0);
   HEAP32[$39>>2] = $38;
   $40 = ((($36)) + 16|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ((($bl)) + 8|0);
   HEAP32[$42>>2] = $41;
   $43 = ((($bl)) + 13|0);
   HEAP8[$43>>0] = 0;
   $44 = ((($1)) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   HEAP32[$bl>>2] = $45;
   HEAP32[$44>>2] = $bl;
   $46 = ((($v)) + 20|0);
   $47 = HEAP32[$46>>2]|0;
   $jf$0 = $47;
  }
 } while(0);
 L15: while(1) {
  $ls$idx$val$i = HEAP32[$2>>2]|0;
  switch ($ls$idx$val$i|0) {
  case 277: case 289: case 262: case 261: case 260:  {
   break L15;
   break;
  }
  default: {
  }
  }
  $48 = ($ls$idx$val$i|0)==(274);
  _statement($ls);
  if ($48) {
   break;
  }
 }
 _leaveblock($1);
 $49 = HEAP32[$2>>2]|0;
 $50 = $49 & -2;
 $switch = ($50|0)==(260);
 if ($switch) {
  $51 = (_luaK_jump($1)|0);
  _luaK_concat($1,$escapelist,$51);
 }
 _luaK_patchtohere($1,$jf$0);
 STACKTOP = sp;return;
}
function _subexpr($ls,$v,$limit) {
 $ls = $ls|0;
 $v = $v|0;
 $limit = $limit|0;
 var $$0$i2$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $ls$idx = 0, $ls$idx$val = 0, $ls$idx1 = 0, $ls$idx1$val = 0, $op$0$lcssa = 0, $op$0$ph$ph = 0, $op$04 = 0, $v2 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 32|0;
 $vararg_buffer = sp + 24|0;
 $v2 = sp;
 $ls$idx = ((($ls)) + 48|0);
 $ls$idx$val = HEAP32[$ls$idx>>2]|0;
 $ls$idx1 = ((($ls)) + 52|0);
 $ls$idx1$val = HEAP32[$ls$idx1>>2]|0;
 $0 = ((($ls$idx1$val)) + 106|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($1) + 1)<<16>>16;
 HEAP16[$0>>1] = $2;
 $3 = ($2&65535)>(200);
 if ($3) {
  $4 = ((($ls$idx$val)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($5)) + 52|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$ls$idx$val>>2]|0;
  $9 = ((($8)) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0);
  if ($11) {
   $13 = 3080;
   HEAP32[$vararg_buffer1>>2] = 3128;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = 200;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $13;
   $14 = (_luaO_pushfstring($7,3096,$vararg_buffer1)|0);
   $15 = HEAP32[$4>>2]|0;
   _luaX_syntaxerror($15,$14);
   // unreachable;
  }
  HEAP32[$vararg_buffer>>2] = $10;
  $12 = (_luaO_pushfstring($7,3056,$vararg_buffer)|0);
  $13 = $12;
  HEAP32[$vararg_buffer1>>2] = 3128;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = 200;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $13;
  $14 = (_luaO_pushfstring($7,3096,$vararg_buffer1)|0);
  $15 = HEAP32[$4>>2]|0;
  _luaX_syntaxerror($15,$14);
  // unreachable;
 }
 $16 = ((($ls)) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 L8: do {
  switch ($17|0) {
  case 265:  {
   _luaX_next($ls);
   $64 = ((($ls)) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   _body($ls,$v,0,$65);
   break;
  }
  case 291:  {
   $27 = ((($v)) + 16|0);
   HEAP32[$27>>2] = -1;
   $28 = ((($v)) + 20|0);
   HEAP32[$28>>2] = -1;
   HEAP32[$v>>2] = 6;
   $29 = ((($v)) + 8|0);
   HEAP32[$29>>2] = 0;
   $30 = ((($ls)) + 24|0);
   $31 = $30;
   $32 = $31;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + 4)|0;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = $29;
   $38 = $37;
   HEAP32[$38>>2] = $33;
   $39 = (($37) + 4)|0;
   $40 = $39;
   HEAP32[$40>>2] = $36;
   label = 22;
   break;
  }
  case 35:  {
   $$0$i2$ph = 3;
   label = 9;
   break;
  }
  case 281:  {
   $56 = HEAP32[$ls$idx$val>>2]|0;
   $57 = ((($56)) + 7|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = ($58<<24>>24)==(0);
   if ($59) {
    _luaX_syntaxerror($ls,3488);
    // unreachable;
   } else {
    $60 = (_luaK_codeABC($ls$idx$val,45,0,1,0)|0);
    $61 = ((($v)) + 16|0);
    HEAP32[$61>>2] = -1;
    $62 = ((($v)) + 20|0);
    HEAP32[$62>>2] = -1;
    HEAP32[$v>>2] = 14;
    $63 = ((($v)) + 8|0);
    HEAP32[$63>>2] = $60;
    label = 22;
    break L8;
   }
   break;
  }
  case 263:  {
   $53 = ((($v)) + 16|0);
   HEAP32[$53>>2] = -1;
   $54 = ((($v)) + 20|0);
   HEAP32[$54>>2] = -1;
   HEAP32[$v>>2] = 3;
   $55 = ((($v)) + 8|0);
   HEAP32[$55>>2] = 0;
   label = 22;
   break;
  }
  case 271:  {
   $$0$i2$ph = 2;
   label = 9;
   break;
  }
  case 276:  {
   $50 = ((($v)) + 16|0);
   HEAP32[$50>>2] = -1;
   $51 = ((($v)) + 20|0);
   HEAP32[$51>>2] = -1;
   HEAP32[$v>>2] = 2;
   $52 = ((($v)) + 8|0);
   HEAP32[$52>>2] = 0;
   label = 22;
   break;
  }
  case 290:  {
   $21 = ((($v)) + 16|0);
   HEAP32[$21>>2] = -1;
   $22 = ((($v)) + 20|0);
   HEAP32[$22>>2] = -1;
   HEAP32[$v>>2] = 5;
   $23 = ((($v)) + 8|0);
   HEAP32[$23>>2] = 0;
   $24 = ((($ls)) + 24|0);
   $25 = +HEAPF64[$24>>3];
   $26 = ((($v)) + 8|0);
   HEAPF64[$26>>3] = $25;
   label = 22;
   break;
  }
  case 270:  {
   $47 = ((($v)) + 16|0);
   HEAP32[$47>>2] = -1;
   $48 = ((($v)) + 20|0);
   HEAP32[$48>>2] = -1;
   HEAP32[$v>>2] = 1;
   $49 = ((($v)) + 8|0);
   HEAP32[$49>>2] = 0;
   label = 22;
   break;
  }
  case 45:  {
   $$0$i2$ph = 0;
   label = 9;
   break;
  }
  case 123:  {
   _constructor($ls,$v);
   break;
  }
  case 293:  {
   $41 = ((($ls)) + 24|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (_luaK_stringK($ls$idx$val,$42)|0);
   $44 = ((($v)) + 16|0);
   HEAP32[$44>>2] = -1;
   $45 = ((($v)) + 20|0);
   HEAP32[$45>>2] = -1;
   HEAP32[$v>>2] = 4;
   $46 = ((($v)) + 8|0);
   HEAP32[$46>>2] = $43;
   label = 22;
   break;
  }
  case 126:  {
   $$0$i2$ph = 1;
   label = 9;
   break;
  }
  default: {
   _suffixedexp($ls,$v);
  }
  }
 } while(0);
 if ((label|0) == 9) {
  $18 = ((($ls)) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  _luaX_next($ls);
  (_subexpr($ls,$v,12)|0);
  $20 = HEAP32[$ls$idx>>2]|0;
  _luaK_prefix($20,$$0$i2$ph,$v,$19);
 }
 else if ((label|0) == 22) {
  _luaX_next($ls);
 }
 $66 = HEAP32[$16>>2]|0;
 do {
  switch ($66|0) {
  case 45:  {
   $op$0$ph$ph = 1;
   break;
  }
  case 42:  {
   $op$0$ph$ph = 2;
   break;
  }
  case 124:  {
   $op$0$ph$ph = 8;
   break;
  }
  case 126:  {
   $op$0$ph$ph = 9;
   break;
  }
  case 286:  {
   $op$0$ph$ph = 10;
   break;
  }
  case 62:  {
   $op$0$ph$ph = 17;
   break;
  }
  case 283:  {
   $op$0$ph$ph = 18;
   break;
  }
  case 257:  {
   $op$0$ph$ph = 19;
   break;
  }
  case 272:  {
   $op$0$ph$ph = 20;
   break;
  }
  case 47:  {
   $op$0$ph$ph = 5;
   break;
  }
  case 279:  {
   $op$0$ph$ph = 6;
   break;
  }
  case 38:  {
   $op$0$ph$ph = 7;
   break;
  }
  case 287:  {
   $op$0$ph$ph = 11;
   break;
  }
  case 280:  {
   $op$0$ph$ph = 12;
   break;
  }
  case 285:  {
   $op$0$ph$ph = 16;
   break;
  }
  case 43:  {
   $op$0$ph$ph = 0;
   break;
  }
  case 282:  {
   $op$0$ph$ph = 13;
   break;
  }
  case 60:  {
   $op$0$ph$ph = 14;
   break;
  }
  case 284:  {
   $op$0$ph$ph = 15;
   break;
  }
  case 37:  {
   $op$0$ph$ph = 3;
   break;
  }
  case 94:  {
   $op$0$ph$ph = 4;
   break;
  }
  default: {
   $op$0$lcssa = 21;
   $80 = HEAP32[$ls$idx1>>2]|0;
   $81 = ((($80)) + 106|0);
   $82 = HEAP16[$81>>1]|0;
   $83 = (($82) + -1)<<16>>16;
   HEAP16[$81>>1] = $83;
   STACKTOP = sp;return ($op$0$lcssa|0);
  }
  }
 } while(0);
 $67 = ((($ls)) + 4|0);
 $op$04 = $op$0$ph$ph;
 while(1) {
  $68 = (3536 + ($op$04<<1)|0);
  $69 = HEAP8[$68>>0]|0;
  $70 = $69&255;
  $71 = ($70|0)>($limit|0);
  if (!($71)) {
   $op$0$lcssa = $op$04;
   label = 47;
   break;
  }
  $72 = HEAP32[$67>>2]|0;
  _luaX_next($ls);
  $73 = HEAP32[$ls$idx>>2]|0;
  _luaK_infix($73,$op$04,$v);
  $74 = (((3536 + ($op$04<<1)|0)) + 1|0);
  $75 = HEAP8[$74>>0]|0;
  $76 = $75&255;
  $77 = (_subexpr($ls,$v2,$76)|0);
  $78 = HEAP32[$ls$idx>>2]|0;
  _luaK_posfix($78,$op$04,$v,$v2,$72);
  $79 = ($77|0)==(21);
  if ($79) {
   $op$0$lcssa = 21;
   label = 47;
   break;
  } else {
   $op$04 = $77;
  }
 }
 if ((label|0) == 47) {
  $80 = HEAP32[$ls$idx1>>2]|0;
  $81 = ((($80)) + 106|0);
  $82 = HEAP16[$81>>1]|0;
  $83 = (($82) + -1)<<16>>16;
  HEAP16[$81>>1] = $83;
  STACKTOP = sp;return ($op$0$lcssa|0);
 }
 return (0)|0;
}
function _new_localvar($ls,$name) {
 $ls = $ls|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $oldsize$01$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($1)) + 40|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8 << 16 >> 16;
 $10 = ($9|0)<($6|0);
 if ($10) {
  $$phi$trans$insert = ((($4)) + 60|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $17 = $6;$20 = $$pre;
 } else {
  $11 = ((($ls)) + 52|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($4)) + 60|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (_luaM_growaux_($12,$14,$5,12,32767,3472)|0);
  HEAP32[$13>>2] = $15;
  $$pre$i = HEAP32[$5>>2]|0;
  $17 = $$pre$i;$20 = $15;
 }
 $16 = ($6|0)<($17|0);
 if ($16) {
  $oldsize$01$i = $6;
  while(1) {
   $18 = (($oldsize$01$i) + 1)|0;
   $19 = (($20) + (($oldsize$01$i*12)|0)|0);
   HEAP32[$19>>2] = 0;
   $exitcond = ($18|0)==($17|0);
   if ($exitcond) {
    break;
   } else {
    $oldsize$01$i = $18;
   }
  }
 }
 $21 = HEAP16[$7>>1]|0;
 $22 = $21 << 16 >> 16;
 $23 = (($20) + (($22*12)|0)|0);
 HEAP32[$23>>2] = $name;
 $24 = ((($4)) + 5|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25 & 4;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  $35 = $21;
 } else {
  $28 = ((($name)) + 5|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29 & 3;
  $31 = ($30<<24>>24)==(0);
  if ($31) {
   $35 = $21;
  } else {
   $32 = ((($ls)) + 52|0);
   $33 = HEAP32[$32>>2]|0;
   _luaC_barrier_($33,$4,$name);
   $$pre3$i = HEAP16[$7>>1]|0;
   $35 = $$pre3$i;
  }
 }
 $34 = (($35) + 1)<<16>>16;
 HEAP16[$7>>1] = $34;
 $36 = ((($3)) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 $39 = ((($1)) + 36|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) - ($40))|0;
 $42 = ($41|0)>(200);
 if ($42) {
  $43 = ((($1)) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($44)) + 52|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$1>>2]|0;
  $48 = ((($47)) + 36|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==(0);
  if ($50) {
   $52 = 3080;
   HEAP32[$vararg_buffer1>>2] = 3472;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = 200;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $52;
   $53 = (_luaO_pushfstring($46,3096,$vararg_buffer1)|0);
   $54 = HEAP32[$43>>2]|0;
   _luaX_syntaxerror($54,$53);
   // unreachable;
  }
  HEAP32[$vararg_buffer>>2] = $49;
  $51 = (_luaO_pushfstring($46,3056,$vararg_buffer)|0);
  $52 = $51;
  HEAP32[$vararg_buffer1>>2] = 3472;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = 200;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $52;
  $53 = (_luaO_pushfstring($46,3096,$vararg_buffer1)|0);
  $54 = HEAP32[$43>>2]|0;
  _luaX_syntaxerror($54,$53);
  // unreachable;
 }
 $55 = (($37) + 2)|0;
 $56 = ((($3)) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($55|0)>($57|0);
 if ($58) {
  $59 = ((($ls)) + 52|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$3>>2]|0;
  $62 = (_luaM_growaux_($60,$61,$56,2,2147483647,3472)|0);
  HEAP32[$3>>2] = $62;
  $$pre1 = HEAP32[$36>>2]|0;
  $64 = $$pre1;$66 = $62;
  $63 = (($64) + 1)|0;
  HEAP32[$36>>2] = $63;
  $65 = (($66) + ($64<<1)|0);
  HEAP16[$65>>1] = $35;
  STACKTOP = sp;return;
 } else {
  $$pre3 = HEAP32[$3>>2]|0;
  $64 = $37;$66 = $$pre3;
  $63 = (($64) + 1)|0;
  HEAP32[$36>>2] = $63;
  $65 = (($66) + ($64<<1)|0);
  HEAP16[$65>>1] = $35;
  STACKTOP = sp;return;
 }
}
function _forbody($ls,$base,$line,$nvars,$isnum) {
 $ls = $ls|0;
 $base = $base|0;
 $line = $line|0;
 $nvars = $nvars|0;
 $isnum = $isnum|0;
 var $$01$i14 = 0, $$idx$val$i = 0, $$idx$val$i3 = 0, $$idx$val$idx$i = 0, $$idx$val$idx$i8 = 0, $$idx$val$idx$val$i = 0, $$idx$val$idx$val$i9 = 0, $$idx1$i = 0, $$idx1$i4 = 0, $$idx1$val$i = 0, $$idx1$val$i5 = 0, $$idx1$val$idx$i = 0, $$idx1$val$idx$i10 = 0, $$idx1$val$idx$val$i = 0, $$idx1$val$idx$val$i11 = 0, $$idx1$val$idx$val$idx$val$i = 0, $$idx1$val$idx$val$idx$val$i13 = 0, $$idx2$i = 0, $$idx2$i6 = 0, $$idx2$val$i = 0;
 var $$idx2$val$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $bl = 0, $bl$i = 0, $endfor$0 = 0, $ls$idx$val = 0, $ls$idx$val$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $bl$i = sp + 16|0;
 $bl = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 42|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = (($4) + 3)|0;
 $6 = $5&255;
 HEAP8[$2>>0] = $6;
 $7 = ((($1)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $5 & 255;
 $$idx$val$i = HEAP32[$1>>2]|0;
 $$idx1$i = ((($1)) + 8|0);
 $$idx1$val$i = HEAP32[$$idx1$i>>2]|0;
 $$idx2$i = ((($1)) + 36|0);
 $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
 $$idx$val$idx$i = ((($$idx$val$i)) + 60|0);
 $$idx$val$idx$val$i = HEAP32[$$idx$val$idx$i>>2]|0;
 $$idx1$val$idx$i = ((($$idx1$val$i)) + 68|0);
 $$idx1$val$idx$val$i = HEAP32[$$idx1$val$idx$i>>2]|0;
 $$idx1$val$idx$val$idx$val$i = HEAP32[$$idx1$val$idx$val$i>>2]|0;
 $10 = (($$idx2$val$i) + ($9))|0;
 $11 = (($10) + -3)|0;
 $12 = (($$idx1$val$idx$val$idx$val$i) + ($11<<1)|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13 << 16 >> 16;
 $15 = (((($$idx$val$idx$val$i) + (($14*12)|0)|0)) + 4|0);
 HEAP32[$15>>2] = $8;
 $16 = (($10) + -2)|0;
 $17 = (($$idx1$val$idx$val$idx$val$i) + ($16<<1)|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18 << 16 >> 16;
 $20 = (((($$idx$val$idx$val$i) + (($19*12)|0)|0)) + 4|0);
 HEAP32[$20>>2] = $8;
 $21 = (($10) + -1)|0;
 $22 = (($$idx1$val$idx$val$idx$val$i) + ($21<<1)|0);
 $23 = HEAP16[$22>>1]|0;
 $24 = $23 << 16 >> 16;
 $25 = (((($$idx$val$idx$val$i) + (($24*12)|0)|0)) + 4|0);
 HEAP32[$25>>2] = $8;
 $26 = ((($ls)) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(259);
 if (!($28)) {
  _error_expected($ls,259);
  // unreachable;
 }
 _luaX_next($ls);
 $29 = ($isnum|0)!=(0);
 if ($29) {
  $30 = (_luaK_codeABx($1,40,$base,131070)|0);
  $83 = $30;
 } else {
  $31 = (_luaK_jump($1)|0);
  $83 = $31;
 }
 $32 = ((($bl)) + 14|0);
 HEAP8[$32>>0] = 0;
 $33 = HEAP8[$2>>0]|0;
 $34 = ((($bl)) + 12|0);
 HEAP8[$34>>0] = $33;
 $35 = HEAP32[$$idx1$i>>2]|0;
 $36 = ((($35)) + 68|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($37)) + 28|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($bl)) + 4|0);
 HEAP32[$40>>2] = $39;
 $41 = ((($37)) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($bl)) + 8|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($bl)) + 13|0);
 HEAP8[$44>>0] = 0;
 $45 = ((($1)) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$bl>>2] = $46;
 HEAP32[$45>>2] = $bl;
 $ls$idx$val = HEAP32[$0>>2]|0;
 $47 = ((($ls$idx$val)) + 42|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = $48&255;
 $50 = (($49) + ($nvars))|0;
 $51 = $50&255;
 HEAP8[$47>>0] = $51;
 $52 = ($nvars|0)==(0);
 if (!($52)) {
  $53 = ((($ls$idx$val)) + 16|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = $50 & 255;
  $$idx$val$i3 = HEAP32[$ls$idx$val>>2]|0;
  $$idx1$i4 = ((($ls$idx$val)) + 8|0);
  $$idx1$val$i5 = HEAP32[$$idx1$i4>>2]|0;
  $$idx2$i6 = ((($ls$idx$val)) + 36|0);
  $$idx2$val$i7 = HEAP32[$$idx2$i6>>2]|0;
  $$idx$val$idx$i8 = ((($$idx$val$i3)) + 60|0);
  $$idx$val$idx$val$i9 = HEAP32[$$idx$val$idx$i8>>2]|0;
  $$idx1$val$idx$i10 = ((($$idx1$val$i5)) + 68|0);
  $$idx1$val$idx$val$i11 = HEAP32[$$idx1$val$idx$i10>>2]|0;
  $$idx1$val$idx$val$idx$val$i13 = HEAP32[$$idx1$val$idx$val$i11>>2]|0;
  $56 = (($$idx2$val$i7) + ($55))|0;
  $$01$i14 = $nvars;
  while(1) {
   $57 = (($56) - ($$01$i14))|0;
   $58 = (($$idx1$val$idx$val$idx$val$i13) + ($57<<1)|0);
   $59 = HEAP16[$58>>1]|0;
   $60 = $59 << 16 >> 16;
   $61 = (((($$idx$val$idx$val$i9) + (($60*12)|0)|0)) + 4|0);
   HEAP32[$61>>2] = $54;
   $62 = (($$01$i14) + -1)|0;
   $63 = ($62|0)==(0);
   if ($63) {
    break;
   } else {
    $$01$i14 = $62;
   }
  }
 }
 _luaK_reserveregs($1,$nvars);
 $64 = HEAP32[$0>>2]|0;
 $65 = ((($bl$i)) + 14|0);
 HEAP8[$65>>0] = 0;
 $66 = ((($64)) + 42|0);
 $67 = HEAP8[$66>>0]|0;
 $68 = ((($bl$i)) + 12|0);
 HEAP8[$68>>0] = $67;
 $69 = ((($64)) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($70)) + 68|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ((($72)) + 28|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ((($bl$i)) + 4|0);
 HEAP32[$75>>2] = $74;
 $76 = ((($72)) + 16|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ((($bl$i)) + 8|0);
 HEAP32[$78>>2] = $77;
 $79 = ((($bl$i)) + 13|0);
 HEAP8[$79>>0] = 0;
 $80 = ((($64)) + 12|0);
 $81 = HEAP32[$80>>2]|0;
 HEAP32[$bl$i>>2] = $81;
 HEAP32[$80>>2] = $bl$i;
 L13: while(1) {
  $ls$idx$val$i$i = HEAP32[$26>>2]|0;
  switch ($ls$idx$val$i$i|0) {
  case 277: case 289: case 262: case 261: case 260:  {
   break L13;
   break;
  }
  default: {
  }
  }
  $82 = ($ls$idx$val$i$i|0)==(274);
  _statement($ls);
  if ($82) {
   break;
  }
 }
 _leaveblock($64);
 _leaveblock($1);
 _luaK_patchtohere($1,$83);
 if ($29) {
  $84 = (_luaK_codeABx($1,39,$base,131070)|0);
  $endfor$0 = $84;
  $87 = (($83) + 1)|0;
  _luaK_patchlist($1,$endfor$0,$87);
  _luaK_fixline($1,$line);
  STACKTOP = sp;return;
 } else {
  (_luaK_codeABC($1,41,$base,0,$nvars)|0);
  _luaK_fixline($1,$line);
  $85 = (($base) + 2)|0;
  $86 = (_luaK_codeABx($1,42,$85,131070)|0);
  $endfor$0 = $86;
  $87 = (($83) + 1)|0;
  _luaK_patchlist($1,$endfor$0,$87);
  _luaK_fixline($1,$line);
  STACKTOP = sp;return;
 }
}
function _singlevaraux($fs,$n,$var,$base) {
 $fs = $fs|0;
 $n = $n|0;
 $var = $var|0;
 $base = $base|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $bl$0$i = 0, $bl$0$i$lcssa = 0, $bl$0$in$i = 0, $fs$idx$val$i = 0, $fs$idx$val$i$lcssa = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$val$i = 0, $fs$idx1$i = 0, $fs$idx1$val$i = 0, $fs$idx1$val$idx$i = 0, $fs$idx1$val$idx$val$i = 0, $fs$idx1$val$idx$val$idx$val$i = 0, $fs$idx2$i = 0, $fs$idx2$val$i = 0, $i$0$i = 0, $i$0$i$lcssa18 = 0, $i$0$in$i = 0;
 var $i$01$i = 0, $i$01$i$lcssa = 0, $idx$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($fs|0)==(0|0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = ((($fs)) + 42|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $fs$idx1$i = ((($fs)) + 8|0);
 $fs$idx2$i = ((($fs)) + 36|0);
 $fs$idx$val$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 60|0);
 $i$0$in$i = $3;
 while(1) {
  $i$0$i = (($i$0$in$i) + -1)|0;
  $4 = ($i$0$in$i|0)>(0);
  if (!($4)) {
   $fs$idx$val$i$lcssa = $fs$idx$val$i;
   break;
  }
  $fs$idx1$val$i = HEAP32[$fs$idx1$i>>2]|0;
  $fs$idx2$val$i = HEAP32[$fs$idx2$i>>2]|0;
  $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
  $fs$idx1$val$idx$i = ((($fs$idx1$val$i)) + 68|0);
  $fs$idx1$val$idx$val$i = HEAP32[$fs$idx1$val$idx$i>>2]|0;
  $fs$idx1$val$idx$val$idx$val$i = HEAP32[$fs$idx1$val$idx$val$i>>2]|0;
  $5 = (($fs$idx2$val$i) + ($i$0$i))|0;
  $6 = (($fs$idx1$val$idx$val$idx$val$i) + ($5<<1)|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = $7 << 16 >> 16;
  $9 = (($fs$idx$val$idx$val$i) + (($8*12)|0)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($n|0);
  if ($11) {
   $i$0$i$lcssa18 = $i$0$i;
   label = 5;
   break;
  } else {
   $i$0$in$i = $i$0$i;
  }
 }
 if ((label|0) == 5) {
  $12 = ((($var)) + 16|0);
  HEAP32[$12>>2] = -1;
  $13 = ((($var)) + 20|0);
  HEAP32[$13>>2] = -1;
  HEAP32[$var>>2] = 8;
  $14 = ((($var)) + 8|0);
  HEAP32[$14>>2] = $i$0$i$lcssa18;
  $15 = ($base|0)==(0);
  if (!($15)) {
   $$0 = 8;
   return ($$0|0);
  }
  $16 = ((($fs)) + 12|0);
  $bl$0$in$i = $16;
  while(1) {
   $bl$0$i = HEAP32[$bl$0$in$i>>2]|0;
   $17 = ((($bl$0$i)) + 12|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = $18&255;
   $20 = ($19|0)>($i$0$i$lcssa18|0);
   if ($20) {
    $bl$0$in$i = $bl$0$i;
   } else {
    $bl$0$i$lcssa = $bl$0$i;
    break;
   }
  }
  $21 = ((($bl$0$i$lcssa)) + 13|0);
  HEAP8[$21>>0] = 1;
  $$0 = 8;
  return ($$0|0);
 }
 $$phi$trans$insert = ((($fs$idx$val$i$lcssa)) + 64|0);
 $$pre8 = HEAP32[$$phi$trans$insert>>2]|0;
 $22 = ((($fs)) + 43|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 L17: do {
  if ($24) {
   label = 14;
  } else {
   $25 = $23&255;
   $i$01$i = 0;
   while(1) {
    $26 = (($$pre8) + ($i$01$i<<3)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==($n|0);
    if ($28) {
     $i$01$i$lcssa = $i$01$i;
     break;
    }
    $29 = (($i$01$i) + 1)|0;
    $30 = ($29|0)<($25|0);
    if ($30) {
     $i$01$i = $29;
    } else {
     label = 14;
     break L17;
    }
   }
   $31 = ($i$01$i$lcssa|0)<(0);
   if ($31) {
    label = 14;
   } else {
    $idx$0 = $i$01$i$lcssa;
   }
  }
 } while(0);
 do {
  if ((label|0) == 14) {
   $32 = ((($fs)) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (_singlevaraux($33,$n,$var,0)|0);
   $35 = ($34|0)==(0);
   if ($35) {
    $$0 = 0;
    return ($$0|0);
   } else {
    $36 = (_newupvalue($fs,$n,$var)|0);
    $idx$0 = $36;
    break;
   }
  }
 } while(0);
 $37 = ((($var)) + 16|0);
 HEAP32[$37>>2] = -1;
 $38 = ((($var)) + 20|0);
 HEAP32[$38>>2] = -1;
 HEAP32[$var>>2] = 9;
 $39 = ((($var)) + 8|0);
 HEAP32[$39>>2] = $idx$0;
 $$0 = 9;
 return ($$0|0);
}
function _fieldsel($ls,$v) {
 $ls = $ls|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $key = 0, $ls$idx$val$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $key = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 _luaK_exp2anyregup($1,$v);
 _luaX_next($ls);
 $2 = ((($ls)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(292);
 if ($4) {
  $5 = ((($ls)) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  _luaX_next($ls);
  $ls$idx$val$i = HEAP32[$0>>2]|0;
  $7 = (_luaK_stringK($ls$idx$val$i,$6)|0);
  $8 = ((($key)) + 16|0);
  HEAP32[$8>>2] = -1;
  $9 = ((($key)) + 20|0);
  HEAP32[$9>>2] = -1;
  HEAP32[$key>>2] = 4;
  $10 = ((($key)) + 8|0);
  HEAP32[$10>>2] = $7;
  _luaK_indexed($1,$v,$key);
  STACKTOP = sp;return;
 } else {
  _error_expected($ls,292);
  // unreachable;
 }
}
function _body($ls,$e,$ismethod,$line) {
 $ls = $ls|0;
 $e = $e|0;
 $ismethod = $ismethod|0;
 $line = $line|0;
 var $$01$i$i = 0, $$idx$val$i = 0, $$idx$val$i$i = 0, $$idx$val$idx$i = 0, $$idx$val$idx$i$i = 0, $$idx$val$idx$val$i = 0, $$idx$val$idx$val$i$i = 0, $$idx1$i = 0, $$idx1$i$i = 0, $$idx1$val$i = 0, $$idx1$val$i$i = 0, $$idx1$val$idx$i = 0, $$idx1$val$idx$i$i = 0, $$idx1$val$idx$val$i = 0, $$idx1$val$idx$val$i$i = 0, $$idx1$val$idx$val$idx$val$i = 0, $$idx1$val$idx$val$idx$val$i$i = 0, $$idx2$i = 0, $$idx2$i$i = 0, $$idx2$val$i = 0;
 var $$idx2$val$i$i = 0, $$pr$i = 0, $$pr1$i = 0, $$pre = 0, $$pre$i = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bl = 0;
 var $exitcond = 0, $ls$idx = 0, $ls$idx$val = 0, $ls$idx$val$i = 0, $ls$idx$val$i7 = 0, $ls$idx1 = 0, $ls$idx1$val = 0, $ls$idx2$val = 0, $ls$idx3$val = 0, $ls$idx3$val$idx = 0, $ls$idx3$val$idx$val = 0, $new_fs = 0, $nparams$0$i = 0, $nparams$0$i$lcssa26 = 0, $nparams$2$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $new_fs = sp + 32|0;
 $bl = sp + 16|0;
 $ls$idx = ((($ls)) + 48|0);
 $ls$idx$val = HEAP32[$ls$idx>>2]|0;
 $ls$idx1 = ((($ls)) + 52|0);
 $ls$idx1$val = HEAP32[$ls$idx1>>2]|0;
 $0 = HEAP32[$ls$idx$val>>2]|0;
 $1 = ((($ls$idx$val)) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)<($4|0);
 $$pre3$i = ((($0)) + 52|0);
 if (!($5)) {
  $6 = HEAP32[$$pre3$i>>2]|0;
  $7 = (_luaM_growaux_($ls$idx1$val,$6,$3,4,262143,3416)|0);
  HEAP32[$$pre3$i>>2] = $7;
  $8 = HEAP32[$3>>2]|0;
  $9 = ($4|0)<($8|0);
  if ($9) {
   $10 = (($4) + 1)|0;
   $11 = (($7) + ($4<<2)|0);
   HEAP32[$11>>2] = 0;
   $12 = ($10|0)<($8|0);
   if ($12) {
    $14 = $10;
    while(1) {
     $$pre$i = HEAP32[$$pre3$i>>2]|0;
     $13 = (($14) + 1)|0;
     $15 = (($$pre$i) + ($14<<2)|0);
     HEAP32[$15>>2] = 0;
     $exitcond = ($13|0)==($8|0);
     if ($exitcond) {
      break;
     } else {
      $14 = $13;
     }
    }
   }
  }
 }
 $16 = (_luaF_newproto($ls$idx1$val)|0);
 $17 = HEAP32[$1>>2]|0;
 $18 = (($17) + 1)|0;
 HEAP32[$1>>2] = $18;
 $19 = HEAP32[$$pre3$i>>2]|0;
 $20 = (($19) + ($17<<2)|0);
 HEAP32[$20>>2] = $16;
 $21 = ((($0)) + 5|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22 & 4;
 $24 = ($23<<24>>24)==(0);
 if (!($24)) {
  $25 = ((($16)) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = $26 & 3;
  $28 = ($27<<24>>24)==(0);
  if (!($28)) {
   _luaC_barrier_($ls$idx1$val,$0,$16);
  }
 }
 HEAP32[$new_fs>>2] = $16;
 $29 = ((($16)) + 36|0);
 HEAP32[$29>>2] = $line;
 $30 = HEAP32[$ls$idx>>2]|0;
 $31 = ((($new_fs)) + 4|0);
 HEAP32[$31>>2] = $30;
 $32 = ((($new_fs)) + 8|0);
 HEAP32[$32>>2] = $ls;
 HEAP32[$ls$idx>>2] = $new_fs;
 $33 = ((($new_fs)) + 16|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($new_fs)) + 20|0);
 HEAP32[$34>>2] = 0;
 $35 = ((($new_fs)) + 24|0);
 HEAP32[$35>>2] = -1;
 $36 = ((($new_fs)) + 28|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($new_fs)) + 32|0);
 HEAP32[$37>>2] = 0;
 $38 = ((($new_fs)) + 40|0);
 $39 = ((($ls)) + 68|0);
 ;HEAP32[$38>>2]=0|0;HEAP8[$38+4>>0]=0|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40)) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($new_fs)) + 36|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($new_fs)) + 12|0);
 $45 = ((($ls)) + 72|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ((($16)) + 72|0);
 HEAP32[$47>>2] = $46;
 $48 = ((($16)) + 8|0);
 HEAP8[$48>>0] = 2;
 $49 = ((($bl)) + 14|0);
 HEAP8[$49>>0] = 0;
 $50 = ((($bl)) + 12|0);
 HEAP8[$50>>0] = 0;
 $51 = ((($40)) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ((($bl)) + 4|0);
 HEAP32[$53>>2] = $52;
 $54 = ((($40)) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ((($bl)) + 8|0);
 HEAP32[$56>>2] = $55;
 $57 = ((($bl)) + 13|0);
 HEAP8[$57>>0] = 0;
 HEAP32[$bl>>2] = 0;
 HEAP32[$44>>2] = $bl;
 $58 = ((($ls)) + 16|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(40);
 if (!($60)) {
  _error_expected($ls,40);
  // unreachable;
 }
 _luaX_next($ls);
 $61 = ($ismethod|0)==(0);
 if ($61) {
  $$pre = HEAP32[$ls$idx>>2]|0;
  $$pre14 = HEAP32[$$pre>>2]|0;
  $105 = $$pre;$78 = $$pre14;
 } else {
  $62 = (_luaX_newstring($ls,3432,4)|0);
  _new_localvar($ls,$62);
  $ls$idx2$val = HEAP32[$ls$idx>>2]|0;
  $63 = ((($ls$idx2$val)) + 42|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = $64&255;
  $66 = (($65) + 1)|0;
  $67 = $66&255;
  HEAP8[$63>>0] = $67;
  $68 = ((($ls$idx2$val)) + 16|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = $66 & 255;
  $$idx$val$i = HEAP32[$ls$idx2$val>>2]|0;
  $$idx1$i = ((($ls$idx2$val)) + 8|0);
  $$idx1$val$i = HEAP32[$$idx1$i>>2]|0;
  $$idx2$i = ((($ls$idx2$val)) + 36|0);
  $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
  $$idx$val$idx$i = ((($$idx$val$i)) + 60|0);
  $$idx$val$idx$val$i = HEAP32[$$idx$val$idx$i>>2]|0;
  $$idx1$val$idx$i = ((($$idx1$val$i)) + 68|0);
  $$idx1$val$idx$val$i = HEAP32[$$idx1$val$idx$i>>2]|0;
  $$idx1$val$idx$val$idx$val$i = HEAP32[$$idx1$val$idx$val$i>>2]|0;
  $71 = (($$idx2$val$i) + ($70))|0;
  $72 = (($71) + -1)|0;
  $73 = (($$idx1$val$idx$val$idx$val$i) + ($72<<1)|0);
  $74 = HEAP16[$73>>1]|0;
  $75 = $74 << 16 >> 16;
  $76 = (((($$idx$val$idx$val$i) + (($75*12)|0)|0)) + 4|0);
  HEAP32[$76>>2] = $69;
  $105 = $ls$idx2$val;$78 = $$idx$val$i;
 }
 $77 = ((($78)) + 7|0);
 HEAP8[$77>>0] = 0;
 $79 = HEAP32[$58>>2]|0;
 $80 = ($79|0)==(41);
 L18: do {
  if ($80) {
   $nparams$2$i = 0;
  } else {
   $81 = ((($ls)) + 24|0);
   $130 = $79;$nparams$0$i = 0;
   while(1) {
    if ((($130|0) == 281)) {
     $nparams$0$i$lcssa26 = $nparams$0$i;
     label = 17;
     break;
    } else if (!((($130|0) == 292))) {
     label = 18;
     break;
    }
    $82 = HEAP32[$81>>2]|0;
    _luaX_next($ls);
    _new_localvar($ls,$82);
    $83 = (($nparams$0$i) + 1)|0;
    $$pr1$i = HEAP8[$77>>0]|0;
    $84 = ($$pr1$i<<24>>24)==(0);
    if (!($84)) {
     $nparams$2$i = $83;
     break L18;
    }
    $85 = HEAP32[$58>>2]|0;
    $86 = ($85|0)==(44);
    if (!($86)) {
     $nparams$2$i = $83;
     break L18;
    }
    _luaX_next($ls);
    $$pr$i = HEAP32[$58>>2]|0;
    $130 = $$pr$i;$nparams$0$i = $83;
   }
   if ((label|0) == 17) {
    _luaX_next($ls);
    HEAP8[$77>>0] = 1;
    $nparams$2$i = $nparams$0$i$lcssa26;
    break;
   }
   else if ((label|0) == 18) {
    _luaX_syntaxerror($ls,3440);
    // unreachable;
   }
  }
 } while(0);
 $ls$idx$val$i = HEAP32[$ls$idx>>2]|0;
 $87 = ((($ls$idx$val$i)) + 42|0);
 $88 = HEAP8[$87>>0]|0;
 $89 = $88&255;
 $90 = (($89) + ($nparams$2$i))|0;
 $91 = $90&255;
 HEAP8[$87>>0] = $91;
 $92 = ($nparams$2$i|0)==(0);
 if (!($92)) {
  $93 = ((($ls$idx$val$i)) + 16|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = $90 & 255;
  $$idx$val$i$i = HEAP32[$ls$idx$val$i>>2]|0;
  $$idx1$i$i = ((($ls$idx$val$i)) + 8|0);
  $$idx1$val$i$i = HEAP32[$$idx1$i$i>>2]|0;
  $$idx2$i$i = ((($ls$idx$val$i)) + 36|0);
  $$idx2$val$i$i = HEAP32[$$idx2$i$i>>2]|0;
  $$idx$val$idx$i$i = ((($$idx$val$i$i)) + 60|0);
  $$idx$val$idx$val$i$i = HEAP32[$$idx$val$idx$i$i>>2]|0;
  $$idx1$val$idx$i$i = ((($$idx1$val$i$i)) + 68|0);
  $$idx1$val$idx$val$i$i = HEAP32[$$idx1$val$idx$i$i>>2]|0;
  $$idx1$val$idx$val$idx$val$i$i = HEAP32[$$idx1$val$idx$val$i$i>>2]|0;
  $96 = (($$idx2$val$i$i) + ($95))|0;
  $$01$i$i = $nparams$2$i;
  while(1) {
   $97 = (($96) - ($$01$i$i))|0;
   $98 = (($$idx1$val$idx$val$idx$val$i$i) + ($97<<1)|0);
   $99 = HEAP16[$98>>1]|0;
   $100 = $99 << 16 >> 16;
   $101 = (((($$idx$val$idx$val$i$i) + (($100*12)|0)|0)) + 4|0);
   HEAP32[$101>>2] = $94;
   $102 = (($$01$i$i) + -1)|0;
   $103 = ($102|0)==(0);
   if ($103) {
    break;
   } else {
    $$01$i$i = $102;
   }
  }
 }
 $104 = ((($105)) + 42|0);
 $106 = HEAP8[$104>>0]|0;
 $107 = ((($78)) + 6|0);
 HEAP8[$107>>0] = $106;
 $108 = $106&255;
 _luaK_reserveregs($105,$108);
 $109 = HEAP32[$58>>2]|0;
 $110 = ($109|0)==(41);
 if (!($110)) {
  _error_expected($ls,41);
  // unreachable;
 }
 _luaX_next($ls);
 L37: while(1) {
  $ls$idx$val$i7 = HEAP32[$58>>2]|0;
  switch ($ls$idx$val$i7|0) {
  case 277: case 289: case 262: case 261: case 260:  {
   $117 = $ls$idx$val$i7;
   break L37;
   break;
  }
  default: {
  }
  }
  $111 = ($ls$idx$val$i7|0)==(274);
  _statement($ls);
  if ($111) {
   label = 29;
   break;
  }
 }
 if ((label|0) == 29) {
  $$pre15 = HEAP32[$58>>2]|0;
  $117 = $$pre15;
 }
 $112 = ((($ls)) + 4|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = HEAP32[$new_fs>>2]|0;
 $115 = ((($114)) + 40|0);
 HEAP32[$115>>2] = $113;
 $116 = ($117|0)==(262);
 if ($116) {
  _luaX_next($ls);
  $ls$idx3$val = HEAP32[$ls$idx>>2]|0;
  $ls$idx3$val$idx = ((($ls$idx3$val)) + 4|0);
  $ls$idx3$val$idx$val = HEAP32[$ls$idx3$val$idx>>2]|0;
  $123 = ((($ls$idx3$val$idx$val)) + 32|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = (($124) + -1)|0;
  $126 = (_luaK_codeABx($ls$idx3$val$idx$val,44,0,$125)|0);
  $127 = ((($e)) + 16|0);
  HEAP32[$127>>2] = -1;
  $128 = ((($e)) + 20|0);
  HEAP32[$128>>2] = -1;
  HEAP32[$e>>2] = 12;
  $129 = ((($e)) + 8|0);
  HEAP32[$129>>2] = $126;
  _luaK_exp2nextreg($ls$idx3$val$idx$val,$e);
  _close_func($ls);
  STACKTOP = sp;return;
 }
 $118 = ($113|0)==($line|0);
 if ($118) {
  _error_expected($ls,262);
  // unreachable;
 } else {
  $119 = HEAP32[$ls$idx1>>2]|0;
  $120 = (_luaX_token2str($ls,262)|0);
  $121 = (_luaX_token2str($ls,265)|0);
  HEAP32[$vararg_buffer>>2] = $120;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $121;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $line;
  $122 = (_luaO_pushfstring($119,3144,$vararg_buffer)|0);
  _luaX_syntaxerror($ls,$122);
  // unreachable;
 }
}
function _gotostat($ls,$pc) {
 $ls = $ls|0;
 $pc = $pc|0;
 var $$lcssa = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04$i = 0, $i$04$i$lcssa = 0, $label$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(266);
 _luaX_next($ls);
 do {
  if ($4) {
   $5 = HEAP32[$2>>2]|0;
   $6 = ($5|0)==(292);
   if ($6) {
    $7 = ((($ls)) + 24|0);
    $8 = HEAP32[$7>>2]|0;
    _luaX_next($ls);
    $label$0 = $8;
    break;
   } else {
    _error_expected($ls,292);
    // unreachable;
   }
  } else {
   $9 = ((($ls)) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (_luaS_new($10,5896)|0);
   $label$0 = $11;
  }
 } while(0);
 $12 = ((($ls)) + 68|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 12|0);
 $15 = ((($13)) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1)|0;
 $18 = ((($13)) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($16|0)<($19|0);
 if ($20) {
  $$pre$i = HEAP32[$14>>2]|0;
  $26 = $$pre$i;$37 = $13;
 } else {
  $21 = ((($ls)) + 52|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$14>>2]|0;
  $24 = (_luaM_growaux_($22,$23,$18,16,32767,2880)|0);
  HEAP32[$14>>2] = $24;
  $$pre = HEAP32[$12>>2]|0;
  $26 = $24;$37 = $$pre;
 }
 $25 = (($26) + ($16<<4)|0);
 HEAP32[$25>>2] = $label$0;
 $27 = (((($26) + ($16<<4)|0)) + 8|0);
 HEAP32[$27>>2] = $1;
 $28 = ((($ls)) + 48|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($29)) + 42|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = (((($26) + ($16<<4)|0)) + 12|0);
 HEAP8[$32>>0] = $31;
 $33 = (((($26) + ($16<<4)|0)) + 4|0);
 HEAP32[$33>>2] = $pc;
 HEAP32[$15>>2] = $17;
 $34 = ((($29)) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($37)) + 12|0);
 $38 = HEAP32[$36>>2]|0;
 $39 = ((($35)) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($37)) + 28|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($40|0)<($42|0);
 if (!($43)) {
  return;
 }
 $44 = ((($37)) + 24|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($38) + ($16<<4)|0);
 $47 = HEAP32[$46>>2]|0;
 $i$04$i = $40;
 while(1) {
  $48 = (($45) + ($i$04$i<<4)|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==($47|0);
  if ($50) {
   $$lcssa = $48;$i$04$i$lcssa = $i$04$i;
   break;
  }
  $59 = (($i$04$i) + 1)|0;
  $60 = ($59|0)<($42|0);
  if ($60) {
   $i$04$i = $59;
  } else {
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  return;
 }
 $51 = (((($38) + ($16<<4)|0)) + 12|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = (((($45) + ($i$04$i$lcssa<<4)|0)) + 12|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($52&255)>($54&255);
 if ($55) {
  $56 = (((($38) + ($16<<4)|0)) + 4|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = $54&255;
  _luaK_patchclose($29,$57,$58);
 }
 _closegoto($ls,$16,$$lcssa);
 return;
}
function _suffixedexp($ls,$v) {
 $ls = $ls|0;
 $v = $v|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $key = 0, $key$i$i = 0, $key1 = 0, $ls$idx$val$i = 0, $ls$idx$val$i$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 72|0;
 $key$i$i = sp + 48|0;
 $key = sp + 24|0;
 $key1 = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($ls)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 do {
  if ((($5|0) == 40)) {
   _luaX_next($ls);
   (_subexpr($ls,$v,0)|0);
   $6 = HEAP32[$4>>2]|0;
   $7 = ($6|0)==(41);
   if ($7) {
    _luaX_next($ls);
    $15 = HEAP32[$0>>2]|0;
    _luaK_dischargevars($15,$v);
    $$pre = ((($ls)) + 24|0);
    $$pre$phi2Z2D = $$pre;
    break;
   }
   $8 = HEAP32[$2>>2]|0;
   $9 = ($8|0)==($3|0);
   if ($9) {
    _error_expected($ls,41);
    // unreachable;
   } else {
    $10 = ((($ls)) + 52|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (_luaX_token2str($ls,41)|0);
    $13 = (_luaX_token2str($ls,40)|0);
    HEAP32[$vararg_buffer>>2] = $12;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $13;
    $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
    HEAP32[$vararg_ptr2>>2] = $3;
    $14 = (_luaO_pushfstring($11,3144,$vararg_buffer)|0);
    _luaX_syntaxerror($ls,$14);
    // unreachable;
   }
  } else if ((($5|0) == 292)) {
   $16 = ((($ls)) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   _luaX_next($ls);
   $18 = HEAP32[$0>>2]|0;
   $19 = (_singlevaraux($18,$17,$v,1)|0);
   $20 = ($19|0)==(0);
   if ($20) {
    $21 = ((($ls)) + 76|0);
    $22 = HEAP32[$21>>2]|0;
    (_singlevaraux($18,$22,$v,1)|0);
    $ls$idx$val$i$i = HEAP32[$0>>2]|0;
    $23 = (_luaK_stringK($ls$idx$val$i$i,$17)|0);
    $24 = ((($key$i$i)) + 16|0);
    HEAP32[$24>>2] = -1;
    $25 = ((($key$i$i)) + 20|0);
    HEAP32[$25>>2] = -1;
    HEAP32[$key$i$i>>2] = 4;
    $26 = ((($key$i$i)) + 8|0);
    HEAP32[$26>>2] = $23;
    _luaK_indexed($18,$v,$key$i$i);
   }
   $$pre$phi2Z2D = $16;
  } else {
   _luaX_syntaxerror($ls,3360);
   // unreachable;
  }
 } while(0);
 $27 = ((($key1)) + 16|0);
 $28 = ((($key1)) + 20|0);
 $29 = ((($key1)) + 8|0);
 L15: while(1) {
  $30 = HEAP32[$4>>2]|0;
  switch ($30|0) {
  case 91:  {
   _luaK_exp2anyregup($1,$v);
   _luaX_next($ls);
   (_subexpr($ls,$key,0)|0);
   $31 = HEAP32[$0>>2]|0;
   _luaK_exp2val($31,$key);
   $32 = HEAP32[$4>>2]|0;
   $33 = ($32|0)==(93);
   if (!($33)) {
    label = 15;
    break L15;
   }
   _luaX_next($ls);
   _luaK_indexed($1,$v,$key);
   continue L15;
   break;
  }
  case 46:  {
   _fieldsel($ls,$v);
   continue L15;
   break;
  }
  case 123: case 293: case 40:  {
   _luaK_exp2nextreg($1,$v);
   _funcargs($ls,$v,$3);
   continue L15;
   break;
  }
  case 58:  {
   _luaX_next($ls);
   $34 = HEAP32[$4>>2]|0;
   $35 = ($34|0)==(292);
   if (!($35)) {
    label = 18;
    break L15;
   }
   $36 = HEAP32[$$pre$phi2Z2D>>2]|0;
   _luaX_next($ls);
   $ls$idx$val$i = HEAP32[$0>>2]|0;
   $37 = (_luaK_stringK($ls$idx$val$i,$36)|0);
   HEAP32[$27>>2] = -1;
   HEAP32[$28>>2] = -1;
   HEAP32[$key1>>2] = 4;
   HEAP32[$29>>2] = $37;
   _luaK_self($1,$v,$key1);
   _funcargs($ls,$v,$3);
   continue L15;
   break;
  }
  default: {
   label = 21;
   break L15;
  }
  }
 }
 if ((label|0) == 15) {
  _error_expected($ls,93);
  // unreachable;
 }
 else if ((label|0) == 18) {
  _error_expected($ls,292);
  // unreachable;
 }
 else if ((label|0) == 21) {
  STACKTOP = sp;return;
 }
}
function _assignment($ls,$lh,$nvars) {
 $ls = $ls|0;
 $lh = $lh|0;
 $nvars = $nvars|0;
 var $$$i = 0, $$02$i = 0, $$02$i$us = 0, $$off = 0, $$pre$phi4Z2D = 0, $$pre$phiZ2D = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $conflict$01$i = 0, $conflict$01$i$us = 0, $conflict$1$i$us = 0, $conflict$2$i = 0, $conflict$2$i$lcssa = 0, $conflict$2$i$us = 0, $e = 0, $ls$idx1$val = 0, $n$0$i$lcssa = 0, $n$0$i2 = 0;
 var $nv = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 64|0;
 $vararg_buffer = sp + 56|0;
 $e = sp + 32|0;
 $nv = sp;
 $0 = ((($lh)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $$off = (($1) + -8)|0;
 $2 = ($$off>>>0)<(3);
 if (!($2)) {
  _luaX_syntaxerror($ls,3344);
  // unreachable;
 }
 $3 = ((($ls)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 do {
  if ((($4|0) == 61)) {
   _luaX_next($ls);
   (_subexpr($ls,$e,0)|0);
   $68 = HEAP32[$3>>2]|0;
   $69 = ($68|0)==(44);
   $70 = ((($ls)) + 48|0);
   if ($69) {
    $n$0$i2 = 1;
    while(1) {
     _luaX_next($ls);
     $71 = HEAP32[$70>>2]|0;
     _luaK_exp2nextreg($71,$e);
     (_subexpr($ls,$e,0)|0);
     $72 = (($n$0$i2) + 1)|0;
     $73 = HEAP32[$3>>2]|0;
     $74 = ($73|0)==(44);
     if ($74) {
      $n$0$i2 = $72;
     } else {
      $n$0$i$lcssa = $72;
      break;
     }
    }
   } else {
    $n$0$i$lcssa = 1;
   }
   $75 = ($n$0$i$lcssa|0)==($nvars|0);
   $76 = HEAP32[$70>>2]|0;
   if ($75) {
    _luaK_setoneret($76,$e);
    $94 = HEAP32[$70>>2]|0;
    _luaK_storevar($94,$0,$e);
    STACKTOP = sp;return;
   }
   $77 = (($nvars) - ($n$0$i$lcssa))|0;
   $78 = HEAP32[$e>>2]|0;
   if ((($78|0) == 0)) {
    label = 33;
   } else if ((($78|0) == 14) | (($78|0) == 13)) {
    $79 = (($77) + 1)|0;
    $80 = ($79|0)<(0);
    $$$i = $80 ? 0 : $79;
    _luaK_setreturns($76,$e,$$$i);
    $81 = ($$$i|0)>(1);
    if ($81) {
     $82 = (($$$i) + -1)|0;
     _luaK_reserveregs($76,$82);
    }
   } else {
    _luaK_exp2nextreg($76,$e);
    label = 33;
   }
   if ((label|0) == 33) {
    $83 = ($77|0)>(0);
    if ($83) {
     $84 = ((($76)) + 44|0);
     $85 = HEAP8[$84>>0]|0;
     $86 = $85&255;
     _luaK_reserveregs($76,$77);
     _luaK_nil($76,$86,$77);
    }
   }
   $87 = ($n$0$i$lcssa|0)>($nvars|0);
   if ($87) {
    $88 = HEAP32[$70>>2]|0;
    $89 = ((($88)) + 44|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = $90&255;
    $92 = (($77) + ($91))|0;
    $93 = $92&255;
    HEAP8[$89>>0] = $93;
    $$pre$phi4Z2D = $e;$$pre$phiZ2D = $70;
   } else {
    $$pre$phi4Z2D = $e;$$pre$phiZ2D = $70;
   }
  } else if ((($4|0) == 44)) {
   _luaX_next($ls);
   HEAP32[$nv>>2] = $lh;
   $5 = ((($nv)) + 8|0);
   _suffixedexp($ls,$5);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(10);
   $$pre5 = ((($ls)) + 48|0);
   if (!($7)) {
    $ls$idx1$val = HEAP32[$$pre5>>2]|0;
    $8 = ((($ls$idx1$val)) + 44|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = $9&255;
    $11 = ((($nv)) + 16|0);
    $12 = $9&255;
    $13 = HEAP32[$11>>2]|0;
    $14 = ($6|0)==(8);
    if ($14) {
     $$02$i$us = $lh;$conflict$01$i$us = 0;
     while(1) {
      $15 = ((($$02$i$us)) + 8|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)==(10);
      if ($17) {
       $18 = ((($$02$i$us)) + 16|0);
       $19 = ((($18)) + 3|0);
       $20 = HEAP8[$19>>0]|0;
       $21 = ($20<<24>>24)==(8);
       if ($21) {
        $22 = ((($18)) + 2|0);
        $23 = HEAP8[$22>>0]|0;
        $24 = $23&255;
        $25 = ($24|0)==($13|0);
        if ($25) {
         HEAP8[$19>>0] = 8;
         HEAP8[$22>>0] = $9;
         $conflict$1$i$us = 1;
        } else {
         $conflict$1$i$us = $conflict$01$i$us;
        }
       } else {
        $conflict$1$i$us = $conflict$01$i$us;
       }
       $26 = HEAP16[$18>>1]|0;
       $27 = $26 << 16 >> 16;
       $28 = ($27|0)==($13|0);
       if ($28) {
        HEAP16[$18>>1] = $12;
        $conflict$2$i$us = 1;
       } else {
        $conflict$2$i$us = $conflict$1$i$us;
       }
      } else {
       $conflict$2$i$us = $conflict$01$i$us;
      }
      $29 = HEAP32[$$02$i$us>>2]|0;
      $30 = ($29|0)==(0|0);
      if ($30) {
       $conflict$2$i$lcssa = $conflict$2$i$us;
       break;
      } else {
       $$02$i$us = $29;$conflict$01$i$us = $conflict$2$i$us;
      }
     }
    } else {
     $$02$i = $lh;$conflict$01$i = 0;
     while(1) {
      $31 = ((($$02$i)) + 8|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($32|0)==(10);
      if ($33) {
       $34 = ((($$02$i)) + 16|0);
       $35 = ((($34)) + 3|0);
       $36 = HEAP8[$35>>0]|0;
       $37 = $36&255;
       $38 = ($37|0)==($6|0);
       if ($38) {
        $39 = ((($34)) + 2|0);
        $40 = HEAP8[$39>>0]|0;
        $41 = $40&255;
        $42 = ($41|0)==($13|0);
        if ($42) {
         HEAP8[$35>>0] = 8;
         HEAP8[$39>>0] = $9;
         $conflict$2$i = 1;
        } else {
         $conflict$2$i = $conflict$01$i;
        }
       } else {
        $conflict$2$i = $conflict$01$i;
       }
      } else {
       $conflict$2$i = $conflict$01$i;
      }
      $43 = HEAP32[$$02$i>>2]|0;
      $44 = ($43|0)==(0|0);
      if ($44) {
       $conflict$2$i$lcssa = $conflict$2$i;
       break;
      } else {
       $$02$i = $43;$conflict$01$i = $conflict$2$i;
      }
     }
    }
    $45 = ($conflict$2$i$lcssa|0)==(0);
    if (!($45)) {
     $46 = $14 ? 0 : 5;
     (_luaK_codeABC($ls$idx1$val,$46,$10,$13,0)|0);
     _luaK_reserveregs($ls$idx1$val,1);
    }
   }
   $47 = HEAP32[$$pre5>>2]|0;
   $48 = ((($ls)) + 52|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ((($49)) + 106|0);
   $51 = HEAP16[$50>>1]|0;
   $52 = $51&65535;
   $53 = (($52) + ($nvars))|0;
   $54 = ($53|0)>(200);
   if (!($54)) {
    $67 = (($nvars) + 1)|0;
    _assignment($ls,$nv,$67);
    $$pre$phi4Z2D = $e;$$pre$phiZ2D = $$pre5;
    break;
   }
   $55 = ((($47)) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ((($56)) + 52|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = HEAP32[$47>>2]|0;
   $60 = ((($59)) + 36|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)==(0);
   if ($62) {
    $64 = 3080;
    HEAP32[$vararg_buffer1>>2] = 3128;
    $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
    HEAP32[$vararg_ptr4>>2] = 200;
    $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
    HEAP32[$vararg_ptr5>>2] = $64;
    $65 = (_luaO_pushfstring($58,3096,$vararg_buffer1)|0);
    $66 = HEAP32[$55>>2]|0;
    _luaX_syntaxerror($66,$65);
    // unreachable;
   }
   HEAP32[$vararg_buffer>>2] = $61;
   $63 = (_luaO_pushfstring($58,3056,$vararg_buffer)|0);
   $64 = $63;
   HEAP32[$vararg_buffer1>>2] = 3128;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = 200;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $64;
   $65 = (_luaO_pushfstring($58,3096,$vararg_buffer1)|0);
   $66 = HEAP32[$55>>2]|0;
   _luaX_syntaxerror($66,$65);
   // unreachable;
  } else {
   _error_expected($ls,61);
   // unreachable;
  }
 } while(0);
 $95 = HEAP32[$$pre$phiZ2D>>2]|0;
 $96 = ((($95)) + 44|0);
 $97 = HEAP8[$96>>0]|0;
 $98 = $97&255;
 $99 = (($98) + -1)|0;
 $100 = ((($e)) + 16|0);
 HEAP32[$100>>2] = -1;
 $101 = ((($e)) + 20|0);
 HEAP32[$101>>2] = -1;
 HEAP32[$$pre$phi4Z2D>>2] = 7;
 $102 = ((($e)) + 8|0);
 HEAP32[$102>>2] = $99;
 _luaK_storevar($95,$0,$e);
 STACKTOP = sp;return;
}
function _funcargs($ls,$f,$line) {
 $ls = $ls|0;
 $f = $f|0;
 $line = $line|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $nparams$0 = 0;
 var $phitmp = 0, $phitmp2 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 24|0;
 $args = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 if ((($3|0) == 123)) {
  _constructor($ls,$args);
 } else if ((($3|0) == 293)) {
  $19 = ((($ls)) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (_luaK_stringK($1,$20)|0);
  $22 = ((($args)) + 16|0);
  HEAP32[$22>>2] = -1;
  $23 = ((($args)) + 20|0);
  HEAP32[$23>>2] = -1;
  HEAP32[$args>>2] = 4;
  $24 = ((($args)) + 8|0);
  HEAP32[$24>>2] = $21;
  _luaX_next($ls);
 } else if ((($3|0) == 40)) {
  _luaX_next($ls);
  $4 = HEAP32[$2>>2]|0;
  $5 = ($4|0)==(41);
  if ($5) {
   HEAP32[$args>>2] = 0;
  } else {
   (_subexpr($ls,$args,0)|0);
   $6 = HEAP32[$2>>2]|0;
   $7 = ($6|0)==(44);
   if ($7) {
    while(1) {
     _luaX_next($ls);
     $8 = HEAP32[$0>>2]|0;
     _luaK_exp2nextreg($8,$args);
     (_subexpr($ls,$args,0)|0);
     $9 = HEAP32[$2>>2]|0;
     $10 = ($9|0)==(44);
     if (!($10)) {
      break;
     }
    }
   }
   _luaK_setreturns($1,$args,-1);
   $$pre = HEAP32[$2>>2]|0;
   $phitmp2 = ($$pre|0)==(41);
   if (!($phitmp2)) {
    $11 = ((($ls)) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($line|0);
    if ($13) {
     _error_expected($ls,41);
     // unreachable;
    } else {
     $14 = ((($ls)) + 52|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (_luaX_token2str($ls,41)|0);
     $17 = (_luaX_token2str($ls,40)|0);
     HEAP32[$vararg_buffer>>2] = $16;
     $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
     HEAP32[$vararg_ptr1>>2] = $17;
     $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
     HEAP32[$vararg_ptr2>>2] = $line;
     $18 = (_luaO_pushfstring($15,3144,$vararg_buffer)|0);
     _luaX_syntaxerror($ls,$18);
     // unreachable;
    }
   }
  }
  _luaX_next($ls);
 } else {
  _luaX_syntaxerror($ls,3384);
  // unreachable;
 }
 $25 = ((($f)) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$args>>2]|0;
 if ((($27|0) == 14) | (($27|0) == 13)) {
  $nparams$0 = 0;
  $31 = (_luaK_codeABC($1,36,$26,$nparams$0,2)|0);
  $32 = ((($f)) + 16|0);
  HEAP32[$32>>2] = -1;
  $33 = ((($f)) + 20|0);
  HEAP32[$33>>2] = -1;
  HEAP32[$f>>2] = 13;
  HEAP32[$25>>2] = $31;
  _luaK_fixline($1,$line);
  $34 = (($26) + 1)|0;
  $35 = $34&255;
  $36 = ((($1)) + 44|0);
  HEAP8[$36>>0] = $35;
  STACKTOP = sp;return;
 } else if (!((($27|0) == 0))) {
  _luaK_exp2nextreg($1,$args);
 }
 $28 = ((($1)) + 44|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $phitmp = (($30) - ($26))|0;
 $nparams$0 = $phitmp;
 $31 = (_luaK_codeABC($1,36,$26,$nparams$0,2)|0);
 $32 = ((($f)) + 16|0);
 HEAP32[$32>>2] = -1;
 $33 = ((($f)) + 20|0);
 HEAP32[$33>>2] = -1;
 HEAP32[$f>>2] = 13;
 HEAP32[$25>>2] = $31;
 _luaK_fixline($1,$line);
 $34 = (($26) + 1)|0;
 $35 = $34&255;
 $36 = ((($1)) + 44|0);
 HEAP8[$36>>0] = $35;
 STACKTOP = sp;return;
}
function _constructor($ls,$t) {
 $ls = $ls|0;
 $t = $t|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $cc = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 40|0;
 $cc = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_luaK_codeABC($1,11,0,0,0)|0);
 $5 = ((($cc)) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($cc)) + 28|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($cc)) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($cc)) + 24|0);
 HEAP32[$8>>2] = $t;
 $9 = ((($t)) + 16|0);
 HEAP32[$9>>2] = -1;
 $10 = ((($t)) + 20|0);
 HEAP32[$10>>2] = -1;
 HEAP32[$t>>2] = 12;
 $11 = ((($t)) + 8|0);
 HEAP32[$11>>2] = $4;
 $12 = ((($cc)) + 16|0);
 HEAP32[$12>>2] = -1;
 $13 = ((($cc)) + 20|0);
 HEAP32[$13>>2] = -1;
 HEAP32[$cc>>2] = 0;
 $14 = ((($cc)) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = HEAP32[$0>>2]|0;
 _luaK_exp2nextreg($15,$t);
 $16 = ((($ls)) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(123);
 if (!($18)) {
  _error_expected($ls,123);
  // unreachable;
 }
 _luaX_next($ls);
 $19 = HEAP32[$16>>2]|0;
 $20 = ($19|0)==(125);
 L4: do {
  if (!($20)) {
   $22 = 0;
   while(1) {
    $21 = ($22|0)==(0);
    if (!($21)) {
     _luaK_exp2nextreg($1,$cc);
     HEAP32[$cc>>2] = 0;
     $23 = HEAP32[$5>>2]|0;
     $24 = ($23|0)==(50);
     if ($24) {
      $25 = HEAP32[$8>>2]|0;
      $26 = ((($25)) + 8|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = HEAP32[$7>>2]|0;
      _luaK_setlist($1,$27,$28,50);
      HEAP32[$5>>2] = 0;
     }
    }
    $29 = HEAP32[$16>>2]|0;
    do {
     if ((($29|0) == 91)) {
      _recfield($ls,$cc);
     } else if ((($29|0) == 292)) {
      $30 = (_luaX_lookahead($ls)|0);
      $31 = ($30|0)==(61);
      if ($31) {
       _recfield($ls,$cc);
       break;
      } else {
       (_subexpr($ls,$cc,0)|0);
       $32 = HEAP32[$7>>2]|0;
       $33 = (($32) + 1)|0;
       HEAP32[$7>>2] = $33;
       $34 = HEAP32[$5>>2]|0;
       $35 = (($34) + 1)|0;
       HEAP32[$5>>2] = $35;
       break;
      }
     } else {
      (_subexpr($ls,$cc,0)|0);
      $36 = HEAP32[$7>>2]|0;
      $37 = (($36) + 1)|0;
      HEAP32[$7>>2] = $37;
      $38 = HEAP32[$5>>2]|0;
      $39 = (($38) + 1)|0;
      HEAP32[$5>>2] = $39;
     }
    } while(0);
    $40 = HEAP32[$16>>2]|0;
    if ((($40|0) == 44)) {
     _luaX_next($ls);
    } else if ((($40|0) == 59)) {
     _luaX_next($ls);
    } else if ((($40|0) == 125)) {
     break L4;
    } else {
     break;
    }
    $41 = HEAP32[$16>>2]|0;
    $42 = ($41|0)==(125);
    if ($42) {
     break L4;
    }
    $$pre = HEAP32[$cc>>2]|0;
    $22 = $$pre;
   }
   $43 = HEAP32[$2>>2]|0;
   $44 = ($43|0)==($3|0);
   if ($44) {
    _error_expected($ls,125);
    // unreachable;
   } else {
    $45 = ((($ls)) + 52|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (_luaX_token2str($ls,125)|0);
    $48 = (_luaX_token2str($ls,123)|0);
    HEAP32[$vararg_buffer>>2] = $47;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $48;
    $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
    HEAP32[$vararg_ptr2>>2] = $3;
    $49 = (_luaO_pushfstring($46,3144,$vararg_buffer)|0);
    _luaX_syntaxerror($ls,$49);
    // unreachable;
   }
  }
 } while(0);
 _luaX_next($ls);
 $50 = HEAP32[$5>>2]|0;
 $51 = ($50|0)==(0);
 do {
  if (!($51)) {
   $52 = HEAP32[$cc>>2]|0;
   if ((($52|0) == 0)) {
    $63 = $50;
   } else if ((($52|0) == 14) | (($52|0) == 13)) {
    _luaK_setreturns($1,$cc,-1);
    $53 = HEAP32[$8>>2]|0;
    $54 = ((($53)) + 8|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = HEAP32[$7>>2]|0;
    _luaK_setlist($1,$55,$56,-1);
    $57 = HEAP32[$7>>2]|0;
    $58 = (($57) + -1)|0;
    HEAP32[$7>>2] = $58;
    break;
   } else {
    _luaK_exp2nextreg($1,$cc);
    $$pre$i = HEAP32[$5>>2]|0;
    $63 = $$pre$i;
   }
   $59 = HEAP32[$8>>2]|0;
   $60 = ((($59)) + 8|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = HEAP32[$7>>2]|0;
   _luaK_setlist($1,$61,$62,$63);
  }
 } while(0);
 $64 = HEAP32[$1>>2]|0;
 $65 = ((($64)) + 48|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + ($4<<2)|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = $68 & 8388607;
 $70 = HEAP32[$7>>2]|0;
 $71 = (_luaO_int2fb($70)|0);
 $72 = $71 << 23;
 $73 = $72 | $69;
 $74 = HEAP32[$1>>2]|0;
 $75 = ((($74)) + 48|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + ($4<<2)|0);
 HEAP32[$77>>2] = $73;
 $78 = $73 & -8372225;
 $79 = HEAP32[$6>>2]|0;
 $80 = (_luaO_int2fb($79)|0);
 $81 = $80 << 14;
 $82 = $81 & 8372224;
 $83 = $82 | $78;
 $84 = HEAP32[$1>>2]|0;
 $85 = ((($84)) + 48|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + ($4<<2)|0);
 HEAP32[$87>>2] = $83;
 STACKTOP = sp;return;
}
function _recfield($ls,$cc) {
 $ls = $ls|0;
 $cc = $cc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $key = 0, $ls$idx$val$i = 0, $val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $key = sp + 24|0;
 $val = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 44|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ((($ls)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(292);
 do {
  if ($6) {
   $7 = ((($ls)) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   _luaX_next($ls);
   $ls$idx$val$i = HEAP32[$0>>2]|0;
   $9 = (_luaK_stringK($ls$idx$val$i,$8)|0);
   $10 = ((($key)) + 16|0);
   HEAP32[$10>>2] = -1;
   $11 = ((($key)) + 20|0);
   HEAP32[$11>>2] = -1;
   HEAP32[$key>>2] = 4;
   $12 = ((($key)) + 8|0);
   HEAP32[$12>>2] = $9;
  } else {
   _luaX_next($ls);
   (_subexpr($ls,$key,0)|0);
   $13 = HEAP32[$0>>2]|0;
   _luaK_exp2val($13,$key);
   $14 = HEAP32[$4>>2]|0;
   $15 = ($14|0)==(93);
   if ($15) {
    _luaX_next($ls);
    break;
   } else {
    _error_expected($ls,93);
    // unreachable;
   }
  }
 } while(0);
 $16 = ((($cc)) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1)|0;
 HEAP32[$16>>2] = $18;
 $19 = HEAP32[$4>>2]|0;
 $20 = ($19|0)==(61);
 if ($20) {
  _luaX_next($ls);
  $21 = (_luaK_exp2RK($1,$key)|0);
  (_subexpr($ls,$val,0)|0);
  $22 = ((($cc)) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($23)) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (_luaK_exp2RK($1,$val)|0);
  (_luaK_codeABC($1,10,$25,$21,$26)|0);
  HEAP8[$2>>0] = $3;
  STACKTOP = sp;return;
 } else {
  _error_expected($ls,61);
  // unreachable;
 }
}
function _luaE_setdebt($g,$debt) {
 $g = $g|0;
 $debt = $debt|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($g)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($g)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($debt))|0;
 $5 = (($4) + ($3))|0;
 HEAP32[$2>>2] = $5;
 HEAP32[$0>>2] = $debt;
 return;
}
function _luaE_extendCI($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaM_realloc_($L,0,0,36)|0);
 $1 = ((($L)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 12|0);
 HEAP32[$3>>2] = $0;
 $4 = $2;
 $5 = ((($0)) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = 0;
 return ($0|0);
}
function _luaE_freeCI($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $next$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$2>>2] = 0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 } else {
  $next$01 = $3;
 }
 while(1) {
  $5 = ((($next$01)) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  (_luaM_realloc_($L,$next$01,36,0)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   break;
  } else {
   $next$01 = $6;
  }
 }
 return;
}
function _luaE_shrinkCI($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 } else {
  $6 = $3;$9 = $2;$ci$01 = $1;
 }
 while(1) {
  $5 = ((($6)) + 12|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   label = 4;
   break;
  }
  (_luaM_realloc_($L,$6,36,0)|0);
  HEAP32[$9>>2] = $7;
  $10 = ((($7)) + 8|0);
  HEAP32[$10>>2] = $ci$01;
  $11 = ((($7)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 4;
   break;
  } else {
   $6 = $12;$9 = $11;$ci$01 = $7;
  }
 }
 if ((label|0) == 4) {
  return;
 }
}
function _luaE_freethread($L,$L1) {
 $L = $L|0;
 $L1 = $L1|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $next$01$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ((($L1)) + -4|0);
 $1 = ((($L1)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 _luaF_close($L1,$2);
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_luaM_realloc_($L,$0,116,0)|0);
  return;
 }
 $5 = ((($L1)) + 48|0);
 $6 = ((($L1)) + 16|0);
 HEAP32[$6>>2] = $5;
 $7 = ((($L1)) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$7>>2] = 0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $16 = $3;
 } else {
  $next$01$i$i = $8;
  while(1) {
   $10 = ((($next$01$i$i)) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   (_luaM_realloc_($L1,$next$01$i$i,36,0)|0);
   $12 = ($11|0)==(0|0);
   if ($12) {
    break;
   } else {
    $next$01$i$i = $11;
   }
  }
  $$pre$i = HEAP32[$1>>2]|0;
  $16 = $$pre$i;
 }
 $13 = ((($L1)) + 92|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 << 4;
 (_luaM_realloc_($L1,$16,$15,0)|0);
 (_luaM_realloc_($L,$0,116,0)|0);
 return;
}
function _lua_newstate($f,$ud) {
 $f = $f|0;
 $ud = $ud|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buff$i = 0, $h$i = 0, $scevgep = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $buff$i = sp + 8|0;
 $h$i = sp;
 $0 = (FUNCTION_TABLE_iiiii[$f & 15]($ud,0,8,400)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ((($0)) + 4|0);
 $3 = ((($0)) + 120|0);
 HEAP32[$2>>2] = 0;
 $4 = ((($0)) + 8|0);
 HEAP8[$4>>0] = 8;
 $5 = ((($0)) + 180|0);
 HEAP8[$5>>0] = 1;
 $6 = ((($0)) + 9|0);
 HEAP8[$6>>0] = 1;
 $7 = ((($0)) + 16|0);
 HEAP32[$7>>2] = $3;
 $8 = ((($0)) + 32|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 20|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 96|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 44|0);
 HEAP32[$11>>2] = $2;
 $12 = ((($0)) + 48|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 110|0);
 HEAP16[$13>>1] = 0;
 $14 = ((($0)) + 88|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 112|0);
 HEAP8[$15>>0] = 0;
 $16 = ((($0)) + 100|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 113|0);
 HEAP8[$17>>0] = 1;
 $18 = ((($0)) + 104|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($0)) + 36|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($0)) + 108|0);
 HEAP16[$20>>1] = 1;
 $21 = ((($0)) + 10|0);
 HEAP8[$21>>0] = 0;
 $22 = ((($0)) + 92|0);
 HEAP32[$22>>2] = 0;
 HEAP32[$3>>2] = $f;
 $23 = ((($0)) + 124|0);
 HEAP32[$23>>2] = $ud;
 $24 = ((($0)) + 256|0);
 HEAP32[$24>>2] = $2;
 $25 = (_time((0|0))|0);
 HEAP32[$h$i>>2] = $25;
 $26 = $2;
 HEAP32[$buff$i>>2] = $26;
 $27 = $h$i;
 $28 = ((($buff$i)) + 4|0);
 HEAP32[$28>>2] = $27;
 $29 = ((($buff$i)) + 8|0);
 HEAP32[$29>>2] = (1760);
 $30 = ((($buff$i)) + 12|0);
 HEAP32[$30>>2] = (9);
 $31 = (_luaS_hash($buff$i,16,$25)|0);
 $32 = ((($0)) + 176|0);
 HEAP32[$32>>2] = $31;
 $33 = ((($0)) + 183|0);
 HEAP8[$33>>0] = 0;
 $34 = ((($0)) + 140|0);
 $35 = ((($0)) + 168|0);
 HEAP32[$35>>2] = 0;
 $36 = ((($0)) + 228|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($0)) + 236|0);
 HEAP32[$37>>2] = 0;
 $38 = ((($0)) + 252|0);
 HEAP32[$38>>2] = 0;
 $39 = ((($0)) + 260|0);
 HEAP32[$39>>2] = 0;
 $40 = ((($0)) + 181|0);
 ;HEAP32[$34>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
 HEAP8[$40>>0] = 7;
 $41 = ((($0)) + 182|0);
 HEAP8[$41>>0] = 0;
 $42 = ((($0)) + 184|0);
 $43 = ((($0)) + 128|0);
 dest=$42; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$43>>2] = 400;
 $44 = ((($0)) + 132|0);
 HEAP32[$44>>2] = 0;
 $45 = ((($0)) + 240|0);
 HEAP32[$45>>2] = 0;
 $46 = ((($0)) + 244|0);
 HEAP32[$46>>2] = 200;
 $47 = ((($0)) + 248|0);
 HEAP32[$47>>2] = 200;
 $scevgep = ((($0)) + 364|0);
 dest=$scevgep; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $48 = (_luaD_rawrunprotected($2,10,0)|0);
 $49 = ($48|0)==(0);
 if ($49) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 _close_state($2);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _lua_close($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 136|0);
 $3 = HEAP32[$2>>2]|0;
 _close_state($3);
 return;
}
function _f_luaopen($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $temp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $temp$i = sp;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaM_realloc_($L,0,0,640)|0);
 $3 = ((($L)) + 28|0);
 HEAP32[$3>>2] = $2;
 $4 = ((($L)) + 92|0);
 HEAP32[$4>>2] = 40;
 $5 = ((($2)) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($2)) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($2)) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($2)) + 56|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($2)) + 72|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($2)) + 88|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($2)) + 104|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($2)) + 120|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($2)) + 136|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($2)) + 152|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($2)) + 168|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($2)) + 184|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($2)) + 200|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($2)) + 216|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($2)) + 232|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($2)) + 248|0);
 HEAP32[$20>>2] = 0;
 $21 = ((($2)) + 264|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($2)) + 280|0);
 HEAP32[$22>>2] = 0;
 $23 = ((($2)) + 296|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($2)) + 312|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($2)) + 328|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($2)) + 344|0);
 HEAP32[$26>>2] = 0;
 $27 = ((($2)) + 360|0);
 HEAP32[$27>>2] = 0;
 $28 = ((($2)) + 376|0);
 HEAP32[$28>>2] = 0;
 $29 = ((($2)) + 392|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($2)) + 408|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($2)) + 424|0);
 HEAP32[$31>>2] = 0;
 $32 = ((($2)) + 440|0);
 HEAP32[$32>>2] = 0;
 $33 = ((($2)) + 456|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($2)) + 472|0);
 HEAP32[$34>>2] = 0;
 $35 = ((($2)) + 488|0);
 HEAP32[$35>>2] = 0;
 $36 = ((($2)) + 504|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($2)) + 520|0);
 HEAP32[$37>>2] = 0;
 $38 = ((($2)) + 536|0);
 HEAP32[$38>>2] = 0;
 $39 = ((($2)) + 552|0);
 HEAP32[$39>>2] = 0;
 $40 = ((($2)) + 568|0);
 HEAP32[$40>>2] = 0;
 $41 = ((($2)) + 584|0);
 HEAP32[$41>>2] = 0;
 $42 = ((($2)) + 600|0);
 HEAP32[$42>>2] = 0;
 $43 = ((($2)) + 616|0);
 HEAP32[$43>>2] = 0;
 $44 = ((($2)) + 632|0);
 HEAP32[$44>>2] = 0;
 $45 = ((($L)) + 8|0);
 $46 = ((($2)) + 560|0);
 $47 = ((($L)) + 24|0);
 HEAP32[$47>>2] = $46;
 $48 = ((($L)) + 48|0);
 $49 = ((($L)) + 56|0);
 HEAP32[$49>>2] = 0;
 $50 = ((($L)) + 60|0);
 HEAP32[$50>>2] = 0;
 $51 = ((($L)) + 82|0);
 HEAP8[$51>>0] = 0;
 $52 = $2;
 HEAP32[$48>>2] = $52;
 $53 = ((($2)) + 16|0);
 HEAP32[$45>>2] = $53;
 HEAP32[$5>>2] = 0;
 $54 = ((($2)) + 336|0);
 $55 = ((($L)) + 52|0);
 HEAP32[$55>>2] = $54;
 $56 = ((($L)) + 16|0);
 HEAP32[$56>>2] = $48;
 $57 = (_luaH_new($L)|0);
 $58 = ((($1)) + 40|0);
 HEAP32[$58>>2] = $57;
 $59 = ((($1)) + 48|0);
 HEAP32[$59>>2] = 69;
 _luaH_resize($L,$57,2,0);
 HEAP32[$temp$i>>2] = $L;
 $60 = ((($temp$i)) + 8|0);
 HEAP32[$60>>2] = 72;
 _luaH_setint($L,$57,1,0,$temp$i);
 $61 = (_luaH_new($L)|0);
 HEAP32[$temp$i>>2] = $61;
 HEAP32[$60>>2] = 69;
 _luaH_setint($L,$57,2,0,$temp$i);
 _luaS_resize($L,64);
 _luaT_init($L);
 _luaX_init($L);
 $62 = (_luaS_newlstr($L,3600,17)|0);
 $63 = ((($1)) + 144|0);
 HEAP32[$63>>2] = $62;
 _luaC_fix($L,$62);
 $64 = ((($1)) + 63|0);
 HEAP8[$64>>0] = 1;
 $65 = (_lua_version(0)|0);
 $66 = ((($1)) + 140|0);
 HEAP32[$66>>2] = $65;
 STACKTOP = sp;return;
}
function _close_state($L) {
 $L = $L|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $next$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 _luaF_close($L,$3);
 _luaC_freeallobjects($L);
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4)) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 2;
 (_luaM_realloc_($L,$6,$9,0)|0);
 $10 = ((($1)) + 108|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($1)) + 116|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (_luaM_realloc_($L,$11,$13,0)|0);
 HEAP32[$10>>2] = $14;
 HEAP32[$12>>2] = 0;
 $15 = HEAP32[$2>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($1)) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($L)) + -4|0);
  (FUNCTION_TABLE_iiiii[$29 & 15]($31,$32,400,0)|0);
  return;
 }
 $17 = ((($L)) + 48|0);
 $18 = ((($L)) + 16|0);
 HEAP32[$18>>2] = $17;
 $19 = ((($L)) + 60|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$19>>2] = 0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $28 = $15;
 } else {
  $next$01$i$i = $20;
  while(1) {
   $22 = ((($next$01$i$i)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   (_luaM_realloc_($L,$next$01$i$i,36,0)|0);
   $24 = ($23|0)==(0|0);
   if ($24) {
    break;
   } else {
    $next$01$i$i = $23;
   }
  }
  $$pre$i = HEAP32[$2>>2]|0;
  $28 = $$pre$i;
 }
 $25 = ((($L)) + 92|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $26 << 4;
 (_luaM_realloc_($L,$28,$27,0)|0);
 $29 = HEAP32[$1>>2]|0;
 $30 = ((($1)) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($L)) + -4|0);
 (FUNCTION_TABLE_iiiii[$29 & 15]($31,$32,400,0)|0);
 return;
}
function _luaS_eqlngstr($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($a)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($a|0)==($b|0);
 if ($2) {
  $11 = 1;
 } else {
  $3 = ((($b)) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($1|0)==($4|0);
  if ($5) {
   $6 = ((($a)) + 24|0);
   $7 = ((($b)) + 24|0);
   $8 = (_memcmp($6,$7,$1)|0);
   $9 = ($8|0)==(0);
   $11 = $9;
  } else {
   $11 = 0;
  }
 }
 $10 = $11&1;
 return ($10|0);
}
function _luaS_hash($str,$l,$seed) {
 $str = $str|0;
 $l = $l|0;
 $seed = $seed|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $h$0$lcssa = 0, $h$02 = 0, $l1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $seed ^ $l;
 $1 = $l >>> 5;
 $2 = (($1) + 1)|0;
 $3 = ($2>>>0)>($l>>>0);
 if ($3) {
  $h$0$lcssa = $0;
  return ($h$0$lcssa|0);
 } else {
  $h$02 = $0;$l1$01 = $l;
 }
 while(1) {
  $4 = $h$02 << 5;
  $5 = $h$02 >>> 2;
  $6 = (($4) + ($5))|0;
  $7 = (($l1$01) + -1)|0;
  $8 = (($str) + ($7)|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = (($6) + ($10))|0;
  $12 = $11 ^ $h$02;
  $13 = (($l1$01) - ($2))|0;
  $14 = ($13>>>0)<($2>>>0);
  if ($14) {
   $h$0$lcssa = $12;
   break;
  } else {
   $h$02 = $12;$l1$01 = $13;
  }
 }
 return ($h$0$lcssa|0);
}
function _luaS_resize($L,$newsize) {
 $L = $L|0;
 $newsize = $newsize|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond9 = 0, $i$12 = 0, $p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 24|0);
 $3 = ((($1)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)<($newsize|0);
 if ($5) {
  $9 = (($newsize) + 1)|0;
  $10 = ($9>>>0)>(1073741823);
  if ($10) {
   _luaM_toobig($L);
   // unreachable;
  }
  $11 = HEAP32[$2>>2]|0;
  $12 = $4 << 2;
  $13 = $newsize << 2;
  $14 = (_luaM_realloc_($L,$11,$12,$13)|0);
  HEAP32[$2>>2] = $14;
  $15 = HEAP32[$3>>2]|0;
  $16 = ($15|0)<($newsize|0);
  if ($16) {
   $17 = (($14) + ($15<<2)|0);
   HEAP32[$17>>2] = 0;
   $18 = (($15) + 1)|0;
   $exitcond9 = ($18|0)==($newsize|0);
   if ($exitcond9) {
    $7 = $15;
   } else {
    $20 = $18;
    while(1) {
     $$pre = HEAP32[$2>>2]|0;
     $19 = (($$pre) + ($20<<2)|0);
     HEAP32[$19>>2] = 0;
     $21 = (($20) + 1)|0;
     $exitcond = ($21|0)==($newsize|0);
     if ($exitcond) {
      $7 = $15;
      break;
     } else {
      $20 = $21;
     }
    }
   }
  } else {
   $7 = $15;
  }
 } else {
  $7 = $4;
 }
 $6 = ($7|0)>(0);
 if ($6) {
  $8 = (($newsize) + -1)|0;
  $i$12 = 0;
  while(1) {
   $22 = HEAP32[$2>>2]|0;
   $23 = (($22) + ($i$12<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$23>>2] = 0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $p$01 = $24;
    while(1) {
     $26 = ((($p$01)) + 16|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($p$01)) + 8|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = $29 & $8;
     $31 = HEAP32[$2>>2]|0;
     $32 = (($31) + ($30<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     HEAP32[$26>>2] = $33;
     HEAP32[$32>>2] = $p$01;
     $34 = ($27|0)==(0|0);
     if ($34) {
      break;
     } else {
      $p$01 = $27;
     }
    }
   }
   $35 = (($i$12) + 1)|0;
   $36 = ($35|0)<($7|0);
   if ($36) {
    $i$12 = $35;
   } else {
    break;
   }
  }
 }
 $37 = ($7|0)>($newsize|0);
 if (!($37)) {
  HEAP32[$3>>2] = $newsize;
  return;
 }
 $38 = (($newsize) + 1)|0;
 $39 = ($38>>>0)>(1073741823);
 if ($39) {
  _luaM_toobig($L);
  // unreachable;
 }
 $40 = HEAP32[$2>>2]|0;
 $41 = $7 << 2;
 $42 = $newsize << 2;
 $43 = (_luaM_realloc_($L,$40,$41,$42)|0);
 HEAP32[$2>>2] = $43;
 HEAP32[$3>>2] = $newsize;
 return;
}
function _luaS_remove($L,$ts) {
 $L = $L|0;
 $ts = $ts|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0;
 var $p$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ts)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + -1)|0;
 $7 = $6 & $3;
 $8 = ((($1)) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7<<2)|0);
 $p$0 = $10;
 while(1) {
  $11 = HEAP32[$p$0>>2]|0;
  $12 = ($11|0)==($ts|0);
  $13 = ((($11)) + 16|0);
  if ($12) {
   $$lcssa = $13;$p$0$lcssa = $p$0;
   break;
  } else {
   $p$0 = $13;
  }
 }
 $14 = HEAP32[$$lcssa>>2]|0;
 HEAP32[$p$0$lcssa>>2] = $14;
 $15 = ((($1)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 return;
}
function _luaS_newlstr($L,$str,$l) {
 $L = $L|0;
 $str = $str|0;
 $l = $l|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $h$0$lcssa$i$i = 0, $h$02$i$i = 0, $l1$01$i$i = 0, $list$0$i = 0, $or$cond$i = 0, $ts$0$i = 0, $ts$02$i = 0, $ts$03$i = 0, $ts$03$i$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($l>>>0)<(41);
 if (!($0)) {
  $68 = (($l) + 1)|0;
  $69 = ($68>>>0)>(4294967275);
  if ($69) {
   _luaM_toobig($L);
   // unreachable;
  }
  $70 = ((($L)) + 12|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ((($71)) + 56|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($l) + 25)|0;
  $75 = (_luaC_newobj($L,20,$74)|0);
  $76 = ((($75)) + 12|0);
  HEAP32[$76>>2] = $l;
  $77 = ((($75)) + 8|0);
  HEAP32[$77>>2] = $73;
  $78 = ((($75)) + 6|0);
  HEAP8[$78>>0] = 0;
  $79 = ((($75)) + 24|0);
  _memcpy(($79|0),($str|0),($l|0))|0;
  $80 = (($79) + ($l)|0);
  HEAP8[$80>>0] = 0;
  $$0 = $75;
  return ($$0|0);
 }
 $1 = ((($L)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 ^ $l;
 $6 = $l >>> 5;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>($l>>>0);
 if ($8) {
  $h$0$lcssa$i$i = $5;
 } else {
  $h$02$i$i = $5;$l1$01$i$i = $l;
  while(1) {
   $9 = $h$02$i$i << 5;
   $10 = $h$02$i$i >>> 2;
   $11 = (($9) + ($10))|0;
   $12 = (($l1$01$i$i) + -1)|0;
   $13 = (($str) + ($12)|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14&255;
   $16 = (($11) + ($15))|0;
   $17 = $16 ^ $h$02$i$i;
   $18 = (($l1$01$i$i) - ($7))|0;
   $19 = ($18>>>0)<($7>>>0);
   if ($19) {
    $h$0$lcssa$i$i = $17;
    break;
   } else {
    $h$02$i$i = $17;$l1$01$i$i = $18;
   }
  }
 }
 $20 = ((($2)) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + -1)|0;
 $23 = $22 & $h$0$lcssa$i$i;
 $24 = ((($2)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23<<2)|0);
 $ts$02$i = HEAP32[$26>>2]|0;
 $27 = ($ts$02$i|0)==(0|0);
 L12: do {
  if (!($27)) {
   $ts$03$i = $ts$02$i;
   while(1) {
    $28 = ((($ts$03$i)) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==($l|0);
    if ($30) {
     $31 = ((($ts$03$i)) + 24|0);
     $32 = (_memcmp($str,$31,$l)|0);
     $33 = ($32|0)==(0);
     if ($33) {
      $ts$03$i$lcssa = $ts$03$i;
      break;
     }
    }
    $45 = ((($ts$03$i)) + 16|0);
    $ts$0$i = HEAP32[$45>>2]|0;
    $46 = ($ts$0$i|0)==(0|0);
    if ($46) {
     break L12;
    } else {
     $ts$03$i = $ts$0$i;
    }
   }
   $34 = ((($ts$03$i$lcssa)) + 5|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   $37 = $36 ^ 3;
   $38 = ((($2)) + 60|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = $39&255;
   $41 = $40 ^ 3;
   $42 = $41 & $37;
   $43 = ($42|0)==(0);
   if (!($43)) {
    $$0 = $ts$03$i$lcssa;
    return ($$0|0);
   }
   $44 = $37&255;
   HEAP8[$34>>0] = $44;
   $$0 = $ts$03$i$lcssa;
   return ($$0|0);
  }
 } while(0);
 $47 = ((($2)) + 28|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)>=($21|0);
 $50 = ($21|0)<(1073741824);
 $or$cond$i = $50 & $49;
 if ($or$cond$i) {
  $51 = $21 << 1;
  _luaS_resize($L,$51);
  $52 = HEAP32[$20>>2]|0;
  $53 = (($52) + -1)|0;
  $54 = $53 & $h$0$lcssa$i$i;
  $55 = HEAP32[$24>>2]|0;
  $56 = (($55) + ($54<<2)|0);
  $list$0$i = $56;
 } else {
  $list$0$i = $26;
 }
 $57 = (($l) + 25)|0;
 $58 = (_luaC_newobj($L,4,$57)|0);
 $59 = ((($58)) + 12|0);
 HEAP32[$59>>2] = $l;
 $60 = ((($58)) + 8|0);
 HEAP32[$60>>2] = $h$0$lcssa$i$i;
 $61 = ((($58)) + 6|0);
 HEAP8[$61>>0] = 0;
 $62 = ((($58)) + 24|0);
 _memcpy(($62|0),($str|0),($l|0))|0;
 $63 = (($62) + ($l)|0);
 HEAP8[$63>>0] = 0;
 $64 = HEAP32[$list$0$i>>2]|0;
 $65 = ((($58)) + 16|0);
 HEAP32[$65>>2] = $64;
 HEAP32[$list$0$i>>2] = $58;
 $66 = HEAP32[$47>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$47>>2] = $67;
 $$0 = $58;
 return ($$0|0);
}
function _luaS_new($L,$str) {
 $L = $L|0;
 $str = $str|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($str|0))|0);
 $1 = (_luaS_newlstr($L,$str,$0)|0);
 return ($1|0);
}
function _luaH_resize($L,$t,$nasize,$nhsize) {
 $L = $L|0;
 $t = $t|0;
 $nasize = $nasize|0;
 $nhsize = $nhsize|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i3 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cell$0$i = 0, $exitcond = 0, $exitcond$i = 0, $i$01$i = 0, $i$01$i1 = 0, $i$07 = 0, $j$06 = 0, $j$06$in = 0, $k$i = 0, $lsize$0$i = 0, $n$0$i$i = 0, $n$0$i$i$lcssa = 0;
 var $phitmp$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 16|0;
 $k$i = sp;
 $0 = ((($t)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($t)) + 7|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = ((($t)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($1>>>0)<($nasize>>>0);
 if ($7) {
  $8 = (($nasize) + 1)|0;
  $9 = ($8>>>0)>(268435455);
  if ($9) {
   _luaM_toobig($L);
   // unreachable;
  }
  $10 = ((($t)) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $1 << 4;
  $13 = $nasize << 4;
  $14 = (_luaM_realloc_($L,$11,$12,$13)|0);
  HEAP32[$10>>2] = $14;
  $15 = HEAP32[$0>>2]|0;
  $16 = ($15>>>0)<($nasize>>>0);
  if ($16) {
   $i$01$i1 = $15;
   while(1) {
    $17 = (((($14) + ($i$01$i1<<4)|0)) + 8|0);
    HEAP32[$17>>2] = 0;
    $18 = (($i$01$i1) + 1)|0;
    $exitcond$i = ($18|0)==($nasize|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i1 = $18;
    }
   }
  }
  HEAP32[$0>>2] = $nasize;
 }
 $19 = ($nhsize|0)==(0);
 if ($19) {
  HEAP32[$5>>2] = 3624;
  $$0$i = 0;$33 = 3624;$lsize$0$i = 0;
 } else {
  $20 = (_luaO_ceillog2($nhsize)|0);
  $21 = ($20|0)>(30);
  if ($21) {
   _luaG_runerror($L,3656,$vararg_buffer);
   // unreachable;
  }
  $22 = 1 << $20;
  $23 = (($22) + 1)|0;
  $24 = ($23>>>0)>(134217727);
  if ($24) {
   _luaM_toobig($L);
   // unreachable;
  }
  $25 = $22 << 5;
  $26 = (_luaM_realloc_($L,0,0,$25)|0);
  HEAP32[$5>>2] = $26;
  $i$01$i = 0;
  while(1) {
   $27 = (((($26) + ($i$01$i<<5)|0)) + 28|0);
   HEAP32[$27>>2] = 0;
   $28 = (((($26) + ($i$01$i<<5)|0)) + 24|0);
   HEAP32[$28>>2] = 0;
   $29 = (((($26) + ($i$01$i<<5)|0)) + 8|0);
   HEAP32[$29>>2] = 0;
   $30 = (($i$01$i) + 1)|0;
   $31 = ($30|0)<($22|0);
   if ($31) {
    $i$01$i = $30;
   } else {
    break;
   }
  }
  $phitmp$i = $20&255;
  $$0$i = $22;$33 = $26;$lsize$0$i = $phitmp$i;
 }
 HEAP8[$2>>0] = $lsize$0$i;
 $32 = (($33) + ($$0$i<<5)|0);
 $34 = ((($t)) + 20|0);
 HEAP32[$34>>2] = $32;
 $35 = ($1>>>0)>($nasize>>>0);
 do {
  if ($35) {
   HEAP32[$0>>2] = $nasize;
   $36 = ((($t)) + 12|0);
   $37 = ((($k$i)) + 8|0);
   $i$07 = $nasize;
   while(1) {
    $38 = HEAP32[$36>>2]|0;
    $39 = (((($38) + ($i$07<<4)|0)) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==(0);
    if ($41) {
     $$pre = (($i$07) + 1)|0;
     $$pre$phiZ2D = $$pre;
    } else {
     $42 = (($38) + ($i$07<<4)|0);
     $43 = (($i$07) + 1)|0;
     $44 = (_i64Add(($43|0),0,-1,-1)|0);
     $45 = tempRet0;
     $46 = HEAP32[$0>>2]|0;
     $47 = ($45>>>0)<(0);
     $48 = ($44>>>0)<($46>>>0);
     $49 = ($45|0)==(0);
     $50 = $49 & $48;
     $51 = $47 | $50;
     L31: do {
      if ($51) {
       $52 = (($38) + ($44<<4)|0);
       $$0$i$i = $52;
       label = 28;
      } else {
       $53 = HEAP8[$2>>0]|0;
       $54 = $53&255;
       $55 = 1 << $54;
       $56 = (($55) + -1)|0;
       $57 = $56 & $43;
       $58 = HEAP32[$5>>2]|0;
       $59 = (($58) + ($57<<5)|0);
       $n$0$i$i = $59;
       while(1) {
        $60 = ((($n$0$i$i)) + 24|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = ($61|0)==(19);
        if ($62) {
         $63 = ((($n$0$i$i)) + 16|0);
         $64 = $63;
         $65 = $64;
         $66 = HEAP32[$65>>2]|0;
         $67 = (($64) + 4)|0;
         $68 = $67;
         $69 = HEAP32[$68>>2]|0;
         $70 = ($66|0)==($43|0);
         $71 = ($69|0)==(0);
         $72 = $70 & $71;
         if ($72) {
          $n$0$i$i$lcssa = $n$0$i$i;
          break;
         }
        }
        $73 = ((($n$0$i$i)) + 28|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = ($74|0)==(0);
        if ($75) {
         label = 29;
         break L31;
        }
        $76 = (($n$0$i$i) + ($74<<5)|0);
        $n$0$i$i = $76;
       }
       $$0$i$i = $n$0$i$i$lcssa;
       label = 28;
      }
     } while(0);
     if ((label|0) == 28) {
      label = 0;
      $77 = ($$0$i$i|0)==(1760|0);
      if ($77) {
       label = 29;
      } else {
       $cell$0$i = $$0$i$i;
      }
     }
     if ((label|0) == 29) {
      label = 0;
      $78 = $k$i;
      $79 = $78;
      HEAP32[$79>>2] = $43;
      $80 = (($78) + 4)|0;
      $81 = $80;
      HEAP32[$81>>2] = 0;
      HEAP32[$37>>2] = 19;
      $82 = (_luaH_newkey($L,$t,$k$i)|0);
      $cell$0$i = $82;
     }
     ;HEAP32[$cell$0$i>>2]=HEAP32[$42>>2]|0;HEAP32[$cell$0$i+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$cell$0$i+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$cell$0$i+12>>2]=HEAP32[$42+12>>2]|0;
     $$pre$phiZ2D = $43;
    }
    $exitcond = ($$pre$phiZ2D|0)==($1|0);
    if ($exitcond) {
     break;
    } else {
     $i$07 = $$pre$phiZ2D;
    }
   }
   $83 = (($nasize) + 1)|0;
   $84 = ($83>>>0)>(268435455);
   if ($84) {
    _luaM_toobig($L);
    // unreachable;
   } else {
    $85 = ((($t)) + 12|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = $1 << 4;
    $88 = $nasize << 4;
    $89 = (_luaM_realloc_($L,$86,$87,$88)|0);
    HEAP32[$85>>2] = $89;
    break;
   }
  }
 } while(0);
 $90 = 1 << $4;
 $91 = ($3<<24>>24)==(31);
 if (!($91)) {
  $j$06$in = $90;
  while(1) {
   $j$06 = (($j$06$in) + -1)|0;
   $92 = (((($6) + ($j$06<<5)|0)) + 8|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(0);
   if (!($94)) {
    $96 = (($6) + ($j$06<<5)|0);
    $97 = (((($6) + ($j$06<<5)|0)) + 16|0);
    $98 = (_luaH_get($t,$97)|0);
    $99 = ($98|0)==(1760|0);
    if ($99) {
     $100 = (_luaH_newkey($L,$t,$97)|0);
     $$0$i3 = $100;
    } else {
     $$0$i3 = $98;
    }
    ;HEAP32[$$0$i3>>2]=HEAP32[$96>>2]|0;HEAP32[$$0$i3+4>>2]=HEAP32[$96+4>>2]|0;HEAP32[$$0$i3+8>>2]=HEAP32[$96+8>>2]|0;HEAP32[$$0$i3+12>>2]=HEAP32[$96+12>>2]|0;
   }
   $95 = ($j$06$in|0)>(1);
   if ($95) {
    $j$06$in = $j$06;
   } else {
    break;
   }
  }
 }
 $101 = ($6|0)==(3624|0);
 if ($101) {
  STACKTOP = sp;return;
 }
 $102 = $90 << 5;
 (_luaM_realloc_($L,$6,$102,0)|0);
 STACKTOP = sp;return;
}
function _luaH_setint($L,$t,$0,$1,$value) {
 $L = $L|0;
 $t = $t|0;
 $0 = $0|0;
 $1 = $1|0;
 $value = $value|0;
 var $$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cell$0 = 0, $k = 0, $n$0$i = 0, $n$0$i$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $k = sp;
 $2 = (_i64Add(($0|0),($1|0),-1,-1)|0);
 $3 = tempRet0;
 $4 = ((($t)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<(0);
 $7 = ($2>>>0)<($5>>>0);
 $8 = ($3|0)==(0);
 $9 = $8 & $7;
 $10 = $6 | $9;
 L1: do {
  if ($10) {
   $11 = ((($t)) + 12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + ($2<<4)|0);
   $$0$i = $13;
   label = 9;
  } else {
   $14 = ((($t)) + 7|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = $15&255;
   $17 = 1 << $16;
   $18 = (($17) + -1)|0;
   $19 = $18 & $0;
   $20 = ((($t)) + 16|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<5)|0);
   $n$0$i = $22;
   while(1) {
    $23 = ((($n$0$i)) + 24|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(19);
    if ($25) {
     $26 = ((($n$0$i)) + 16|0);
     $27 = $26;
     $28 = $27;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($27) + 4)|0;
     $31 = $30;
     $32 = HEAP32[$31>>2]|0;
     $33 = ($29|0)==($0|0);
     $34 = ($32|0)==($1|0);
     $35 = $33 & $34;
     if ($35) {
      $n$0$i$lcssa = $n$0$i;
      break;
     }
    }
    $36 = ((($n$0$i)) + 28|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)==(0);
    if ($38) {
     break L1;
    }
    $39 = (($n$0$i) + ($37<<5)|0);
    $n$0$i = $39;
   }
   $$0$i = $n$0$i$lcssa;
   label = 9;
  }
 } while(0);
 if ((label|0) == 9) {
  $40 = ($$0$i|0)==(1760|0);
  if (!($40)) {
   $cell$0 = $$0$i;
   ;HEAP32[$cell$0>>2]=HEAP32[$value>>2]|0;HEAP32[$cell$0+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$cell$0+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$cell$0+12>>2]=HEAP32[$value+12>>2]|0;
   STACKTOP = sp;return;
  }
 }
 $41 = $k;
 $42 = $41;
 HEAP32[$42>>2] = $0;
 $43 = (($41) + 4)|0;
 $44 = $43;
 HEAP32[$44>>2] = $1;
 $45 = ((($k)) + 8|0);
 HEAP32[$45>>2] = 19;
 $46 = (_luaH_newkey($L,$t,$k)|0);
 $cell$0 = $46;
 ;HEAP32[$cell$0>>2]=HEAP32[$value>>2]|0;HEAP32[$cell$0+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$cell$0+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$cell$0+12>>2]=HEAP32[$value+12>>2]|0;
 STACKTOP = sp;return;
}
function _luaH_set($L,$t,$key) {
 $L = $L|0;
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaH_get($t,$key)|0);
 $1 = ($0|0)==(1760|0);
 if (!($1)) {
  $$0 = $0;
  return ($$0|0);
 }
 $2 = (_luaH_newkey($L,$t,$key)|0);
 $$0 = $2;
 return ($$0|0);
}
function _luaH_resizearray($L,$t,$nasize) {
 $L = $L|0;
 $t = $t|0;
 $nasize = $nasize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($t)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3624|0);
 if ($2) {
  $7 = 0;
 } else {
  $3 = ((($t)) + 7|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4&255;
  $6 = 1 << $5;
  $7 = $6;
 }
 _luaH_resize($L,$t,$nasize,$7);
 return;
}
function _luaH_new($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaC_newobj($L,5,32)|0);
 $1 = ((($0)) + 24|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 6|0);
 HEAP8[$2>>0] = -1;
 $3 = ((($0)) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 16|0);
 HEAP32[$5>>2] = 3624;
 $6 = ((($0)) + 7|0);
 HEAP8[$6>>0] = 0;
 $7 = ((($0)) + 20|0);
 HEAP32[$7>>2] = 3624;
 return ($0|0);
}
function _luaH_free($L,$t) {
 $L = $L|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($t)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3624|0);
 if (!($2)) {
  $3 = ((($t)) + 7|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4&255;
  $6 = 32 << $5;
  (_luaM_realloc_($L,$1,$6,0)|0);
 }
 $7 = ((($t)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($t)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 4;
 (_luaM_realloc_($L,$8,$11,0)|0);
 (_luaM_realloc_($L,$t,32,0)|0);
 return;
}
function _luaH_newkey($L,$t,$key) {
 $L = $L|0;
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$02 = 0, $$lcssa = 0, $$lcssa44 = 0, $$lcssa45 = 0, $$lcssa48 = 0, $$lcssa49 = 0, $$na$0$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $a$03$i$i = 0, $a$1$i$i = 0, $ause$0$lcssa$i$i = 0, $ause$0$ph$i$i = 0, $ause$0$ph$i$i$lcssa = 0, $ause$06$i$i = 0, $aux = 0, $i$0$i$i = 0, $i$0$ph$i$i = 0, $i$01$i$i = 0, $i$07$i$i = 0, $i$1$lcssa$i$i = 0, $i$11$i$i = 0, $lc$0$$i$i = 0, $lc$0$lcssa$i$i = 0, $lc$02$i$i = 0, $lg$04$i$i = 0, $lim$0$ph$i$i = 0, $mp$0 = 0, $n$05$i$i = 0;
 var $n$1$i$i = 0, $n$2$i$i = 0, $na$04$i$i = 0, $na$1$i$i = 0, $na$2$i$i = 0, $not$$i$i = 0, $nums$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i$i$i = 0, $or$cond$i$not$i$i = 0, $or$cond$i$not$i$i$i = 0, $othern$0 = 0, $othern$0$lcssa = 0, $totaluse$0$ph$i$i = 0, $totaluse$0$ph$i$i$lcssa = 0, $ttlg$05$i$i = 0, $twotoi$0$n$0$i$i = 0, $twotoi$02$i$i = 0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 24|0;
 $vararg_buffer = sp + 16|0;
 $nums$i = sp + 32|0;
 $aux = sp;
 $0 = ((($key)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 0)) {
  _luaG_runerror($L,3672,$vararg_buffer);
  // unreachable;
 } else if ((($1|0) == 3)) {
  label = 3;
 } else {
  $$02 = $key;
 }
 if ((label|0) == 3) {
  $2 = +HEAPF64[$key>>3];
  $3 = ($2 == $2) & (0.0 == 0.0);
  if (!($3)) {
   _luaG_runerror($L,3696,$vararg_buffer1);
   // unreachable;
  }
  $4 = (+Math_floor((+$2)));
  $5 = $4 == $2;
  if ($5) {
   $6 = $2 >= -9.2233720368547758E+18;
   $7 = $2 < 9.2233720368547758E+18;
   $or$cond$i = $6 & $7;
   if ($or$cond$i) {
    $8 = (~~$2)>>>0;
    $9 = +Math_abs($2) >= 1.0 ? $2 > 0.0 ? (~~+Math_min(+Math_floor($2 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($2 - +(~~$2 >>> 0)) / 4294967296.0) >>> 0 : 0;
    $10 = $aux;
    $11 = $10;
    HEAP32[$11>>2] = $8;
    $12 = (($10) + 4)|0;
    $13 = $12;
    HEAP32[$13>>2] = $9;
    $14 = ((($aux)) + 8|0);
    HEAP32[$14>>2] = 19;
    $$02 = $aux;
   } else {
    $$02 = $key;
   }
  } else {
   $$02 = $key;
  }
 }
 $15 = (_mainposition($t,$$02)|0);
 $16 = ((($15)) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)!=(0);
 $19 = ($15|0)==(3624|0);
 $or$cond = $19 | $18;
 do {
  if ($or$cond) {
   $20 = ((($t)) + 20|0);
   $21 = ((($t)) + 16|0);
   $22 = HEAP32[$21>>2]|0;
   $$pre$i = HEAP32[$20>>2]|0;
   $24 = $$pre$i;
   while(1) {
    $23 = ($24>>>0)>($22>>>0);
    if (!($23)) {
     break;
    }
    $25 = ((($24)) + -32|0);
    HEAP32[$20>>2] = $25;
    $26 = ((($24)) + -8|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==(0);
    if ($28) {
     $$lcssa48 = $24;$$lcssa49 = $25;
     label = 37;
     break;
    } else {
     $24 = $25;
    }
   }
   if ((label|0) == 37) {
    $130 = ((($15)) + 16|0);
    $131 = (_mainposition($t,$130)|0);
    $132 = ($131|0)==($15|0);
    if ($132) {
     $150 = ((($15)) + 28|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = ($151|0)==(0);
     if ($152) {
      $$pre = $$lcssa49;
      $$pre$phiZ2D = $$pre;
     } else {
      $153 = (($15) + ($151<<5)|0);
      $154 = $153;
      $155 = $$lcssa49;
      $156 = (($154) - ($155))|0;
      $157 = $156 >> 5;
      $158 = ((($$lcssa48)) + -4|0);
      HEAP32[$158>>2] = $157;
      $$pre$phiZ2D = $155;
     }
     $159 = $15;
     $160 = (($$pre$phiZ2D) - ($159))|0;
     $161 = $160 >> 5;
     HEAP32[$150>>2] = $161;
     $mp$0 = $$lcssa49;
     break;
    } else {
     $othern$0 = $131;
     while(1) {
      $133 = ((($othern$0)) + 28|0);
      $134 = HEAP32[$133>>2]|0;
      $135 = (($othern$0) + ($134<<5)|0);
      $136 = ($135|0)==($15|0);
      if ($136) {
       $$lcssa = $133;$othern$0$lcssa = $othern$0;
       break;
      } else {
       $othern$0 = $135;
      }
     }
     $137 = $$lcssa49;
     $138 = $othern$0$lcssa;
     $139 = (($137) - ($138))|0;
     $140 = $139 >> 5;
     HEAP32[$$lcssa>>2] = $140;
     ;HEAP32[$$lcssa49>>2]=HEAP32[$15>>2]|0;HEAP32[$$lcssa49+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$$lcssa49+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$$lcssa49+12>>2]=HEAP32[$15+12>>2]|0;HEAP32[$$lcssa49+16>>2]=HEAP32[$15+16>>2]|0;HEAP32[$$lcssa49+20>>2]=HEAP32[$15+20>>2]|0;HEAP32[$$lcssa49+24>>2]=HEAP32[$15+24>>2]|0;HEAP32[$$lcssa49+28>>2]=HEAP32[$15+28>>2]|0;
     $141 = ((($15)) + 28|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = ($142|0)==(0);
     if (!($143)) {
      $144 = $15;
      $145 = (($144) - ($137))|0;
      $146 = $145 >> 5;
      $147 = ((($$lcssa48)) + -4|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = (($148) + ($146))|0;
      HEAP32[$147>>2] = $149;
      HEAP32[$141>>2] = 0;
     }
     HEAP32[$16>>2] = 0;
     $mp$0 = $15;
     break;
    }
   }
   dest=$nums$i; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $29 = ((($t)) + 8|0);
   $30 = ((($t)) + 12|0);
   $31 = HEAP32[$29>>2]|0;
   $ause$06$i$i = 0;$i$07$i$i = 1;$lg$04$i$i = 0;$ttlg$05$i$i = 1;
   while(1) {
    $32 = ($ttlg$05$i$i>>>0)>($31>>>0);
    if ($32) {
     $33 = ($i$07$i$i>>>0)>($31>>>0);
     if ($33) {
      $ause$0$lcssa$i$i = $ause$06$i$i;
      break;
     } else {
      $lim$0$ph$i$i = $31;
     }
    } else {
     $lim$0$ph$i$i = $ttlg$05$i$i;
    }
    $34 = ($i$07$i$i>>>0)>($lim$0$ph$i$i>>>0);
    if ($34) {
     $i$1$lcssa$i$i = $i$07$i$i;$lc$0$lcssa$i$i = 0;
    } else {
     $35 = HEAP32[$30>>2]|0;
     $i$11$i$i = $i$07$i$i;$lc$02$i$i = 0;
     while(1) {
      $36 = (($i$11$i$i) + -1)|0;
      $37 = (((($35) + ($36<<4)|0)) + 8|0);
      $38 = HEAP32[$37>>2]|0;
      $not$$i$i = ($38|0)!=(0);
      $39 = $not$$i$i&1;
      $lc$0$$i$i = (($39) + ($lc$02$i$i))|0;
      $40 = (($i$11$i$i) + 1)|0;
      $41 = ($40>>>0)>($lim$0$ph$i$i>>>0);
      if ($41) {
       $i$1$lcssa$i$i = $40;$lc$0$lcssa$i$i = $lc$0$$i$i;
       break;
      } else {
       $i$11$i$i = $40;$lc$02$i$i = $lc$0$$i$i;
      }
     }
    }
    $42 = (($nums$i) + ($lg$04$i$i<<2)|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + ($lc$0$lcssa$i$i))|0;
    HEAP32[$42>>2] = $44;
    $45 = (($lc$0$lcssa$i$i) + ($ause$06$i$i))|0;
    $46 = (($lg$04$i$i) + 1)|0;
    $47 = $ttlg$05$i$i << 1;
    $48 = ($46|0)<(32);
    if ($48) {
     $ause$06$i$i = $45;$i$07$i$i = $i$1$lcssa$i$i;$lg$04$i$i = $46;$ttlg$05$i$i = $47;
    } else {
     $ause$0$lcssa$i$i = $45;
     break;
    }
   }
   $49 = ((($t)) + 7|0);
   $50 = HEAP8[$49>>0]|0;
   $51 = $50&255;
   $52 = 1 << $51;
   $ause$0$ph$i$i = 0;$i$0$ph$i$i = $52;$totaluse$0$ph$i$i = 0;
   L42: while(1) {
    $i$0$i$i = $i$0$ph$i$i;
    while(1) {
     $53 = (($i$0$i$i) + -1)|0;
     $54 = ($i$0$i$i|0)==(0);
     if ($54) {
      $ause$0$ph$i$i$lcssa = $ause$0$ph$i$i;$totaluse$0$ph$i$i$lcssa = $totaluse$0$ph$i$i;
      break L42;
     }
     $55 = HEAP32[$21>>2]|0;
     $56 = (((($55) + ($53<<5)|0)) + 8|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0);
     if ($58) {
      $i$0$i$i = $53;
     } else {
      $$lcssa44 = $53;$$lcssa45 = $55;
      break;
     }
    }
    $59 = (((($$lcssa45) + ($$lcssa44<<5)|0)) + 24|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60|0)==(19);
    if ($61) {
     $62 = (((($$lcssa45) + ($$lcssa44<<5)|0)) + 16|0);
     $63 = $62;
     $64 = $63;
     $65 = HEAP32[$64>>2]|0;
     $66 = (($63) + 4)|0;
     $67 = $66;
     $68 = HEAP32[$67>>2]|0;
     $69 = ($68|0)<(0);
     $70 = ($65>>>0)<(1);
     $71 = ($68|0)==(0);
     $72 = $71 & $70;
     $73 = $69 | $72;
     $74 = ($68>>>0)>(0);
     $75 = ($65>>>0)>(2147483648);
     $76 = ($68|0)==(0);
     $77 = $76 & $75;
     $78 = $74 | $77;
     $or$cond$i$not$i$i$i = $78 | $73;
     $79 = ($65|0)==(0);
     $or$cond$i$i$i = $or$cond$i$not$i$i$i | $79;
     if ($or$cond$i$i$i) {
      $$0$i$i$i = 0;
     } else {
      $80 = (_luaO_ceillog2($65)|0);
      $81 = (($nums$i) + ($80<<2)|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($82) + 1)|0;
      HEAP32[$81>>2] = $83;
      $$0$i$i$i = 1;
     }
    } else {
     $$0$i$i$i = 0;
    }
    $84 = (($$0$i$i$i) + ($ause$0$ph$i$i))|0;
    $85 = (($totaluse$0$ph$i$i) + 1)|0;
    $ause$0$ph$i$i = $84;$i$0$ph$i$i = $$lcssa44;$totaluse$0$ph$i$i = $85;
   }
   $86 = (($ause$0$ph$i$i$lcssa) + ($ause$0$lcssa$i$i))|0;
   $87 = ((($$02)) + 8|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88|0)==(19);
   if ($89) {
    $90 = $$02;
    $91 = $90;
    $92 = HEAP32[$91>>2]|0;
    $93 = (($90) + 4)|0;
    $94 = $93;
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)<(0);
    $97 = ($92>>>0)<(1);
    $98 = ($95|0)==(0);
    $99 = $98 & $97;
    $100 = $96 | $99;
    $101 = ($95>>>0)>(0);
    $102 = ($92>>>0)>(2147483648);
    $103 = ($95|0)==(0);
    $104 = $103 & $102;
    $105 = $101 | $104;
    $or$cond$i$not$i$i = $105 | $100;
    $106 = ($92|0)==(0);
    $or$cond$i$i = $or$cond$i$not$i$i | $106;
    if ($or$cond$i$i) {
     $$0$i$i = 0;
    } else {
     $107 = (_luaO_ceillog2($92)|0);
     $108 = (($nums$i) + ($107<<2)|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = (($109) + 1)|0;
     HEAP32[$108>>2] = $110;
     $$0$i$i = 1;
    }
   } else {
    $$0$i$i = 0;
   }
   $111 = (($86) + ($$0$i$i))|0;
   $112 = ($111|0)==(0);
   L57: do {
    if ($112) {
     $n$2$i$i = 0;$na$2$i$i = 0;
    } else {
     $118 = 0;$a$03$i$i = 0;$i$01$i$i = 0;$n$05$i$i = 0;$na$04$i$i = 0;$twotoi$02$i$i = 1;
     while(1) {
      $113 = (($nums$i) + ($i$01$i$i<<2)|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = ($114|0)==(0);
      if ($115) {
       $a$1$i$i = $a$03$i$i;$n$1$i$i = $n$05$i$i;$na$1$i$i = $na$04$i$i;
      } else {
       $116 = (($114) + ($a$03$i$i))|0;
       $117 = ($116>>>0)>($118>>>0);
       $$na$0$i$i = $117 ? $116 : $na$04$i$i;
       $twotoi$0$n$0$i$i = $117 ? $twotoi$02$i$i : $n$05$i$i;
       $a$1$i$i = $116;$n$1$i$i = $twotoi$0$n$0$i$i;$na$1$i$i = $$na$0$i$i;
      }
      $119 = ($a$1$i$i|0)==($111|0);
      if ($119) {
       $n$2$i$i = $n$1$i$i;$na$2$i$i = $na$1$i$i;
       break L57;
      }
      $120 = (($i$01$i$i) + 1)|0;
      $121 = $twotoi$02$i$i << 1;
      $122 = $twotoi$02$i$i & 2147483647;
      $123 = ($122>>>0)<($111>>>0);
      if ($123) {
       $118 = $122;$a$03$i$i = $a$1$i$i;$i$01$i$i = $120;$n$05$i$i = $n$1$i$i;$na$04$i$i = $na$1$i$i;$twotoi$02$i$i = $121;
      } else {
       $n$2$i$i = $n$1$i$i;$na$2$i$i = $na$1$i$i;
       break;
      }
     }
    }
   } while(0);
   $124 = (($ause$0$lcssa$i$i) + 1)|0;
   $125 = (($124) + ($totaluse$0$ph$i$i$lcssa))|0;
   $126 = (($125) - ($na$2$i$i))|0;
   _luaH_resize($L,$t,$n$2$i$i,$126);
   $127 = (_luaH_get($t,$$02)|0);
   $128 = ($127|0)==(1760|0);
   if (!($128)) {
    $$0 = $127;
    STACKTOP = sp;return ($$0|0);
   }
   $129 = (_luaH_newkey($L,$t,$$02)|0);
   $$0 = $129;
   STACKTOP = sp;return ($$0|0);
  } else {
   $mp$0 = $15;
  }
 } while(0);
 $162 = ((($mp$0)) + 16|0);
 $163 = $$02;
 $164 = $163;
 $165 = HEAP32[$164>>2]|0;
 $166 = (($163) + 4)|0;
 $167 = $166;
 $168 = HEAP32[$167>>2]|0;
 $169 = $162;
 $170 = $169;
 HEAP32[$170>>2] = $165;
 $171 = (($169) + 4)|0;
 $172 = $171;
 HEAP32[$172>>2] = $168;
 $173 = ((($$02)) + 8|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = ((($mp$0)) + 24|0);
 HEAP32[$175>>2] = $174;
 $176 = $174 & 64;
 $177 = ($176|0)==(0);
 if (!($177)) {
  $178 = ((($t)) + 5|0);
  $179 = HEAP8[$178>>0]|0;
  $180 = $179 & 4;
  $181 = ($180<<24>>24)==(0);
  if (!($181)) {
   $182 = HEAP32[$$02>>2]|0;
   $183 = ((($182)) + 5|0);
   $184 = HEAP8[$183>>0]|0;
   $185 = $184 & 3;
   $186 = ($185<<24>>24)==(0);
   if (!($186)) {
    _luaC_barrierback_($L,$t);
   }
  }
 }
 $$0 = $mp$0;
 STACKTOP = sp;return ($$0|0);
}
function _luaH_getint($t,$0,$1) {
 $t = $t|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$0 = 0;
 var $n$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_i64Add(($0|0),($1|0),-1,-1)|0);
 $3 = tempRet0;
 $4 = ((($t)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<(0);
 $7 = ($2>>>0)<($5>>>0);
 $8 = ($3|0)==(0);
 $9 = $8 & $7;
 $10 = $6 | $9;
 if ($10) {
  $11 = ((($t)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($2<<4)|0);
  $$0 = $13;
  return ($$0|0);
 }
 $14 = ((($t)) + 7|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15&255;
 $17 = 1 << $16;
 $18 = (($17) + -1)|0;
 $19 = $18 & $0;
 $20 = ((($t)) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19<<5)|0);
 $n$0 = $22;
 while(1) {
  $23 = ((($n$0)) + 24|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(19);
  if ($25) {
   $26 = ((($n$0)) + 16|0);
   $27 = $26;
   $28 = $27;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($27) + 4)|0;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = ($29|0)==($0|0);
   $34 = ($32|0)==($1|0);
   $35 = $33 & $34;
   if ($35) {
    $n$0$lcssa = $n$0;
    break;
   }
  }
  $36 = ((($n$0)) + 28|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0);
  if ($38) {
   $$0 = 1760;
   label = 9;
   break;
  }
  $39 = (($n$0) + ($37<<5)|0);
  $n$0 = $39;
 }
 if ((label|0) == 9) {
  return ($$0|0);
 }
 $$0 = $n$0$lcssa;
 return ($$0|0);
}
function _luaH_getstr($t,$key) {
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $n$0 = 0, $n$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($key)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($t)) + 7|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = 1 << $4;
 $6 = (($5) + -1)|0;
 $7 = $6 & $1;
 $8 = ((($t)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7<<5)|0);
 $n$0 = $10;
 while(1) {
  $11 = ((($n$0)) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(68);
  if ($13) {
   $14 = ((($n$0)) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==($key|0);
   if ($16) {
    $n$0$lcssa = $n$0;
    break;
   }
  }
  $17 = ((($n$0)) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0 = 1760;
   label = 7;
   break;
  }
  $20 = (($n$0) + ($18<<5)|0);
  $n$0 = $20;
 }
 if ((label|0) == 7) {
  return ($$0|0);
 }
 $$0 = $n$0$lcssa;
 return ($$0|0);
}
function _luaH_get($t,$key) {
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $n$0$i = 0, $n$0$i$lcssa = 0, $n$0$i1 = 0, $n$0$i1$lcssa = 0, $n$0$i3 = 0, $n$0$i3$lcssa = 0, $n$0$lcssa = 0, $n$014 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($key)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 63;
 if ((($2|0) == 19)) {
  $25 = $key;
  $26 = $25;
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 4)|0;
  $29 = $28;
  $30 = HEAP32[$29>>2]|0;
  $31 = (_i64Add(($27|0),($30|0),-1,-1)|0);
  $32 = tempRet0;
  $33 = ((($t)) + 8|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<(0);
  $36 = ($31>>>0)<($34>>>0);
  $37 = ($32|0)==(0);
  $38 = $37 & $36;
  $39 = $35 | $38;
  if ($39) {
   $40 = ((($t)) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + ($31<<4)|0);
   $$0 = $42;
   return ($$0|0);
  }
  $43 = ((($t)) + 7|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = 1 << $45;
  $47 = (($46) + -1)|0;
  $48 = $47 & $27;
  $49 = ((($t)) + 16|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + ($48<<5)|0);
  $n$0$i1 = $51;
  while(1) {
   $52 = ((($n$0$i1)) + 24|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(19);
   if ($54) {
    $55 = ((($n$0$i1)) + 16|0);
    $56 = $55;
    $57 = $56;
    $58 = HEAP32[$57>>2]|0;
    $59 = (($56) + 4)|0;
    $60 = $59;
    $61 = HEAP32[$60>>2]|0;
    $62 = ($58|0)==($27|0);
    $63 = ($61|0)==($30|0);
    $64 = $62 & $63;
    if ($64) {
     $n$0$i1$lcssa = $n$0$i1;
     break;
    }
   }
   $65 = ((($n$0$i1)) + 28|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0);
   if ($67) {
    $$0 = 1760;
    label = 30;
    break;
   }
   $68 = (($n$0$i1) + ($66<<5)|0);
   $n$0$i1 = $68;
  }
  if ((label|0) == 30) {
   return ($$0|0);
  }
  $$0 = $n$0$i1$lcssa;
  return ($$0|0);
 } else if ((($2|0) == 0)) {
  $$0 = 1760;
  return ($$0|0);
 } else if ((($2|0) == 3)) {
  $69 = +HEAPF64[$key>>3];
  $70 = (+Math_floor((+$69)));
  $71 = $70 == $69;
  if ($71) {
   $72 = $69 >= -9.2233720368547758E+18;
   $73 = $69 < 9.2233720368547758E+18;
   $or$cond$i = $72 & $73;
   if ($or$cond$i) {
    $74 = (~~$69)>>>0;
    $75 = +Math_abs($69) >= 1.0 ? $69 > 0.0 ? (~~+Math_min(+Math_floor($69 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($69 - +(~~$69 >>> 0)) / 4294967296.0) >>> 0 : 0;
    $76 = (_i64Add(($74|0),($75|0),-1,-1)|0);
    $77 = tempRet0;
    $78 = ((($t)) + 8|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($77>>>0)<(0);
    $81 = ($76>>>0)<($79>>>0);
    $82 = ($77|0)==(0);
    $83 = $82 & $81;
    $84 = $80 | $83;
    if ($84) {
     $85 = ((($t)) + 12|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = (($86) + ($76<<4)|0);
     $$0 = $87;
     return ($$0|0);
    }
    $88 = ((($t)) + 7|0);
    $89 = HEAP8[$88>>0]|0;
    $90 = $89&255;
    $91 = 1 << $90;
    $92 = (($91) + -1)|0;
    $93 = $92 & $74;
    $94 = ((($t)) + 16|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (($95) + ($93<<5)|0);
    $n$0$i3 = $96;
    while(1) {
     $97 = ((($n$0$i3)) + 24|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = ($98|0)==(19);
     if ($99) {
      $100 = ((($n$0$i3)) + 16|0);
      $101 = $100;
      $102 = $101;
      $103 = HEAP32[$102>>2]|0;
      $104 = (($101) + 4)|0;
      $105 = $104;
      $106 = HEAP32[$105>>2]|0;
      $107 = ($103|0)==($74|0);
      $108 = ($106|0)==($75|0);
      $109 = $107 & $108;
      if ($109) {
       $n$0$i3$lcssa = $n$0$i3;
       break;
      }
     }
     $110 = ((($n$0$i3)) + 28|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = ($111|0)==(0);
     if ($112) {
      $$0 = 1760;
      label = 30;
      break;
     }
     $113 = (($n$0$i3) + ($111<<5)|0);
     $n$0$i3 = $113;
    }
    if ((label|0) == 30) {
     return ($$0|0);
    }
    $$0 = $n$0$i3$lcssa;
    return ($$0|0);
   }
  }
 } else if ((($2|0) == 4)) {
  $3 = HEAP32[$key>>2]|0;
  $4 = ((($3)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($t)) + 7|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7&255;
  $9 = 1 << $8;
  $10 = (($9) + -1)|0;
  $11 = $10 & $5;
  $12 = ((($t)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($11<<5)|0);
  $n$0$i = $14;
  while(1) {
   $15 = ((($n$0$i)) + 24|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(68);
   if ($17) {
    $18 = ((($n$0$i)) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==($3|0);
    if ($20) {
     $n$0$i$lcssa = $n$0$i;
     break;
    }
   }
   $21 = ((($n$0$i)) + 28|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $$0 = 1760;
    label = 30;
    break;
   }
   $24 = (($n$0$i) + ($22<<5)|0);
   $n$0$i = $24;
  }
  if ((label|0) == 30) {
   return ($$0|0);
  }
  $$0 = $n$0$i$lcssa;
  return ($$0|0);
 }
 $114 = (_mainposition($t,$key)|0);
 $115 = ((($114)) + 16|0);
 $116 = (_luaV_equalobj(0,$115,$key)|0);
 $117 = ($116|0)==(0);
 L47: do {
  if ($117) {
   $n$014 = $114;
   while(1) {
    $118 = ((($n$014)) + 28|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = ($119|0)==(0);
    if ($120) {
     $$0 = 1760;
     break;
    }
    $121 = (($n$014) + ($119<<5)|0);
    $122 = (((($n$014) + ($119<<5)|0)) + 16|0);
    $123 = (_luaV_equalobj(0,$122,$key)|0);
    $124 = ($123|0)==(0);
    if ($124) {
     $n$014 = $121;
    } else {
     $n$0$lcssa = $121;
     break L47;
    }
   }
   return ($$0|0);
  } else {
   $n$0$lcssa = $114;
  }
 } while(0);
 $$0 = $n$0$lcssa;
 return ($$0|0);
}
function _luaH_getn($t) {
 $t = $t|0;
 var $$$1$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i3$i = 0, $$0$i6$i = 0, $$01$i = 0, $$01$i$lcssa = 0, $$115$i = 0, $$j$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$0$ = 0, $i$0$i = 0, $i$0$i$lcssa = 0, $i$0$i$phi = 0, $i$08 = 0, $i$1$i = 0, $i$1$i$lcssa = 0, $i$2$$i = 0, $i$216$i = 0, $j$07 = 0, $n$0$i$i = 0, $n$0$i$i$lcssa = 0;
 var $n$0$i2$i = 0, $n$0$i2$i$lcssa = 0, $n$0$i5$i = 0, $n$0$i5$i$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($t)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($1) + -1)|0;
  $4 = ((($t)) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (((($5) + ($3<<4)|0)) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = ($1>>>0)>(1);
   if ($9) {
    $i$08 = 0;$j$07 = $1;
   } else {
    $$0 = 0;
    return ($$0|0);
   }
   while(1) {
    $10 = (($i$08) + ($j$07))|0;
    $11 = $10 >>> 1;
    $12 = (($11) + -1)|0;
    $13 = (((($5) + ($12<<4)|0)) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0);
    $$j$0 = $15 ? $11 : $j$07;
    $i$0$ = $15 ? $i$08 : $11;
    $16 = (($$j$0) - ($i$0$))|0;
    $17 = ($16>>>0)>(1);
    if ($17) {
     $i$08 = $i$0$;$j$07 = $$j$0;
    } else {
     $$0 = $i$0$;
     break;
    }
   }
   return ($$0|0);
  }
 }
 $18 = ((($t)) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(3624|0);
 if ($20) {
  $$0 = $1;
  return ($$0|0);
 }
 $21 = (($1) + 1)|0;
 $22 = ((($t)) + 12|0);
 $23 = ((($t)) + 7|0);
 $$01$i = $21;$i$0$i = $1;
 while(1) {
  $24 = (_i64Add(($$01$i|0),0,-1,-1)|0);
  $25 = tempRet0;
  $26 = ($25>>>0)<(0);
  $27 = ($24>>>0)<($1>>>0);
  $28 = ($25|0)==(0);
  $29 = $28 & $27;
  $30 = $26 | $29;
  L15: do {
   if ($30) {
    $31 = HEAP32[$22>>2]|0;
    $32 = (($31) + ($24<<4)|0);
    $$0$i$i = $32;
   } else {
    $33 = HEAP8[$23>>0]|0;
    $34 = $33&255;
    $35 = 1 << $34;
    $36 = (($35) + -1)|0;
    $37 = $36 & $$01$i;
    $38 = (($19) + ($37<<5)|0);
    $n$0$i$i = $38;
    while(1) {
     $39 = ((($n$0$i$i)) + 24|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==(19);
     if ($41) {
      $42 = ((($n$0$i$i)) + 16|0);
      $43 = $42;
      $44 = $43;
      $45 = HEAP32[$44>>2]|0;
      $46 = (($43) + 4)|0;
      $47 = $46;
      $48 = HEAP32[$47>>2]|0;
      $49 = ($45|0)==($$01$i|0);
      $50 = ($48|0)==(0);
      $51 = $49 & $50;
      if ($51) {
       $n$0$i$i$lcssa = $n$0$i$i;
       break;
      }
     }
     $52 = ((($n$0$i$i)) + 28|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)==(0);
     if ($54) {
      $$0$i$i = 1760;
      break L15;
     }
     $55 = (($n$0$i$i) + ($53<<5)|0);
     $n$0$i$i = $55;
    }
    $$0$i$i = $n$0$i$i$lcssa;
   }
  } while(0);
  $56 = ((($$0$i$i)) + 8|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0);
  if ($58) {
   $$01$i$lcssa = $$01$i;$i$0$i$lcssa = $i$0$i;
   break;
  }
  $61 = ($$01$i>>>0)>(1073741823);
  if ($61) {
   $i$1$i = 1;
   label = 18;
   break;
  }
  $99 = $$01$i << 1;
  $i$0$i$phi = $$01$i;$$01$i = $99;$i$0$i = $i$0$i$phi;
 }
 if ((label|0) == 18) {
  while(1) {
   label = 0;
   $62 = (_i64Add(($i$1$i|0),0,-1,-1)|0);
   $63 = tempRet0;
   $64 = ($63>>>0)<(0);
   $65 = ($62>>>0)<($1>>>0);
   $66 = ($63|0)==(0);
   $67 = $66 & $65;
   $68 = $64 | $67;
   L31: do {
    if ($68) {
     $69 = HEAP32[$22>>2]|0;
     $70 = (($69) + ($62<<4)|0);
     $$0$i6$i = $70;
    } else {
     $71 = HEAP8[$23>>0]|0;
     $72 = $71&255;
     $73 = 1 << $72;
     $74 = (($73) + -1)|0;
     $75 = $74 & $i$1$i;
     $76 = (($19) + ($75<<5)|0);
     $n$0$i5$i = $76;
     while(1) {
      $77 = ((($n$0$i5$i)) + 24|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = ($78|0)==(19);
      if ($79) {
       $80 = ((($n$0$i5$i)) + 16|0);
       $81 = $80;
       $82 = $81;
       $83 = HEAP32[$82>>2]|0;
       $84 = (($81) + 4)|0;
       $85 = $84;
       $86 = HEAP32[$85>>2]|0;
       $87 = ($83|0)==($i$1$i|0);
       $88 = ($86|0)==(0);
       $89 = $87 & $88;
       if ($89) {
        $n$0$i5$i$lcssa = $n$0$i5$i;
        break;
       }
      }
      $90 = ((($n$0$i5$i)) + 28|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = ($91|0)==(0);
      if ($92) {
       $$0$i6$i = 1760;
       break L31;
      }
      $93 = (($n$0$i5$i) + ($91<<5)|0);
      $n$0$i5$i = $93;
     }
     $$0$i6$i = $n$0$i5$i$lcssa;
    }
   } while(0);
   $94 = ((($$0$i6$i)) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($95|0)==(0);
   $97 = (($i$1$i) + 1)|0;
   if ($96) {
    $i$1$i$lcssa = $i$1$i;
    break;
   } else {
    $i$1$i = $97;
    label = 18;
   }
  }
  $98 = (($i$1$i$lcssa) + -1)|0;
  $$0 = $98;
  return ($$0|0);
 }
 $59 = (($$01$i$lcssa) - ($i$0$i$lcssa))|0;
 $60 = ($59>>>0)>(1);
 if ($60) {
  $$115$i = $$01$i$lcssa;$i$216$i = $i$0$i$lcssa;
 } else {
  $$0 = $i$0$i$lcssa;
  return ($$0|0);
 }
 while(1) {
  $100 = (($$115$i) + ($i$216$i))|0;
  $101 = $100 >>> 1;
  $102 = (_i64Add(($101|0),0,-1,-1)|0);
  $103 = tempRet0;
  $104 = ($103>>>0)<(0);
  $105 = ($102>>>0)<($1>>>0);
  $106 = ($103|0)==(0);
  $107 = $106 & $105;
  $108 = $104 | $107;
  L49: do {
   if ($108) {
    $109 = HEAP32[$22>>2]|0;
    $110 = (($109) + ($102<<4)|0);
    $$0$i3$i = $110;
   } else {
    $111 = HEAP8[$23>>0]|0;
    $112 = $111&255;
    $113 = 1 << $112;
    $114 = (($113) + 2147483647)|0;
    $115 = $114 & $101;
    $116 = (($19) + ($115<<5)|0);
    $n$0$i2$i = $116;
    while(1) {
     $117 = ((($n$0$i2$i)) + 24|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = ($118|0)==(19);
     if ($119) {
      $120 = ((($n$0$i2$i)) + 16|0);
      $121 = $120;
      $122 = $121;
      $123 = HEAP32[$122>>2]|0;
      $124 = (($121) + 4)|0;
      $125 = $124;
      $126 = HEAP32[$125>>2]|0;
      $127 = ($123|0)==($101|0);
      $128 = ($126|0)==(0);
      $129 = $127 & $128;
      if ($129) {
       $n$0$i2$i$lcssa = $n$0$i2$i;
       break;
      }
     }
     $130 = ((($n$0$i2$i)) + 28|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ($131|0)==(0);
     if ($132) {
      $$0$i3$i = 1760;
      break L49;
     }
     $133 = (($n$0$i2$i) + ($131<<5)|0);
     $n$0$i2$i = $133;
    }
    $$0$i3$i = $n$0$i2$i$lcssa;
   }
  } while(0);
  $134 = ((($$0$i3$i)) + 8|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ($135|0)==(0);
  $$$1$i = $136 ? $101 : $$115$i;
  $i$2$$i = $136 ? $i$216$i : $101;
  $137 = (($$$1$i) - ($i$2$$i))|0;
  $138 = ($137>>>0)>(1);
  if ($138) {
   $$115$i = $$$1$i;$i$216$i = $i$2$$i;
  } else {
   $$0 = $i$2$$i;
   break;
  }
 }
 return ($$0|0);
}
function _mainposition($t,$key) {
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $i$i = sp;
 $0 = ((($key)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 63;
 switch ($2|0) {
 case 4:  {
  $40 = HEAP32[$key>>2]|0;
  $41 = ((($40)) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($t)) + 7|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = 1 << $45;
  $47 = (($46) + -1)|0;
  $48 = $47 & $42;
  $49 = ((($t)) + 16|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + ($48<<5)|0);
  $$0 = $51;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 19:  {
  $3 = $key;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($t)) + 7|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = 1 << $11;
  $13 = (($12) + -1)|0;
  $14 = $13 & $5;
  $15 = ((($t)) + 16|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + ($14<<5)|0);
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 22:  {
  $96 = HEAP32[$key>>2]|0;
  $97 = $96;
  $98 = ((($t)) + 7|0);
  $99 = HEAP8[$98>>0]|0;
  $100 = $99&255;
  $101 = 1 << $100;
  $102 = (($101) + -1)|0;
  $103 = $102 | 1;
  $104 = (($97>>>0) % ($103>>>0))&-1;
  $105 = ((($t)) + 16|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($106) + ($104<<5)|0);
  $$0 = $107;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 20:  {
  $52 = HEAP32[$key>>2]|0;
  $53 = ((($52)) + 6|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = ($54<<24>>24)==(0);
  if ($55) {
   $56 = ((($52)) + 24|0);
   $57 = ((($52)) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ((($52)) + 8|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (_luaS_hash($56,$58,$60)|0);
   HEAP32[$59>>2] = $61;
   HEAP8[$53>>0] = 1;
   $$pre = HEAP32[$key>>2]|0;
   $63 = $$pre;
  } else {
   $63 = $52;
  }
  $62 = ((($63)) + 8|0);
  $64 = HEAP32[$62>>2]|0;
  $65 = ((($t)) + 7|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = $66&255;
  $68 = 1 << $67;
  $69 = (($68) + -1)|0;
  $70 = $69 & $64;
  $71 = ((($t)) + 16|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($72) + ($70<<5)|0);
  $$0 = $73;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $18 = +HEAPF64[$key>>3];
  $19 = (+_frexp($18,$i$i));
  $20 = $19 * 2147482623.0;
  $21 = (~~(($20)));
  $22 = HEAP32[$i$i>>2]|0;
  $23 = (($21) + ($22))|0;
  HEAP32[$i$i>>2] = $23;
  $24 = ($23|0)<(0);
  if ($24) {
   $25 = (0 - ($23))|0;
   $26 = ($23|0)==($25|0);
   if ($26) {
    HEAP32[$i$i>>2] = 0;
    $28 = 0;
   } else {
    $28 = $23;
   }
   $27 = (0 - ($28))|0;
   HEAP32[$i$i>>2] = $27;
   $36 = $27;
  } else {
   $36 = $23;
  }
  $29 = ((($t)) + 7|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = 1 << $31;
  $33 = (($32) + -1)|0;
  $34 = $33 | 1;
  $35 = (($36|0) % ($34|0))&-1;
  $37 = ((($t)) + 16|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($35<<5)|0);
  $$0 = $39;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1:  {
  $74 = HEAP32[$key>>2]|0;
  $75 = ((($t)) + 7|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = $76&255;
  $78 = 1 << $77;
  $79 = (($78) + -1)|0;
  $80 = $79 & $74;
  $81 = ((($t)) + 16|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (($82) + ($80<<5)|0);
  $$0 = $83;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $84 = HEAP32[$key>>2]|0;
  $85 = $84;
  $86 = ((($t)) + 7|0);
  $87 = HEAP8[$86>>0]|0;
  $88 = $87&255;
  $89 = 1 << $88;
  $90 = (($89) + -1)|0;
  $91 = $90 | 1;
  $92 = (($85>>>0) % ($91>>>0))&-1;
  $93 = ((($t)) + 16|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (($94) + ($92<<5)|0);
  $$0 = $95;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $108 = HEAP32[$key>>2]|0;
  $109 = $108;
  $110 = ((($t)) + 7|0);
  $111 = HEAP8[$110>>0]|0;
  $112 = $111&255;
  $113 = 1 << $112;
  $114 = (($113) + -1)|0;
  $115 = $114 | 1;
  $116 = (($109>>>0) % ($115>>>0))&-1;
  $117 = ((($t)) + 16|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (($118) + ($116<<5)|0);
  $$0 = $119;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return (0)|0;
}
function _luaT_init($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $i$01 = 0;
 while(1) {
  $1 = (3768 + ($i$01<<2)|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (_luaS_new($L,$2)|0);
  $4 = HEAP32[$0>>2]|0;
  $5 = (((($4)) + 148|0) + ($i$01<<2)|0);
  HEAP32[$5>>2] = $3;
  $6 = HEAP32[$0>>2]|0;
  $7 = (((($6)) + 148|0) + ($i$01<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  _luaC_fix($L,$8);
  $9 = (($i$01) + 1)|0;
  $exitcond = ($9|0)==(24);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $9;
  }
 }
 return;
}
function _luaT_gettm($events,$event,$ename) {
 $events = $events|0;
 $event = $event|0;
 $ename = $ename|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaH_getstr($events,$ename)|0);
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $0;
  return ($$0|0);
 }
 $4 = 1 << $event;
 $5 = ((($events)) + 6|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $$0 = 0;
 return ($$0|0);
}
function _luaT_gettmbyobj($L,$o,$event) {
 $L = $L|0;
 $o = $o|0;
 $event = $event|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mt$0 = 0, $mt$0$in = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ((($o)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 if ((($2|0) == 5)) {
  $3 = HEAP32[$o>>2]|0;
  $4 = ((($3)) + 24|0);
  $mt$0$in = $4;
 } else if ((($2|0) == 7)) {
  $5 = HEAP32[$o>>2]|0;
  $6 = ((($5)) + 8|0);
  $mt$0$in = $6;
 } else {
  $7 = ((($L)) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (((($8)) + 244|0) + ($2<<2)|0);
  $mt$0$in = $9;
 }
 $mt$0 = HEAP32[$mt$0$in>>2]|0;
 $10 = ($mt$0|0)==(0|0);
 if ($10) {
  $16 = 1760;
  return ($16|0);
 }
 $11 = ((($L)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (((($12)) + 148|0) + ($event<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (_luaH_getstr($mt$0,$14)|0);
 $16 = $15;
 return ($16|0);
}
function _luaT_callTM($L,$f,$p1,$p2,$p3,$hasres) {
 $L = $L|0;
 $f = $f|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $hasres = $hasres|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 16|0);
 HEAP32[$2>>2] = $4;
 ;HEAP32[$3>>2]=HEAP32[$f>>2]|0;HEAP32[$3+4>>2]=HEAP32[$f+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$f+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$f+12>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($5)) + 16|0);
 HEAP32[$2>>2] = $6;
 ;HEAP32[$5>>2]=HEAP32[$p1>>2]|0;HEAP32[$5+4>>2]=HEAP32[$p1+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$p1+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$p1+12>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 $8 = ((($7)) + 16|0);
 HEAP32[$2>>2] = $8;
 ;HEAP32[$7>>2]=HEAP32[$p2>>2]|0;HEAP32[$7+4>>2]=HEAP32[$p2+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$p2+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$p2+12>>2]|0;
 $9 = ($hasres|0)==(0);
 if ($9) {
  $10 = HEAP32[$2>>2]|0;
  $11 = ((($10)) + 16|0);
  HEAP32[$2>>2] = $11;
  ;HEAP32[$10>>2]=HEAP32[$p3>>2]|0;HEAP32[$10+4>>2]=HEAP32[$p3+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$p3+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$p3+12>>2]|0;
  $12 = HEAP32[$2>>2]|0;
  $13 = ((($12)) + -64|0);
  $14 = ((($L)) + 16|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($15)) + 34|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $18 & 2;
  _luaD_call($L,$13,0,$19);
  return;
 } else {
  $20 = $p3;
  $21 = $1;
  $22 = (($20) - ($21))|0;
  $23 = HEAP32[$2>>2]|0;
  $24 = (($hasres) + -4)|0;
  $25 = (($23) + ($24<<4)|0);
  $26 = ((($L)) + 16|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($27)) + 34|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = $30 & 2;
  _luaD_call($L,$25,$hasres,$31);
  $32 = HEAP32[$0>>2]|0;
  $33 = (($32) + ($22)|0);
  $34 = HEAP32[$2>>2]|0;
  $35 = ((($34)) + -16|0);
  HEAP32[$2>>2] = $35;
  ;HEAP32[$33>>2]=HEAP32[$35>>2]|0;HEAP32[$33+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$33+12>>2]=HEAP32[$35+12>>2]|0;
  return;
 }
}
function _luaT_callbinTM($L,$p1,$p2,$res,$event) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $res = $res|0;
 $event = $event|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $mt$0$i = 0, $mt$0$i2 = 0, $mt$0$in$i = 0, $mt$0$in$i1 = 0, $tm$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($p1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 if ((($2|0) == 5)) {
  $3 = HEAP32[$p1>>2]|0;
  $4 = ((($3)) + 24|0);
  $mt$0$in$i = $4;
 } else if ((($2|0) == 7)) {
  $5 = HEAP32[$p1>>2]|0;
  $6 = ((($5)) + 8|0);
  $mt$0$in$i = $6;
 } else {
  $7 = ((($L)) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (((($8)) + 244|0) + ($2<<2)|0);
  $mt$0$in$i = $9;
 }
 $mt$0$i = HEAP32[$mt$0$in$i>>2]|0;
 $10 = ($mt$0$i|0)==(0|0);
 if ($10) {
  $17 = 1760;
 } else {
  $11 = ((($L)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (((($12)) + 148|0) + ($event<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (_luaH_getstr($mt$0$i,$14)|0);
  $17 = $15;
 }
 $16 = ((($17)) + 8|0);
 $18 = HEAP32[$16>>2]|0;
 $19 = ($18|0)==(0);
 if ($19) {
  $20 = ((($p2)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 15;
  if ((($22|0) == 7)) {
   $25 = HEAP32[$p2>>2]|0;
   $26 = ((($25)) + 8|0);
   $mt$0$in$i1 = $26;
  } else if ((($22|0) == 5)) {
   $23 = HEAP32[$p2>>2]|0;
   $24 = ((($23)) + 24|0);
   $mt$0$in$i1 = $24;
  } else {
   $27 = ((($L)) + 12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (((($28)) + 244|0) + ($22<<2)|0);
   $mt$0$in$i1 = $29;
  }
  $mt$0$i2 = HEAP32[$mt$0$in$i1>>2]|0;
  $30 = ($mt$0$i2|0)==(0|0);
  if ($30) {
   $tm$0 = 1760;
  } else {
   $31 = ((($L)) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (((($32)) + 148|0) + ($event<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (_luaH_getstr($mt$0$i2,$34)|0);
   $tm$0 = $35;
  }
 } else {
  $tm$0 = $17;
 }
 $36 = ((($tm$0)) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0);
 if ($38) {
  $$0 = 0;
  return ($$0|0);
 }
 $39 = ((($L)) + 28|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($L)) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42)) + 16|0);
 HEAP32[$41>>2] = $43;
 ;HEAP32[$42>>2]=HEAP32[$tm$0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$tm$0+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$tm$0+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$tm$0+12>>2]|0;
 $44 = HEAP32[$41>>2]|0;
 $45 = ((($44)) + 16|0);
 HEAP32[$41>>2] = $45;
 ;HEAP32[$44>>2]=HEAP32[$p1>>2]|0;HEAP32[$44+4>>2]=HEAP32[$p1+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$p1+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$p1+12>>2]|0;
 $46 = HEAP32[$41>>2]|0;
 $47 = ((($46)) + 16|0);
 HEAP32[$41>>2] = $47;
 ;HEAP32[$46>>2]=HEAP32[$p2>>2]|0;HEAP32[$46+4>>2]=HEAP32[$p2+4>>2]|0;HEAP32[$46+8>>2]=HEAP32[$p2+8>>2]|0;HEAP32[$46+12>>2]=HEAP32[$p2+12>>2]|0;
 $48 = $res;
 $49 = $40;
 $50 = (($48) - ($49))|0;
 $51 = HEAP32[$41>>2]|0;
 $52 = ((($51)) + -48|0);
 $53 = ((($L)) + 16|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ((($54)) + 34|0);
 $56 = HEAP8[$55>>0]|0;
 $57 = $56&255;
 $58 = $57 & 2;
 _luaD_call($L,$52,1,$58);
 $59 = HEAP32[$39>>2]|0;
 $60 = (($59) + ($50)|0);
 $61 = HEAP32[$41>>2]|0;
 $62 = ((($61)) + -16|0);
 HEAP32[$41>>2] = $62;
 ;HEAP32[$60>>2]=HEAP32[$62>>2]|0;HEAP32[$60+4>>2]=HEAP32[$62+4>>2]|0;HEAP32[$60+8>>2]=HEAP32[$62+8>>2]|0;HEAP32[$60+12>>2]=HEAP32[$62+12>>2]|0;
 $$0 = 1;
 return ($$0|0);
}
function _luaT_trybinTM($L,$p1,$p2,$res,$event) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $res = $res|0;
 $event = $event|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dummy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $dummy = sp;
 $0 = (_luaT_callbinTM($L,$p1,$p2,$res,$event)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 switch ($event|0) {
 case 22:  {
  _luaG_concaterror($L,$p1,$p2);
  // unreachable;
  break;
 }
 case 19: case 17: case 16: case 15: case 14: case 13:  {
  $2 = ((($p1)) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(3);
  if ($4) {
   $5 = +HEAPF64[$p1>>3];
   HEAPF64[$dummy>>3] = $5;
  } else {
   $6 = (_luaV_tonumber_($p1,$dummy)|0);
   $7 = ($6|0)==(0);
   if ($7) {
    _luaG_opinterror($L,$p1,$p2,3864);
    // unreachable;
   }
  }
  $8 = ((($p2)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(3);
  if ($10) {
   $11 = +HEAPF64[$p2>>3];
   HEAPF64[$dummy>>3] = $11;
   _luaG_tointerror($L,$p1,$p2);
   // unreachable;
  }
  $12 = (_luaV_tonumber_($p2,$dummy)|0);
  $13 = ($12|0)==(0);
  if ($13) {
   _luaG_opinterror($L,$p1,$p2,3864);
   // unreachable;
  } else {
   _luaG_tointerror($L,$p1,$p2);
   // unreachable;
  }
  break;
 }
 default: {
  _luaG_opinterror($L,$p1,$p2,3896);
  // unreachable;
 }
 }
}
function _luaT_callorderTM($L,$p1,$p2,$event) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $event = $event|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaT_callbinTM($L,$p1,$p2,$1,$event)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = -1;
  return ($$0|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $11 = 0;
 } else {
  $8 = ($6|0)==(1);
  if ($8) {
   $9 = HEAP32[$4>>2]|0;
   $phitmp = ($9|0)!=(0);
   $11 = $phitmp;
  } else {
   $11 = 1;
  }
 }
 $10 = $11&1;
 $$0 = $10;
 return ($$0|0);
}
function _luaU_undump($L,$Z,$buff,$name) {
 $L = $L|0;
 $Z = $Z|0;
 $buff = $buff|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $S = 0, $buff$i$i = 0, $vararg_buffer = 0;
 var $vararg_buffer1 = 0, $vararg_buffer10 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, $x$i = 0, $x$i$i = 0, $x$i$i$i = 0, $x$i$i11$i = 0, $x$i$i14$i = 0, $x$i$i17$i = 0, $x$i$i8$i = 0, $x$i2$i = 0, $x$i20$i = 0, $x$i22$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer10 = sp + 48|0;
 $vararg_buffer7 = sp + 40|0;
 $vararg_buffer4 = sp + 32|0;
 $vararg_buffer1 = sp + 24|0;
 $vararg_buffer = sp + 16|0;
 $x$i = sp + 91|0;
 $x$i22$i = sp + 8|0;
 $x$i20$i = sp;
 $x$i$i17$i = sp + 90|0;
 $x$i$i14$i = sp + 89|0;
 $x$i$i11$i = sp + 88|0;
 $x$i$i8$i = sp + 87|0;
 $x$i$i$i = sp + 86|0;
 $x$i2$i = sp + 85|0;
 $x$i$i = sp + 84|0;
 $buff$i$i = sp + 72|0;
 $S = sp + 56|0;
 $0 = HEAP8[$name>>0]|0;
 if ((($0<<24>>24) == 61) | (($0<<24>>24) == 64)) {
  $1 = ((($name)) + 1|0);
  $2 = ((($S)) + 12|0);
  HEAP32[$2>>2] = $1;
 } else if ((($0<<24>>24) == 27)) {
  $3 = ((($S)) + 12|0);
  HEAP32[$3>>2] = 4200;
 } else {
  $4 = ((($S)) + 12|0);
  HEAP32[$4>>2] = $name;
 }
 HEAP32[$S>>2] = $L;
 $5 = ((($S)) + 4|0);
 HEAP32[$5>>2] = $Z;
 $6 = ((($S)) + 8|0);
 HEAP32[$6>>2] = $buff;
 $7 = (_luaZ_read($Z,$buff$i$i,3)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  _error($S,4216);
  // unreachable;
 }
 $9 = (_memcmp((4233),$buff$i$i,3)|0);
 $10 = ($9|0)==(0);
 if (!($10)) {
  _error($S,4240);
  // unreachable;
 }
 $11 = HEAP32[$5>>2]|0;
 $12 = (_luaZ_read($11,$x$i$i,1)|0);
 $13 = ($12|0)==(0);
 if (!($13)) {
  _error($S,4216);
  // unreachable;
 }
 $14 = HEAP8[$x$i$i>>0]|0;
 $15 = ($14<<24>>24)==(83);
 if (!($15)) {
  _error($S,4248);
  // unreachable;
 }
 $16 = HEAP32[$5>>2]|0;
 $17 = (_luaZ_read($16,$x$i2$i,1)|0);
 $18 = ($17|0)==(0);
 if (!($18)) {
  _error($S,4216);
  // unreachable;
 }
 $19 = HEAP8[$x$i2$i>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  _error($S,4272);
  // unreachable;
 }
 $21 = HEAP32[$5>>2]|0;
 $22 = (_luaZ_read($21,$buff$i$i,6)|0);
 $23 = ($22|0)==(0);
 if (!($23)) {
  _error($S,4216);
  // unreachable;
 }
 $24 = (_memcmp(4296,$buff$i$i,6)|0);
 $25 = ($24|0)==(0);
 if (!($25)) {
  _error($S,4304);
  // unreachable;
 }
 $26 = HEAP32[$5>>2]|0;
 $27 = (_luaZ_read($26,$x$i$i$i,1)|0);
 $28 = ($27|0)==(0);
 if (!($28)) {
  _error($S,4216);
  // unreachable;
 }
 $29 = HEAP8[$x$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(4);
 if (!($30)) {
  $31 = HEAP32[$S>>2]|0;
  HEAP32[$vararg_buffer>>2] = 4344;
  $32 = (_luaO_pushfstring($31,4320,$vararg_buffer)|0);
  _error($S,$32);
  // unreachable;
 }
 $33 = HEAP32[$5>>2]|0;
 $34 = (_luaZ_read($33,$x$i$i8$i,1)|0);
 $35 = ($34|0)==(0);
 if (!($35)) {
  _error($S,4216);
  // unreachable;
 }
 $36 = HEAP8[$x$i$i8$i>>0]|0;
 $37 = ($36<<24>>24)==(4);
 if (!($37)) {
  $38 = HEAP32[$S>>2]|0;
  HEAP32[$vararg_buffer1>>2] = 4352;
  $39 = (_luaO_pushfstring($38,4320,$vararg_buffer1)|0);
  _error($S,$39);
  // unreachable;
 }
 $40 = HEAP32[$5>>2]|0;
 $41 = (_luaZ_read($40,$x$i$i11$i,1)|0);
 $42 = ($41|0)==(0);
 if (!($42)) {
  _error($S,4216);
  // unreachable;
 }
 $43 = HEAP8[$x$i$i11$i>>0]|0;
 $44 = ($43<<24>>24)==(4);
 if (!($44)) {
  $45 = HEAP32[$S>>2]|0;
  HEAP32[$vararg_buffer4>>2] = 4360;
  $46 = (_luaO_pushfstring($45,4320,$vararg_buffer4)|0);
  _error($S,$46);
  // unreachable;
 }
 $47 = HEAP32[$5>>2]|0;
 $48 = (_luaZ_read($47,$x$i$i14$i,1)|0);
 $49 = ($48|0)==(0);
 if (!($49)) {
  _error($S,4216);
  // unreachable;
 }
 $50 = HEAP8[$x$i$i14$i>>0]|0;
 $51 = ($50<<24>>24)==(8);
 if (!($51)) {
  $52 = HEAP32[$S>>2]|0;
  HEAP32[$vararg_buffer7>>2] = 4376;
  $53 = (_luaO_pushfstring($52,4320,$vararg_buffer7)|0);
  _error($S,$53);
  // unreachable;
 }
 $54 = HEAP32[$5>>2]|0;
 $55 = (_luaZ_read($54,$x$i$i17$i,1)|0);
 $56 = ($55|0)==(0);
 if (!($56)) {
  _error($S,4216);
  // unreachable;
 }
 $57 = HEAP8[$x$i$i17$i>>0]|0;
 $58 = ($57<<24>>24)==(8);
 if (!($58)) {
  $59 = HEAP32[$S>>2]|0;
  HEAP32[$vararg_buffer10>>2] = 4392;
  $60 = (_luaO_pushfstring($59,4320,$vararg_buffer10)|0);
  _error($S,$60);
  // unreachable;
 }
 $61 = HEAP32[$5>>2]|0;
 $62 = (_luaZ_read($61,$x$i20$i,8)|0);
 $63 = ($62|0)==(0);
 if (!($63)) {
  _error($S,4216);
  // unreachable;
 }
 $64 = $x$i20$i;
 $65 = $64;
 $66 = HEAP32[$65>>2]|0;
 $67 = (($64) + 4)|0;
 $68 = $67;
 $69 = HEAP32[$68>>2]|0;
 $70 = ($66|0)==(22136);
 $71 = ($69|0)==(0);
 $72 = $70 & $71;
 if (!($72)) {
  _error($S,4408);
  // unreachable;
 }
 $73 = HEAP32[$5>>2]|0;
 $74 = (_luaZ_read($73,$x$i22$i,8)|0);
 $75 = ($74|0)==(0);
 if (!($75)) {
  _error($S,4216);
  // unreachable;
 }
 $76 = +HEAPF64[$x$i22$i>>3];
 $77 = $76 != 370.5;
 if ($77) {
  _error($S,4432);
  // unreachable;
 }
 $78 = HEAP32[$5>>2]|0;
 $79 = (_luaZ_read($78,$x$i,1)|0);
 $80 = ($79|0)==(0);
 if (!($80)) {
  _error($S,4216);
  // unreachable;
 }
 $81 = HEAP8[$x$i>>0]|0;
 $82 = $81&255;
 $83 = (_luaF_newLclosure($L,$82)|0);
 $84 = ((($L)) + 8|0);
 $85 = HEAP32[$84>>2]|0;
 HEAP32[$85>>2] = $83;
 $86 = ((($85)) + 8|0);
 HEAP32[$86>>2] = 70;
 $87 = HEAP32[$84>>2]|0;
 $88 = ((($87)) + 16|0);
 HEAP32[$84>>2] = $88;
 $89 = ((($L)) + 24|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = $90;
 $92 = $88;
 $93 = (($91) - ($92))|0;
 $94 = ($93|0)<(16);
 if (!($94)) {
  $95 = (_luaF_newproto($L)|0);
  $96 = ((($83)) + 12|0);
  HEAP32[$96>>2] = $95;
  _LoadFunction($S,$95,0);
  STACKTOP = sp;return ($83|0);
 }
 _luaD_growstack($L,0);
 $95 = (_luaF_newproto($L)|0);
 $96 = ((($83)) + 12|0);
 HEAP32[$96>>2] = $95;
 _LoadFunction($S,$95,0);
 STACKTOP = sp;return ($83|0);
}
function _error($S,$why) {
 $S = $S|0;
 $why = $why|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[$S>>2]|0;
 $1 = ((($S)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $why;
 (_luaO_pushfstring($0,4464,$vararg_buffer)|0);
 $3 = HEAP32[$S>>2]|0;
 _luaD_throw($3,3);
 // unreachable;
}
function _LoadFunction($S,$f,$psource) {
 $S = $S|0;
 $f = $f|0;
 $psource = $psource|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i22 = 0, $exitcond$i28 = 0, $exitcond16$i = 0, $exitcond38 = 0, $exitcond3840 = 0, $i$013$i = 0, $i$05$i = 0, $i$08$i = 0;
 var $i$1$i34 = 0, $i$110$i = 0, $i$14$i = 0, $i$16$i37 = 0, $i$29$i = 0, $psource$ = 0, $x$i = 0, $x$i$i = 0, $x$i$i13 = 0, $x$i$i18 = 0, $x$i$i25 = 0, $x$i$i32 = 0, $x$i1$i = 0, $x$i1$i17 = 0, $x$i1$i24 = 0, $x$i10 = 0, $x$i2 = 0, $x$i2$i = 0, $x$i2$i23 = 0, $x$i3$i = 0;
 var $x$i4$i = 0, $x$i5 = 0, $x$i5$i = 0, $x$i5$i16 = 0, $x$i7 = 0, $x$i7$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i$i32 = sp + 56|0;
 $x$i2$i23 = sp + 66|0;
 $x$i1$i24 = sp + 65|0;
 $x$i$i25 = sp + 52|0;
 $x$i5$i16 = sp + 8|0;
 $x$i4$i = sp;
 $x$i2$i = sp + 64|0;
 $x$i1$i17 = sp + 63|0;
 $x$i$i18 = sp + 48|0;
 $x$i$i13 = sp + 44|0;
 $x$i10 = sp + 62|0;
 $x$i7 = sp + 61|0;
 $x$i5 = sp + 60|0;
 $x$i2 = sp + 40|0;
 $x$i = sp + 36|0;
 $x$i7$i = sp + 32|0;
 $x$i5$i = sp + 28|0;
 $x$i3$i = sp + 24|0;
 $x$i1$i = sp + 20|0;
 $x$i$i = sp + 16|0;
 $0 = (_LoadString($S)|0);
 $1 = ((($f)) + 72|0);
 $2 = ($0|0)==(0|0);
 $psource$ = $2 ? $psource : $0;
 HEAP32[$1>>2] = $psource$;
 $3 = ((($S)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (_luaZ_read($4,$x$i,4)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  _error($S,4216);
  // unreachable;
 }
 $7 = HEAP32[$x$i>>2]|0;
 $8 = ((($f)) + 36|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$3>>2]|0;
 $10 = (_luaZ_read($9,$x$i2,4)|0);
 $11 = ($10|0)==(0);
 if (!($11)) {
  _error($S,4216);
  // unreachable;
 }
 $12 = HEAP32[$x$i2>>2]|0;
 $13 = ((($f)) + 40|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$3>>2]|0;
 $15 = (_luaZ_read($14,$x$i5,1)|0);
 $16 = ($15|0)==(0);
 if (!($16)) {
  _error($S,4216);
  // unreachable;
 }
 $17 = HEAP8[$x$i5>>0]|0;
 $18 = ((($f)) + 6|0);
 HEAP8[$18>>0] = $17;
 $19 = HEAP32[$3>>2]|0;
 $20 = (_luaZ_read($19,$x$i7,1)|0);
 $21 = ($20|0)==(0);
 if (!($21)) {
  _error($S,4216);
  // unreachable;
 }
 $22 = HEAP8[$x$i7>>0]|0;
 $23 = ((($f)) + 7|0);
 HEAP8[$23>>0] = $22;
 $24 = HEAP32[$3>>2]|0;
 $25 = (_luaZ_read($24,$x$i10,1)|0);
 $26 = ($25|0)==(0);
 if (!($26)) {
  _error($S,4216);
  // unreachable;
 }
 $27 = HEAP8[$x$i10>>0]|0;
 $28 = ((($f)) + 8|0);
 HEAP8[$28>>0] = $27;
 $29 = HEAP32[$3>>2]|0;
 $30 = (_luaZ_read($29,$x$i$i13,4)|0);
 $31 = ($30|0)==(0);
 if (!($31)) {
  _error($S,4216);
  // unreachable;
 }
 $32 = HEAP32[$x$i$i13>>2]|0;
 $33 = (($32) + 1)|0;
 $34 = ($33>>>0)>(1073741823);
 $35 = HEAP32[$S>>2]|0;
 if ($34) {
  _luaM_toobig($35);
  // unreachable;
 }
 $36 = $32 << 2;
 $37 = (_luaM_realloc_($35,0,0,$36)|0);
 $38 = ((($f)) + 48|0);
 HEAP32[$38>>2] = $37;
 $39 = ((($f)) + 20|0);
 HEAP32[$39>>2] = $32;
 $40 = HEAP32[$3>>2]|0;
 $41 = (_luaZ_read($40,$37,$36)|0);
 $42 = ($41|0)==(0);
 if (!($42)) {
  _error($S,4216);
  // unreachable;
 }
 $43 = HEAP32[$3>>2]|0;
 $44 = (_luaZ_read($43,$x$i$i18,4)|0);
 $45 = ($44|0)==(0);
 if (!($45)) {
  _error($S,4216);
  // unreachable;
 }
 $46 = HEAP32[$x$i$i18>>2]|0;
 $47 = (($46) + 1)|0;
 $48 = ($47>>>0)>(268435455);
 $49 = HEAP32[$S>>2]|0;
 if ($48) {
  _luaM_toobig($49);
  // unreachable;
 }
 $50 = $46 << 4;
 $51 = (_luaM_realloc_($49,0,0,$50)|0);
 $52 = ((($f)) + 44|0);
 HEAP32[$52>>2] = $51;
 $53 = ((($f)) + 16|0);
 HEAP32[$53>>2] = $46;
 $54 = ($46|0)>(0);
 L31: do {
  if ($54) {
   $i$08$i = 0;
   while(1) {
    $58 = (((($51) + ($i$08$i<<4)|0)) + 8|0);
    HEAP32[$58>>2] = 0;
    $59 = (($i$08$i) + 1)|0;
    $exitcond$i22 = ($59|0)==($46|0);
    if ($exitcond$i22) {
     break;
    } else {
     $i$08$i = $59;
    }
   }
   $55 = HEAP32[$3>>2]|0;
   $56 = (_luaZ_read($55,$x$i1$i17,1)|0);
   $57 = ($56|0)==(0);
   if ($57) {
    $63 = $51;$69 = $51;$i$16$i37 = 0;
   } else {
    _error($S,4216);
    // unreachable;
   }
   L37: while(1) {
    $60 = HEAP8[$x$i1$i17>>0]|0;
    $61 = $60&255;
    switch ($61|0) {
    case 1:  {
     $64 = HEAP32[$3>>2]|0;
     $65 = (_luaZ_read($64,$x$i2$i,1)|0);
     $66 = ($65|0)==(0);
     if (!($66)) {
      label = 28;
      break L37;
     }
     $67 = HEAP8[$x$i2$i>>0]|0;
     $68 = $67&255;
     HEAP32[$69>>2] = $68;
     $70 = (((($63) + ($i$16$i37<<4)|0)) + 8|0);
     HEAP32[$70>>2] = 1;
     break;
    }
    case 19:  {
     $76 = HEAP32[$3>>2]|0;
     $77 = (_luaZ_read($76,$x$i5$i16,8)|0);
     $78 = ($77|0)==(0);
     if (!($78)) {
      label = 34;
      break L37;
     }
     $79 = $x$i5$i16;
     $80 = $79;
     $81 = HEAP32[$80>>2]|0;
     $82 = (($79) + 4)|0;
     $83 = $82;
     $84 = HEAP32[$83>>2]|0;
     $85 = $69;
     $86 = $85;
     HEAP32[$86>>2] = $81;
     $87 = (($85) + 4)|0;
     $88 = $87;
     HEAP32[$88>>2] = $84;
     $89 = (((($63) + ($i$16$i37<<4)|0)) + 8|0);
     HEAP32[$89>>2] = 19;
     break;
    }
    case 0:  {
     $62 = (((($63) + ($i$16$i37<<4)|0)) + 8|0);
     HEAP32[$62>>2] = 0;
     break;
    }
    case 20: case 4:  {
     $90 = (_LoadString($S)|0);
     HEAP32[$69>>2] = $90;
     $91 = ((($90)) + 4|0);
     $92 = HEAP8[$91>>0]|0;
     $93 = $92&255;
     $94 = $93 | 64;
     $95 = (((($63) + ($i$16$i37<<4)|0)) + 8|0);
     HEAP32[$95>>2] = $94;
     break;
    }
    case 3:  {
     $71 = HEAP32[$3>>2]|0;
     $72 = (_luaZ_read($71,$x$i4$i,8)|0);
     $73 = ($72|0)==(0);
     if (!($73)) {
      label = 31;
      break L37;
     }
     $74 = +HEAPF64[$x$i4$i>>3];
     HEAPF64[$69>>3] = $74;
     $75 = (((($63) + ($i$16$i37<<4)|0)) + 8|0);
     HEAP32[$75>>2] = 3;
     break;
    }
    default: {
    }
    }
    $96 = (($i$16$i37) + 1)|0;
    $97 = ($96|0)<($46|0);
    if (!($97)) {
     break L31;
    }
    $$pre$i = HEAP32[$52>>2]|0;
    $98 = (($$pre$i) + ($96<<4)|0);
    $99 = HEAP32[$3>>2]|0;
    $100 = (_luaZ_read($99,$x$i1$i17,1)|0);
    $101 = ($100|0)==(0);
    if ($101) {
     $63 = $$pre$i;$69 = $98;$i$16$i37 = $96;
    } else {
     label = 24;
     break;
    }
   }
   if ((label|0) == 24) {
    _error($S,4216);
    // unreachable;
   }
   else if ((label|0) == 28) {
    _error($S,4216);
    // unreachable;
   }
   else if ((label|0) == 31) {
    _error($S,4216);
    // unreachable;
   }
   else if ((label|0) == 34) {
    _error($S,4216);
    // unreachable;
   }
  }
 } while(0);
 $102 = HEAP32[$3>>2]|0;
 $103 = (_luaZ_read($102,$x$i$i25,4)|0);
 $104 = ($103|0)==(0);
 if (!($104)) {
  _error($S,4216);
  // unreachable;
 }
 $105 = HEAP32[$x$i$i25>>2]|0;
 $106 = (($105) + 1)|0;
 $107 = ($106>>>0)>(536870911);
 $108 = HEAP32[$S>>2]|0;
 if ($107) {
  _luaM_toobig($108);
  // unreachable;
 }
 $109 = $105 << 3;
 $110 = (_luaM_realloc_($108,0,0,$109)|0);
 $111 = ((($f)) + 64|0);
 HEAP32[$111>>2] = $110;
 $112 = ((($f)) + 12|0);
 HEAP32[$112>>2] = $105;
 $113 = ($105|0)>(0);
 L62: do {
  if ($113) {
   $i$05$i = 0;
   while(1) {
    $114 = (($110) + ($i$05$i<<3)|0);
    HEAP32[$114>>2] = 0;
    $115 = (($i$05$i) + 1)|0;
    $exitcond$i28 = ($115|0)==($105|0);
    if ($exitcond$i28) {
     $i$14$i = 0;
     break;
    } else {
     $i$05$i = $115;
    }
   }
   while(1) {
    $116 = HEAP32[$3>>2]|0;
    $117 = (_luaZ_read($116,$x$i1$i24,1)|0);
    $118 = ($117|0)==(0);
    if (!($118)) {
     label = 46;
     break;
    }
    $119 = HEAP8[$x$i1$i24>>0]|0;
    $120 = HEAP32[$111>>2]|0;
    $121 = (((($120) + ($i$14$i<<3)|0)) + 4|0);
    HEAP8[$121>>0] = $119;
    $122 = HEAP32[$3>>2]|0;
    $123 = (_luaZ_read($122,$x$i2$i23,1)|0);
    $124 = ($123|0)==(0);
    if (!($124)) {
     label = 48;
     break;
    }
    $125 = HEAP8[$x$i2$i23>>0]|0;
    $126 = HEAP32[$111>>2]|0;
    $127 = (((($126) + ($i$14$i<<3)|0)) + 5|0);
    HEAP8[$127>>0] = $125;
    $128 = (($i$14$i) + 1)|0;
    $129 = ($128|0)<($105|0);
    if ($129) {
     $i$14$i = $128;
    } else {
     break L62;
    }
   }
   if ((label|0) == 46) {
    _error($S,4216);
    // unreachable;
   }
   else if ((label|0) == 48) {
    _error($S,4216);
    // unreachable;
   }
  }
 } while(0);
 $130 = HEAP32[$3>>2]|0;
 $131 = (_luaZ_read($130,$x$i$i32,4)|0);
 $132 = ($131|0)==(0);
 if (!($132)) {
  _error($S,4216);
  // unreachable;
 }
 $133 = HEAP32[$x$i$i32>>2]|0;
 $134 = (($133) + 1)|0;
 $135 = ($134>>>0)>(1073741823);
 $136 = HEAP32[$S>>2]|0;
 if ($135) {
  _luaM_toobig($136);
  // unreachable;
 }
 $137 = $133 << 2;
 $138 = (_luaM_realloc_($136,0,0,$137)|0);
 $139 = ((($f)) + 52|0);
 HEAP32[$139>>2] = $138;
 $140 = ((($f)) + 28|0);
 HEAP32[$140>>2] = $133;
 $141 = ($133|0)>(0);
 if ($141) {
  HEAP32[$138>>2] = 0;
  $exitcond3840 = ($133|0)==(1);
  if (!($exitcond3840)) {
   $143 = 1;
   while(1) {
    $$pre = HEAP32[$139>>2]|0;
    $142 = (($$pre) + ($143<<2)|0);
    HEAP32[$142>>2] = 0;
    $144 = (($143) + 1)|0;
    $exitcond38 = ($144|0)==($133|0);
    if ($exitcond38) {
     break;
    } else {
     $143 = $144;
    }
   }
  }
  if ($141) {
   $i$1$i34 = 0;
   while(1) {
    $145 = HEAP32[$S>>2]|0;
    $146 = (_luaF_newproto($145)|0);
    $147 = HEAP32[$139>>2]|0;
    $148 = (($147) + ($i$1$i34<<2)|0);
    HEAP32[$148>>2] = $146;
    $149 = HEAP32[$139>>2]|0;
    $150 = (($149) + ($i$1$i34<<2)|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = HEAP32[$1>>2]|0;
    _LoadFunction($S,$151,$152);
    $153 = (($i$1$i34) + 1)|0;
    $exitcond = ($153|0)==($133|0);
    if ($exitcond) {
     break;
    } else {
     $i$1$i34 = $153;
    }
   }
  }
 }
 $154 = HEAP32[$3>>2]|0;
 $155 = (_luaZ_read($154,$x$i$i,4)|0);
 $156 = ($155|0)==(0);
 if (!($156)) {
  _error($S,4216);
  // unreachable;
 }
 $157 = HEAP32[$x$i$i>>2]|0;
 $158 = (($157) + 1)|0;
 $159 = ($158>>>0)>(1073741823);
 $160 = HEAP32[$S>>2]|0;
 if ($159) {
  _luaM_toobig($160);
  // unreachable;
 }
 $161 = $157 << 2;
 $162 = (_luaM_realloc_($160,0,0,$161)|0);
 $163 = ((($f)) + 56|0);
 HEAP32[$163>>2] = $162;
 $164 = ((($f)) + 24|0);
 HEAP32[$164>>2] = $157;
 $165 = HEAP32[$3>>2]|0;
 $166 = (_luaZ_read($165,$162,$161)|0);
 $167 = ($166|0)==(0);
 if (!($167)) {
  _error($S,4216);
  // unreachable;
 }
 $168 = HEAP32[$3>>2]|0;
 $169 = (_luaZ_read($168,$x$i1$i,4)|0);
 $170 = ($169|0)==(0);
 if (!($170)) {
  _error($S,4216);
  // unreachable;
 }
 $171 = HEAP32[$x$i1$i>>2]|0;
 $172 = (($171) + 1)|0;
 $173 = ($172>>>0)>(357913941);
 $174 = HEAP32[$S>>2]|0;
 if ($173) {
  _luaM_toobig($174);
  // unreachable;
 }
 $175 = ($171*12)|0;
 $176 = (_luaM_realloc_($174,0,0,$175)|0);
 $177 = ((($f)) + 60|0);
 HEAP32[$177>>2] = $176;
 $178 = ((($f)) + 32|0);
 HEAP32[$178>>2] = $171;
 $179 = ($171|0)>(0);
 L103: do {
  if ($179) {
   $i$013$i = 0;
   while(1) {
    $180 = (($176) + (($i$013$i*12)|0)|0);
    HEAP32[$180>>2] = 0;
    $181 = (($i$013$i) + 1)|0;
    $exitcond16$i = ($181|0)==($171|0);
    if ($exitcond16$i) {
     break;
    } else {
     $i$013$i = $181;
    }
   }
   $i$110$i = 0;
   while(1) {
    $182 = (_LoadString($S)|0);
    $183 = HEAP32[$177>>2]|0;
    $184 = (($183) + (($i$110$i*12)|0)|0);
    HEAP32[$184>>2] = $182;
    $185 = HEAP32[$3>>2]|0;
    $186 = (_luaZ_read($185,$x$i3$i,4)|0);
    $187 = ($186|0)==(0);
    if (!($187)) {
     label = 73;
     break;
    }
    $188 = HEAP32[$x$i3$i>>2]|0;
    $189 = HEAP32[$177>>2]|0;
    $190 = (((($189) + (($i$110$i*12)|0)|0)) + 4|0);
    HEAP32[$190>>2] = $188;
    $191 = HEAP32[$3>>2]|0;
    $192 = (_luaZ_read($191,$x$i5$i,4)|0);
    $193 = ($192|0)==(0);
    if (!($193)) {
     label = 75;
     break;
    }
    $194 = HEAP32[$x$i5$i>>2]|0;
    $195 = HEAP32[$177>>2]|0;
    $196 = (((($195) + (($i$110$i*12)|0)|0)) + 8|0);
    HEAP32[$196>>2] = $194;
    $197 = (($i$110$i) + 1)|0;
    $198 = ($197|0)<($171|0);
    if ($198) {
     $i$110$i = $197;
    } else {
     break L103;
    }
   }
   if ((label|0) == 73) {
    _error($S,4216);
    // unreachable;
   }
   else if ((label|0) == 75) {
    _error($S,4216);
    // unreachable;
   }
  }
 } while(0);
 $199 = HEAP32[$3>>2]|0;
 $200 = (_luaZ_read($199,$x$i7$i,4)|0);
 $201 = ($200|0)==(0);
 if (!($201)) {
  _error($S,4216);
  // unreachable;
 }
 $202 = HEAP32[$x$i7$i>>2]|0;
 $203 = ($202|0)>(0);
 if ($203) {
  $i$29$i = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $204 = (_LoadString($S)|0);
  $205 = HEAP32[$111>>2]|0;
  $206 = (($205) + ($i$29$i<<3)|0);
  HEAP32[$206>>2] = $204;
  $207 = (($i$29$i) + 1)|0;
  $exitcond$i = ($207|0)==($202|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$29$i = $207;
  }
 }
 STACKTOP = sp;return;
}
function _LoadString($S) {
 $S = $S|0;
 var $$0 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, $x$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i = sp + 4|0;
 $size = sp;
 $0 = ((($S)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaZ_read($1,$x$i,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  _error($S,4216);
  // unreachable;
 }
 $4 = HEAP8[$x$i>>0]|0;
 $5 = $4&255;
 HEAP32[$size>>2] = $5;
 $6 = ($4<<24>>24)==(-1);
 do {
  if ($6) {
   $7 = HEAP32[$0>>2]|0;
   $8 = (_luaZ_read($7,$size,4)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$pr = HEAP32[$size>>2]|0;
    $11 = $$pr;
    break;
   } else {
    _error($S,4216);
    // unreachable;
   }
  } else {
   $11 = $5;
  }
 } while(0);
 $10 = ($11|0)==(0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[$S>>2]|0;
 $13 = ((($S)) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($11) + -1)|0;
 HEAP32[$size>>2] = $15;
 $16 = (_luaZ_openspace($12,$14,$15)|0);
 $17 = HEAP32[$size>>2]|0;
 $18 = HEAP32[$0>>2]|0;
 $19 = (_luaZ_read($18,$16,$17)|0);
 $20 = ($19|0)==(0);
 if (!($20)) {
  _error($S,4216);
  // unreachable;
 }
 $21 = HEAP32[$S>>2]|0;
 $22 = HEAP32[$size>>2]|0;
 $23 = (_luaS_newlstr($21,$16,$22)|0);
 $$0 = $23;
 STACKTOP = sp;return ($$0|0);
}
function _luaV_tonumber_($obj,$n) {
 $obj = $obj|0;
 $n = $n|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $v = sp;
 $0 = ((($obj)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(19);
 if ($2) {
  $3 = $obj;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (+($5>>>0)) + (4294967296.0*(+($8|0)));
  HEAPF64[$n>>3] = $9;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = $1 & 15;
 $11 = ($10|0)==(4);
 if (!($11)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[$obj>>2]|0;
 $13 = ((($12)) + 24|0);
 $14 = (_luaO_str2num($13,$v)|0);
 $15 = HEAP32[$obj>>2]|0;
 $16 = ((($15)) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1)|0;
 $19 = ($14|0)==($18|0);
 if (!($19)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = ((($v)) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(19);
 $23 = $v;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (+($25>>>0)) + (4294967296.0*(+($28|0)));
 HEAP32[tempDoublePtr>>2] = $25;HEAP32[tempDoublePtr+4>>2] = $28;$30 = +HEAPF64[tempDoublePtr>>3];
 $31 = $22 ? $29 : $30;
 HEAPF64[$n>>3] = $31;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _luaV_tointeger_($obj,$p) {
 $obj = $obj|0;
 $p = $p|0;
 var $$0$i = 0, $$02$i = 0, $$02$i$lcssa = 0, $$02$i$lcssa11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $v$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $v$i = sp;
 $$02$i = $obj;
 while(1) {
  $0 = ((($$02$i)) + 8|0);
  $1 = HEAP32[$0>>2]|0;
  if ((($1|0) == 19)) {
   $$02$i$lcssa11 = $$02$i;
   label = 6;
   break;
  } else if ((($1|0) == 3)) {
   $$02$i$lcssa = $$02$i;
   label = 3;
   break;
  }
  $23 = $1 & 15;
  $24 = ($23|0)==(4);
  if (!($24)) {
   $$0$i = 0;
   label = 9;
   break;
  }
  $25 = HEAP32[$$02$i>>2]|0;
  $26 = ((($25)) + 24|0);
  $27 = (_luaO_str2num($26,$v$i)|0);
  $28 = HEAP32[$$02$i>>2]|0;
  $29 = ((($28)) + 12|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  $32 = ($27|0)==($31|0);
  if ($32) {
   $$02$i = $v$i;
  } else {
   $$0$i = 0;
   label = 9;
   break;
  }
 }
 if ((label|0) == 3) {
  $2 = +HEAPF64[$$02$i$lcssa>>3];
  $3 = (+Math_floor((+$2)));
  $4 = $2 != $3;
  if ($4) {
   $$0$i = 0;
   STACKTOP = sp;return ($$0$i|0);
  }
  $5 = $3 >= -9.2233720368547758E+18;
  $6 = $3 < 9.2233720368547758E+18;
  $or$cond$i = $5 & $6;
  if (!($or$cond$i)) {
   $$0$i = 0;
   STACKTOP = sp;return ($$0$i|0);
  }
  $7 = (~~$3)>>>0;
  $8 = +Math_abs($3) >= 1.0 ? $3 > 0.0 ? (~~+Math_min(+Math_floor($3 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($3 - +(~~$3 >>> 0)) / 4294967296.0) >>> 0 : 0;
  $9 = $p;
  $10 = $9;
  HEAP32[$10>>2] = $7;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 6) {
  $13 = $$02$i$lcssa11;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4)|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = $p;
  $20 = $19;
  HEAP32[$20>>2] = $15;
  $21 = (($19) + 4)|0;
  $22 = $21;
  HEAP32[$22>>2] = $18;
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 9) {
  STACKTOP = sp;return ($$0$i|0);
 }
 return (0)|0;
}
function _luaV_gettable($L,$t,$key,$val) {
 $L = $L|0;
 $t = $t|0;
 $key = $key|0;
 $val = $val|0;
 var $$05 = 0, $$05$lcssa = 0, $$05$lcssa25 = 0, $$lcssa = 0, $$phi$trans$insert = 0, $$phi$trans$insert10 = 0, $$pre = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $loop$04 = 0, $tm$0 = 0, $tm$0$lcssa = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($L)) + 12|0);
 $$phi$trans$insert = ((($t)) + 8|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 $$05 = $t;$4 = $$pre;$loop$04 = 0;
 while(1) {
  $3 = ($4|0)==(69);
  if ($3) {
   $5 = HEAP32[$$05>>2]|0;
   $6 = (_luaH_get($5,$key)|0);
   $7 = ((($6)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   if (!($9)) {
    $$lcssa = $6;
    label = 9;
    break;
   }
   $10 = ((($5)) + 24|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$lcssa = $6;
    label = 9;
    break;
   }
   $13 = ((($11)) + 6|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14 & 1;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    $$lcssa = $6;
    label = 9;
    break;
   }
   $17 = HEAP32[$0>>2]|0;
   $18 = ((($17)) + 148|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (_luaT_gettm($11,0,$19)|0);
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$lcssa = $6;
    label = 9;
    break;
   }
   $$phi$trans$insert10 = ((($20)) + 8|0);
   $$pre11 = HEAP32[$$phi$trans$insert10>>2]|0;
   $27 = $$pre11;$tm$0 = $20;
  } else {
   $22 = (_luaT_gettmbyobj($L,$$05,0)|0);
   $23 = ((($22)) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0);
   if ($25) {
    $$05$lcssa = $$05;
    label = 11;
    break;
   } else {
    $27 = $24;$tm$0 = $22;
   }
  }
  $26 = $27 & 15;
  $28 = ($26|0)==(6);
  $2 = (($loop$04) + 1)|0;
  if ($28) {
   $$05$lcssa25 = $$05;$tm$0$lcssa = $tm$0;
   label = 13;
   break;
  }
  $1 = ($2|0)<(2000);
  if ($1) {
   $$05 = $tm$0;$4 = $27;$loop$04 = $2;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 9) {
  ;HEAP32[$val>>2]=HEAP32[$$lcssa>>2]|0;HEAP32[$val+4>>2]=HEAP32[$$lcssa+4>>2]|0;HEAP32[$val+8>>2]=HEAP32[$$lcssa+8>>2]|0;HEAP32[$val+12>>2]=HEAP32[$$lcssa+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  _luaG_typeerror($L,$$05$lcssa,4496);
  // unreachable;
 }
 else if ((label|0) == 13) {
  _luaT_callTM($L,$tm$0$lcssa,$$05$lcssa25,$key,$val,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  _luaG_runerror($L,4504,$vararg_buffer);
  // unreachable;
 }
}
function _luaV_settable($L,$t,$key,$val) {
 $L = $L|0;
 $t = $t|0;
 $key = $key|0;
 $val = $val|0;
 var $$09 = 0, $$09$lcssa = 0, $$09$lcssa46 = 0, $$lcssa48 = 0, $$lcssa50 = 0, $$phi$trans$insert = 0, $$phi$trans$insert18 = 0, $$pre = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $loop$08 = 0, $oldval$0 = 0, $tm$0 = 0, $tm$0$lcssa = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($L)) + 12|0);
 $$phi$trans$insert = ((($t)) + 8|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 $$09 = $t;$4 = $$pre;$loop$08 = 0;
 while(1) {
  $3 = ($4|0)==(69);
  if ($3) {
   $5 = HEAP32[$$09>>2]|0;
   $6 = (_luaH_get($5,$key)|0);
   $7 = ((($6)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   if (!($9)) {
    $25 = $5;$oldval$0 = $6;
    break;
   }
   $10 = ((($5)) + 24|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$lcssa48 = $5;$$lcssa50 = $6;
    label = 9;
    break;
   }
   $13 = ((($11)) + 6|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14 & 2;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    $$lcssa48 = $5;$$lcssa50 = $6;
    label = 9;
    break;
   }
   $17 = HEAP32[$0>>2]|0;
   $18 = ((($17)) + 152|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (_luaT_gettm($11,1,$19)|0);
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$lcssa48 = $5;$$lcssa50 = $6;
    label = 9;
    break;
   }
   $$phi$trans$insert18 = ((($20)) + 8|0);
   $$pre19 = HEAP32[$$phi$trans$insert18>>2]|0;
   $44 = $$pre19;$tm$0 = $20;
  } else {
   $39 = (_luaT_gettmbyobj($L,$$09,1)|0);
   $40 = ((($39)) + 8|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0);
   if ($42) {
    $$09$lcssa = $$09;
    label = 16;
    break;
   } else {
    $44 = $41;$tm$0 = $39;
   }
  }
  $43 = $44 & 15;
  $45 = ($43|0)==(6);
  $2 = (($loop$08) + 1)|0;
  if ($45) {
   $$09$lcssa46 = $$09;$tm$0$lcssa = $tm$0;
   label = 18;
   break;
  }
  $1 = ($2|0)<(2000);
  if ($1) {
   $$09 = $tm$0;$4 = $44;$loop$08 = $2;
  } else {
   label = 19;
   break;
  }
 }
 if ((label|0) == 9) {
  $22 = ($$lcssa50|0)==(1760|0);
  if ($22) {
   $23 = (_luaH_newkey($L,$$lcssa48,$key)|0);
   $25 = $$lcssa48;$oldval$0 = $23;
  } else {
   $25 = $$lcssa48;$oldval$0 = $$lcssa50;
  }
 }
 else if ((label|0) == 16) {
  _luaG_typeerror($L,$$09$lcssa,4496);
  // unreachable;
 }
 else if ((label|0) == 18) {
  _luaT_callTM($L,$tm$0$lcssa,$$09$lcssa46,$key,$val,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 19) {
  _luaG_runerror($L,4544,$vararg_buffer);
  // unreachable;
 }
 ;HEAP32[$oldval$0>>2]=HEAP32[$val>>2]|0;HEAP32[$oldval$0+4>>2]=HEAP32[$val+4>>2]|0;HEAP32[$oldval$0+8>>2]=HEAP32[$val+8>>2]|0;HEAP32[$oldval$0+12>>2]=HEAP32[$val+12>>2]|0;
 $24 = ((($25)) + 6|0);
 HEAP8[$24>>0] = 0;
 $26 = ((($val)) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27 & 64;
 $29 = ($28|0)==(0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = ((($25)) + 5|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = $31 & 4;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$val>>2]|0;
 $35 = ((($34)) + 5|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = $36 & 3;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 _luaC_barrierback_($L,$25);
 STACKTOP = sp;return;
}
function _luaV_lessthan($L,$l,$r) {
 $L = $L|0;
 $l = $l|0;
 $r = $r|0;
 var $$0 = 0, $$0$i1 = 0, $$lcssa = 0, $$lobit = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $8 = 0, $9 = 0, $cond = 0, $l$01$i = 0, $ll$02$i = 0, $lr$04$i = 0, $r$03$i = 0, $storemerge1$i$ph = 0.0, $storemerge1$i3$ph = 0.0, $x$i = 0, $x$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i2 = sp + 8|0;
 $x$i = sp;
 $0 = ((($l)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(19);
 do {
  if ($2) {
   $3 = ((($r)) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(19);
   if (!($5)) {
    $6 = $l;
    $7 = $6;
    $8 = HEAP32[$7>>2]|0;
    $9 = (($6) + 4)|0;
    $10 = $9;
    $11 = HEAP32[$10>>2]|0;
    $12 = (+($8>>>0)) + (4294967296.0*(+($11|0)));
    HEAPF64[$x$i>>3] = $12;
    $13 = +HEAPF64[$x$i>>3];
    $77 = $x$i;$storemerge1$i$ph = $13;
    label = 8;
    break;
   }
   $14 = $l;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = $r;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = ($19|0)<($25|0);
   $27 = ($16>>>0)<($22>>>0);
   $28 = ($19|0)==($25|0);
   $29 = $28 & $27;
   $30 = $26 | $29;
   $31 = $30&1;
   $$0 = $31;
   STACKTOP = sp;return ($$0|0);
  } else {
   $cond = ($1|0)==(3);
   if ($cond) {
    $32 = +HEAPF64[$l>>3];
    $77 = $x$i;$storemerge1$i$ph = $32;
    label = 8;
    break;
   } else {
    $47 = $1;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 8) {
   $33 = ((($r)) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   if ((($34|0) == 3)) {
    $35 = +HEAPF64[$r>>3];
    $storemerge1$i3$ph = $35;
   } else if ((($34|0) == 19)) {
    $36 = $r;
    $37 = $36;
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + 4)|0;
    $40 = $39;
    $41 = HEAP32[$40>>2]|0;
    $42 = (+($38>>>0)) + (4294967296.0*(+($41|0)));
    HEAPF64[$x$i2>>3] = $42;
    $43 = +HEAPF64[$x$i2>>3];
    $storemerge1$i3$ph = $43;
   } else {
    $$pre = HEAP32[$0>>2]|0;
    $47 = $$pre;
    break;
   }
   $44 = $storemerge1$i$ph < $storemerge1$i3$ph;
   $45 = $44&1;
   $$0 = $45;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $46 = $47 & 15;
 $48 = ($46|0)==(4);
 if ($48) {
  $49 = ((($r)) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 & 15;
  $52 = ($51|0)==(4);
  if ($52) {
   $53 = HEAP32[$l>>2]|0;
   $54 = HEAP32[$r>>2]|0;
   $55 = ((($53)) + 24|0);
   $56 = ((($54)) + 24|0);
   $57 = (_strcoll($55,$56)|0);
   $58 = ($57|0)==(0);
   L23: do {
    if ($58) {
     $59 = ((($54)) + 12|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($53)) + 12|0);
     $62 = HEAP32[$61>>2]|0;
     $l$01$i = $55;$ll$02$i = $62;$lr$04$i = $60;$r$03$i = $56;
     while(1) {
      $63 = (_strlen(($l$01$i|0))|0);
      $64 = ($63|0)==($lr$04$i|0);
      $65 = ($63|0)==($ll$02$i|0);
      if ($64) {
       $$lcssa = $65;
       break;
      }
      if ($65) {
       $$0$i1 = -1;
       break L23;
      }
      $68 = (($63) + 1)|0;
      $69 = (($l$01$i) + ($68)|0);
      $70 = (($ll$02$i) - ($68))|0;
      $71 = (($r$03$i) + ($68)|0);
      $72 = (($lr$04$i) - ($68))|0;
      $73 = (_strcoll($69,$71)|0);
      $74 = ($73|0)==(0);
      if ($74) {
       $l$01$i = $69;$ll$02$i = $70;$lr$04$i = $72;$r$03$i = $71;
      } else {
       $$0$i1 = $73;
       break L23;
      }
     }
     $66 = $$lcssa&1;
     $67 = $66 ^ 1;
     $$0$i1 = $67;
    } else {
     $$0$i1 = $57;
    }
   } while(0);
   $$lobit = $$0$i1 >>> 31;
   $$0 = $$lobit;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $75 = (_luaT_callorderTM($L,$l,$r,20)|0);
 $76 = ($75|0)<(0);
 if ($76) {
  _luaG_ordererror($L,$l,$r);
  // unreachable;
 } else {
  $$0 = $75;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _luaV_lessequal($L,$l,$r) {
 $L = $L|0;
 $l = $l|0;
 $r = $r|0;
 var $$0 = 0, $$0$i1 = 0, $$lcssa = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $cond = 0, $l$01$i = 0, $ll$02$i = 0, $lr$04$i = 0, $r$03$i = 0, $storemerge1$i$ph = 0.0, $storemerge1$i3$ph = 0.0, $x$i = 0, $x$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i2 = sp + 8|0;
 $x$i = sp;
 $0 = ((($l)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(19);
 do {
  if ($2) {
   $3 = ((($r)) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(19);
   if (!($5)) {
    $6 = $l;
    $7 = $6;
    $8 = HEAP32[$7>>2]|0;
    $9 = (($6) + 4)|0;
    $10 = $9;
    $11 = HEAP32[$10>>2]|0;
    $12 = (+($8>>>0)) + (4294967296.0*(+($11|0)));
    HEAPF64[$x$i>>3] = $12;
    $13 = +HEAPF64[$x$i>>3];
    $83 = $x$i;$storemerge1$i$ph = $13;
    label = 8;
    break;
   }
   $14 = $l;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = $r;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = ($19|0)<($25|0);
   $27 = ($16>>>0)<=($22>>>0);
   $28 = ($19|0)==($25|0);
   $29 = $28 & $27;
   $30 = $26 | $29;
   $31 = $30&1;
   $$0 = $31;
   STACKTOP = sp;return ($$0|0);
  } else {
   $cond = ($1|0)==(3);
   if ($cond) {
    $32 = +HEAPF64[$l>>3];
    $83 = $x$i;$storemerge1$i$ph = $32;
    label = 8;
    break;
   } else {
    $47 = $1;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 8) {
   $33 = ((($r)) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   if ((($34|0) == 19)) {
    $36 = $r;
    $37 = $36;
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + 4)|0;
    $40 = $39;
    $41 = HEAP32[$40>>2]|0;
    $42 = (+($38>>>0)) + (4294967296.0*(+($41|0)));
    HEAPF64[$x$i2>>3] = $42;
    $43 = +HEAPF64[$x$i2>>3];
    $storemerge1$i3$ph = $43;
   } else if ((($34|0) == 3)) {
    $35 = +HEAPF64[$r>>3];
    $storemerge1$i3$ph = $35;
   } else {
    $$pre = HEAP32[$0>>2]|0;
    $47 = $$pre;
    break;
   }
   $44 = $storemerge1$i$ph <= $storemerge1$i3$ph;
   $45 = $44&1;
   $$0 = $45;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $46 = $47 & 15;
 $48 = ($46|0)==(4);
 if ($48) {
  $49 = ((($r)) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 & 15;
  $52 = ($51|0)==(4);
  if ($52) {
   $53 = HEAP32[$l>>2]|0;
   $54 = HEAP32[$r>>2]|0;
   $55 = ((($53)) + 24|0);
   $56 = ((($54)) + 24|0);
   $57 = (_strcoll($55,$56)|0);
   $58 = ($57|0)==(0);
   L23: do {
    if ($58) {
     $59 = ((($54)) + 12|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($53)) + 12|0);
     $62 = HEAP32[$61>>2]|0;
     $l$01$i = $55;$ll$02$i = $62;$lr$04$i = $60;$r$03$i = $56;
     while(1) {
      $63 = (_strlen(($l$01$i|0))|0);
      $64 = ($63|0)==($lr$04$i|0);
      $65 = ($63|0)==($ll$02$i|0);
      if ($64) {
       $$lcssa = $65;
       break;
      }
      if ($65) {
       $$0$i1 = -1;
       break L23;
      }
      $68 = (($63) + 1)|0;
      $69 = (($l$01$i) + ($68)|0);
      $70 = (($ll$02$i) - ($68))|0;
      $71 = (($r$03$i) + ($68)|0);
      $72 = (($lr$04$i) - ($68))|0;
      $73 = (_strcoll($69,$71)|0);
      $74 = ($73|0)==(0);
      if ($74) {
       $l$01$i = $69;$ll$02$i = $70;$lr$04$i = $72;$r$03$i = $71;
      } else {
       $$0$i1 = $73;
       break L23;
      }
     }
     $66 = $$lcssa&1;
     $67 = $66 ^ 1;
     $$0$i1 = $67;
    } else {
     $$0$i1 = $57;
    }
   } while(0);
   $75 = ($$0$i1|0)<(1);
   $76 = $75&1;
   $$0 = $76;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $77 = (_luaT_callorderTM($L,$l,$r,21)|0);
 $78 = ($77|0)>(-1);
 if ($78) {
  $$0 = $77;
  STACKTOP = sp;return ($$0|0);
 }
 $79 = (_luaT_callorderTM($L,$r,$l,20)|0);
 $80 = ($79|0)<(0);
 if ($80) {
  _luaG_ordererror($L,$l,$r);
  // unreachable;
 }
 $81 = ($79|0)==(0);
 $82 = $81&1;
 $$0 = $82;
 STACKTOP = sp;return ($$0|0);
}
function _luaV_equalobj($L,$t1,$t2) {
 $L = $L|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$0 = 0, $$pre = 0, $$pre12 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $phitmp = 0, $storemerge1$i = 0.0, $storemerge1$i2 = 0.0, $tm$0 = 0, $tm$011 = 0, $x$i = 0, $x$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i1 = sp + 8|0;
 $x$i = sp;
 $0 = ((($t1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 63;
 $3 = ((($t2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 63;
 $6 = ($2|0)==($5|0);
 if (!($6)) {
  $7 = $1 & 15;
  $8 = $4 & 15;
  $9 = ($7|0)==($8|0);
  $10 = ($7|0)==(3);
  $or$cond = $10 & $9;
  if (!($or$cond)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  if ((($1|0) == 3)) {
   $11 = +HEAPF64[$t1>>3];
   $145 = $4;$storemerge1$i = $11;
  } else if ((($1|0) == 19)) {
   $12 = $t1;
   $13 = $12;
   $14 = HEAP32[$13>>2]|0;
   $15 = (($12) + 4)|0;
   $16 = $15;
   $17 = HEAP32[$16>>2]|0;
   $18 = (+($14>>>0)) + (4294967296.0*(+($17|0)));
   HEAPF64[$x$i>>3] = $18;
   $19 = +HEAPF64[$x$i>>3];
   $$pre = HEAP32[$3>>2]|0;
   $145 = $$pre;$storemerge1$i = $19;
  } else {
   $145 = $4;$storemerge1$i = 0.0;
  }
  if ((($145|0) == 19)) {
   $21 = $t2;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = (+($23>>>0)) + (4294967296.0*(+($26|0)));
   HEAPF64[$x$i1>>3] = $27;
   $28 = +HEAPF64[$x$i1>>3];
   $storemerge1$i2 = $28;
  } else if ((($145|0) == 3)) {
   $20 = +HEAPF64[$t2>>3];
   $storemerge1$i2 = $20;
  } else {
   $storemerge1$i2 = 0.0;
  }
  $29 = $storemerge1$i == $storemerge1$i2;
  $30 = $29&1;
  $$0 = $30;
  STACKTOP = sp;return ($$0|0);
 }
 L16: do {
  switch ($2|0) {
  case 20:  {
   $67 = HEAP32[$t1>>2]|0;
   $68 = HEAP32[$t2>>2]|0;
   $69 = (_luaS_eqlngstr($67,$68)|0);
   $$0 = $69;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 5:  {
   $100 = HEAP32[$t1>>2]|0;
   $101 = HEAP32[$t2>>2]|0;
   $102 = ($100|0)==($101|0);
   if ($102) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $103 = ($L|0)==(0|0);
   if ($103) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $104 = ((($100)) + 24|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = ($105|0)==(0|0);
   if ($106) {
    $118 = $101;
   } else {
    $107 = ((($105)) + 6|0);
    $108 = HEAP8[$107>>0]|0;
    $109 = $108 & 32;
    $110 = ($109<<24>>24)==(0);
    if ($110) {
     $111 = ((($L)) + 12|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ((($112)) + 168|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = (_luaT_gettm($105,5,$114)|0);
     $116 = ($115|0)==(0|0);
     if (!($116)) {
      $tm$011 = $115;
      break L16;
     }
     $$pre12 = HEAP32[$t2>>2]|0;
     $118 = $$pre12;
    } else {
     $118 = $101;
    }
   }
   $117 = ((($118)) + 24|0);
   $119 = HEAP32[$117>>2]|0;
   $120 = ($119|0)==(0|0);
   if ($120) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $121 = ((($119)) + 6|0);
   $122 = HEAP8[$121>>0]|0;
   $123 = $122 & 32;
   $124 = ($123<<24>>24)==(0);
   if ($124) {
    $125 = ((($L)) + 12|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ((($126)) + 168|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = (_luaT_gettm($119,5,$128)|0);
    $tm$0 = $129;
    label = 37;
    break L16;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   break;
  }
  case 22:  {
   $59 = HEAP32[$t1>>2]|0;
   $60 = HEAP32[$t2>>2]|0;
   $61 = ($59|0)==($60|0);
   $62 = $61&1;
   $$0 = $62;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 1:  {
   $51 = HEAP32[$t1>>2]|0;
   $52 = HEAP32[$t2>>2]|0;
   $53 = ($51|0)==($52|0);
   $54 = $53&1;
   $$0 = $54;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 0:  {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 2:  {
   $55 = HEAP32[$t1>>2]|0;
   $56 = HEAP32[$t2>>2]|0;
   $57 = ($55|0)==($56|0);
   $58 = $57&1;
   $$0 = $58;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 3:  {
   $47 = +HEAPF64[$t1>>3];
   $48 = +HEAPF64[$t2>>3];
   $49 = $47 == $48;
   $50 = $49&1;
   $$0 = $50;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 7:  {
   $70 = HEAP32[$t1>>2]|0;
   $71 = HEAP32[$t2>>2]|0;
   $72 = ($70|0)==($71|0);
   if ($72) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $73 = ($L|0)==(0|0);
   if ($73) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $74 = ((($70)) + 8|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ($75|0)==(0|0);
   if ($76) {
    $88 = $71;
   } else {
    $77 = ((($75)) + 6|0);
    $78 = HEAP8[$77>>0]|0;
    $79 = $78 & 32;
    $80 = ($79<<24>>24)==(0);
    if ($80) {
     $81 = ((($L)) + 12|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = ((($82)) + 168|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = (_luaT_gettm($75,5,$84)|0);
     $86 = ($85|0)==(0|0);
     if (!($86)) {
      $tm$011 = $85;
      break L16;
     }
     $$pre13 = HEAP32[$t2>>2]|0;
     $88 = $$pre13;
    } else {
     $88 = $71;
    }
   }
   $87 = ((($88)) + 8|0);
   $89 = HEAP32[$87>>2]|0;
   $90 = ($89|0)==(0|0);
   if ($90) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $91 = ((($89)) + 6|0);
   $92 = HEAP8[$91>>0]|0;
   $93 = $92 & 32;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $95 = ((($L)) + 12|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ((($96)) + 168|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (_luaT_gettm($89,5,$98)|0);
    $tm$0 = $99;
    label = 37;
    break L16;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   break;
  }
  case 19:  {
   $31 = $t1;
   $32 = $31;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + 4)|0;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = $t2;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = (($37) + 4)|0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = ($33|0)==($39|0);
   $44 = ($36|0)==($42|0);
   $45 = $43 & $44;
   $46 = $45&1;
   $$0 = $46;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 4:  {
   $63 = HEAP32[$t1>>2]|0;
   $64 = HEAP32[$t2>>2]|0;
   $65 = ($63|0)==($64|0);
   $66 = $65&1;
   $$0 = $66;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  default: {
   $130 = HEAP32[$t1>>2]|0;
   $131 = HEAP32[$t2>>2]|0;
   $132 = ($130|0)==($131|0);
   $133 = $132&1;
   $$0 = $133;
   STACKTOP = sp;return ($$0|0);
  }
  }
 } while(0);
 if ((label|0) == 37) {
  $134 = ($tm$0|0)==(0|0);
  if ($134) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $tm$011 = $tm$0;
  }
 }
 $135 = ((($L)) + 8|0);
 $136 = HEAP32[$135>>2]|0;
 _luaT_callTM($L,$tm$011,$t1,$t2,$136,1);
 $137 = HEAP32[$135>>2]|0;
 $138 = ((($137)) + 8|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = ($139|0)==(0);
 if ($140) {
  $144 = 0;
 } else {
  $141 = ($139|0)==(1);
  if ($141) {
   $142 = HEAP32[$137>>2]|0;
   $phitmp = ($142|0)!=(0);
   $144 = $phitmp;
  } else {
   $144 = 1;
  }
 }
 $143 = $144&1;
 $$0 = $143;
 STACKTOP = sp;return ($$0|0);
}
function _luaV_concat($L,$total) {
 $L = $L|0;
 $total = $total|0;
 var $$0 = 0, $$lcssa = 0, $$neg = 0, $$not = 0, $$off = 0, $$pre = 0, $$pre17 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$lcssa = 0, $i$05 = 0, $i$1 = 0, $n$0 = 0, $or$cond = 0, $switch = 0, $tl$0$lcssa = 0, $tl$06 = 0, $tl$1 = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($L)) + 8|0);
 $1 = ((($L)) + 12|0);
 $$pre = HEAP32[$0>>2]|0;
 $$0 = $total;$3 = $$pre;
 L1: while(1) {
  $2 = ((($3)) + -32|0);
  $4 = ((($3)) + -24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 & 15;
  $$off = (($6) + -3)|0;
  $switch = ($$off>>>0)<(2);
  $7 = ((($3)) + -16|0);
  do {
   if ($switch) {
    $8 = ((($3)) + -8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = $9 & 15;
    if ((($10|0) == 3)) {
     _luaO_tostring($L,$7);
     $$pre17 = HEAP32[$4>>2]|0;
     $16 = $$pre17;
    } else if ((($10|0) == 4)) {
     $16 = $5;
    } else {
     label = 5;
     break;
    }
    $11 = HEAP32[$7>>2]|0;
    $12 = ((($11)) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0);
    $15 = $16 & 15;
    $17 = ($15|0)==(4);
    if ($14) {
     $$not = $17 ^ 1;
     $18 = ($15|0)==(3);
     $or$cond = $18 & $$not;
     if (!($or$cond)) {
      $n$0 = 2;
      break;
     }
     _luaO_tostring($L,$2);
     $n$0 = 2;
     break;
    }
    if ($17) {
     $19 = HEAP32[$2>>2]|0;
     $20 = ((($19)) + 12|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==(0);
     if ($22) {
      ;HEAP32[$2>>2]=HEAP32[$7>>2]|0;HEAP32[$2+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$7+12>>2]|0;
      $n$0 = 2;
      break;
     }
    }
    $23 = ($$0|0)>(1);
    L16: do {
     if ($23) {
      $i$05 = 1;$tl$06 = $13;
      while(1) {
       $$sum = $i$05 ^ -1;
       $24 = (($3) + ($$sum<<4)|0);
       $25 = (((($3) + ($$sum<<4)|0)) + 8|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = $26 & 15;
       if ((($27|0) == 3)) {
        _luaO_tostring($L,$24);
       } else if (!((($27|0) == 4))) {
        $i$0$lcssa = $i$05;$tl$0$lcssa = $tl$06;
        break L16;
       }
       $28 = HEAP32[$24>>2]|0;
       $29 = ((($28)) + 12|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = $tl$06 ^ -1;
       $32 = ($30>>>0)<($31>>>0);
       if (!($32)) {
        label = 16;
        break L1;
       }
       $33 = (($30) + ($tl$06))|0;
       $34 = (($i$05) + 1)|0;
       $35 = ($34|0)<($$0|0);
       if ($35) {
        $i$05 = $34;$tl$06 = $33;
       } else {
        $i$0$lcssa = $34;$tl$0$lcssa = $33;
        break;
       }
      }
     } else {
      $i$0$lcssa = 1;$tl$0$lcssa = $13;
     }
    } while(0);
    $36 = HEAP32[$1>>2]|0;
    $37 = ((($36)) + 108|0);
    $38 = (_luaZ_openspace($L,$37,$tl$0$lcssa)|0);
    $i$1 = $i$0$lcssa;$tl$1 = 0;
    while(1) {
     $39 = (0 - ($i$1))|0;
     $40 = (($3) + ($39<<4)|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ((($41)) + 12|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($38) + ($tl$1)|0);
     $45 = ((($41)) + 24|0);
     _memcpy(($44|0),($45|0),($43|0))|0;
     $46 = (($43) + ($tl$1))|0;
     $47 = (($i$1) + -1)|0;
     $48 = ($i$1|0)>(1);
     if ($48) {
      $i$1 = $47;$tl$1 = $46;
     } else {
      $$lcssa = $46;
      break;
     }
    }
    $49 = (0 - ($i$0$lcssa))|0;
    $50 = (($3) + ($49<<4)|0);
    $51 = (_luaS_newlstr($L,$38,$$lcssa)|0);
    HEAP32[$50>>2] = $51;
    $52 = ((($51)) + 4|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = $53&255;
    $55 = $54 | 64;
    $56 = (((($3) + ($49<<4)|0)) + 8|0);
    HEAP32[$56>>2] = $55;
    $n$0 = $i$0$lcssa;
   } else {
    label = 5;
   }
  } while(0);
  if ((label|0) == 5) {
   label = 0;
   _luaT_trybinTM($L,$2,$7,$2,22);
   $n$0 = 2;
  }
  $$neg = (($$0) + 1)|0;
  $57 = (($$neg) - ($n$0))|0;
  $58 = HEAP32[$0>>2]|0;
  $59 = (1 - ($n$0))|0;
  $60 = (($58) + ($59<<4)|0);
  HEAP32[$0>>2] = $60;
  $61 = ($57|0)>(1);
  if ($61) {
   $$0 = $57;$3 = $60;
  } else {
   label = 22;
   break;
  }
 }
 if ((label|0) == 16) {
  _luaG_runerror($L,4584,$vararg_buffer);
  // unreachable;
 }
 else if ((label|0) == 22) {
  STACKTOP = sp;return;
 }
}
function _luaV_objlen($L,$ra,$rb) {
 $L = $L|0;
 $ra = $ra|0;
 $rb = $rb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tm$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($rb)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 do {
  if ((($2|0) == 4)) {
   $25 = HEAP32[$rb>>2]|0;
   $26 = ((($25)) + 12|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = $ra;
   $29 = $28;
   HEAP32[$29>>2] = $27;
   $30 = (($28) + 4)|0;
   $31 = $30;
   HEAP32[$31>>2] = 0;
   $32 = ((($ra)) + 8|0);
   HEAP32[$32>>2] = 19;
   return;
  } else if ((($2|0) == 5)) {
   $3 = HEAP32[$rb>>2]|0;
   $4 = ((($3)) + 24|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $7 = ((($5)) + 6|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8 & 16;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $11 = ((($L)) + 12|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ((($12)) + 164|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (_luaT_gettm($5,4,$14)|0);
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      $tm$0 = $15;
      break;
     }
    }
   }
   $17 = (_luaH_getn($3)|0);
   $18 = ($17|0)<(0);
   $19 = $18 << 31 >> 31;
   $20 = $ra;
   $21 = $20;
   HEAP32[$21>>2] = $17;
   $22 = (($20) + 4)|0;
   $23 = $22;
   HEAP32[$23>>2] = $19;
   $24 = ((($ra)) + 8|0);
   HEAP32[$24>>2] = 19;
   return;
  } else {
   $33 = (_luaT_gettmbyobj($L,$rb,4)|0);
   $34 = ((($33)) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0);
   if ($36) {
    _luaG_typeerror($L,$rb,4608);
    // unreachable;
   } else {
    $tm$0 = $33;
   }
  }
 } while(0);
 _luaT_callTM($L,$tm$0,$rb,$rb,$ra,1);
 return;
}
function _luaV_div($L,$0,$1,$2,$3) {
 $L = $L|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $4 = (_i64Add(($2|0),($3|0),1,0)|0);
 $5 = tempRet0;
 $6 = ($5>>>0)<(0);
 $7 = ($4>>>0)<(2);
 $8 = ($5|0)==(0);
 $9 = $8 & $7;
 $10 = $6 | $9;
 if (!($10)) {
  $16 = (___divdi3(($0|0),($1|0),($2|0),($3|0))|0);
  $17 = tempRet0;
  $2 ^ $0;
  $18 = $3 ^ $1;
  $19 = ($18|0)<(0);
  if ($19) {
   $20 = (___remdi3(($0|0),($1|0),($2|0),($3|0))|0);
   $21 = tempRet0;
   $22 = ($20|0)!=(0);
   $23 = ($21|0)!=(0);
   $24 = $22 | $23;
   $25 = $24 << 31 >> 31;
   $26 = ($25|0)<(0);
   $27 = $26 << 31 >> 31;
   $28 = (_i64Add(($25|0),($27|0),($16|0),($17|0))|0);
   $29 = tempRet0;
   tempRet0 = ($29);
   STACKTOP = sp;return ($28|0);
  } else {
   $30 = $17;$31 = $16;
   tempRet0 = ($30);
   STACKTOP = sp;return ($31|0);
  }
 }
 $11 = ($2|0)==(0);
 $12 = ($3|0)==(0);
 $13 = $11 & $12;
 if ($13) {
  _luaG_runerror($L,4624,$vararg_buffer);
  // unreachable;
 }
 $14 = (_i64Subtract(0,0,($0|0),($1|0))|0);
 $15 = tempRet0;
 $30 = $15;$31 = $14;
 tempRet0 = ($30);
 STACKTOP = sp;return ($31|0);
}
function _luaV_mod($L,$0,$1,$2,$3) {
 $L = $L|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $4 = (_i64Add(($2|0),($3|0),1,0)|0);
 $5 = tempRet0;
 $6 = ($5>>>0)<(0);
 $7 = ($4>>>0)<(2);
 $8 = ($5|0)==(0);
 $9 = $8 & $7;
 $10 = $6 | $9;
 if (!($10)) {
  $14 = (___remdi3(($0|0),($1|0),($2|0),($3|0))|0);
  $15 = tempRet0;
  $16 = ($14|0)!=(0);
  $17 = ($15|0)!=(0);
  $18 = $16 | $17;
  $2 ^ $0;
  $19 = $3 ^ $1;
  $20 = ($19|0)<(0);
  $or$cond = $20 & $18;
  $21 = $or$cond ? $2 : 0;
  $22 = $or$cond ? $3 : 0;
  $23 = (_i64Add(($21|0),($22|0),($14|0),($15|0))|0);
  $24 = tempRet0;
  $25 = $24;$26 = $23;
  tempRet0 = ($25);
  STACKTOP = sp;return ($26|0);
 }
 $11 = ($2|0)==(0);
 $12 = ($3|0)==(0);
 $13 = $11 & $12;
 if ($13) {
  _luaG_runerror($L,4656,$vararg_buffer);
  // unreachable;
 } else {
  $25 = 0;$26 = 0;
  tempRet0 = ($25);
  STACKTOP = sp;return ($26|0);
 }
 return (0)|0;
}
function _luaV_shiftl($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)<(0);
 if ($4) {
  $5 = ($3|0)<(-1);
  $6 = ($2>>>0)<(4294967233);
  $7 = ($3|0)==(-1);
  $8 = $7 & $6;
  $9 = $5 | $8;
  $10 = (_i64Subtract(0,0,($2|0),($3|0))|0);
  $11 = tempRet0;
  $12 = (_bitshift64Lshr(($0|0),($1|0),($10|0))|0);
  $13 = tempRet0;
  $14 = $9 ? 0 : $12;
  $15 = $9 ? 0 : $13;
  tempRet0 = ($15);
  return ($14|0);
 } else {
  $16 = ($3|0)>(0);
  $17 = ($2>>>0)>(63);
  $18 = ($3|0)==(0);
  $19 = $18 & $17;
  $20 = $16 | $19;
  $21 = (_bitshift64Shl(($0|0),($1|0),($2|0))|0);
  $22 = tempRet0;
  $23 = $20 ? 0 : $21;
  $24 = $20 ? 0 : $22;
  tempRet0 = ($24);
  return ($23|0);
 }
 return (0)|0;
}
function _luaV_execute($L) {
 $L = $L|0;
 var $$02$i$i = 0, $$02$i$i$lcssa = 0, $$02$i$i$lcssa959 = 0, $$02$i$i102 = 0, $$02$i$i102$lcssa = 0, $$02$i$i102$lcssa943 = 0, $$02$i$i107 = 0, $$02$i$i107$lcssa = 0, $$02$i$i107$lcssa945 = 0, $$02$i$i146 = 0, $$02$i$i146$lcssa = 0, $$02$i$i146$lcssa941 = 0, $$02$i$i151 = 0, $$02$i$i151$lcssa = 0, $$02$i$i151$lcssa939 = 0, $$02$i$i66 = 0, $$02$i$i66$lcssa = 0, $$02$i$i66$lcssa961 = 0, $$02$i$i71 = 0, $$02$i$i71$lcssa = 0;
 var $$02$i$i71$lcssa955 = 0, $$02$i$i76 = 0, $$02$i$i76$lcssa = 0, $$02$i$i76$lcssa957 = 0, $$02$i$i81 = 0, $$02$i$i81$lcssa = 0, $$02$i$i81$lcssa951 = 0, $$02$i$i86 = 0, $$02$i$i86$lcssa = 0, $$02$i$i86$lcssa953 = 0, $$02$i$i91 = 0, $$02$i$i91$lcssa = 0, $$02$i$i91$lcssa947 = 0, $$02$i$i96 = 0, $$02$i$i96$lcssa = 0, $$02$i$i96$lcssa949 = 0, $$lcssa = 0, $$lcssa977 = 0, $$lcssa985 = 0, $$ph = 0.0;
 var $$ph$i = 0.0, $$ph173 = 0.0, $$ph178 = 0.0, $$ph181 = 0.0, $$ph186 = 0.0, $$ph189 = 0.0, $$ph192 = 0.0, $$ph195 = 0.0, $$ph230 = 0.0, $$ph233 = 0.0, $$ph238 = 0.0, $$ph241 = 0.0, $$ph244 = 0.0, $$ph247 = 0.0, $$ph263 = 0.0, $$ph266 = 0.0, $$ph269 = 0.0, $$phi$trans$insert = 0, $$phi$trans$insert723 = 0, $$phi$trans$insert733 = 0;
 var $$phi$trans$insert736 = 0, $$phi$trans$insert739 = 0, $$phi$trans$insert742 = 0, $$phi$trans$insert745 = 0, $$phi$trans$insert748 = 0, $$phi$trans$insert751 = 0, $$phi$trans$insert754 = 0, $$phi$trans$insert757 = 0, $$phi$trans$insert760 = 0, $$pre = 0, $$pre$phi765Z2D = 0, $$pre$phi767Z2D = 0, $$pre$phi769Z2D = 0, $$pre$phiZ2D = 0, $$pre724 = 0, $$pre725 = 0, $$pre726 = 0, $$pre727 = 0, $$pre728 = 0, $$pre729 = 0;
 var $$pre731 = 0, $$pre734 = 0, $$pre737 = 0, $$pre740 = 0, $$pre743 = 0, $$pre746 = 0, $$pre749 = 0, $$pre752 = 0, $$pre755 = 0, $$pre758 = 0, $$pre761 = 0, $$pre762$pre$phiZZ2D = 0, $$pre763 = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0;
 var $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum26 = 0, $$sum28 = 0, $$sum3 = 0, $$sum30 = 0, $$sum31 = 0, $$sum32 = 0, $$sum33 = 0, $$sum34 = 0, $$sum35 = 0, $$sum4 = 0;
 var $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0;
 var $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0.0;
 var $1029 = 0.0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0;
 var $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0;
 var $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0;
 var $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0;
 var $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0;
 var $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0;
 var $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0.0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0;
 var $1155 = 0, $1156 = 0.0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0;
 var $1173 = 0, $1174 = 0, $1175 = 0.0, $1176 = 0.0, $1177 = 0.0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0.0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0.0, $119 = 0, $1190 = 0;
 var $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0.0;
 var $1209 = 0.0, $121 = 0, $1210 = 0.0, $1211 = 0.0, $1212 = 0.0, $1213 = 0.0, $1214 = 0.0, $1215 = 0, $1216 = 0.0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0;
 var $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0;
 var $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0;
 var $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0;
 var $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0.0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0.0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0;
 var $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0.0, $1311 = 0.0, $1312 = 0.0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0.0;
 var $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0.0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0;
 var $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0.0, $1344 = 0.0, $1345 = 0.0, $1346 = 0.0, $1347 = 0.0, $1348 = 0.0, $1349 = 0.0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0;
 var $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0.0;
 var $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0.0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0;
 var $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0.0, $1398 = 0.0, $1399 = 0.0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0.0, $1404 = 0, $1405 = 0, $1406 = 0;
 var $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0.0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0;
 var $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0.0, $1431 = 0.0, $1432 = 0.0, $1433 = 0.0, $1434 = 0.0, $1435 = 0.0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0;
 var $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0.0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0;
 var $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0.0, $1475 = 0.0, $1476 = 0.0, $1477 = 0.0, $1478 = 0.0, $1479 = 0;
 var $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0.0, $1495 = 0.0, $1496 = 0, $1497 = 0;
 var $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0;
 var $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0;
 var $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0;
 var $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0;
 var $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0;
 var $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0;
 var $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0;
 var $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0;
 var $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0;
 var $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0;
 var $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0;
 var $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0;
 var $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0;
 var $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0;
 var $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0;
 var $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0;
 var $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0;
 var $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0;
 var $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0;
 var $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0.0, $1848 = 0.0, $1849 = 0.0, $185 = 0, $1850 = 0, $1851 = 0.0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0;
 var $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0;
 var $1876 = 0, $1877 = 0, $1878 = 0.0, $1879 = 0.0, $188 = 0, $1880 = 0, $1881 = 0.0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0;
 var $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0.0, $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0;
 var $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0.0, $1915 = 0, $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0;
 var $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0.0, $1934 = 0.0, $1935 = 0.0, $1936 = 0, $1937 = 0.0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0;
 var $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0;
 var $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0, $1970 = 0, $1971 = 0, $1972 = 0.0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0, $198 = 0, $1980 = 0.0, $1981 = 0, $1982 = 0, $1983 = 0;
 var $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = 0, $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0, $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0.0, $2 = 0, $20 = 0, $200 = 0;
 var $2000 = 0.0, $2001 = 0.0, $2002 = 0.0, $2003 = 0, $2004 = 0, $2005 = 0, $2006 = 0.0, $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0.0, $2015 = 0, $2016 = 0, $2017 = 0, $2018 = 0;
 var $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0, $2022 = 0, $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0, $203 = 0, $2030 = 0, $2031 = 0, $2032 = 0, $2033 = 0.0, $2034 = 0.0, $2035 = 0.0, $2036 = 0.0;
 var $2037 = 0, $2038 = 0, $2039 = 0.0, $204 = 0, $2040 = 0, $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0.0, $2048 = 0, $2049 = 0, $205 = 0, $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0, $2054 = 0;
 var $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0, $2059 = 0, $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0, $2066 = 0.0, $2067 = 0.0, $2068 = 0.0, $2069 = 0.0, $207 = 0, $2070 = 0.0, $2071 = 0, $2072 = 0;
 var $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0, $2078 = 0, $2079 = 0, $208 = 0, $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0, $2084 = 0, $2085 = 0, $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0, $209 = 0, $2090 = 0;
 var $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0, $2096 = 0, $2097 = 0, $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0, $2101 = 0, $2102 = 0, $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0, $2108 = 0;
 var $2109 = 0, $211 = 0, $2110 = 0, $2111 = 0, $2112 = 0, $2113 = 0, $2114 = 0, $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0, $212 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0;
 var $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0.0, $2130 = 0, $2131 = 0, $2132 = 0, $2133 = 0, $2134 = 0, $2135 = 0, $2136 = 0, $2137 = 0, $2138 = 0, $2139 = 0, $214 = 0, $2140 = 0, $2141 = 0, $2142 = 0, $2143 = 0, $2144 = 0;
 var $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0, $2149 = 0, $215 = 0, $2150 = 0, $2151 = 0, $2152 = 0, $2153 = 0, $2154 = 0, $2155 = 0, $2156 = 0, $2157 = 0, $2158 = 0, $2159 = 0, $216 = 0, $2160 = 0, $2161 = 0, $2162 = 0;
 var $2163 = 0, $2164 = 0, $2165 = 0, $2166 = 0, $2167 = 0, $2168 = 0, $2169 = 0, $217 = 0, $2170 = 0, $2171 = 0, $2172 = 0, $2173 = 0, $2174 = 0, $2175 = 0, $2176 = 0, $2177 = 0, $2178 = 0, $2179 = 0, $218 = 0, $2180 = 0;
 var $2181 = 0, $2182 = 0, $2183 = 0, $2184 = 0, $2185 = 0, $2186 = 0, $2187 = 0, $2188 = 0, $2189 = 0, $219 = 0, $2190 = 0, $2191 = 0, $2192 = 0, $2193 = 0, $2194 = 0, $2195 = 0, $2196 = 0, $2197 = 0, $2198 = 0, $2199 = 0;
 var $22 = 0, $220 = 0.0, $2200 = 0, $2201 = 0, $2202 = 0, $2203 = 0, $2204 = 0, $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = 0, $221 = 0, $2210 = 0, $2211 = 0, $2212 = 0, $2213 = 0, $2214 = 0, $2215 = 0, $2216 = 0;
 var $2217 = 0, $2218 = 0, $2219 = 0, $222 = 0, $2220 = 0, $2221 = 0, $2222 = 0, $2223 = 0, $2224 = 0, $2225 = 0, $2226 = 0, $2227 = 0, $2228 = 0, $2229 = 0, $223 = 0, $2230 = 0, $2231 = 0, $2232 = 0, $2233 = 0, $2234 = 0;
 var $2235 = 0, $2236 = 0, $2237 = 0, $2238 = 0, $2239 = 0, $224 = 0, $2240 = 0, $2241 = 0, $2242 = 0, $2243 = 0, $2244 = 0, $2245 = 0, $2246 = 0, $2247 = 0, $2248 = 0, $2249 = 0, $225 = 0, $2250 = 0, $2251 = 0, $2252 = 0;
 var $2253 = 0, $2254 = 0, $2255 = 0, $2256 = 0, $2257 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0.0;
 var $24 = 0, $240 = 0.0, $241 = 0.0, $242 = 0, $243 = 0, $244 = 0, $245 = 0.0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0.0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0.0, $273 = 0.0, $274 = 0.0, $275 = 0.0;
 var $276 = 0.0, $277 = 0.0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0.0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0.0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0.0, $346 = 0.0, $347 = 0.0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0.0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0.0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0.0, $379 = 0.0, $38 = 0, $380 = 0.0, $381 = 0.0, $382 = 0.0, $383 = 0.0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0.0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0.0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0.0, $452 = 0.0, $453 = 0.0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0.0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0.0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0.0, $485 = 0.0, $486 = 0.0, $487 = 0.0, $488 = 0.0, $489 = 0.0, $49 = 0, $490 = 0, $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0.0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0.0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0.0, $538 = 0.0, $539 = 0.0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0.0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0.0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0.0, $571 = 0.0, $572 = 0.0, $573 = 0.0, $574 = 0.0, $575 = 0.0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0.0, $603 = 0.0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0.0;
 var $636 = 0.0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0;
 var $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0;
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0.0, $696 = 0.0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0;
 var $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0;
 var $726 = 0, $727 = 0, $728 = 0.0, $729 = 0.0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0;
 var $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0;
 var $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0.0, $789 = 0.0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0;
 var $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0;
 var $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0.0, $822 = 0.0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0;
 var $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0;
 var $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0;
 var $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0.0, $882 = 0.0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0;
 var $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0;
 var $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0.0, $915 = 0.0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0;
 var $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0;
 var $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0;
 var $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0;
 var $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0.0, $996 = 0.0;
 var $997 = 0, $998 = 0, $999 = 0, $aux$0521 = 0, $b$0 = 0, $b131$0 = 0, $base$0 = 0, $base$1 = 0, $base$1$lcssa = 0, $base$2 = 0, $c128$0 = 0, $ci$0 = 0, $exitcond = 0, $exitcond$i = 0, $f$0$i$i = 0.0, $i$0 = 0, $i$01$i = 0, $i$01$i168 = 0, $j$0517 = 0, $last$0519 = 0;
 var $m$0 = 0.0, $n$0 = 0, $n$1518 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i$i103 = 0, $or$cond$i$i108 = 0, $or$cond$i$i147 = 0, $or$cond$i$i152 = 0, $or$cond$i$i67 = 0, $or$cond$i$i72 = 0, $or$cond$i$i77 = 0, $or$cond$i$i82 = 0, $or$cond$i$i87 = 0, $or$cond$i$i92 = 0, $or$cond$i$i97 = 0, $or$cond828 = 0, $ra$0 = 0, $ra$1 = 0;
 var $storemerge = 0, $storemerge25 = 0, $storemerge27 = 0, $storemerge29 = 0, $v$i = 0, $v$i$i = 0, $v$i$i101 = 0, $v$i$i106 = 0, $v$i$i145 = 0, $v$i$i150 = 0, $v$i$i65 = 0, $v$i$i70 = 0, $v$i$i75 = 0, $v$i$i80 = 0, $v$i$i85 = 0, $v$i$i90 = 0, $v$i$i95 = 0, $v$i1$i = 0, $v$i115 = 0, $v$i119 = 0;
 var $v$i125 = 0, $v$i129 = 0, $v$i133 = 0, $v$i137 = 0, $v$i141 = 0, $v$i154 = 0, $v$i158 = 0, $v$i162 = 0, $v$i37 = 0, $v$i41 = 0, $v$i45 = 0, $v$i49 = 0, $v$i53 = 0, $v$i57 = 0, $v$i61 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer7 = sp + 528|0;
 $vararg_buffer5 = sp + 520|0;
 $vararg_buffer3 = sp + 512|0;
 $vararg_buffer1 = sp + 504|0;
 $vararg_buffer = sp + 496|0;
 $v$i162 = sp + 480|0;
 $v$i158 = sp + 464|0;
 $v$i154 = sp + 448|0;
 $v$i1$i = sp + 432|0;
 $v$i$i150 = sp + 416|0;
 $v$i$i145 = sp + 400|0;
 $v$i141 = sp + 384|0;
 $v$i137 = sp + 368|0;
 $v$i133 = sp + 352|0;
 $v$i129 = sp + 336|0;
 $v$i125 = sp + 320|0;
 $v$i119 = sp + 304|0;
 $v$i115 = sp + 288|0;
 $v$i$i106 = sp + 272|0;
 $v$i$i101 = sp + 256|0;
 $v$i$i95 = sp + 240|0;
 $v$i$i90 = sp + 224|0;
 $v$i$i85 = sp + 208|0;
 $v$i$i80 = sp + 192|0;
 $v$i$i75 = sp + 176|0;
 $v$i$i70 = sp + 160|0;
 $v$i$i65 = sp + 144|0;
 $v$i$i = sp + 128|0;
 $v$i61 = sp + 112|0;
 $v$i57 = sp + 96|0;
 $v$i53 = sp + 80|0;
 $v$i49 = sp + 64|0;
 $v$i45 = sp + 48|0;
 $v$i41 = sp + 32|0;
 $v$i37 = sp + 16|0;
 $v$i = sp;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 108|0);
 $3 = ((($L)) + 12|0);
 $4 = ((($L)) + 8|0);
 $5 = ((($v$i37)) + 8|0);
 $6 = ((($v$i)) + 8|0);
 $7 = ((($v$i45)) + 8|0);
 $8 = ((($v$i41)) + 8|0);
 $9 = ((($v$i53)) + 8|0);
 $10 = ((($v$i49)) + 8|0);
 $11 = ((($v$i61)) + 8|0);
 $12 = ((($v$i57)) + 8|0);
 $13 = ((($v$i119)) + 8|0);
 $14 = ((($v$i115)) + 8|0);
 $15 = ((($v$i129)) + 8|0);
 $16 = ((($v$i125)) + 8|0);
 $17 = ((($v$i137)) + 8|0);
 $18 = ((($v$i133)) + 8|0);
 $19 = ((($v$i141)) + 8|0);
 $20 = ((($v$i1$i)) + 8|0);
 $21 = ((($v$i162)) + 8|0);
 $22 = ((($v$i158)) + 8|0);
 $23 = ((($v$i154)) + 8|0);
 $24 = ((($L)) + 24|0);
 $25 = ((($L)) + 100|0);
 $$phi$trans$insert760 = ((($v$i$i65)) + 8|0);
 $$phi$trans$insert757 = ((($v$i$i)) + 8|0);
 $$phi$trans$insert754 = ((($v$i$i75)) + 8|0);
 $$phi$trans$insert751 = ((($v$i$i70)) + 8|0);
 $$phi$trans$insert748 = ((($v$i$i85)) + 8|0);
 $$phi$trans$insert745 = ((($v$i$i80)) + 8|0);
 $$phi$trans$insert742 = ((($v$i$i95)) + 8|0);
 $$phi$trans$insert739 = ((($v$i$i90)) + 8|0);
 $$phi$trans$insert736 = ((($v$i$i106)) + 8|0);
 $$phi$trans$insert733 = ((($v$i$i101)) + 8|0);
 $ci$0 = $1;
 L1: while(1) {
  $26 = HEAP32[$ci$0>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($27)) + 12|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ((($29)) + 44|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($ci$0)) + 16|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($ci$0)) + 20|0);
  $35 = ((($ci$0)) + 4|0);
  $base$0 = $33;
  L3: while(1) {
   $36 = HEAP32[$34>>2]|0;
   $37 = ((($36)) + 4|0);
   HEAP32[$34>>2] = $37;
   $38 = HEAP32[$36>>2]|0;
   $39 = HEAP8[$2>>0]|0;
   $40 = $39 & 12;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    $base$1 = $base$0;
   } else {
    $42 = HEAP32[$25>>2]|0;
    $43 = (($42) + -1)|0;
    HEAP32[$25>>2] = $43;
    $44 = ($43|0)!=(0);
    $45 = $39 & 4;
    $46 = ($45<<24>>24)==(0);
    $or$cond828 = $44 & $46;
    if ($or$cond828) {
     $base$1 = $base$0;
    } else {
     _luaG_traceexec($L);
     $47 = HEAP32[$32>>2]|0;
     $base$1 = $47;
    }
   }
   $48 = $38 >>> 6;
   $49 = $48 & 255;
   $50 = (($base$1) + ($49<<4)|0);
   $51 = $38 & 63;
   do {
    switch ($51|0) {
    case 7:  {
     $89 = $38 >>> 23;
     $90 = (($base$1) + ($89<<4)|0);
     $91 = $38 >>> 14;
     $92 = $91 & 256;
     $93 = ($92|0)==(0);
     $94 = $91 & 255;
     $95 = (($31) + ($94<<4)|0);
     $96 = $91 & 511;
     $97 = (($base$1) + ($96<<4)|0);
     $98 = $93 ? $97 : $95;
     _luaV_gettable($L,$90,$98,$50);
     $99 = HEAP32[$32>>2]|0;
     $base$0 = $99;
     continue L3;
     break;
    }
    case 15:  {
     $386 = $38 >>> 23;
     $387 = $386 & 256;
     $388 = ($387|0)==(0);
     $389 = $386 & 255;
     $390 = (($31) + ($389<<4)|0);
     $391 = (($base$1) + ($386<<4)|0);
     $392 = $388 ? $391 : $390;
     $393 = $38 >>> 14;
     $394 = $393 & 256;
     $395 = ($394|0)==(0);
     $396 = $393 & 255;
     $397 = (($31) + ($396<<4)|0);
     $398 = $393 & 511;
     $399 = (($base$1) + ($398<<4)|0);
     $400 = $395 ? $399 : $397;
     $401 = ((($392)) + 8|0);
     $402 = HEAP32[$401>>2]|0;
     do {
      if ((($402|0) == 19)) {
       $403 = ((($400)) + 8|0);
       $404 = HEAP32[$403>>2]|0;
       $405 = ($404|0)==(19);
       if ($405) {
        $406 = $392;
        $407 = $406;
        $408 = HEAP32[$407>>2]|0;
        $409 = (($406) + 4)|0;
        $410 = $409;
        $411 = HEAP32[$410>>2]|0;
        $412 = $400;
        $413 = $412;
        $414 = HEAP32[$413>>2]|0;
        $415 = (($412) + 4)|0;
        $416 = $415;
        $417 = HEAP32[$416>>2]|0;
        $418 = (___muldi3(($414|0),($417|0),($408|0),($411|0))|0);
        $419 = tempRet0;
        $420 = $50;
        $421 = $420;
        HEAP32[$421>>2] = $418;
        $422 = (($420) + 4)|0;
        $423 = $422;
        HEAP32[$423>>2] = $419;
        $424 = (((($base$1) + ($49<<4)|0)) + 8|0);
        HEAP32[$424>>2] = 19;
        $base$0 = $base$1;
        continue L3;
       } else {
        $426 = $392;
        $427 = $426;
        $428 = HEAP32[$427>>2]|0;
        $429 = (($426) + 4)|0;
        $430 = $429;
        $431 = HEAP32[$430>>2]|0;
        $432 = (+($428>>>0)) + (4294967296.0*(+($431|0)));
        $$ph186 = $432;
        label = 78;
        break;
       }
      } else if ((($402|0) == 3)) {
       $425 = +HEAPF64[$392>>3];
       $488 = $425;
       label = 79;
      } else {
       $433 = $402 & 15;
       $434 = ($433|0)==(4);
       if ($434) {
        $435 = HEAP32[$392>>2]|0;
        $436 = ((($435)) + 24|0);
        $437 = (_luaO_str2num($436,$v$i49)|0);
        $438 = HEAP32[$392>>2]|0;
        $439 = ((($438)) + 12|0);
        $440 = HEAP32[$439>>2]|0;
        $441 = (($440) + 1)|0;
        $442 = ($437|0)==($441|0);
        if ($442) {
         $443 = HEAP32[$10>>2]|0;
         $444 = ($443|0)==(19);
         $445 = $v$i49;
         $446 = $445;
         $447 = HEAP32[$446>>2]|0;
         $448 = (($445) + 4)|0;
         $449 = $448;
         $450 = HEAP32[$449>>2]|0;
         $451 = (+($447>>>0)) + (4294967296.0*(+($450|0)));
         HEAP32[tempDoublePtr>>2] = $447;HEAP32[tempDoublePtr+4>>2] = $450;$452 = +HEAPF64[tempDoublePtr>>3];
         $453 = $444 ? $451 : $452;
         $$ph186 = $453;
         label = 78;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 78) {
      label = 0;
      $488 = $$ph186;
      label = 79;
     }
     L25: do {
      if ((label|0) == 79) {
       label = 0;
       $454 = ((($400)) + 8|0);
       $455 = HEAP32[$454>>2]|0;
       $456 = ($455|0)==(3);
       if ($456) {
        $457 = +HEAPF64[$400>>3];
        $489 = $457;
       } else {
        $458 = ($455|0)==(19);
        do {
         if ($458) {
          $459 = $400;
          $460 = $459;
          $461 = HEAP32[$460>>2]|0;
          $462 = (($459) + 4)|0;
          $463 = $462;
          $464 = HEAP32[$463>>2]|0;
          $465 = (+($461>>>0)) + (4294967296.0*(+($464|0)));
          $$ph189 = $465;
         } else {
          $466 = $455 & 15;
          $467 = ($466|0)==(4);
          if ($467) {
           $468 = HEAP32[$400>>2]|0;
           $469 = ((($468)) + 24|0);
           $470 = (_luaO_str2num($469,$v$i53)|0);
           $471 = HEAP32[$400>>2]|0;
           $472 = ((($471)) + 12|0);
           $473 = HEAP32[$472>>2]|0;
           $474 = (($473) + 1)|0;
           $475 = ($470|0)==($474|0);
           if ($475) {
            $476 = HEAP32[$9>>2]|0;
            $477 = ($476|0)==(19);
            $478 = $v$i53;
            $479 = $478;
            $480 = HEAP32[$479>>2]|0;
            $481 = (($478) + 4)|0;
            $482 = $481;
            $483 = HEAP32[$482>>2]|0;
            $484 = (+($480>>>0)) + (4294967296.0*(+($483|0)));
            HEAP32[tempDoublePtr>>2] = $480;HEAP32[tempDoublePtr+4>>2] = $483;$485 = +HEAPF64[tempDoublePtr>>3];
            $486 = $477 ? $484 : $485;
            $$ph189 = $486;
            break;
           }
          }
          break L25;
         }
        } while(0);
        $489 = $$ph189;
       }
       $487 = $488 * $489;
       HEAPF64[$50>>3] = $487;
       $490 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$490>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$392,$400,$50,8);
     $491 = HEAP32[$32>>2]|0;
     $base$0 = $491;
     continue L3;
     break;
    }
    case 11:  {
     $146 = $38 >>> 23;
     $147 = $38 >>> 14;
     $148 = $147 & 511;
     $149 = (_luaH_new($L)|0);
     HEAP32[$50>>2] = $149;
     $150 = (((($base$1) + ($49<<4)|0)) + 8|0);
     HEAP32[$150>>2] = 69;
     $151 = $148 | $146;
     $152 = ($151|0)==(0);
     if (!($152)) {
      $153 = (_luaO_fb2int($146)|0);
      $154 = (_luaO_fb2int($148)|0);
      _luaH_resize($L,$149,$153,$154);
     }
     $155 = HEAP32[$3>>2]|0;
     $156 = ((($155)) + 12|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = ($157|0)>(0);
     if ($158) {
      $$sum35 = (($49) + 1)|0;
      $159 = (($base$1) + ($$sum35<<4)|0);
      HEAP32[$4>>2] = $159;
      _luaC_step($L);
      $160 = HEAP32[$35>>2]|0;
      HEAP32[$4>>2] = $160;
     }
     $161 = HEAP32[$32>>2]|0;
     $base$0 = $161;
     continue L3;
     break;
    }
    case 4:  {
     $67 = $38 >>> 23;
     $b$0 = $67;$ra$0 = $50;
     while(1) {
      $68 = ((($ra$0)) + 16|0);
      $69 = ((($ra$0)) + 8|0);
      HEAP32[$69>>2] = 0;
      $70 = (($b$0) + -1)|0;
      $71 = ($b$0|0)==(0);
      if ($71) {
       $base$0 = $base$1;
       continue L3;
      } else {
       $b$0 = $70;$ra$0 = $68;
      }
     }
     break;
    }
    case 1:  {
     $54 = $38 >>> 14;
     $55 = (($31) + ($54<<4)|0);
     ;HEAP32[$50>>2]=HEAP32[$55>>2]|0;HEAP32[$50+4>>2]=HEAP32[$55+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$55+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$55+12>>2]|0;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 9:  {
     $119 = $38 >>> 23;
     $120 = (((($27)) + 16|0) + ($119<<2)|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = HEAP32[$121>>2]|0;
     ;HEAP32[$122>>2]=HEAP32[$50>>2]|0;HEAP32[$122+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$122+8>>2]=HEAP32[$50+8>>2]|0;HEAP32[$122+12>>2]=HEAP32[$50+12>>2]|0;
     $123 = HEAP32[$121>>2]|0;
     $124 = ((($123)) + 8|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = $125 & 64;
     $127 = ($126|0)!=(0);
     $128 = ((($121)) + 8|0);
     $129 = ($123|0)==($128|0);
     $or$cond = $129 & $127;
     if (!($or$cond)) {
      $base$0 = $base$1;
      continue L3;
     }
     _luaC_upvalbarrier_($L,$121);
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 2:  {
     $56 = HEAP32[$34>>2]|0;
     $57 = ((($56)) + 4|0);
     HEAP32[$34>>2] = $57;
     $58 = HEAP32[$56>>2]|0;
     $59 = $58 >>> 6;
     $60 = (($31) + ($59<<4)|0);
     ;HEAP32[$50>>2]=HEAP32[$60>>2]|0;HEAP32[$50+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$60+12>>2]|0;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 13:  {
     $174 = $38 >>> 23;
     $175 = $174 & 256;
     $176 = ($175|0)==(0);
     $177 = $174 & 255;
     $178 = (($31) + ($177<<4)|0);
     $179 = (($base$1) + ($174<<4)|0);
     $180 = $176 ? $179 : $178;
     $181 = $38 >>> 14;
     $182 = $181 & 256;
     $183 = ($182|0)==(0);
     $184 = $181 & 255;
     $185 = (($31) + ($184<<4)|0);
     $186 = $181 & 511;
     $187 = (($base$1) + ($186<<4)|0);
     $188 = $183 ? $187 : $185;
     $189 = ((($180)) + 8|0);
     $190 = HEAP32[$189>>2]|0;
     do {
      if ((($190|0) == 3)) {
       $213 = +HEAPF64[$180>>3];
       $276 = $213;
       label = 37;
      } else if ((($190|0) == 19)) {
       $191 = ((($188)) + 8|0);
       $192 = HEAP32[$191>>2]|0;
       $193 = ($192|0)==(19);
       if ($193) {
        $194 = $180;
        $195 = $194;
        $196 = HEAP32[$195>>2]|0;
        $197 = (($194) + 4)|0;
        $198 = $197;
        $199 = HEAP32[$198>>2]|0;
        $200 = $188;
        $201 = $200;
        $202 = HEAP32[$201>>2]|0;
        $203 = (($200) + 4)|0;
        $204 = $203;
        $205 = HEAP32[$204>>2]|0;
        $206 = (_i64Add(($202|0),($205|0),($196|0),($199|0))|0);
        $207 = tempRet0;
        $208 = $50;
        $209 = $208;
        HEAP32[$209>>2] = $206;
        $210 = (($208) + 4)|0;
        $211 = $210;
        HEAP32[$211>>2] = $207;
        $212 = (((($base$1) + ($49<<4)|0)) + 8|0);
        HEAP32[$212>>2] = 19;
        $base$0 = $base$1;
        continue L3;
       } else {
        $214 = $180;
        $215 = $214;
        $216 = HEAP32[$215>>2]|0;
        $217 = (($214) + 4)|0;
        $218 = $217;
        $219 = HEAP32[$218>>2]|0;
        $220 = (+($216>>>0)) + (4294967296.0*(+($219|0)));
        $$ph = $220;
        label = 36;
        break;
       }
      } else {
       $221 = $190 & 15;
       $222 = ($221|0)==(4);
       if ($222) {
        $223 = HEAP32[$180>>2]|0;
        $224 = ((($223)) + 24|0);
        $225 = (_luaO_str2num($224,$v$i)|0);
        $226 = HEAP32[$180>>2]|0;
        $227 = ((($226)) + 12|0);
        $228 = HEAP32[$227>>2]|0;
        $229 = (($228) + 1)|0;
        $230 = ($225|0)==($229|0);
        if ($230) {
         $231 = HEAP32[$6>>2]|0;
         $232 = ($231|0)==(19);
         $233 = $v$i;
         $234 = $233;
         $235 = HEAP32[$234>>2]|0;
         $236 = (($233) + 4)|0;
         $237 = $236;
         $238 = HEAP32[$237>>2]|0;
         $239 = (+($235>>>0)) + (4294967296.0*(+($238|0)));
         HEAP32[tempDoublePtr>>2] = $235;HEAP32[tempDoublePtr+4>>2] = $238;$240 = +HEAPF64[tempDoublePtr>>3];
         $241 = $232 ? $239 : $240;
         $$ph = $241;
         label = 36;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 36) {
      label = 0;
      $276 = $$ph;
      label = 37;
     }
     L68: do {
      if ((label|0) == 37) {
       label = 0;
       $242 = ((($188)) + 8|0);
       $243 = HEAP32[$242>>2]|0;
       $244 = ($243|0)==(3);
       if ($244) {
        $245 = +HEAPF64[$188>>3];
        $277 = $245;
       } else {
        $246 = ($243|0)==(19);
        do {
         if ($246) {
          $247 = $188;
          $248 = $247;
          $249 = HEAP32[$248>>2]|0;
          $250 = (($247) + 4)|0;
          $251 = $250;
          $252 = HEAP32[$251>>2]|0;
          $253 = (+($249>>>0)) + (4294967296.0*(+($252|0)));
          $$ph173 = $253;
         } else {
          $254 = $243 & 15;
          $255 = ($254|0)==(4);
          if ($255) {
           $256 = HEAP32[$188>>2]|0;
           $257 = ((($256)) + 24|0);
           $258 = (_luaO_str2num($257,$v$i37)|0);
           $259 = HEAP32[$188>>2]|0;
           $260 = ((($259)) + 12|0);
           $261 = HEAP32[$260>>2]|0;
           $262 = (($261) + 1)|0;
           $263 = ($258|0)==($262|0);
           if ($263) {
            $264 = HEAP32[$5>>2]|0;
            $265 = ($264|0)==(19);
            $266 = $v$i37;
            $267 = $266;
            $268 = HEAP32[$267>>2]|0;
            $269 = (($266) + 4)|0;
            $270 = $269;
            $271 = HEAP32[$270>>2]|0;
            $272 = (+($268>>>0)) + (4294967296.0*(+($271|0)));
            HEAP32[tempDoublePtr>>2] = $268;HEAP32[tempDoublePtr+4>>2] = $271;$273 = +HEAPF64[tempDoublePtr>>3];
            $274 = $265 ? $272 : $273;
            $$ph173 = $274;
            break;
           }
          }
          break L68;
         }
        } while(0);
        $277 = $$ph173;
       }
       $275 = $276 + $277;
       HEAPF64[$50>>3] = $275;
       $278 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$278>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$180,$188,$50,6);
     $279 = HEAP32[$32>>2]|0;
     $base$0 = $279;
     continue L3;
     break;
    }
    case 5:  {
     $72 = $38 >>> 23;
     $73 = (((($27)) + 16|0) + ($72<<2)|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = HEAP32[$74>>2]|0;
     ;HEAP32[$50>>2]=HEAP32[$75>>2]|0;HEAP32[$50+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$75+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$75+12>>2]|0;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 8:  {
     $100 = (((($27)) + 16|0) + ($49<<2)|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = HEAP32[$101>>2]|0;
     $103 = $38 >>> 23;
     $104 = $103 & 256;
     $105 = ($104|0)==(0);
     $106 = $103 & 255;
     $107 = (($31) + ($106<<4)|0);
     $108 = (($base$1) + ($103<<4)|0);
     $109 = $105 ? $108 : $107;
     $110 = $38 >>> 14;
     $111 = $110 & 256;
     $112 = ($111|0)==(0);
     $113 = $110 & 255;
     $114 = (($31) + ($113<<4)|0);
     $115 = $110 & 511;
     $116 = (($base$1) + ($115<<4)|0);
     $117 = $112 ? $116 : $114;
     _luaV_settable($L,$102,$109,$117);
     $118 = HEAP32[$32>>2]|0;
     $base$0 = $118;
     continue L3;
     break;
    }
    case 20:  {
     $578 = $38 >>> 23;
     $579 = $578 & 256;
     $580 = ($579|0)==(0);
     $581 = $578 & 255;
     $582 = (($31) + ($581<<4)|0);
     $583 = (($base$1) + ($578<<4)|0);
     $584 = $580 ? $583 : $582;
     $585 = $38 >>> 14;
     $586 = $585 & 256;
     $587 = ($586|0)==(0);
     $588 = $585 & 255;
     $589 = (($31) + ($588<<4)|0);
     $590 = $585 & 511;
     $591 = (($base$1) + ($590<<4)|0);
     $592 = $587 ? $591 : $589;
     $593 = ((($584)) + 8|0);
     $594 = HEAP32[$593>>2]|0;
     $595 = ($594|0)==(19);
     do {
      if ($595) {
       $596 = $584;
       $597 = $596;
       $598 = HEAP32[$597>>2]|0;
       $599 = (($596) + 4)|0;
       $600 = $599;
       $601 = HEAP32[$600>>2]|0;
       $661 = $598;$664 = $601;
       label = 123;
      } else {
       $$02$i$i = $584;$616 = $594;
       while(1) {
        if ((($616|0) == 3)) {
         $$02$i$i$lcssa = $$02$i$i;
         label = 114;
         break;
        } else if ((($616|0) == 19)) {
         $$02$i$i$lcssa959 = $$02$i$i;
         label = 117;
         break;
        }
        $615 = $616 & 15;
        $617 = ($615|0)==(4);
        if (!($617)) {
         label = 121;
         break;
        }
        $618 = HEAP32[$$02$i$i>>2]|0;
        $619 = ((($618)) + 24|0);
        $620 = (_luaO_str2num($619,$v$i$i)|0);
        $621 = HEAP32[$$02$i$i>>2]|0;
        $622 = ((($621)) + 12|0);
        $623 = HEAP32[$622>>2]|0;
        $624 = (($623) + 1)|0;
        $625 = ($620|0)==($624|0);
        if (!($625)) {
         label = 121;
         break;
        }
        $$pre758 = HEAP32[$$phi$trans$insert757>>2]|0;
        $$02$i$i = $v$i$i;$616 = $$pre758;
       }
       if ((label|0) == 114) {
        label = 0;
        $602 = +HEAPF64[$$02$i$i$lcssa>>3];
        $603 = (+Math_floor((+$602)));
        $604 = $602 != $603;
        if ($604) {
         label = 121;
        } else {
         $605 = $603 >= -9.2233720368547758E+18;
         $606 = $603 < 9.2233720368547758E+18;
         $or$cond$i$i = $605 & $606;
         if ($or$cond$i$i) {
          $607 = (~~$603)>>>0;
          $608 = +Math_abs($603) >= 1.0 ? $603 > 0.0 ? (~~+Math_min(+Math_floor($603 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($603 - +(~~$603 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2232 = $607;$2233 = $608;
          label = 122;
         } else {
          label = 121;
         }
        }
       }
       else if ((label|0) == 117) {
        label = 0;
        $609 = $$02$i$i$lcssa959;
        $610 = $609;
        $611 = HEAP32[$610>>2]|0;
        $612 = (($609) + 4)|0;
        $613 = $612;
        $614 = HEAP32[$613>>2]|0;
        $2232 = $611;$2233 = $614;
        label = 122;
       }
       if ((label|0) == 121) {
        label = 0;
        break;
       }
       else if ((label|0) == 122) {
        label = 0;
        $661 = $2232;$664 = $2233;
        label = 123;
        break;
       }
      }
     } while(0);
     L102: do {
      if ((label|0) == 123) {
       label = 0;
       $626 = ((($592)) + 8|0);
       $627 = HEAP32[$626>>2]|0;
       $628 = ($627|0)==(19);
       do {
        if ($628) {
         $629 = $592;
         $630 = $629;
         $631 = HEAP32[$630>>2]|0;
         $632 = (($629) + 4)|0;
         $633 = $632;
         $634 = HEAP32[$633>>2]|0;
         $660 = $631;$663 = $634;
        } else {
         $$02$i$i66 = $592;$649 = $627;
         while(1) {
          if ((($649|0) == 3)) {
           $$02$i$i66$lcssa = $$02$i$i66;
           label = 127;
           break;
          } else if ((($649|0) == 19)) {
           $$02$i$i66$lcssa961 = $$02$i$i66;
           label = 130;
           break;
          }
          $648 = $649 & 15;
          $650 = ($648|0)==(4);
          if (!($650)) {
           label = 134;
           break;
          }
          $651 = HEAP32[$$02$i$i66>>2]|0;
          $652 = ((($651)) + 24|0);
          $653 = (_luaO_str2num($652,$v$i$i65)|0);
          $654 = HEAP32[$$02$i$i66>>2]|0;
          $655 = ((($654)) + 12|0);
          $656 = HEAP32[$655>>2]|0;
          $657 = (($656) + 1)|0;
          $658 = ($653|0)==($657|0);
          if (!($658)) {
           label = 134;
           break;
          }
          $$pre761 = HEAP32[$$phi$trans$insert760>>2]|0;
          $$02$i$i66 = $v$i$i65;$649 = $$pre761;
         }
         if ((label|0) == 127) {
          label = 0;
          $635 = +HEAPF64[$$02$i$i66$lcssa>>3];
          $636 = (+Math_floor((+$635)));
          $637 = $635 != $636;
          if ($637) {
           label = 134;
          } else {
           $638 = $636 >= -9.2233720368547758E+18;
           $639 = $636 < 9.2233720368547758E+18;
           $or$cond$i$i67 = $638 & $639;
           if ($or$cond$i$i67) {
            $640 = (~~$636)>>>0;
            $641 = +Math_abs($636) >= 1.0 ? $636 > 0.0 ? (~~+Math_min(+Math_floor($636 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($636 - +(~~$636 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $2234 = $640;$2235 = $641;
            label = 135;
           } else {
            label = 134;
           }
          }
         }
         else if ((label|0) == 130) {
          label = 0;
          $642 = $$02$i$i66$lcssa961;
          $643 = $642;
          $644 = HEAP32[$643>>2]|0;
          $645 = (($642) + 4)|0;
          $646 = $645;
          $647 = HEAP32[$646>>2]|0;
          $2234 = $644;$2235 = $647;
          label = 135;
         }
         if ((label|0) == 134) {
          label = 0;
          break L102;
         }
         else if ((label|0) == 135) {
          label = 0;
          $660 = $2234;$663 = $2235;
          break;
         }
        }
       } while(0);
       $659 = $660 & $661;
       $662 = $663 & $664;
       $665 = $50;
       $666 = $665;
       HEAP32[$666>>2] = $659;
       $667 = (($665) + 4)|0;
       $668 = $667;
       HEAP32[$668>>2] = $662;
       $669 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$669>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$584,$592,$50,13);
     $670 = HEAP32[$32>>2]|0;
     $base$0 = $670;
     continue L3;
     break;
    }
    case 18:  {
     $492 = $38 >>> 23;
     $493 = $492 & 256;
     $494 = ($493|0)==(0);
     $495 = $492 & 255;
     $496 = (($31) + ($495<<4)|0);
     $497 = (($base$1) + ($492<<4)|0);
     $498 = $494 ? $497 : $496;
     $499 = $38 >>> 14;
     $500 = $499 & 256;
     $501 = ($500|0)==(0);
     $502 = $499 & 255;
     $503 = (($31) + ($502<<4)|0);
     $504 = $499 & 511;
     $505 = (($base$1) + ($504<<4)|0);
     $506 = $501 ? $505 : $503;
     $507 = ((($498)) + 8|0);
     $508 = HEAP32[$507>>2]|0;
     $509 = ($508|0)==(3);
     L123: do {
      if ($509) {
       $510 = +HEAPF64[$498>>3];
       $574 = $510;
       label = 99;
      } else {
       $511 = ($508|0)==(19);
       do {
        if ($511) {
         $512 = $498;
         $513 = $512;
         $514 = HEAP32[$513>>2]|0;
         $515 = (($512) + 4)|0;
         $516 = $515;
         $517 = HEAP32[$516>>2]|0;
         $518 = (+($514>>>0)) + (4294967296.0*(+($517|0)));
         $$ph192 = $518;
        } else {
         $519 = $508 & 15;
         $520 = ($519|0)==(4);
         if ($520) {
          $521 = HEAP32[$498>>2]|0;
          $522 = ((($521)) + 24|0);
          $523 = (_luaO_str2num($522,$v$i57)|0);
          $524 = HEAP32[$498>>2]|0;
          $525 = ((($524)) + 12|0);
          $526 = HEAP32[$525>>2]|0;
          $527 = (($526) + 1)|0;
          $528 = ($523|0)==($527|0);
          if ($528) {
           $529 = HEAP32[$12>>2]|0;
           $530 = ($529|0)==(19);
           $531 = $v$i57;
           $532 = $531;
           $533 = HEAP32[$532>>2]|0;
           $534 = (($531) + 4)|0;
           $535 = $534;
           $536 = HEAP32[$535>>2]|0;
           $537 = (+($533>>>0)) + (4294967296.0*(+($536|0)));
           HEAP32[tempDoublePtr>>2] = $533;HEAP32[tempDoublePtr+4>>2] = $536;$538 = +HEAPF64[tempDoublePtr>>3];
           $539 = $530 ? $537 : $538;
           $$ph192 = $539;
           break;
          }
         }
         break L123;
        }
       } while(0);
       $574 = $$ph192;
       label = 99;
      }
     } while(0);
     L134: do {
      if ((label|0) == 99) {
       label = 0;
       $540 = ((($506)) + 8|0);
       $541 = HEAP32[$540>>2]|0;
       $542 = ($541|0)==(3);
       if ($542) {
        $543 = +HEAPF64[$506>>3];
        $575 = $543;
       } else {
        $544 = ($541|0)==(19);
        do {
         if ($544) {
          $545 = $506;
          $546 = $545;
          $547 = HEAP32[$546>>2]|0;
          $548 = (($545) + 4)|0;
          $549 = $548;
          $550 = HEAP32[$549>>2]|0;
          $551 = (+($547>>>0)) + (4294967296.0*(+($550|0)));
          $$ph195 = $551;
         } else {
          $552 = $541 & 15;
          $553 = ($552|0)==(4);
          if ($553) {
           $554 = HEAP32[$506>>2]|0;
           $555 = ((($554)) + 24|0);
           $556 = (_luaO_str2num($555,$v$i61)|0);
           $557 = HEAP32[$506>>2]|0;
           $558 = ((($557)) + 12|0);
           $559 = HEAP32[$558>>2]|0;
           $560 = (($559) + 1)|0;
           $561 = ($556|0)==($560|0);
           if ($561) {
            $562 = HEAP32[$11>>2]|0;
            $563 = ($562|0)==(19);
            $564 = $v$i61;
            $565 = $564;
            $566 = HEAP32[$565>>2]|0;
            $567 = (($564) + 4)|0;
            $568 = $567;
            $569 = HEAP32[$568>>2]|0;
            $570 = (+($566>>>0)) + (4294967296.0*(+($569|0)));
            HEAP32[tempDoublePtr>>2] = $566;HEAP32[tempDoublePtr+4>>2] = $569;$571 = +HEAPF64[tempDoublePtr>>3];
            $572 = $563 ? $570 : $571;
            $$ph195 = $572;
            break;
           }
          }
          break L134;
         }
        } while(0);
        $575 = $$ph195;
       }
       $573 = $574 / $575;
       HEAPF64[$50>>3] = $573;
       $576 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$576>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$498,$506,$50,11);
     $577 = HEAP32[$32>>2]|0;
     $base$0 = $577;
     continue L3;
     break;
    }
    case 14:  {
     $280 = $38 >>> 23;
     $281 = $280 & 256;
     $282 = ($281|0)==(0);
     $283 = $280 & 255;
     $284 = (($31) + ($283<<4)|0);
     $285 = (($base$1) + ($280<<4)|0);
     $286 = $282 ? $285 : $284;
     $287 = $38 >>> 14;
     $288 = $287 & 256;
     $289 = ($288|0)==(0);
     $290 = $287 & 255;
     $291 = (($31) + ($290<<4)|0);
     $292 = $287 & 511;
     $293 = (($base$1) + ($292<<4)|0);
     $294 = $289 ? $293 : $291;
     $295 = ((($286)) + 8|0);
     $296 = HEAP32[$295>>2]|0;
     do {
      if ((($296|0) == 19)) {
       $297 = ((($294)) + 8|0);
       $298 = HEAP32[$297>>2]|0;
       $299 = ($298|0)==(19);
       if ($299) {
        $300 = $286;
        $301 = $300;
        $302 = HEAP32[$301>>2]|0;
        $303 = (($300) + 4)|0;
        $304 = $303;
        $305 = HEAP32[$304>>2]|0;
        $306 = $294;
        $307 = $306;
        $308 = HEAP32[$307>>2]|0;
        $309 = (($306) + 4)|0;
        $310 = $309;
        $311 = HEAP32[$310>>2]|0;
        $312 = (_i64Subtract(($302|0),($305|0),($308|0),($311|0))|0);
        $313 = tempRet0;
        $314 = $50;
        $315 = $314;
        HEAP32[$315>>2] = $312;
        $316 = (($314) + 4)|0;
        $317 = $316;
        HEAP32[$317>>2] = $313;
        $318 = (((($base$1) + ($49<<4)|0)) + 8|0);
        HEAP32[$318>>2] = 19;
        $base$0 = $base$1;
        continue L3;
       } else {
        $320 = $286;
        $321 = $320;
        $322 = HEAP32[$321>>2]|0;
        $323 = (($320) + 4)|0;
        $324 = $323;
        $325 = HEAP32[$324>>2]|0;
        $326 = (+($322>>>0)) + (4294967296.0*(+($325|0)));
        $$ph178 = $326;
        label = 57;
        break;
       }
      } else if ((($296|0) == 3)) {
       $319 = +HEAPF64[$286>>3];
       $382 = $319;
       label = 58;
      } else {
       $327 = $296 & 15;
       $328 = ($327|0)==(4);
       if ($328) {
        $329 = HEAP32[$286>>2]|0;
        $330 = ((($329)) + 24|0);
        $331 = (_luaO_str2num($330,$v$i41)|0);
        $332 = HEAP32[$286>>2]|0;
        $333 = ((($332)) + 12|0);
        $334 = HEAP32[$333>>2]|0;
        $335 = (($334) + 1)|0;
        $336 = ($331|0)==($335|0);
        if ($336) {
         $337 = HEAP32[$8>>2]|0;
         $338 = ($337|0)==(19);
         $339 = $v$i41;
         $340 = $339;
         $341 = HEAP32[$340>>2]|0;
         $342 = (($339) + 4)|0;
         $343 = $342;
         $344 = HEAP32[$343>>2]|0;
         $345 = (+($341>>>0)) + (4294967296.0*(+($344|0)));
         HEAP32[tempDoublePtr>>2] = $341;HEAP32[tempDoublePtr+4>>2] = $344;$346 = +HEAPF64[tempDoublePtr>>3];
         $347 = $338 ? $345 : $346;
         $$ph178 = $347;
         label = 57;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 57) {
      label = 0;
      $382 = $$ph178;
      label = 58;
     }
     L163: do {
      if ((label|0) == 58) {
       label = 0;
       $348 = ((($294)) + 8|0);
       $349 = HEAP32[$348>>2]|0;
       $350 = ($349|0)==(3);
       if ($350) {
        $351 = +HEAPF64[$294>>3];
        $383 = $351;
       } else {
        $352 = ($349|0)==(19);
        do {
         if ($352) {
          $353 = $294;
          $354 = $353;
          $355 = HEAP32[$354>>2]|0;
          $356 = (($353) + 4)|0;
          $357 = $356;
          $358 = HEAP32[$357>>2]|0;
          $359 = (+($355>>>0)) + (4294967296.0*(+($358|0)));
          $$ph181 = $359;
         } else {
          $360 = $349 & 15;
          $361 = ($360|0)==(4);
          if ($361) {
           $362 = HEAP32[$294>>2]|0;
           $363 = ((($362)) + 24|0);
           $364 = (_luaO_str2num($363,$v$i45)|0);
           $365 = HEAP32[$294>>2]|0;
           $366 = ((($365)) + 12|0);
           $367 = HEAP32[$366>>2]|0;
           $368 = (($367) + 1)|0;
           $369 = ($364|0)==($368|0);
           if ($369) {
            $370 = HEAP32[$7>>2]|0;
            $371 = ($370|0)==(19);
            $372 = $v$i45;
            $373 = $372;
            $374 = HEAP32[$373>>2]|0;
            $375 = (($372) + 4)|0;
            $376 = $375;
            $377 = HEAP32[$376>>2]|0;
            $378 = (+($374>>>0)) + (4294967296.0*(+($377|0)));
            HEAP32[tempDoublePtr>>2] = $374;HEAP32[tempDoublePtr+4>>2] = $377;$379 = +HEAPF64[tempDoublePtr>>3];
            $380 = $371 ? $378 : $379;
            $$ph181 = $380;
            break;
           }
          }
          break L163;
         }
        } while(0);
        $383 = $$ph181;
       }
       $381 = $382 - $383;
       HEAPF64[$50>>3] = $381;
       $384 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$384>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$286,$294,$50,7);
     $385 = HEAP32[$32>>2]|0;
     $base$0 = $385;
     continue L3;
     break;
    }
    case 10:  {
     $130 = $38 >>> 23;
     $131 = $130 & 256;
     $132 = ($131|0)==(0);
     $133 = $130 & 255;
     $134 = (($31) + ($133<<4)|0);
     $135 = (($base$1) + ($130<<4)|0);
     $136 = $132 ? $135 : $134;
     $137 = $38 >>> 14;
     $138 = $137 & 256;
     $139 = ($138|0)==(0);
     $140 = $137 & 255;
     $141 = (($31) + ($140<<4)|0);
     $142 = $137 & 511;
     $143 = (($base$1) + ($142<<4)|0);
     $144 = $139 ? $143 : $141;
     _luaV_settable($L,$50,$136,$144);
     $145 = HEAP32[$32>>2]|0;
     $base$0 = $145;
     continue L3;
     break;
    }
    case 12:  {
     $162 = $38 >>> 23;
     $163 = (($base$1) + ($162<<4)|0);
     $$sum34 = (($49) + 1)|0;
     $164 = (($base$1) + ($$sum34<<4)|0);
     ;HEAP32[$164>>2]=HEAP32[$163>>2]|0;HEAP32[$164+4>>2]=HEAP32[$163+4>>2]|0;HEAP32[$164+8>>2]=HEAP32[$163+8>>2]|0;HEAP32[$164+12>>2]=HEAP32[$163+12>>2]|0;
     $165 = $38 >>> 14;
     $166 = $165 & 256;
     $167 = ($166|0)==(0);
     $168 = $165 & 255;
     $169 = (($31) + ($168<<4)|0);
     $170 = $165 & 511;
     $171 = (($base$1) + ($170<<4)|0);
     $172 = $167 ? $171 : $169;
     _luaV_gettable($L,$163,$172,$50);
     $173 = HEAP32[$32>>2]|0;
     $base$0 = $173;
     continue L3;
     break;
    }
    case 6:  {
     $76 = $38 >>> 23;
     $77 = (((($27)) + 16|0) + ($76<<2)|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = HEAP32[$78>>2]|0;
     $80 = $38 >>> 14;
     $81 = $80 & 256;
     $82 = ($81|0)==(0);
     $83 = $80 & 255;
     $84 = (($31) + ($83<<4)|0);
     $85 = $80 & 511;
     $86 = (($base$1) + ($85<<4)|0);
     $87 = $82 ? $86 : $84;
     _luaV_gettable($L,$79,$87,$50);
     $88 = HEAP32[$32>>2]|0;
     $base$0 = $88;
     continue L3;
     break;
    }
    case 0:  {
     $52 = $38 >>> 23;
     $53 = (($base$1) + ($52<<4)|0);
     ;HEAP32[$50>>2]=HEAP32[$53>>2]|0;HEAP32[$50+4>>2]=HEAP32[$53+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$53+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$53+12>>2]|0;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 3:  {
     $61 = $38 >>> 23;
     HEAP32[$50>>2] = $61;
     $62 = (((($base$1) + ($49<<4)|0)) + 8|0);
     HEAP32[$62>>2] = 1;
     $63 = $38 & 8372224;
     $64 = ($63|0)==(0);
     if ($64) {
      $base$0 = $base$1;
      continue L3;
     }
     $65 = HEAP32[$34>>2]|0;
     $66 = ((($65)) + 4|0);
     HEAP32[$34>>2] = $66;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 21:  {
     $671 = $38 >>> 23;
     $672 = $671 & 256;
     $673 = ($672|0)==(0);
     $674 = $671 & 255;
     $675 = (($31) + ($674<<4)|0);
     $676 = (($base$1) + ($671<<4)|0);
     $677 = $673 ? $676 : $675;
     $678 = $38 >>> 14;
     $679 = $678 & 256;
     $680 = ($679|0)==(0);
     $681 = $678 & 255;
     $682 = (($31) + ($681<<4)|0);
     $683 = $678 & 511;
     $684 = (($base$1) + ($683<<4)|0);
     $685 = $680 ? $684 : $682;
     $686 = ((($677)) + 8|0);
     $687 = HEAP32[$686>>2]|0;
     $688 = ($687|0)==(19);
     do {
      if ($688) {
       $689 = $677;
       $690 = $689;
       $691 = HEAP32[$690>>2]|0;
       $692 = (($689) + 4)|0;
       $693 = $692;
       $694 = HEAP32[$693>>2]|0;
       $754 = $691;$757 = $694;
       label = 151;
      } else {
       $$02$i$i71 = $677;$709 = $687;
       while(1) {
        if ((($709|0) == 3)) {
         $$02$i$i71$lcssa = $$02$i$i71;
         label = 142;
         break;
        } else if ((($709|0) == 19)) {
         $$02$i$i71$lcssa955 = $$02$i$i71;
         label = 145;
         break;
        }
        $708 = $709 & 15;
        $710 = ($708|0)==(4);
        if (!($710)) {
         label = 149;
         break;
        }
        $711 = HEAP32[$$02$i$i71>>2]|0;
        $712 = ((($711)) + 24|0);
        $713 = (_luaO_str2num($712,$v$i$i70)|0);
        $714 = HEAP32[$$02$i$i71>>2]|0;
        $715 = ((($714)) + 12|0);
        $716 = HEAP32[$715>>2]|0;
        $717 = (($716) + 1)|0;
        $718 = ($713|0)==($717|0);
        if (!($718)) {
         label = 149;
         break;
        }
        $$pre752 = HEAP32[$$phi$trans$insert751>>2]|0;
        $$02$i$i71 = $v$i$i70;$709 = $$pre752;
       }
       if ((label|0) == 142) {
        label = 0;
        $695 = +HEAPF64[$$02$i$i71$lcssa>>3];
        $696 = (+Math_floor((+$695)));
        $697 = $695 != $696;
        if ($697) {
         label = 149;
        } else {
         $698 = $696 >= -9.2233720368547758E+18;
         $699 = $696 < 9.2233720368547758E+18;
         $or$cond$i$i72 = $698 & $699;
         if ($or$cond$i$i72) {
          $700 = (~~$696)>>>0;
          $701 = +Math_abs($696) >= 1.0 ? $696 > 0.0 ? (~~+Math_min(+Math_floor($696 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($696 - +(~~$696 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2236 = $700;$2237 = $701;
          label = 150;
         } else {
          label = 149;
         }
        }
       }
       else if ((label|0) == 145) {
        label = 0;
        $702 = $$02$i$i71$lcssa955;
        $703 = $702;
        $704 = HEAP32[$703>>2]|0;
        $705 = (($702) + 4)|0;
        $706 = $705;
        $707 = HEAP32[$706>>2]|0;
        $2236 = $704;$2237 = $707;
        label = 150;
       }
       if ((label|0) == 149) {
        label = 0;
        break;
       }
       else if ((label|0) == 150) {
        label = 0;
        $754 = $2236;$757 = $2237;
        label = 151;
        break;
       }
      }
     } while(0);
     L201: do {
      if ((label|0) == 151) {
       label = 0;
       $719 = ((($685)) + 8|0);
       $720 = HEAP32[$719>>2]|0;
       $721 = ($720|0)==(19);
       do {
        if ($721) {
         $722 = $685;
         $723 = $722;
         $724 = HEAP32[$723>>2]|0;
         $725 = (($722) + 4)|0;
         $726 = $725;
         $727 = HEAP32[$726>>2]|0;
         $753 = $724;$756 = $727;
        } else {
         $$02$i$i76 = $685;$742 = $720;
         while(1) {
          if ((($742|0) == 3)) {
           $$02$i$i76$lcssa = $$02$i$i76;
           label = 155;
           break;
          } else if ((($742|0) == 19)) {
           $$02$i$i76$lcssa957 = $$02$i$i76;
           label = 158;
           break;
          }
          $741 = $742 & 15;
          $743 = ($741|0)==(4);
          if (!($743)) {
           label = 162;
           break;
          }
          $744 = HEAP32[$$02$i$i76>>2]|0;
          $745 = ((($744)) + 24|0);
          $746 = (_luaO_str2num($745,$v$i$i75)|0);
          $747 = HEAP32[$$02$i$i76>>2]|0;
          $748 = ((($747)) + 12|0);
          $749 = HEAP32[$748>>2]|0;
          $750 = (($749) + 1)|0;
          $751 = ($746|0)==($750|0);
          if (!($751)) {
           label = 162;
           break;
          }
          $$pre755 = HEAP32[$$phi$trans$insert754>>2]|0;
          $$02$i$i76 = $v$i$i75;$742 = $$pre755;
         }
         if ((label|0) == 155) {
          label = 0;
          $728 = +HEAPF64[$$02$i$i76$lcssa>>3];
          $729 = (+Math_floor((+$728)));
          $730 = $728 != $729;
          if ($730) {
           label = 162;
          } else {
           $731 = $729 >= -9.2233720368547758E+18;
           $732 = $729 < 9.2233720368547758E+18;
           $or$cond$i$i77 = $731 & $732;
           if ($or$cond$i$i77) {
            $733 = (~~$729)>>>0;
            $734 = +Math_abs($729) >= 1.0 ? $729 > 0.0 ? (~~+Math_min(+Math_floor($729 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($729 - +(~~$729 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $2238 = $733;$2239 = $734;
            label = 163;
           } else {
            label = 162;
           }
          }
         }
         else if ((label|0) == 158) {
          label = 0;
          $735 = $$02$i$i76$lcssa957;
          $736 = $735;
          $737 = HEAP32[$736>>2]|0;
          $738 = (($735) + 4)|0;
          $739 = $738;
          $740 = HEAP32[$739>>2]|0;
          $2238 = $737;$2239 = $740;
          label = 163;
         }
         if ((label|0) == 162) {
          label = 0;
          break L201;
         }
         else if ((label|0) == 163) {
          label = 0;
          $753 = $2238;$756 = $2239;
          break;
         }
        }
       } while(0);
       $752 = $753 | $754;
       $755 = $756 | $757;
       $758 = $50;
       $759 = $758;
       HEAP32[$759>>2] = $752;
       $760 = (($758) + 4)|0;
       $761 = $760;
       HEAP32[$761>>2] = $755;
       $762 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$762>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$677,$685,$50,14);
     $763 = HEAP32[$32>>2]|0;
     $base$0 = $763;
     continue L3;
     break;
    }
    case 22:  {
     $764 = $38 >>> 23;
     $765 = $764 & 256;
     $766 = ($765|0)==(0);
     $767 = $764 & 255;
     $768 = (($31) + ($767<<4)|0);
     $769 = (($base$1) + ($764<<4)|0);
     $770 = $766 ? $769 : $768;
     $771 = $38 >>> 14;
     $772 = $771 & 256;
     $773 = ($772|0)==(0);
     $774 = $771 & 255;
     $775 = (($31) + ($774<<4)|0);
     $776 = $771 & 511;
     $777 = (($base$1) + ($776<<4)|0);
     $778 = $773 ? $777 : $775;
     $779 = ((($770)) + 8|0);
     $780 = HEAP32[$779>>2]|0;
     $781 = ($780|0)==(19);
     do {
      if ($781) {
       $782 = $770;
       $783 = $782;
       $784 = HEAP32[$783>>2]|0;
       $785 = (($782) + 4)|0;
       $786 = $785;
       $787 = HEAP32[$786>>2]|0;
       $847 = $784;$850 = $787;
       label = 179;
      } else {
       $$02$i$i81 = $770;$802 = $780;
       while(1) {
        if ((($802|0) == 3)) {
         $$02$i$i81$lcssa = $$02$i$i81;
         label = 170;
         break;
        } else if ((($802|0) == 19)) {
         $$02$i$i81$lcssa951 = $$02$i$i81;
         label = 173;
         break;
        }
        $801 = $802 & 15;
        $803 = ($801|0)==(4);
        if (!($803)) {
         label = 177;
         break;
        }
        $804 = HEAP32[$$02$i$i81>>2]|0;
        $805 = ((($804)) + 24|0);
        $806 = (_luaO_str2num($805,$v$i$i80)|0);
        $807 = HEAP32[$$02$i$i81>>2]|0;
        $808 = ((($807)) + 12|0);
        $809 = HEAP32[$808>>2]|0;
        $810 = (($809) + 1)|0;
        $811 = ($806|0)==($810|0);
        if (!($811)) {
         label = 177;
         break;
        }
        $$pre746 = HEAP32[$$phi$trans$insert745>>2]|0;
        $$02$i$i81 = $v$i$i80;$802 = $$pre746;
       }
       if ((label|0) == 170) {
        label = 0;
        $788 = +HEAPF64[$$02$i$i81$lcssa>>3];
        $789 = (+Math_floor((+$788)));
        $790 = $788 != $789;
        if ($790) {
         label = 177;
        } else {
         $791 = $789 >= -9.2233720368547758E+18;
         $792 = $789 < 9.2233720368547758E+18;
         $or$cond$i$i82 = $791 & $792;
         if ($or$cond$i$i82) {
          $793 = (~~$789)>>>0;
          $794 = +Math_abs($789) >= 1.0 ? $789 > 0.0 ? (~~+Math_min(+Math_floor($789 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($789 - +(~~$789 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2240 = $793;$2241 = $794;
          label = 178;
         } else {
          label = 177;
         }
        }
       }
       else if ((label|0) == 173) {
        label = 0;
        $795 = $$02$i$i81$lcssa951;
        $796 = $795;
        $797 = HEAP32[$796>>2]|0;
        $798 = (($795) + 4)|0;
        $799 = $798;
        $800 = HEAP32[$799>>2]|0;
        $2240 = $797;$2241 = $800;
        label = 178;
       }
       if ((label|0) == 177) {
        label = 0;
        break;
       }
       else if ((label|0) == 178) {
        label = 0;
        $847 = $2240;$850 = $2241;
        label = 179;
        break;
       }
      }
     } while(0);
     L238: do {
      if ((label|0) == 179) {
       label = 0;
       $812 = ((($778)) + 8|0);
       $813 = HEAP32[$812>>2]|0;
       $814 = ($813|0)==(19);
       do {
        if ($814) {
         $815 = $778;
         $816 = $815;
         $817 = HEAP32[$816>>2]|0;
         $818 = (($815) + 4)|0;
         $819 = $818;
         $820 = HEAP32[$819>>2]|0;
         $846 = $817;$849 = $820;
        } else {
         $$02$i$i86 = $778;$835 = $813;
         while(1) {
          if ((($835|0) == 3)) {
           $$02$i$i86$lcssa = $$02$i$i86;
           label = 183;
           break;
          } else if ((($835|0) == 19)) {
           $$02$i$i86$lcssa953 = $$02$i$i86;
           label = 186;
           break;
          }
          $834 = $835 & 15;
          $836 = ($834|0)==(4);
          if (!($836)) {
           label = 190;
           break;
          }
          $837 = HEAP32[$$02$i$i86>>2]|0;
          $838 = ((($837)) + 24|0);
          $839 = (_luaO_str2num($838,$v$i$i85)|0);
          $840 = HEAP32[$$02$i$i86>>2]|0;
          $841 = ((($840)) + 12|0);
          $842 = HEAP32[$841>>2]|0;
          $843 = (($842) + 1)|0;
          $844 = ($839|0)==($843|0);
          if (!($844)) {
           label = 190;
           break;
          }
          $$pre749 = HEAP32[$$phi$trans$insert748>>2]|0;
          $$02$i$i86 = $v$i$i85;$835 = $$pre749;
         }
         if ((label|0) == 183) {
          label = 0;
          $821 = +HEAPF64[$$02$i$i86$lcssa>>3];
          $822 = (+Math_floor((+$821)));
          $823 = $821 != $822;
          if ($823) {
           label = 190;
          } else {
           $824 = $822 >= -9.2233720368547758E+18;
           $825 = $822 < 9.2233720368547758E+18;
           $or$cond$i$i87 = $824 & $825;
           if ($or$cond$i$i87) {
            $826 = (~~$822)>>>0;
            $827 = +Math_abs($822) >= 1.0 ? $822 > 0.0 ? (~~+Math_min(+Math_floor($822 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($822 - +(~~$822 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $2242 = $826;$2243 = $827;
            label = 191;
           } else {
            label = 190;
           }
          }
         }
         else if ((label|0) == 186) {
          label = 0;
          $828 = $$02$i$i86$lcssa953;
          $829 = $828;
          $830 = HEAP32[$829>>2]|0;
          $831 = (($828) + 4)|0;
          $832 = $831;
          $833 = HEAP32[$832>>2]|0;
          $2242 = $830;$2243 = $833;
          label = 191;
         }
         if ((label|0) == 190) {
          label = 0;
          break L238;
         }
         else if ((label|0) == 191) {
          label = 0;
          $846 = $2242;$849 = $2243;
          break;
         }
        }
       } while(0);
       $845 = $846 ^ $847;
       $848 = $849 ^ $850;
       $851 = $50;
       $852 = $851;
       HEAP32[$852>>2] = $845;
       $853 = (($851) + 4)|0;
       $854 = $853;
       HEAP32[$854>>2] = $848;
       $855 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$855>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$770,$778,$50,15);
     $856 = HEAP32[$32>>2]|0;
     $base$0 = $856;
     continue L3;
     break;
    }
    case 23:  {
     $857 = $38 >>> 23;
     $858 = $857 & 256;
     $859 = ($858|0)==(0);
     $860 = $857 & 255;
     $861 = (($31) + ($860<<4)|0);
     $862 = (($base$1) + ($857<<4)|0);
     $863 = $859 ? $862 : $861;
     $864 = $38 >>> 14;
     $865 = $864 & 256;
     $866 = ($865|0)==(0);
     $867 = $864 & 255;
     $868 = (($31) + ($867<<4)|0);
     $869 = $864 & 511;
     $870 = (($base$1) + ($869<<4)|0);
     $871 = $866 ? $870 : $868;
     $872 = ((($863)) + 8|0);
     $873 = HEAP32[$872>>2]|0;
     $874 = ($873|0)==(19);
     do {
      if ($874) {
       $875 = $863;
       $876 = $875;
       $877 = HEAP32[$876>>2]|0;
       $878 = (($875) + 4)|0;
       $879 = $878;
       $880 = HEAP32[$879>>2]|0;
       $948 = $877;$949 = $880;
       label = 207;
      } else {
       $$02$i$i91 = $863;$895 = $873;
       while(1) {
        if ((($895|0) == 3)) {
         $$02$i$i91$lcssa = $$02$i$i91;
         label = 198;
         break;
        } else if ((($895|0) == 19)) {
         $$02$i$i91$lcssa947 = $$02$i$i91;
         label = 201;
         break;
        }
        $894 = $895 & 15;
        $896 = ($894|0)==(4);
        if (!($896)) {
         label = 205;
         break;
        }
        $897 = HEAP32[$$02$i$i91>>2]|0;
        $898 = ((($897)) + 24|0);
        $899 = (_luaO_str2num($898,$v$i$i90)|0);
        $900 = HEAP32[$$02$i$i91>>2]|0;
        $901 = ((($900)) + 12|0);
        $902 = HEAP32[$901>>2]|0;
        $903 = (($902) + 1)|0;
        $904 = ($899|0)==($903|0);
        if (!($904)) {
         label = 205;
         break;
        }
        $$pre740 = HEAP32[$$phi$trans$insert739>>2]|0;
        $$02$i$i91 = $v$i$i90;$895 = $$pre740;
       }
       if ((label|0) == 198) {
        label = 0;
        $881 = +HEAPF64[$$02$i$i91$lcssa>>3];
        $882 = (+Math_floor((+$881)));
        $883 = $881 != $882;
        if ($883) {
         label = 205;
        } else {
         $884 = $882 >= -9.2233720368547758E+18;
         $885 = $882 < 9.2233720368547758E+18;
         $or$cond$i$i92 = $884 & $885;
         if ($or$cond$i$i92) {
          $886 = (~~$882)>>>0;
          $887 = +Math_abs($882) >= 1.0 ? $882 > 0.0 ? (~~+Math_min(+Math_floor($882 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($882 - +(~~$882 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2244 = $886;$2245 = $887;
          label = 206;
         } else {
          label = 205;
         }
        }
       }
       else if ((label|0) == 201) {
        label = 0;
        $888 = $$02$i$i91$lcssa947;
        $889 = $888;
        $890 = HEAP32[$889>>2]|0;
        $891 = (($888) + 4)|0;
        $892 = $891;
        $893 = HEAP32[$892>>2]|0;
        $2244 = $890;$2245 = $893;
        label = 206;
       }
       if ((label|0) == 205) {
        label = 0;
        break;
       }
       else if ((label|0) == 206) {
        label = 0;
        $948 = $2244;$949 = $2245;
        label = 207;
        break;
       }
      }
     } while(0);
     L275: do {
      if ((label|0) == 207) {
       label = 0;
       $905 = ((($871)) + 8|0);
       $906 = HEAP32[$905>>2]|0;
       $907 = ($906|0)==(19);
       do {
        if ($907) {
         $908 = $871;
         $909 = $908;
         $910 = HEAP32[$909>>2]|0;
         $911 = (($908) + 4)|0;
         $912 = $911;
         $913 = HEAP32[$912>>2]|0;
         $939 = $913;$942 = $910;
        } else {
         $$02$i$i96 = $871;$928 = $906;
         while(1) {
          if ((($928|0) == 3)) {
           $$02$i$i96$lcssa = $$02$i$i96;
           label = 211;
           break;
          } else if ((($928|0) == 19)) {
           $$02$i$i96$lcssa949 = $$02$i$i96;
           label = 214;
           break;
          }
          $927 = $928 & 15;
          $929 = ($927|0)==(4);
          if (!($929)) {
           label = 218;
           break;
          }
          $930 = HEAP32[$$02$i$i96>>2]|0;
          $931 = ((($930)) + 24|0);
          $932 = (_luaO_str2num($931,$v$i$i95)|0);
          $933 = HEAP32[$$02$i$i96>>2]|0;
          $934 = ((($933)) + 12|0);
          $935 = HEAP32[$934>>2]|0;
          $936 = (($935) + 1)|0;
          $937 = ($932|0)==($936|0);
          if (!($937)) {
           label = 218;
           break;
          }
          $$pre743 = HEAP32[$$phi$trans$insert742>>2]|0;
          $$02$i$i96 = $v$i$i95;$928 = $$pre743;
         }
         if ((label|0) == 211) {
          label = 0;
          $914 = +HEAPF64[$$02$i$i96$lcssa>>3];
          $915 = (+Math_floor((+$914)));
          $916 = $914 != $915;
          if ($916) {
           label = 218;
          } else {
           $917 = $915 >= -9.2233720368547758E+18;
           $918 = $915 < 9.2233720368547758E+18;
           $or$cond$i$i97 = $917 & $918;
           if ($or$cond$i$i97) {
            $919 = (~~$915)>>>0;
            $920 = +Math_abs($915) >= 1.0 ? $915 > 0.0 ? (~~+Math_min(+Math_floor($915 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($915 - +(~~$915 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $2246 = $919;$2247 = $920;
            label = 219;
           } else {
            label = 218;
           }
          }
         }
         else if ((label|0) == 214) {
          label = 0;
          $921 = $$02$i$i96$lcssa949;
          $922 = $921;
          $923 = HEAP32[$922>>2]|0;
          $924 = (($921) + 4)|0;
          $925 = $924;
          $926 = HEAP32[$925>>2]|0;
          $2246 = $923;$2247 = $926;
          label = 219;
         }
         if ((label|0) == 218) {
          label = 0;
          break L275;
         }
         else if ((label|0) == 219) {
          label = 0;
          $939 = $2247;$942 = $2246;
          break;
         }
        }
       } while(0);
       $938 = ($939|0)<(0);
       if ($938) {
        $940 = ($939|0)<(-1);
        $941 = ($942>>>0)<(4294967233);
        $943 = ($939|0)==(-1);
        $944 = $943 & $941;
        $945 = $940 | $944;
        $946 = (_i64Subtract(0,0,($942|0),($939|0))|0);
        $947 = tempRet0;
        $950 = (_bitshift64Lshr(($948|0),($949|0),($946|0))|0);
        $951 = tempRet0;
        $952 = $945 ? 0 : $950;
        $953 = $945 ? 0 : $951;
        $965 = $952;$968 = $953;
       } else {
        $954 = ($939|0)>(0);
        $955 = ($942>>>0)>(63);
        $956 = ($939|0)==(0);
        $957 = $956 & $955;
        $958 = $954 | $957;
        $959 = (_bitshift64Shl(($948|0),($949|0),($942|0))|0);
        $960 = tempRet0;
        $961 = $958 ? 0 : $959;
        $962 = $958 ? 0 : $960;
        $965 = $961;$968 = $962;
       }
       $963 = $50;
       $964 = $963;
       HEAP32[$964>>2] = $965;
       $966 = (($963) + 4)|0;
       $967 = $966;
       HEAP32[$967>>2] = $968;
       $969 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$969>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$863,$871,$50,16);
     $970 = HEAP32[$32>>2]|0;
     $base$0 = $970;
     continue L3;
     break;
    }
    case 24:  {
     $971 = $38 >>> 23;
     $972 = $971 & 256;
     $973 = ($972|0)==(0);
     $974 = $971 & 255;
     $975 = (($31) + ($974<<4)|0);
     $976 = (($base$1) + ($971<<4)|0);
     $977 = $973 ? $976 : $975;
     $978 = $38 >>> 14;
     $979 = $978 & 256;
     $980 = ($979|0)==(0);
     $981 = $978 & 255;
     $982 = (($31) + ($981<<4)|0);
     $983 = $978 & 511;
     $984 = (($base$1) + ($983<<4)|0);
     $985 = $980 ? $984 : $982;
     $986 = ((($977)) + 8|0);
     $987 = HEAP32[$986>>2]|0;
     $988 = ($987|0)==(19);
     do {
      if ($988) {
       $989 = $977;
       $990 = $989;
       $991 = HEAP32[$990>>2]|0;
       $992 = (($989) + 4)|0;
       $993 = $992;
       $994 = HEAP32[$993>>2]|0;
       $1064 = $991;$1065 = $994;
       label = 238;
      } else {
       $$02$i$i102 = $977;$1009 = $987;
       while(1) {
        if ((($1009|0) == 19)) {
         $$02$i$i102$lcssa943 = $$02$i$i102;
         label = 232;
         break;
        } else if ((($1009|0) == 3)) {
         $$02$i$i102$lcssa = $$02$i$i102;
         label = 229;
         break;
        }
        $1008 = $1009 & 15;
        $1010 = ($1008|0)==(4);
        if (!($1010)) {
         label = 236;
         break;
        }
        $1011 = HEAP32[$$02$i$i102>>2]|0;
        $1012 = ((($1011)) + 24|0);
        $1013 = (_luaO_str2num($1012,$v$i$i101)|0);
        $1014 = HEAP32[$$02$i$i102>>2]|0;
        $1015 = ((($1014)) + 12|0);
        $1016 = HEAP32[$1015>>2]|0;
        $1017 = (($1016) + 1)|0;
        $1018 = ($1013|0)==($1017|0);
        if (!($1018)) {
         label = 236;
         break;
        }
        $$pre734 = HEAP32[$$phi$trans$insert733>>2]|0;
        $$02$i$i102 = $v$i$i101;$1009 = $$pre734;
       }
       if ((label|0) == 229) {
        label = 0;
        $995 = +HEAPF64[$$02$i$i102$lcssa>>3];
        $996 = (+Math_floor((+$995)));
        $997 = $995 != $996;
        if ($997) {
         label = 236;
        } else {
         $998 = $996 >= -9.2233720368547758E+18;
         $999 = $996 < 9.2233720368547758E+18;
         $or$cond$i$i103 = $998 & $999;
         if ($or$cond$i$i103) {
          $1000 = (~~$996)>>>0;
          $1001 = +Math_abs($996) >= 1.0 ? $996 > 0.0 ? (~~+Math_min(+Math_floor($996 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($996 - +(~~$996 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2248 = $1000;$2249 = $1001;
          label = 237;
         } else {
          label = 236;
         }
        }
       }
       else if ((label|0) == 232) {
        label = 0;
        $1002 = $$02$i$i102$lcssa943;
        $1003 = $1002;
        $1004 = HEAP32[$1003>>2]|0;
        $1005 = (($1002) + 4)|0;
        $1006 = $1005;
        $1007 = HEAP32[$1006>>2]|0;
        $2248 = $1004;$2249 = $1007;
        label = 237;
       }
       if ((label|0) == 236) {
        label = 0;
        break;
       }
       else if ((label|0) == 237) {
        label = 0;
        $1064 = $2248;$1065 = $2249;
        label = 238;
        break;
       }
      }
     } while(0);
     L316: do {
      if ((label|0) == 238) {
       label = 0;
       $1019 = ((($985)) + 8|0);
       $1020 = HEAP32[$1019>>2]|0;
       $1021 = ($1020|0)==(19);
       do {
        if ($1021) {
         $1022 = $985;
         $1023 = $1022;
         $1024 = HEAP32[$1023>>2]|0;
         $1025 = (($1022) + 4)|0;
         $1026 = $1025;
         $1027 = HEAP32[$1026>>2]|0;
         $1053 = $1027;$1055 = $1024;
        } else {
         $$02$i$i107 = $985;$1042 = $1020;
         while(1) {
          if ((($1042|0) == 3)) {
           $$02$i$i107$lcssa = $$02$i$i107;
           label = 242;
           break;
          } else if ((($1042|0) == 19)) {
           $$02$i$i107$lcssa945 = $$02$i$i107;
           label = 245;
           break;
          }
          $1041 = $1042 & 15;
          $1043 = ($1041|0)==(4);
          if (!($1043)) {
           label = 249;
           break;
          }
          $1044 = HEAP32[$$02$i$i107>>2]|0;
          $1045 = ((($1044)) + 24|0);
          $1046 = (_luaO_str2num($1045,$v$i$i106)|0);
          $1047 = HEAP32[$$02$i$i107>>2]|0;
          $1048 = ((($1047)) + 12|0);
          $1049 = HEAP32[$1048>>2]|0;
          $1050 = (($1049) + 1)|0;
          $1051 = ($1046|0)==($1050|0);
          if (!($1051)) {
           label = 249;
           break;
          }
          $$pre737 = HEAP32[$$phi$trans$insert736>>2]|0;
          $$02$i$i107 = $v$i$i106;$1042 = $$pre737;
         }
         if ((label|0) == 242) {
          label = 0;
          $1028 = +HEAPF64[$$02$i$i107$lcssa>>3];
          $1029 = (+Math_floor((+$1028)));
          $1030 = $1028 != $1029;
          if ($1030) {
           label = 249;
          } else {
           $1031 = $1029 >= -9.2233720368547758E+18;
           $1032 = $1029 < 9.2233720368547758E+18;
           $or$cond$i$i108 = $1031 & $1032;
           if ($or$cond$i$i108) {
            $1033 = (~~$1029)>>>0;
            $1034 = +Math_abs($1029) >= 1.0 ? $1029 > 0.0 ? (~~+Math_min(+Math_floor($1029 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($1029 - +(~~$1029 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $2250 = $1033;$2251 = $1034;
            label = 250;
           } else {
            label = 249;
           }
          }
         }
         else if ((label|0) == 245) {
          label = 0;
          $1035 = $$02$i$i107$lcssa945;
          $1036 = $1035;
          $1037 = HEAP32[$1036>>2]|0;
          $1038 = (($1035) + 4)|0;
          $1039 = $1038;
          $1040 = HEAP32[$1039>>2]|0;
          $2250 = $1037;$2251 = $1040;
          label = 250;
         }
         if ((label|0) == 249) {
          label = 0;
          break L316;
         }
         else if ((label|0) == 250) {
          label = 0;
          $1053 = $2251;$1055 = $2250;
          break;
         }
        }
       } while(0);
       $1052 = ($1053|0)>(0);
       $1054 = ($1055>>>0)>(0);
       $1056 = ($1053|0)==(0);
       $1057 = $1056 & $1054;
       $1058 = $1052 | $1057;
       if ($1058) {
        $1059 = ($1053|0)>(0);
        $1060 = ($1055>>>0)>(63);
        $1061 = ($1053|0)==(0);
        $1062 = $1061 & $1060;
        $1063 = $1059 | $1062;
        $1066 = (_bitshift64Lshr(($1064|0),($1065|0),($1055|0))|0);
        $1067 = tempRet0;
        $1068 = $1063 ? 0 : $1066;
        $1069 = $1063 ? 0 : $1067;
        $1083 = $1068;$1086 = $1069;
       } else {
        $1070 = (_i64Subtract(0,0,($1055|0),($1053|0))|0);
        $1071 = tempRet0;
        $1072 = ($1053|0)<(-1);
        $1073 = ($1055>>>0)<(4294967233);
        $1074 = ($1053|0)==(-1);
        $1075 = $1074 & $1073;
        $1076 = $1072 | $1075;
        $1077 = (_bitshift64Shl(($1064|0),($1065|0),($1070|0))|0);
        $1078 = tempRet0;
        $1079 = $1076 ? 0 : $1077;
        $1080 = $1076 ? 0 : $1078;
        $1083 = $1079;$1086 = $1080;
       }
       $1081 = $50;
       $1082 = $1081;
       HEAP32[$1082>>2] = $1083;
       $1084 = (($1081) + 4)|0;
       $1085 = $1084;
       HEAP32[$1085>>2] = $1086;
       $1087 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1087>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$977,$985,$50,17);
     $1088 = HEAP32[$32>>2]|0;
     $base$0 = $1088;
     continue L3;
     break;
    }
    case 16:  {
     $1089 = $38 >>> 23;
     $1090 = $1089 & 256;
     $1091 = ($1090|0)==(0);
     $1092 = $1089 & 255;
     $1093 = (($31) + ($1092<<4)|0);
     $1094 = (($base$1) + ($1089<<4)|0);
     $1095 = $1091 ? $1094 : $1093;
     $1096 = $38 >>> 14;
     $1097 = $1096 & 256;
     $1098 = ($1097|0)==(0);
     $1099 = $1096 & 255;
     $1100 = (($31) + ($1099<<4)|0);
     $1101 = $1096 & 511;
     $1102 = (($base$1) + ($1101<<4)|0);
     $1103 = $1098 ? $1102 : $1100;
     $1104 = ((($1095)) + 8|0);
     $1105 = HEAP32[$1104>>2]|0;
     do {
      if ((($1105|0) == 19)) {
       $1106 = ((($1103)) + 8|0);
       $1107 = HEAP32[$1106>>2]|0;
       $1108 = ($1107|0)==(19);
       if (!($1108)) {
        $1150 = $1095;
        $1151 = $1150;
        $1152 = HEAP32[$1151>>2]|0;
        $1153 = (($1150) + 4)|0;
        $1154 = $1153;
        $1155 = HEAP32[$1154>>2]|0;
        $1156 = (+($1152>>>0)) + (4294967296.0*(+($1155|0)));
        $$ph230 = $1156;
        label = 269;
        break;
       }
       $1109 = $1095;
       $1110 = $1109;
       $1111 = HEAP32[$1110>>2]|0;
       $1112 = (($1109) + 4)|0;
       $1113 = $1112;
       $1114 = HEAP32[$1113>>2]|0;
       $1115 = $1103;
       $1116 = $1115;
       $1117 = HEAP32[$1116>>2]|0;
       $1118 = (($1115) + 4)|0;
       $1119 = $1118;
       $1120 = HEAP32[$1119>>2]|0;
       $1121 = (_i64Add(($1117|0),($1120|0),1,0)|0);
       $1122 = tempRet0;
       $1123 = ($1122>>>0)<(0);
       $1124 = ($1121>>>0)<(2);
       $1125 = ($1122|0)==(0);
       $1126 = $1125 & $1124;
       $1127 = $1123 | $1126;
       if ($1127) {
        $1128 = ($1117|0)==(0);
        $1129 = ($1120|0)==(0);
        $1130 = $1128 & $1129;
        if ($1130) {
         label = 260;
         break L1;
        } else {
         $1144 = 0;$1147 = 0;
        }
       } else {
        $1131 = (___remdi3(($1111|0),($1114|0),($1117|0),($1120|0))|0);
        $1132 = tempRet0;
        $1133 = ($1131|0)!=(0);
        $1134 = ($1132|0)!=(0);
        $1135 = $1133 | $1134;
        $1117 ^ $1111;
        $1136 = $1120 ^ $1114;
        $1137 = ($1136|0)<(0);
        $or$cond$i = $1137 & $1135;
        $1138 = $or$cond$i ? $1117 : 0;
        $1139 = $or$cond$i ? $1120 : 0;
        $1140 = (_i64Add(($1138|0),($1139|0),($1131|0),($1132|0))|0);
        $1141 = tempRet0;
        $1144 = $1140;$1147 = $1141;
       }
       $1142 = $50;
       $1143 = $1142;
       HEAP32[$1143>>2] = $1144;
       $1145 = (($1142) + 4)|0;
       $1146 = $1145;
       HEAP32[$1146>>2] = $1147;
       $1148 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1148>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      } else if ((($1105|0) == 3)) {
       $1149 = +HEAPF64[$1095>>3];
       $1211 = $1149;
       label = 270;
      } else {
       $1157 = $1105 & 15;
       $1158 = ($1157|0)==(4);
       if ($1158) {
        $1159 = HEAP32[$1095>>2]|0;
        $1160 = ((($1159)) + 24|0);
        $1161 = (_luaO_str2num($1160,$v$i115)|0);
        $1162 = HEAP32[$1095>>2]|0;
        $1163 = ((($1162)) + 12|0);
        $1164 = HEAP32[$1163>>2]|0;
        $1165 = (($1164) + 1)|0;
        $1166 = ($1161|0)==($1165|0);
        if ($1166) {
         $1167 = HEAP32[$14>>2]|0;
         $1168 = ($1167|0)==(19);
         $1169 = $v$i115;
         $1170 = $1169;
         $1171 = HEAP32[$1170>>2]|0;
         $1172 = (($1169) + 4)|0;
         $1173 = $1172;
         $1174 = HEAP32[$1173>>2]|0;
         $1175 = (+($1171>>>0)) + (4294967296.0*(+($1174|0)));
         HEAP32[tempDoublePtr>>2] = $1171;HEAP32[tempDoublePtr+4>>2] = $1174;$1176 = +HEAPF64[tempDoublePtr>>3];
         $1177 = $1168 ? $1175 : $1176;
         $$ph230 = $1177;
         label = 269;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 269) {
      label = 0;
      $1211 = $$ph230;
      label = 270;
     }
     L358: do {
      if ((label|0) == 270) {
       label = 0;
       $1178 = ((($1103)) + 8|0);
       $1179 = HEAP32[$1178>>2]|0;
       $1180 = ($1179|0)==(3);
       if ($1180) {
        $1181 = +HEAPF64[$1103>>3];
        $1212 = $1181;
       } else {
        $1182 = ($1179|0)==(19);
        do {
         if ($1182) {
          $1183 = $1103;
          $1184 = $1183;
          $1185 = HEAP32[$1184>>2]|0;
          $1186 = (($1183) + 4)|0;
          $1187 = $1186;
          $1188 = HEAP32[$1187>>2]|0;
          $1189 = (+($1185>>>0)) + (4294967296.0*(+($1188|0)));
          $$ph233 = $1189;
         } else {
          $1190 = $1179 & 15;
          $1191 = ($1190|0)==(4);
          if ($1191) {
           $1192 = HEAP32[$1103>>2]|0;
           $1193 = ((($1192)) + 24|0);
           $1194 = (_luaO_str2num($1193,$v$i119)|0);
           $1195 = HEAP32[$1103>>2]|0;
           $1196 = ((($1195)) + 12|0);
           $1197 = HEAP32[$1196>>2]|0;
           $1198 = (($1197) + 1)|0;
           $1199 = ($1194|0)==($1198|0);
           if ($1199) {
            $1200 = HEAP32[$13>>2]|0;
            $1201 = ($1200|0)==(19);
            $1202 = $v$i119;
            $1203 = $1202;
            $1204 = HEAP32[$1203>>2]|0;
            $1205 = (($1202) + 4)|0;
            $1206 = $1205;
            $1207 = HEAP32[$1206>>2]|0;
            $1208 = (+($1204>>>0)) + (4294967296.0*(+($1207|0)));
            HEAP32[tempDoublePtr>>2] = $1204;HEAP32[tempDoublePtr+4>>2] = $1207;$1209 = +HEAPF64[tempDoublePtr>>3];
            $1210 = $1201 ? $1208 : $1209;
            $$ph233 = $1210;
            break;
           }
          }
          break L358;
         }
        } while(0);
        $1212 = $$ph233;
       }
       $1213 = (+_fmod($1211,$1212));
       $1214 = $1212 * $1213;
       $1215 = $1214 < 0.0;
       $1216 = $1212 + $1213;
       $m$0 = $1215 ? $1216 : $1213;
       HEAPF64[$50>>3] = $m$0;
       $1217 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1217>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$1095,$1103,$50,9);
     $1218 = HEAP32[$32>>2]|0;
     $base$0 = $1218;
     continue L3;
     break;
    }
    case 19:  {
     $1219 = $38 >>> 23;
     $1220 = $1219 & 256;
     $1221 = ($1220|0)==(0);
     $1222 = $1219 & 255;
     $1223 = (($31) + ($1222<<4)|0);
     $1224 = (($base$1) + ($1219<<4)|0);
     $1225 = $1221 ? $1224 : $1223;
     $1226 = $38 >>> 14;
     $1227 = $1226 & 256;
     $1228 = ($1227|0)==(0);
     $1229 = $1226 & 255;
     $1230 = (($31) + ($1229<<4)|0);
     $1231 = $1226 & 511;
     $1232 = (($base$1) + ($1231<<4)|0);
     $1233 = $1228 ? $1232 : $1230;
     $1234 = ((($1225)) + 8|0);
     $1235 = HEAP32[$1234>>2]|0;
     do {
      if ((($1235|0) == 19)) {
       $1236 = ((($1233)) + 8|0);
       $1237 = HEAP32[$1236>>2]|0;
       $1238 = ($1237|0)==(19);
       if (!($1238)) {
        $1285 = $1225;
        $1286 = $1285;
        $1287 = HEAP32[$1286>>2]|0;
        $1288 = (($1285) + 4)|0;
        $1289 = $1288;
        $1290 = HEAP32[$1289>>2]|0;
        $1291 = (+($1287>>>0)) + (4294967296.0*(+($1290|0)));
        $$ph238 = $1291;
        label = 296;
        break;
       }
       $1239 = $1225;
       $1240 = $1239;
       $1241 = HEAP32[$1240>>2]|0;
       $1242 = (($1239) + 4)|0;
       $1243 = $1242;
       $1244 = HEAP32[$1243>>2]|0;
       $1245 = $1233;
       $1246 = $1245;
       $1247 = HEAP32[$1246>>2]|0;
       $1248 = (($1245) + 4)|0;
       $1249 = $1248;
       $1250 = HEAP32[$1249>>2]|0;
       $1251 = (_i64Add(($1247|0),($1250|0),1,0)|0);
       $1252 = tempRet0;
       $1253 = ($1252>>>0)<(0);
       $1254 = ($1251>>>0)<(2);
       $1255 = ($1252|0)==(0);
       $1256 = $1255 & $1254;
       $1257 = $1253 | $1256;
       if ($1257) {
        $1258 = ($1247|0)==(0);
        $1259 = ($1250|0)==(0);
        $1260 = $1258 & $1259;
        if ($1260) {
         label = 285;
         break L1;
        }
        $1261 = (_i64Subtract(0,0,($1241|0),($1244|0))|0);
        $1262 = tempRet0;
        $1279 = $1261;$1282 = $1262;
       } else {
        $1263 = (___divdi3(($1241|0),($1244|0),($1247|0),($1250|0))|0);
        $1264 = tempRet0;
        $1247 ^ $1241;
        $1265 = $1250 ^ $1244;
        $1266 = ($1265|0)<(0);
        if ($1266) {
         $1267 = (___remdi3(($1241|0),($1244|0),($1247|0),($1250|0))|0);
         $1268 = tempRet0;
         $1269 = ($1267|0)!=(0);
         $1270 = ($1268|0)!=(0);
         $1271 = $1269 | $1270;
         $1272 = $1271 << 31 >> 31;
         $1273 = ($1272|0)<(0);
         $1274 = $1273 << 31 >> 31;
         $1275 = (_i64Add(($1272|0),($1274|0),($1263|0),($1264|0))|0);
         $1276 = tempRet0;
         $1279 = $1275;$1282 = $1276;
        } else {
         $1279 = $1263;$1282 = $1264;
        }
       }
       $1277 = $50;
       $1278 = $1277;
       HEAP32[$1278>>2] = $1279;
       $1280 = (($1277) + 4)|0;
       $1281 = $1280;
       HEAP32[$1281>>2] = $1282;
       $1283 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1283>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      } else if ((($1235|0) == 3)) {
       $1284 = +HEAPF64[$1225>>3];
       $1347 = $1284;
       label = 297;
      } else {
       $1292 = $1235 & 15;
       $1293 = ($1292|0)==(4);
       if ($1293) {
        $1294 = HEAP32[$1225>>2]|0;
        $1295 = ((($1294)) + 24|0);
        $1296 = (_luaO_str2num($1295,$v$i125)|0);
        $1297 = HEAP32[$1225>>2]|0;
        $1298 = ((($1297)) + 12|0);
        $1299 = HEAP32[$1298>>2]|0;
        $1300 = (($1299) + 1)|0;
        $1301 = ($1296|0)==($1300|0);
        if ($1301) {
         $1302 = HEAP32[$16>>2]|0;
         $1303 = ($1302|0)==(19);
         $1304 = $v$i125;
         $1305 = $1304;
         $1306 = HEAP32[$1305>>2]|0;
         $1307 = (($1304) + 4)|0;
         $1308 = $1307;
         $1309 = HEAP32[$1308>>2]|0;
         $1310 = (+($1306>>>0)) + (4294967296.0*(+($1309|0)));
         HEAP32[tempDoublePtr>>2] = $1306;HEAP32[tempDoublePtr+4>>2] = $1309;$1311 = +HEAPF64[tempDoublePtr>>3];
         $1312 = $1303 ? $1310 : $1311;
         $$ph238 = $1312;
         label = 296;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 296) {
      label = 0;
      $1347 = $$ph238;
      label = 297;
     }
     L393: do {
      if ((label|0) == 297) {
       label = 0;
       $1313 = ((($1233)) + 8|0);
       $1314 = HEAP32[$1313>>2]|0;
       $1315 = ($1314|0)==(3);
       if ($1315) {
        $1316 = +HEAPF64[$1233>>3];
        $1348 = $1316;
       } else {
        $1317 = ($1314|0)==(19);
        do {
         if ($1317) {
          $1318 = $1233;
          $1319 = $1318;
          $1320 = HEAP32[$1319>>2]|0;
          $1321 = (($1318) + 4)|0;
          $1322 = $1321;
          $1323 = HEAP32[$1322>>2]|0;
          $1324 = (+($1320>>>0)) + (4294967296.0*(+($1323|0)));
          $$ph241 = $1324;
         } else {
          $1325 = $1314 & 15;
          $1326 = ($1325|0)==(4);
          if ($1326) {
           $1327 = HEAP32[$1233>>2]|0;
           $1328 = ((($1327)) + 24|0);
           $1329 = (_luaO_str2num($1328,$v$i129)|0);
           $1330 = HEAP32[$1233>>2]|0;
           $1331 = ((($1330)) + 12|0);
           $1332 = HEAP32[$1331>>2]|0;
           $1333 = (($1332) + 1)|0;
           $1334 = ($1329|0)==($1333|0);
           if ($1334) {
            $1335 = HEAP32[$15>>2]|0;
            $1336 = ($1335|0)==(19);
            $1337 = $v$i129;
            $1338 = $1337;
            $1339 = HEAP32[$1338>>2]|0;
            $1340 = (($1337) + 4)|0;
            $1341 = $1340;
            $1342 = HEAP32[$1341>>2]|0;
            $1343 = (+($1339>>>0)) + (4294967296.0*(+($1342|0)));
            HEAP32[tempDoublePtr>>2] = $1339;HEAP32[tempDoublePtr+4>>2] = $1342;$1344 = +HEAPF64[tempDoublePtr>>3];
            $1345 = $1336 ? $1343 : $1344;
            $$ph241 = $1345;
            break;
           }
          }
          break L393;
         }
        } while(0);
        $1348 = $$ph241;
       }
       $1346 = $1347 / $1348;
       $1349 = (+Math_floor((+$1346)));
       HEAPF64[$50>>3] = $1349;
       $1350 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1350>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$1225,$1233,$50,12);
     $1351 = HEAP32[$32>>2]|0;
     $base$0 = $1351;
     continue L3;
     break;
    }
    case 17:  {
     $1352 = $38 >>> 23;
     $1353 = $1352 & 256;
     $1354 = ($1353|0)==(0);
     $1355 = $1352 & 255;
     $1356 = (($31) + ($1355<<4)|0);
     $1357 = (($base$1) + ($1352<<4)|0);
     $1358 = $1354 ? $1357 : $1356;
     $1359 = $38 >>> 14;
     $1360 = $1359 & 256;
     $1361 = ($1360|0)==(0);
     $1362 = $1359 & 255;
     $1363 = (($31) + ($1362<<4)|0);
     $1364 = $1359 & 511;
     $1365 = (($base$1) + ($1364<<4)|0);
     $1366 = $1361 ? $1365 : $1363;
     $1367 = ((($1358)) + 8|0);
     $1368 = HEAP32[$1367>>2]|0;
     $1369 = ($1368|0)==(3);
     L409: do {
      if ($1369) {
       $1370 = +HEAPF64[$1358>>3];
       $1433 = $1370;
       label = 317;
      } else {
       $1371 = ($1368|0)==(19);
       do {
        if ($1371) {
         $1372 = $1358;
         $1373 = $1372;
         $1374 = HEAP32[$1373>>2]|0;
         $1375 = (($1372) + 4)|0;
         $1376 = $1375;
         $1377 = HEAP32[$1376>>2]|0;
         $1378 = (+($1374>>>0)) + (4294967296.0*(+($1377|0)));
         $$ph244 = $1378;
        } else {
         $1379 = $1368 & 15;
         $1380 = ($1379|0)==(4);
         if ($1380) {
          $1381 = HEAP32[$1358>>2]|0;
          $1382 = ((($1381)) + 24|0);
          $1383 = (_luaO_str2num($1382,$v$i133)|0);
          $1384 = HEAP32[$1358>>2]|0;
          $1385 = ((($1384)) + 12|0);
          $1386 = HEAP32[$1385>>2]|0;
          $1387 = (($1386) + 1)|0;
          $1388 = ($1383|0)==($1387|0);
          if ($1388) {
           $1389 = HEAP32[$18>>2]|0;
           $1390 = ($1389|0)==(19);
           $1391 = $v$i133;
           $1392 = $1391;
           $1393 = HEAP32[$1392>>2]|0;
           $1394 = (($1391) + 4)|0;
           $1395 = $1394;
           $1396 = HEAP32[$1395>>2]|0;
           $1397 = (+($1393>>>0)) + (4294967296.0*(+($1396|0)));
           HEAP32[tempDoublePtr>>2] = $1393;HEAP32[tempDoublePtr+4>>2] = $1396;$1398 = +HEAPF64[tempDoublePtr>>3];
           $1399 = $1390 ? $1397 : $1398;
           $$ph244 = $1399;
           break;
          }
         }
         break L409;
        }
       } while(0);
       $1433 = $$ph244;
       label = 317;
      }
     } while(0);
     L420: do {
      if ((label|0) == 317) {
       label = 0;
       $1400 = ((($1366)) + 8|0);
       $1401 = HEAP32[$1400>>2]|0;
       $1402 = ($1401|0)==(3);
       if ($1402) {
        $1403 = +HEAPF64[$1366>>3];
        $1434 = $1403;
       } else {
        $1404 = ($1401|0)==(19);
        do {
         if ($1404) {
          $1405 = $1366;
          $1406 = $1405;
          $1407 = HEAP32[$1406>>2]|0;
          $1408 = (($1405) + 4)|0;
          $1409 = $1408;
          $1410 = HEAP32[$1409>>2]|0;
          $1411 = (+($1407>>>0)) + (4294967296.0*(+($1410|0)));
          $$ph247 = $1411;
         } else {
          $1412 = $1401 & 15;
          $1413 = ($1412|0)==(4);
          if ($1413) {
           $1414 = HEAP32[$1366>>2]|0;
           $1415 = ((($1414)) + 24|0);
           $1416 = (_luaO_str2num($1415,$v$i137)|0);
           $1417 = HEAP32[$1366>>2]|0;
           $1418 = ((($1417)) + 12|0);
           $1419 = HEAP32[$1418>>2]|0;
           $1420 = (($1419) + 1)|0;
           $1421 = ($1416|0)==($1420|0);
           if ($1421) {
            $1422 = HEAP32[$17>>2]|0;
            $1423 = ($1422|0)==(19);
            $1424 = $v$i137;
            $1425 = $1424;
            $1426 = HEAP32[$1425>>2]|0;
            $1427 = (($1424) + 4)|0;
            $1428 = $1427;
            $1429 = HEAP32[$1428>>2]|0;
            $1430 = (+($1426>>>0)) + (4294967296.0*(+($1429|0)));
            HEAP32[tempDoublePtr>>2] = $1426;HEAP32[tempDoublePtr+4>>2] = $1429;$1431 = +HEAPF64[tempDoublePtr>>3];
            $1432 = $1423 ? $1430 : $1431;
            $$ph247 = $1432;
            break;
           }
          }
          break L420;
         }
        } while(0);
        $1434 = $$ph247;
       }
       $1435 = (+Math_pow((+$1433),(+$1434)));
       HEAPF64[$50>>3] = $1435;
       $1436 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1436>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$1358,$1366,$50,10);
     $1437 = HEAP32[$32>>2]|0;
     $base$0 = $1437;
     continue L3;
     break;
    }
    case 25:  {
     $1438 = $38 >>> 23;
     $1439 = (($base$1) + ($1438<<4)|0);
     $1440 = (((($base$1) + ($1438<<4)|0)) + 8|0);
     $1441 = HEAP32[$1440>>2]|0;
     do {
      if ((($1441|0) == 19)) {
       $1442 = $1439;
       $1443 = $1442;
       $1444 = HEAP32[$1443>>2]|0;
       $1445 = (($1442) + 4)|0;
       $1446 = $1445;
       $1447 = HEAP32[$1446>>2]|0;
       $1448 = (_i64Subtract(0,0,($1444|0),($1447|0))|0);
       $1449 = tempRet0;
       $1450 = $50;
       $1451 = $1450;
       HEAP32[$1451>>2] = $1448;
       $1452 = (($1450) + 4)|0;
       $1453 = $1452;
       HEAP32[$1453>>2] = $1449;
       $1454 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1454>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      } else if ((($1441|0) == 3)) {
       $1455 = +HEAPF64[$1439>>3];
       $1478 = $1455;
      } else {
       $1456 = $1441 & 15;
       $1457 = ($1456|0)==(4);
       if ($1457) {
        $1458 = HEAP32[$1439>>2]|0;
        $1459 = ((($1458)) + 24|0);
        $1460 = (_luaO_str2num($1459,$v$i141)|0);
        $1461 = HEAP32[$1439>>2]|0;
        $1462 = ((($1461)) + 12|0);
        $1463 = HEAP32[$1462>>2]|0;
        $1464 = (($1463) + 1)|0;
        $1465 = ($1460|0)==($1464|0);
        if ($1465) {
         $1466 = HEAP32[$19>>2]|0;
         $1467 = ($1466|0)==(19);
         $1468 = $v$i141;
         $1469 = $1468;
         $1470 = HEAP32[$1469>>2]|0;
         $1471 = (($1468) + 4)|0;
         $1472 = $1471;
         $1473 = HEAP32[$1472>>2]|0;
         $1474 = (+($1470>>>0)) + (4294967296.0*(+($1473|0)));
         HEAP32[tempDoublePtr>>2] = $1470;HEAP32[tempDoublePtr+4>>2] = $1473;$1475 = +HEAPF64[tempDoublePtr>>3];
         $1476 = $1467 ? $1474 : $1475;
         $1478 = $1476;
         break;
        }
       }
       _luaT_trybinTM($L,$1439,$1439,$50,18);
       $1480 = HEAP32[$32>>2]|0;
       $base$0 = $1480;
       continue L3;
      }
     } while(0);
     $1477 = -$1478;
     HEAPF64[$50>>3] = $1477;
     $1479 = (((($base$1) + ($49<<4)|0)) + 8|0);
     HEAP32[$1479>>2] = 3;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 26:  {
     $1481 = $38 >>> 23;
     $1482 = (($base$1) + ($1481<<4)|0);
     $1483 = (((($base$1) + ($1481<<4)|0)) + 8|0);
     $1484 = HEAP32[$1483>>2]|0;
     $1485 = ($1484|0)==(19);
     do {
      if ($1485) {
       $1486 = $1482;
       $1487 = $1486;
       $1488 = HEAP32[$1487>>2]|0;
       $1489 = (($1486) + 4)|0;
       $1490 = $1489;
       $1491 = HEAP32[$1490>>2]|0;
       $1518 = $1488;$1520 = $1491;
      } else {
       $$02$i$i146 = $1482;
       while(1) {
        $1492 = ((($$02$i$i146)) + 8|0);
        $1493 = HEAP32[$1492>>2]|0;
        if ((($1493|0) == 3)) {
         $$02$i$i146$lcssa = $$02$i$i146;
         label = 340;
         break;
        } else if ((($1493|0) == 19)) {
         $$02$i$i146$lcssa941 = $$02$i$i146;
         label = 343;
         break;
        }
        $1507 = $1493 & 15;
        $1508 = ($1507|0)==(4);
        if (!($1508)) {
         label = 348;
         break;
        }
        $1509 = HEAP32[$$02$i$i146>>2]|0;
        $1510 = ((($1509)) + 24|0);
        $1511 = (_luaO_str2num($1510,$v$i$i145)|0);
        $1512 = HEAP32[$$02$i$i146>>2]|0;
        $1513 = ((($1512)) + 12|0);
        $1514 = HEAP32[$1513>>2]|0;
        $1515 = (($1514) + 1)|0;
        $1516 = ($1511|0)==($1515|0);
        if ($1516) {
         $$02$i$i146 = $v$i$i145;
        } else {
         label = 348;
         break;
        }
       }
       if ((label|0) == 340) {
        label = 0;
        $1494 = +HEAPF64[$$02$i$i146$lcssa>>3];
        $1495 = (+Math_floor((+$1494)));
        $1496 = $1494 != $1495;
        if ($1496) {
         label = 348;
        } else {
         $1497 = $1495 >= -9.2233720368547758E+18;
         $1498 = $1495 < 9.2233720368547758E+18;
         $or$cond$i$i147 = $1497 & $1498;
         if ($or$cond$i$i147) {
          $1499 = (~~$1495)>>>0;
          $1500 = +Math_abs($1495) >= 1.0 ? $1495 > 0.0 ? (~~+Math_min(+Math_floor($1495 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($1495 - +(~~$1495 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2252 = $1499;$2253 = $1500;
          label = 346;
         } else {
          label = 348;
         }
        }
       }
       else if ((label|0) == 343) {
        label = 0;
        $1501 = $$02$i$i146$lcssa941;
        $1502 = $1501;
        $1503 = HEAP32[$1502>>2]|0;
        $1504 = (($1501) + 4)|0;
        $1505 = $1504;
        $1506 = HEAP32[$1505>>2]|0;
        $2252 = $1503;$2253 = $1506;
        label = 346;
       }
       if ((label|0) == 346) {
        label = 0;
        $1518 = $2252;$1520 = $2253;
        break;
       }
       else if ((label|0) == 348) {
        label = 0;
        _luaT_trybinTM($L,$1482,$1482,$50,19);
        $1526 = HEAP32[$32>>2]|0;
        $base$0 = $1526;
        continue L3;
       }
      }
     } while(0);
     $1517 = $1518 ^ -1;
     $1519 = $1520 ^ -1;
     $1521 = $50;
     $1522 = $1521;
     HEAP32[$1522>>2] = $1517;
     $1523 = (($1521) + 4)|0;
     $1524 = $1523;
     HEAP32[$1524>>2] = $1519;
     $1525 = (((($base$1) + ($49<<4)|0)) + 8|0);
     HEAP32[$1525>>2] = 19;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 27:  {
     $1527 = $38 >>> 23;
     $1528 = (((($base$1) + ($1527<<4)|0)) + 8|0);
     $1529 = HEAP32[$1528>>2]|0;
     $1530 = ($1529|0)==(0);
     if ($1530) {
      $1536 = 1;
     } else {
      $1531 = ($1529|0)==(1);
      if ($1531) {
       $1532 = (($base$1) + ($1527<<4)|0);
       $1533 = HEAP32[$1532>>2]|0;
       $1534 = ($1533|0)==(0);
       $1536 = $1534;
      } else {
       $1536 = 0;
      }
     }
     $1535 = $1536&1;
     HEAP32[$50>>2] = $1535;
     $1537 = (((($base$1) + ($49<<4)|0)) + 8|0);
     HEAP32[$1537>>2] = 1;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 30:  {
     $1560 = ($49|0)==(0);
     if (!($1560)) {
      $1561 = HEAP32[$32>>2]|0;
      $$sum31 = (($49) + -1)|0;
      $1562 = (($1561) + ($$sum31<<4)|0);
      _luaF_close($L,$1562);
     }
     $1563 = $38 >>> 14;
     $1564 = (($1563) + -131071)|0;
     $1565 = HEAP32[$34>>2]|0;
     $1566 = (($1565) + ($1564<<2)|0);
     HEAP32[$34>>2] = $1566;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 31:  {
     $1567 = $38 >>> 23;
     $1568 = $1567 & 256;
     $1569 = ($1568|0)==(0);
     $1570 = $1567 & 255;
     $1571 = (($31) + ($1570<<4)|0);
     $1572 = (($base$1) + ($1567<<4)|0);
     $1573 = $1569 ? $1572 : $1571;
     $1574 = $38 >>> 14;
     $1575 = $1574 & 256;
     $1576 = ($1575|0)==(0);
     $1577 = $1574 & 255;
     $1578 = (($31) + ($1577<<4)|0);
     $1579 = $1574 & 511;
     $1580 = (($base$1) + ($1579<<4)|0);
     $1581 = $1576 ? $1580 : $1578;
     $1582 = (_luaV_equalobj($L,$1573,$1581)|0);
     $1583 = ($1582|0)==($49|0);
     $1584 = HEAP32[$34>>2]|0;
     if ($1583) {
      $1586 = HEAP32[$1584>>2]|0;
      $1587 = $1586 >>> 6;
      $1588 = $1587 & 255;
      $1589 = ($1588|0)==(0);
      if ($1589) {
       $1595 = $1584;
      } else {
       $1590 = HEAP32[$32>>2]|0;
       $$sum30 = (($1588) + -1)|0;
       $1591 = (($1590) + ($$sum30<<4)|0);
       _luaF_close($L,$1591);
       $$pre729 = HEAP32[$34>>2]|0;
       $1595 = $$pre729;
      }
      $1592 = $1586 >>> 14;
      $1593 = (($1592) + -131070)|0;
      $1594 = (($1595) + ($1593<<2)|0);
      $storemerge29 = $1594;
     } else {
      $1585 = ((($1584)) + 4|0);
      $storemerge29 = $1585;
     }
     HEAP32[$34>>2] = $storemerge29;
     $1596 = HEAP32[$32>>2]|0;
     $base$0 = $1596;
     continue L3;
     break;
    }
    case 28:  {
     $1538 = $38 >>> 23;
     $1539 = (($base$1) + ($1538<<4)|0);
     _luaV_objlen($L,$50,$1539);
     $1540 = HEAP32[$32>>2]|0;
     $base$0 = $1540;
     continue L3;
     break;
    }
    case 29:  {
     $1541 = $38 >>> 23;
     $1542 = $38 >>> 14;
     $1543 = $1542 & 511;
     $$sum32 = (($1543) + 1)|0;
     $1544 = (($base$1) + ($$sum32<<4)|0);
     HEAP32[$4>>2] = $1544;
     $1545 = (1 - ($1541))|0;
     $1546 = (($1545) + ($1543))|0;
     _luaV_concat($L,$1546);
     $1547 = HEAP32[$32>>2]|0;
     $1548 = (($1547) + ($49<<4)|0);
     $1549 = (($1547) + ($1541<<4)|0);
     ;HEAP32[$1548>>2]=HEAP32[$1549>>2]|0;HEAP32[$1548+4>>2]=HEAP32[$1549+4>>2]|0;HEAP32[$1548+8>>2]=HEAP32[$1549+8>>2]|0;HEAP32[$1548+12>>2]=HEAP32[$1549+12>>2]|0;
     $1550 = HEAP32[$3>>2]|0;
     $1551 = ((($1550)) + 12|0);
     $1552 = HEAP32[$1551>>2]|0;
     $1553 = ($1552|0)>(0);
     if ($1553) {
      $1554 = ($49>>>0)>=($1541>>>0);
      $$sum33 = (($49) + 1)|0;
      $1555 = (($1547) + ($$sum33<<4)|0);
      $1556 = $1554 ? $1555 : $1549;
      HEAP32[$4>>2] = $1556;
      _luaC_step($L);
      $1557 = HEAP32[$35>>2]|0;
      HEAP32[$4>>2] = $1557;
      $1559 = $1557;
     } else {
      $$pre731 = HEAP32[$35>>2]|0;
      $1559 = $$pre731;
     }
     $1558 = HEAP32[$32>>2]|0;
     HEAP32[$4>>2] = $1559;
     $base$0 = $1558;
     continue L3;
     break;
    }
    case 32:  {
     $1597 = $38 >>> 23;
     $1598 = $1597 & 256;
     $1599 = ($1598|0)==(0);
     $1600 = $1597 & 255;
     $1601 = (($31) + ($1600<<4)|0);
     $1602 = (($base$1) + ($1597<<4)|0);
     $1603 = $1599 ? $1602 : $1601;
     $1604 = $38 >>> 14;
     $1605 = $1604 & 256;
     $1606 = ($1605|0)==(0);
     $1607 = $1604 & 255;
     $1608 = (($31) + ($1607<<4)|0);
     $1609 = $1604 & 511;
     $1610 = (($base$1) + ($1609<<4)|0);
     $1611 = $1606 ? $1610 : $1608;
     $1612 = (_luaV_lessthan($L,$1603,$1611)|0);
     $1613 = ($1612|0)==($49|0);
     $1614 = HEAP32[$34>>2]|0;
     if ($1613) {
      $1616 = HEAP32[$1614>>2]|0;
      $1617 = $1616 >>> 6;
      $1618 = $1617 & 255;
      $1619 = ($1618|0)==(0);
      if ($1619) {
       $1625 = $1614;
      } else {
       $1620 = HEAP32[$32>>2]|0;
       $$sum28 = (($1618) + -1)|0;
       $1621 = (($1620) + ($$sum28<<4)|0);
       _luaF_close($L,$1621);
       $$pre728 = HEAP32[$34>>2]|0;
       $1625 = $$pre728;
      }
      $1622 = $1616 >>> 14;
      $1623 = (($1622) + -131070)|0;
      $1624 = (($1625) + ($1623<<2)|0);
      $storemerge27 = $1624;
     } else {
      $1615 = ((($1614)) + 4|0);
      $storemerge27 = $1615;
     }
     HEAP32[$34>>2] = $storemerge27;
     $1626 = HEAP32[$32>>2]|0;
     $base$0 = $1626;
     continue L3;
     break;
    }
    case 33:  {
     $1627 = $38 >>> 23;
     $1628 = $1627 & 256;
     $1629 = ($1628|0)==(0);
     $1630 = $1627 & 255;
     $1631 = (($31) + ($1630<<4)|0);
     $1632 = (($base$1) + ($1627<<4)|0);
     $1633 = $1629 ? $1632 : $1631;
     $1634 = $38 >>> 14;
     $1635 = $1634 & 256;
     $1636 = ($1635|0)==(0);
     $1637 = $1634 & 255;
     $1638 = (($31) + ($1637<<4)|0);
     $1639 = $1634 & 511;
     $1640 = (($base$1) + ($1639<<4)|0);
     $1641 = $1636 ? $1640 : $1638;
     $1642 = (_luaV_lessequal($L,$1633,$1641)|0);
     $1643 = ($1642|0)==($49|0);
     $1644 = HEAP32[$34>>2]|0;
     if ($1643) {
      $1646 = HEAP32[$1644>>2]|0;
      $1647 = $1646 >>> 6;
      $1648 = $1647 & 255;
      $1649 = ($1648|0)==(0);
      if ($1649) {
       $1655 = $1644;
      } else {
       $1650 = HEAP32[$32>>2]|0;
       $$sum26 = (($1648) + -1)|0;
       $1651 = (($1650) + ($$sum26<<4)|0);
       _luaF_close($L,$1651);
       $$pre727 = HEAP32[$34>>2]|0;
       $1655 = $$pre727;
      }
      $1652 = $1646 >>> 14;
      $1653 = (($1652) + -131070)|0;
      $1654 = (($1655) + ($1653<<2)|0);
      $storemerge25 = $1654;
     } else {
      $1645 = ((($1644)) + 4|0);
      $storemerge25 = $1645;
     }
     HEAP32[$34>>2] = $storemerge25;
     $1656 = HEAP32[$32>>2]|0;
     $base$0 = $1656;
     continue L3;
     break;
    }
    case 34:  {
     $1657 = $38 & 8372224;
     $1658 = ($1657|0)==(0);
     $1659 = (((($base$1) + ($49<<4)|0)) + 8|0);
     $1660 = HEAP32[$1659>>2]|0;
     $1661 = ($1660|0)==(0);
     if ($1658) {
      if (!($1661)) {
       $1665 = ($1660|0)==(1);
       if ($1665) {
        $1666 = HEAP32[$50>>2]|0;
        $1667 = ($1666|0)==(0);
        if (!($1667)) {
         label = 386;
        }
       } else {
        label = 386;
       }
      }
     } else {
      if ($1661) {
       label = 386;
      } else {
       $1662 = ($1660|0)==(1);
       if ($1662) {
        $1663 = HEAP32[$50>>2]|0;
        $1664 = ($1663|0)==(0);
        if ($1664) {
         label = 386;
        }
       }
      }
     }
     if ((label|0) == 386) {
      label = 0;
      $1668 = HEAP32[$34>>2]|0;
      $1669 = ((($1668)) + 4|0);
      HEAP32[$34>>2] = $1669;
      $base$0 = $base$1;
      continue L3;
     }
     $1670 = HEAP32[$34>>2]|0;
     $1671 = HEAP32[$1670>>2]|0;
     $1672 = $1671 >>> 6;
     $1673 = $1672 & 255;
     $1674 = ($1673|0)==(0);
     if ($1674) {
      $1680 = $1670;
     } else {
      $1675 = HEAP32[$32>>2]|0;
      $$sum24 = (($1673) + -1)|0;
      $1676 = (($1675) + ($$sum24<<4)|0);
      _luaF_close($L,$1676);
      $$pre726 = HEAP32[$34>>2]|0;
      $1680 = $$pre726;
     }
     $1677 = $1671 >>> 14;
     $1678 = (($1677) + -131070)|0;
     $1679 = (($1680) + ($1678<<2)|0);
     HEAP32[$34>>2] = $1679;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 35:  {
     $1681 = $38 >>> 23;
     $1682 = (($base$1) + ($1681<<4)|0);
     $1683 = $38 & 8372224;
     $1684 = ($1683|0)==(0);
     $1685 = (((($base$1) + ($1681<<4)|0)) + 8|0);
     $1686 = HEAP32[$1685>>2]|0;
     $1687 = ($1686|0)==(0);
     if ($1684) {
      if (!($1687)) {
       $1691 = ($1686|0)==(1);
       if ($1691) {
        $1692 = HEAP32[$1682>>2]|0;
        $1693 = ($1692|0)==(0);
        if (!($1693)) {
         label = 397;
        }
       } else {
        label = 397;
       }
      }
     } else {
      if ($1687) {
       label = 397;
      } else {
       $1688 = ($1686|0)==(1);
       if ($1688) {
        $1689 = HEAP32[$1682>>2]|0;
        $1690 = ($1689|0)==(0);
        if ($1690) {
         label = 397;
        }
       }
      }
     }
     if ((label|0) == 397) {
      label = 0;
      $1694 = HEAP32[$34>>2]|0;
      $1695 = ((($1694)) + 4|0);
      HEAP32[$34>>2] = $1695;
      $base$0 = $base$1;
      continue L3;
     }
     ;HEAP32[$50>>2]=HEAP32[$1682>>2]|0;HEAP32[$50+4>>2]=HEAP32[$1682+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$1682+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$1682+12>>2]|0;
     $1696 = HEAP32[$34>>2]|0;
     $1697 = HEAP32[$1696>>2]|0;
     $1698 = $1697 >>> 6;
     $1699 = $1698 & 255;
     $1700 = ($1699|0)==(0);
     if ($1700) {
      $1706 = $1696;
     } else {
      $1701 = HEAP32[$32>>2]|0;
      $$sum23 = (($1699) + -1)|0;
      $1702 = (($1701) + ($$sum23<<4)|0);
      _luaF_close($L,$1702);
      $$pre725 = HEAP32[$34>>2]|0;
      $1706 = $$pre725;
     }
     $1703 = $1697 >>> 14;
     $1704 = (($1703) + -131070)|0;
     $1705 = (($1706) + ($1704<<2)|0);
     HEAP32[$34>>2] = $1705;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 37:  {
     $1724 = $38 >>> 23;
     $1725 = ($1724|0)==(0);
     if (!($1725)) {
      $$sum21 = (($49) + ($1724))|0;
      $1726 = (($base$1) + ($$sum21<<4)|0);
      HEAP32[$4>>2] = $1726;
     }
     $1727 = (_luaD_precall($L,$50,-1)|0);
     $1728 = ($1727|0)==(0);
     if ($1728) {
      label = 412;
      break L3;
     }
     $1729 = HEAP32[$32>>2]|0;
     $base$0 = $1729;
     continue L3;
     break;
    }
    case 36:  {
     $1707 = $38 >>> 23;
     $1708 = $38 >>> 14;
     $1709 = $1708 & 511;
     $1710 = (($1709) + -1)|0;
     $1711 = ($1707|0)==(0);
     if (!($1711)) {
      $$sum22 = (($49) + ($1707))|0;
      $1712 = (($base$1) + ($$sum22<<4)|0);
      HEAP32[$4>>2] = $1712;
     }
     $1713 = (_luaD_precall($L,$50,$1710)|0);
     $1714 = ($1713|0)==(0);
     if ($1714) {
      label = 407;
      break L3;
     }
     $1715 = ($1709|0)==(0);
     if (!($1715)) {
      $1716 = HEAP32[$35>>2]|0;
      HEAP32[$4>>2] = $1716;
     }
     $1717 = HEAP32[$32>>2]|0;
     $base$0 = $1717;
     continue L3;
     break;
    }
    case 38:  {
     $$lcssa = $38;$$lcssa977 = $49;$$lcssa985 = $50;$base$1$lcssa = $base$1;
     label = 417;
     break L3;
     break;
    }
    case 39:  {
     $1793 = (((($base$1) + ($49<<4)|0)) + 8|0);
     $1794 = HEAP32[$1793>>2]|0;
     $1795 = ($1794|0)==(19);
     $$sum14 = (($49) + 2)|0;
     $1796 = (($base$1) + ($$sum14<<4)|0);
     if ($1795) {
      $1797 = $1796;
      $1798 = $1797;
      $1799 = HEAP32[$1798>>2]|0;
      $1800 = (($1797) + 4)|0;
      $1801 = $1800;
      $1802 = HEAP32[$1801>>2]|0;
      $1803 = $50;
      $1804 = $1803;
      $1805 = HEAP32[$1804>>2]|0;
      $1806 = (($1803) + 4)|0;
      $1807 = $1806;
      $1808 = HEAP32[$1807>>2]|0;
      $1809 = (_i64Add(($1805|0),($1808|0),($1799|0),($1802|0))|0);
      $1810 = tempRet0;
      $$sum17 = (($49) + 1)|0;
      $1811 = (($base$1) + ($$sum17<<4)|0);
      $1812 = $1811;
      $1813 = $1812;
      $1814 = HEAP32[$1813>>2]|0;
      $1815 = (($1812) + 4)|0;
      $1816 = $1815;
      $1817 = HEAP32[$1816>>2]|0;
      $1818 = ($1802|0)>(0);
      $1819 = ($1799>>>0)>(0);
      $1820 = ($1802|0)==(0);
      $1821 = $1820 & $1819;
      $1822 = $1818 | $1821;
      if ($1822) {
       $1823 = ($1810|0)>($1817|0);
       $1824 = ($1809>>>0)>($1814>>>0);
       $1825 = ($1810|0)==($1817|0);
       $1826 = $1825 & $1824;
       $1827 = $1823 | $1826;
       if ($1827) {
        $base$0 = $base$1;
        continue L3;
       }
      } else {
       $1828 = ($1817|0)>($1810|0);
       $1829 = ($1814>>>0)>($1809>>>0);
       $1830 = ($1817|0)==($1810|0);
       $1831 = $1830 & $1829;
       $1832 = $1828 | $1831;
       if ($1832) {
        $base$0 = $base$1;
        continue L3;
       }
      }
      $1833 = $38 >>> 14;
      $1834 = (($1833) + -131071)|0;
      $1835 = HEAP32[$34>>2]|0;
      $1836 = (($1835) + ($1834<<2)|0);
      HEAP32[$34>>2] = $1836;
      $1837 = $50;
      $1838 = $1837;
      HEAP32[$1838>>2] = $1809;
      $1839 = (($1837) + 4)|0;
      $1840 = $1839;
      HEAP32[$1840>>2] = $1810;
      HEAP32[$1793>>2] = 19;
      $$sum18 = (($49) + 3)|0;
      $1841 = (($base$1) + ($$sum18<<4)|0);
      $1842 = $1841;
      $1843 = $1842;
      HEAP32[$1843>>2] = $1809;
      $1844 = (($1842) + 4)|0;
      $1845 = $1844;
      HEAP32[$1845>>2] = $1810;
      $1846 = (((($base$1) + ($$sum18<<4)|0)) + 8|0);
      HEAP32[$1846>>2] = 19;
      $base$0 = $base$1;
      continue L3;
     } else {
      $1847 = +HEAPF64[$1796>>3];
      $1848 = +HEAPF64[$50>>3];
      $1849 = $1847 + $1848;
      $$sum15 = (($49) + 1)|0;
      $1850 = (($base$1) + ($$sum15<<4)|0);
      $1851 = +HEAPF64[$1850>>3];
      $1852 = $1847 > 0.0;
      if ($1852) {
       $1853 = !($1849 <= $1851);
       if ($1853) {
        $base$0 = $base$1;
        continue L3;
       }
      } else {
       $1854 = !($1851 <= $1849);
       if ($1854) {
        $base$0 = $base$1;
        continue L3;
       }
      }
      $1855 = $38 >>> 14;
      $1856 = (($1855) + -131071)|0;
      $1857 = HEAP32[$34>>2]|0;
      $1858 = (($1857) + ($1856<<2)|0);
      HEAP32[$34>>2] = $1858;
      HEAPF64[$50>>3] = $1849;
      HEAP32[$1793>>2] = 3;
      $$sum16 = (($49) + 3)|0;
      $1859 = (($base$1) + ($$sum16<<4)|0);
      HEAPF64[$1859>>3] = $1849;
      $1860 = (((($base$1) + ($$sum16<<4)|0)) + 8|0);
      HEAP32[$1860>>2] = 3;
      $base$0 = $base$1;
      continue L3;
     }
     break;
    }
    case 40:  {
     $$sum12 = (($49) + 1)|0;
     $1861 = (($base$1) + ($$sum12<<4)|0);
     $$sum13 = (($49) + 2)|0;
     $1862 = (($base$1) + ($$sum13<<4)|0);
     $1863 = (((($base$1) + ($49<<4)|0)) + 8|0);
     $1864 = HEAP32[$1863>>2]|0;
     $1865 = ($1864|0)==(19);
     L555: do {
      if ($1865) {
       $1866 = (((($base$1) + ($$sum13<<4)|0)) + 8|0);
       $1867 = HEAP32[$1866>>2]|0;
       $1868 = ($1867|0)==(19);
       if ($1868) {
        $1869 = $1862;
        $1870 = $1869;
        $1871 = HEAP32[$1870>>2]|0;
        $1872 = (($1869) + 4)|0;
        $1873 = $1872;
        $1874 = HEAP32[$1873>>2]|0;
        $1875 = ($1874|0)<(0);
        $$02$i$i151 = $1861;
        while(1) {
         $1876 = ((($$02$i$i151)) + 8|0);
         $1877 = HEAP32[$1876>>2]|0;
         if ((($1877|0) == 3)) {
          $$02$i$i151$lcssa = $$02$i$i151;
          label = 438;
          break;
         } else if ((($1877|0) == 19)) {
          $$02$i$i151$lcssa939 = $$02$i$i151;
          label = 440;
          break;
         }
         $1893 = $1877 & 15;
         $1894 = ($1893|0)==(4);
         if (!($1894)) {
          label = 444;
          break;
         }
         $1895 = HEAP32[$$02$i$i151>>2]|0;
         $1896 = ((($1895)) + 24|0);
         $1897 = (_luaO_str2num($1896,$v$i$i150)|0);
         $1898 = HEAP32[$$02$i$i151>>2]|0;
         $1899 = ((($1898)) + 12|0);
         $1900 = HEAP32[$1899>>2]|0;
         $1901 = (($1900) + 1)|0;
         $1902 = ($1897|0)==($1901|0);
         if ($1902) {
          $$02$i$i151 = $v$i$i150;
         } else {
          label = 444;
          break;
         }
        }
        if ((label|0) == 438) {
         label = 0;
         $1878 = +HEAPF64[$$02$i$i151$lcssa>>3];
         $1879 = (+Math_floor((+$1878)));
         $1880 = $1878 != $1879;
         $1881 = $1879 + 1.0;
         $1882 = $1875 & $1880;
         $f$0$i$i = $1882 ? $1881 : $1879;
         $1883 = $f$0$i$i >= -9.2233720368547758E+18;
         $1884 = $f$0$i$i < 9.2233720368547758E+18;
         $or$cond$i$i152 = $1883 & $1884;
         if ($or$cond$i$i152) {
          $1885 = (~~$f$0$i$i)>>>0;
          $1886 = +Math_abs($f$0$i$i) >= 1.0 ? $f$0$i$i > 0.0 ? (~~+Math_min(+Math_floor($f$0$i$i / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($f$0$i$i - +(~~$f$0$i$i >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2254 = $1885;$2255 = $1886;
          label = 443;
         } else {
          label = 444;
         }
        }
        else if ((label|0) == 440) {
         label = 0;
         $1887 = $$02$i$i151$lcssa939;
         $1888 = $1887;
         $1889 = HEAP32[$1888>>2]|0;
         $1890 = (($1887) + 4)|0;
         $1891 = $1890;
         $1892 = HEAP32[$1891>>2]|0;
         $2254 = $1889;$2255 = $1892;
         label = 443;
        }
        do {
         if ((label|0) == 443) {
          label = 0;
          $$pre763 = (((($base$1) + ($$sum12<<4)|0)) + 8|0);
          $$pre762$pre$phiZZ2D = $$pre763;$2256 = $2254;$2257 = $2255;
          label = 456;
         }
         else if ((label|0) == 444) {
          label = 0;
          $1903 = (((($base$1) + ($$sum12<<4)|0)) + 8|0);
          $1904 = HEAP32[$1903>>2]|0;
          $1905 = ($1904|0)==(3);
          if ($1905) {
           $1906 = +HEAPF64[$1861>>3];
           $1937 = $1906;
          } else {
           $1907 = ($1904|0)==(19);
           do {
            if ($1907) {
             $1908 = $1861;
             $1909 = $1908;
             $1910 = HEAP32[$1909>>2]|0;
             $1911 = (($1908) + 4)|0;
             $1912 = $1911;
             $1913 = HEAP32[$1912>>2]|0;
             $1914 = (+($1910>>>0)) + (4294967296.0*(+($1913|0)));
             $$ph$i = $1914;
            } else {
             $1915 = $1904 & 15;
             $1916 = ($1915|0)==(4);
             if ($1916) {
              $1917 = HEAP32[$1861>>2]|0;
              $1918 = ((($1917)) + 24|0);
              $1919 = (_luaO_str2num($1918,$v$i1$i)|0);
              $1920 = HEAP32[$1861>>2]|0;
              $1921 = ((($1920)) + 12|0);
              $1922 = HEAP32[$1921>>2]|0;
              $1923 = (($1922) + 1)|0;
              $1924 = ($1919|0)==($1923|0);
              if ($1924) {
               $1925 = HEAP32[$20>>2]|0;
               $1926 = ($1925|0)==(19);
               $1927 = $v$i1$i;
               $1928 = $1927;
               $1929 = HEAP32[$1928>>2]|0;
               $1930 = (($1927) + 4)|0;
               $1931 = $1930;
               $1932 = HEAP32[$1931>>2]|0;
               $1933 = (+($1929>>>0)) + (4294967296.0*(+($1932|0)));
               HEAP32[tempDoublePtr>>2] = $1929;HEAP32[tempDoublePtr+4>>2] = $1932;$1934 = +HEAPF64[tempDoublePtr>>3];
               $1935 = $1926 ? $1933 : $1934;
               $$ph$i = $1935;
               break;
              }
             }
             label = 458;
             break L555;
            }
           } while(0);
           $1937 = $$ph$i;
          }
          $1936 = $1937 > 0.0;
          if ($1936) {
           if ($1875) {
            $$pre$phiZ2D = $1903;$1951 = -1;$1954 = 2147483647;$1961 = 0;$1962 = 0;
            break;
           } else {
            $$pre762$pre$phiZZ2D = $1903;$2256 = -1;$2257 = 2147483647;
            label = 456;
            break;
           }
          } else {
           $1938 = ($1874|0)>(-1);
           $1939 = ($1871>>>0)>(4294967295);
           $1940 = ($1874|0)==(-1);
           $1941 = $1940 & $1939;
           $1942 = $1938 | $1941;
           if ($1942) {
            $$pre$phiZ2D = $1903;$1951 = 0;$1954 = -2147483648;$1961 = 0;$1962 = 0;
            break;
           } else {
            $$pre762$pre$phiZZ2D = $1903;$2256 = 0;$2257 = -2147483648;
            label = 456;
            break;
           }
          }
         }
        } while(0);
        if ((label|0) == 456) {
         label = 0;
         $1943 = $50;
         $1944 = $1943;
         $1945 = HEAP32[$1944>>2]|0;
         $1946 = (($1943) + 4)|0;
         $1947 = $1946;
         $1948 = HEAP32[$1947>>2]|0;
         $$pre$phiZ2D = $$pre762$pre$phiZZ2D;$1951 = $2256;$1954 = $2257;$1961 = $1945;$1962 = $1948;
        }
        $1949 = $1861;
        $1950 = $1949;
        HEAP32[$1950>>2] = $1951;
        $1952 = (($1949) + 4)|0;
        $1953 = $1952;
        HEAP32[$1953>>2] = $1954;
        HEAP32[$$pre$phiZ2D>>2] = 19;
        $1955 = $1862;
        $1956 = $1955;
        $1957 = HEAP32[$1956>>2]|0;
        $1958 = (($1955) + 4)|0;
        $1959 = $1958;
        $1960 = HEAP32[$1959>>2]|0;
        $1963 = (_i64Subtract(($1961|0),($1962|0),($1957|0),($1960|0))|0);
        $1964 = tempRet0;
        $1965 = $50;
        $1966 = $1965;
        HEAP32[$1966>>2] = $1963;
        $1967 = (($1965) + 4)|0;
        $1968 = $1967;
        HEAP32[$1968>>2] = $1964;
        $storemerge = 19;
       } else {
        label = 458;
       }
      } else {
       label = 458;
      }
     } while(0);
     if ((label|0) == 458) {
      label = 0;
      $1969 = (((($base$1) + ($$sum12<<4)|0)) + 8|0);
      $1970 = HEAP32[$1969>>2]|0;
      $1971 = ($1970|0)==(3);
      if ($1971) {
       $1972 = +HEAPF64[$1861>>3];
       $$pre$phi765Z2D = $1861;$2002 = $1972;
      } else {
       $1973 = ($1970|0)==(19);
       if ($1973) {
        $1974 = $1861;
        $1975 = $1974;
        $1976 = HEAP32[$1975>>2]|0;
        $1977 = (($1974) + 4)|0;
        $1978 = $1977;
        $1979 = HEAP32[$1978>>2]|0;
        $1980 = (+($1976>>>0)) + (4294967296.0*(+($1979|0)));
        $$ph263 = $1980;
       } else {
        $1981 = $1970 & 15;
        $1982 = ($1981|0)==(4);
        if (!($1982)) {
         label = 466;
         break L1;
        }
        $1983 = HEAP32[$1861>>2]|0;
        $1984 = ((($1983)) + 24|0);
        $1985 = (_luaO_str2num($1984,$v$i154)|0);
        $1986 = HEAP32[$1861>>2]|0;
        $1987 = ((($1986)) + 12|0);
        $1988 = HEAP32[$1987>>2]|0;
        $1989 = (($1988) + 1)|0;
        $1990 = ($1985|0)==($1989|0);
        if (!($1990)) {
         label = 466;
         break L1;
        }
        $1991 = HEAP32[$23>>2]|0;
        $1992 = ($1991|0)==(19);
        $1993 = $v$i154;
        $1994 = $1993;
        $1995 = HEAP32[$1994>>2]|0;
        $1996 = (($1993) + 4)|0;
        $1997 = $1996;
        $1998 = HEAP32[$1997>>2]|0;
        $1999 = (+($1995>>>0)) + (4294967296.0*(+($1998|0)));
        HEAP32[tempDoublePtr>>2] = $1995;HEAP32[tempDoublePtr+4>>2] = $1998;$2000 = +HEAPF64[tempDoublePtr>>3];
        $2001 = $1992 ? $1999 : $2000;
        $$ph263 = $2001;
       }
       $$pre$phi765Z2D = $1861;$2002 = $$ph263;
      }
      HEAPF64[$$pre$phi765Z2D>>3] = $2002;
      HEAP32[$1969>>2] = 3;
      $2003 = (((($base$1) + ($$sum13<<4)|0)) + 8|0);
      $2004 = HEAP32[$2003>>2]|0;
      $2005 = ($2004|0)==(3);
      if ($2005) {
       $2006 = +HEAPF64[$1862>>3];
       $$pre$phi767Z2D = $1862;$2036 = $2006;
      } else {
       $2007 = ($2004|0)==(19);
       if ($2007) {
        $2008 = $1862;
        $2009 = $2008;
        $2010 = HEAP32[$2009>>2]|0;
        $2011 = (($2008) + 4)|0;
        $2012 = $2011;
        $2013 = HEAP32[$2012>>2]|0;
        $2014 = (+($2010>>>0)) + (4294967296.0*(+($2013|0)));
        $$ph266 = $2014;
       } else {
        $2015 = $2004 & 15;
        $2016 = ($2015|0)==(4);
        if (!($2016)) {
         label = 475;
         break L1;
        }
        $2017 = HEAP32[$1862>>2]|0;
        $2018 = ((($2017)) + 24|0);
        $2019 = (_luaO_str2num($2018,$v$i158)|0);
        $2020 = HEAP32[$1862>>2]|0;
        $2021 = ((($2020)) + 12|0);
        $2022 = HEAP32[$2021>>2]|0;
        $2023 = (($2022) + 1)|0;
        $2024 = ($2019|0)==($2023|0);
        if (!($2024)) {
         label = 475;
         break L1;
        }
        $2025 = HEAP32[$22>>2]|0;
        $2026 = ($2025|0)==(19);
        $2027 = $v$i158;
        $2028 = $2027;
        $2029 = HEAP32[$2028>>2]|0;
        $2030 = (($2027) + 4)|0;
        $2031 = $2030;
        $2032 = HEAP32[$2031>>2]|0;
        $2033 = (+($2029>>>0)) + (4294967296.0*(+($2032|0)));
        HEAP32[tempDoublePtr>>2] = $2029;HEAP32[tempDoublePtr+4>>2] = $2032;$2034 = +HEAPF64[tempDoublePtr>>3];
        $2035 = $2026 ? $2033 : $2034;
        $$ph266 = $2035;
       }
       $$pre$phi767Z2D = $1862;$2036 = $$ph266;
      }
      HEAPF64[$$pre$phi767Z2D>>3] = $2036;
      HEAP32[$2003>>2] = 3;
      $2037 = HEAP32[$1863>>2]|0;
      $2038 = ($2037|0)==(3);
      if ($2038) {
       $2039 = +HEAPF64[$50>>3];
       $$pre$phi769Z2D = $50;$2070 = $2039;
      } else {
       $2040 = ($2037|0)==(19);
       if ($2040) {
        $2041 = $50;
        $2042 = $2041;
        $2043 = HEAP32[$2042>>2]|0;
        $2044 = (($2041) + 4)|0;
        $2045 = $2044;
        $2046 = HEAP32[$2045>>2]|0;
        $2047 = (+($2043>>>0)) + (4294967296.0*(+($2046|0)));
        $$ph269 = $2047;
       } else {
        $2048 = $2037 & 15;
        $2049 = ($2048|0)==(4);
        if (!($2049)) {
         label = 484;
         break L1;
        }
        $2050 = HEAP32[$50>>2]|0;
        $2051 = ((($2050)) + 24|0);
        $2052 = (_luaO_str2num($2051,$v$i162)|0);
        $2053 = HEAP32[$50>>2]|0;
        $2054 = ((($2053)) + 12|0);
        $2055 = HEAP32[$2054>>2]|0;
        $2056 = (($2055) + 1)|0;
        $2057 = ($2052|0)==($2056|0);
        if (!($2057)) {
         label = 484;
         break L1;
        }
        $2058 = HEAP32[$21>>2]|0;
        $2059 = ($2058|0)==(19);
        $2060 = $v$i162;
        $2061 = $2060;
        $2062 = HEAP32[$2061>>2]|0;
        $2063 = (($2060) + 4)|0;
        $2064 = $2063;
        $2065 = HEAP32[$2064>>2]|0;
        $2066 = (+($2062>>>0)) + (4294967296.0*(+($2065|0)));
        HEAP32[tempDoublePtr>>2] = $2062;HEAP32[tempDoublePtr+4>>2] = $2065;$2067 = +HEAPF64[tempDoublePtr>>3];
        $2068 = $2059 ? $2066 : $2067;
        $$ph269 = $2068;
       }
       $$pre$phi769Z2D = $50;$2070 = $$ph269;
      }
      $2069 = $2070 - $2036;
      HEAPF64[$$pre$phi769Z2D>>3] = $2069;
      $storemerge = 3;
     }
     HEAP32[$1863>>2] = $storemerge;
     $2071 = $38 >>> 14;
     $2072 = (($2071) + -131071)|0;
     $2073 = HEAP32[$34>>2]|0;
     $2074 = (($2073) + ($2072<<2)|0);
     HEAP32[$34>>2] = $2074;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 41:  {
     $$sum6 = (($49) + 3)|0;
     $2075 = (($base$1) + ($$sum6<<4)|0);
     $$sum7 = (($49) + 5)|0;
     $2076 = (($base$1) + ($$sum7<<4)|0);
     $$sum8 = (($49) + 2)|0;
     $2077 = (($base$1) + ($$sum8<<4)|0);
     ;HEAP32[$2076>>2]=HEAP32[$2077>>2]|0;HEAP32[$2076+4>>2]=HEAP32[$2077+4>>2]|0;HEAP32[$2076+8>>2]=HEAP32[$2077+8>>2]|0;HEAP32[$2076+12>>2]=HEAP32[$2077+12>>2]|0;
     $$sum9 = (($49) + 4)|0;
     $2078 = (($base$1) + ($$sum9<<4)|0);
     $$sum10 = (($49) + 1)|0;
     $2079 = (($base$1) + ($$sum10<<4)|0);
     ;HEAP32[$2078>>2]=HEAP32[$2079>>2]|0;HEAP32[$2078+4>>2]=HEAP32[$2079+4>>2]|0;HEAP32[$2078+8>>2]=HEAP32[$2079+8>>2]|0;HEAP32[$2078+12>>2]=HEAP32[$2079+12>>2]|0;
     ;HEAP32[$2075>>2]=HEAP32[$50>>2]|0;HEAP32[$2075+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$2075+8>>2]=HEAP32[$50+8>>2]|0;HEAP32[$2075+12>>2]=HEAP32[$50+12>>2]|0;
     $$sum11 = (($49) + 6)|0;
     $2080 = (($base$1) + ($$sum11<<4)|0);
     HEAP32[$4>>2] = $2080;
     $2081 = $38 >>> 14;
     $2082 = $2081 & 511;
     _luaD_call($L,$2075,$2082,1);
     $2083 = HEAP32[$32>>2]|0;
     $2084 = HEAP32[$35>>2]|0;
     HEAP32[$4>>2] = $2084;
     $2085 = HEAP32[$34>>2]|0;
     $2086 = ((($2085)) + 4|0);
     HEAP32[$34>>2] = $2086;
     $2087 = HEAP32[$2085>>2]|0;
     $2088 = $2087 >>> 6;
     $2089 = $2088 & 255;
     $2090 = (($2083) + ($2089<<4)|0);
     $base$2 = $2083;$i$0 = $2087;$ra$1 = $2090;
     break;
    }
    case 43:  {
     $2099 = $38 >>> 23;
     $2100 = $38 >>> 14;
     $2101 = $2100 & 511;
     $2102 = ($2099|0)==(0);
     if ($2102) {
      $2103 = HEAP32[$4>>2]|0;
      $2104 = $2103;
      $2105 = $50;
      $2106 = (($2104) - ($2105))|0;
      $2107 = $2106 >> 4;
      $2108 = (($2107) + -1)|0;
      $n$0 = $2108;
     } else {
      $n$0 = $2099;
     }
     $2109 = ($2101|0)==(0);
     if ($2109) {
      $2110 = HEAP32[$34>>2]|0;
      $2111 = ((($2110)) + 4|0);
      HEAP32[$34>>2] = $2111;
      $2112 = HEAP32[$2110>>2]|0;
      $2113 = $2112 >>> 6;
      $c128$0 = $2113;
     } else {
      $c128$0 = $2101;
     }
     $2114 = HEAP32[$50>>2]|0;
     $2115 = ($c128$0*50)|0;
     $2116 = (($n$0) + -50)|0;
     $2117 = (($2116) + ($2115))|0;
     $2118 = ((($2114)) + 8|0);
     $2119 = HEAP32[$2118>>2]|0;
     $2120 = ($2117>>>0)>($2119>>>0);
     if ($2120) {
      _luaH_resizearray($L,$2114,$2117);
     }
     $2121 = ($n$0|0)>(0);
     if ($2121) {
      $2122 = ((($2114)) + 5|0);
      $last$0519 = $2117;$n$1518 = $n$0;
      while(1) {
       $$sum5 = (($n$1518) + ($49))|0;
       $2123 = (($base$1) + ($$sum5<<4)|0);
       $2124 = (($last$0519) + -1)|0;
       _luaH_setint($L,$2114,$last$0519,0,$2123);
       $2125 = (((($base$1) + ($$sum5<<4)|0)) + 8|0);
       $2126 = HEAP32[$2125>>2]|0;
       $2127 = $2126 & 64;
       $2128 = ($2127|0)==(0);
       if (!($2128)) {
        $2129 = HEAP8[$2122>>0]|0;
        $2130 = $2129 & 4;
        $2131 = ($2130<<24>>24)==(0);
        if (!($2131)) {
         $2132 = HEAP32[$2123>>2]|0;
         $2133 = ((($2132)) + 5|0);
         $2134 = HEAP8[$2133>>0]|0;
         $2135 = $2134 & 3;
         $2136 = ($2135<<24>>24)==(0);
         if (!($2136)) {
          _luaC_barrierback_($L,$2114);
         }
        }
       }
       $2137 = (($n$1518) + -1)|0;
       $2138 = ($n$1518|0)>(1);
       if ($2138) {
        $last$0519 = $2124;$n$1518 = $2137;
       } else {
        break;
       }
      }
     }
     $2139 = HEAP32[$35>>2]|0;
     HEAP32[$4>>2] = $2139;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 42:  {
     $base$2 = $base$1;$i$0 = $38;$ra$1 = $50;
     break;
    }
    case 44:  {
     $2140 = $38 >>> 14;
     $2141 = HEAP32[$28>>2]|0;
     $2142 = ((($2141)) + 52|0);
     $2143 = HEAP32[$2142>>2]|0;
     $2144 = (($2143) + ($2140<<2)|0);
     $2145 = HEAP32[$2144>>2]|0;
     $2146 = ((($2145)) + 68|0);
     $2147 = HEAP32[$2146>>2]|0;
     $2148 = ($2147|0)==(0|0);
     $$phi$trans$insert = ((($2145)) + 12|0);
     $$pre = HEAP32[$$phi$trans$insert>>2]|0;
     $$phi$trans$insert723 = ((($2145)) + 64|0);
     $$pre724 = HEAP32[$$phi$trans$insert723>>2]|0;
     L642: do {
      if ($2148) {
       label = 511;
      } else {
       $2149 = ($$pre|0)>(0);
       if ($2149) {
        $i$01$i = 0;
        while(1) {
         $2152 = (((($$pre724) + ($i$01$i<<3)|0)) + 4|0);
         $2153 = HEAP8[$2152>>0]|0;
         $2154 = ($2153<<24>>24)==(0);
         $2155 = (((($$pre724) + ($i$01$i<<3)|0)) + 5|0);
         $2156 = HEAP8[$2155>>0]|0;
         $2157 = $2156&255;
         if ($2154) {
          $2159 = (((($27)) + 16|0) + ($2157<<2)|0);
          $2160 = HEAP32[$2159>>2]|0;
          $2161 = HEAP32[$2160>>2]|0;
          $2166 = $2161;
         } else {
          $2158 = (($base$1) + ($2157<<4)|0);
          $2166 = $2158;
         }
         $2162 = (((($2147)) + 16|0) + ($i$01$i<<2)|0);
         $2163 = HEAP32[$2162>>2]|0;
         $2164 = HEAP32[$2163>>2]|0;
         $2165 = ($2164|0)==($2166|0);
         $2151 = (($i$01$i) + 1)|0;
         if (!($2165)) {
          label = 511;
          break L642;
         }
         $2150 = ($2151|0)<($$pre|0);
         if ($2150) {
          $i$01$i = $2151;
         } else {
          break;
         }
        }
       }
       HEAP32[$50>>2] = $2147;
       $2193 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$2193>>2] = 70;
      }
     } while(0);
     if ((label|0) == 511) {
      label = 0;
      $2167 = (_luaF_newLclosure($L,$$pre)|0);
      $2168 = ((($2167)) + 12|0);
      HEAP32[$2168>>2] = $2145;
      HEAP32[$50>>2] = $2167;
      $2169 = (((($base$1) + ($49<<4)|0)) + 8|0);
      HEAP32[$2169>>2] = 70;
      $2170 = ($$pre|0)>(0);
      if ($2170) {
       $i$01$i168 = 0;
       while(1) {
        $2171 = (((($$pre724) + ($i$01$i168<<3)|0)) + 4|0);
        $2172 = HEAP8[$2171>>0]|0;
        $2173 = ($2172<<24>>24)==(0);
        $2174 = (((($$pre724) + ($i$01$i168<<3)|0)) + 5|0);
        $2175 = HEAP8[$2174>>0]|0;
        $2176 = $2175&255;
        if ($2173) {
         $2180 = (((($27)) + 16|0) + ($2176<<2)|0);
         $2181 = HEAP32[$2180>>2]|0;
         $2182 = (((($2167)) + 16|0) + ($i$01$i168<<2)|0);
         HEAP32[$2182>>2] = $2181;
         $2183 = $2181;
         $2185 = $2183;
        } else {
         $2177 = (($base$1) + ($2176<<4)|0);
         $2178 = (_luaF_findupval($L,$2177)|0);
         $2179 = (((($2167)) + 16|0) + ($i$01$i168<<2)|0);
         HEAP32[$2179>>2] = $2178;
         $2185 = $2178;
        }
        $2184 = ((($2185)) + 4|0);
        $2186 = HEAP32[$2184>>2]|0;
        $2187 = (($2186) + 1)|0;
        HEAP32[$2184>>2] = $2187;
        $2188 = (($i$01$i168) + 1)|0;
        $exitcond$i = ($2188|0)==($$pre|0);
        if ($exitcond$i) {
         break;
        } else {
         $i$01$i168 = $2188;
        }
       }
      }
      $2189 = ((($2145)) + 5|0);
      $2190 = HEAP8[$2189>>0]|0;
      $2191 = $2190 & 4;
      $2192 = ($2191<<24>>24)==(0);
      if ($2192) {
       HEAP32[$2146>>2] = $2167;
      }
     }
     $2194 = HEAP32[$3>>2]|0;
     $2195 = ((($2194)) + 12|0);
     $2196 = HEAP32[$2195>>2]|0;
     $2197 = ($2196|0)>(0);
     if ($2197) {
      $$sum4 = (($49) + 1)|0;
      $2198 = (($base$1) + ($$sum4<<4)|0);
      HEAP32[$4>>2] = $2198;
      _luaC_step($L);
      $2199 = HEAP32[$35>>2]|0;
      HEAP32[$4>>2] = $2199;
     }
     $2200 = HEAP32[$32>>2]|0;
     $base$0 = $2200;
     continue L3;
     break;
    }
    case 45:  {
     $2201 = $38 >>> 23;
     $2202 = (($2201) + -1)|0;
     $2203 = HEAP32[$ci$0>>2]|0;
     $2204 = $base$1;
     $2205 = $2203;
     $2206 = (($2204) - ($2205))|0;
     $2207 = $2206 >> 4;
     $2208 = HEAP32[$28>>2]|0;
     $2209 = ((($2208)) + 6|0);
     $2210 = HEAP8[$2209>>0]|0;
     $2211 = $2210&255;
     $2212 = (($2207) - ($2211))|0;
     $2213 = (($2212) + -1)|0;
     $2214 = ($2201|0)==(0);
     if ($2214) {
      $2215 = HEAP32[$24>>2]|0;
      $2216 = HEAP32[$4>>2]|0;
      $2217 = $2215;
      $2218 = $2216;
      $2219 = (($2217) - ($2218))|0;
      $2220 = $2219 >> 4;
      $2221 = ($2220|0)>($2213|0);
      if (!($2221)) {
       _luaD_growstack($L,$2213);
      }
      $2222 = HEAP32[$32>>2]|0;
      $$sum3 = (($2213) + ($49))|0;
      $2223 = (($2222) + ($$sum3<<4)|0);
      HEAP32[$4>>2] = $2223;
      $2228 = $2222;$b131$0 = $2213;
     } else {
      $2228 = $base$1;$b131$0 = $2202;
     }
     $2224 = ($b131$0|0)>(0);
     if (!($2224)) {
      $base$0 = $2228;
      continue L3;
     }
     $2225 = (1 - ($2212))|0;
     $j$0517 = 0;
     while(1) {
      $2226 = ($j$0517|0)<($2213|0);
      $$sum = (($j$0517) + ($49))|0;
      if ($2226) {
       $2227 = (($2228) + ($$sum<<4)|0);
       $$sum2 = (($2225) + ($j$0517))|0;
       $2229 = (($2228) + ($$sum2<<4)|0);
       ;HEAP32[$2227>>2]=HEAP32[$2229>>2]|0;HEAP32[$2227+4>>2]=HEAP32[$2229+4>>2]|0;HEAP32[$2227+8>>2]=HEAP32[$2229+8>>2]|0;HEAP32[$2227+12>>2]=HEAP32[$2229+12>>2]|0;
      } else {
       $2230 = (((($2228) + ($$sum<<4)|0)) + 8|0);
       HEAP32[$2230>>2] = 0;
      }
      $2231 = (($j$0517) + 1)|0;
      $exitcond = ($2231|0)==($b131$0|0);
      if ($exitcond) {
       $base$0 = $2228;
       continue L3;
      } else {
       $j$0517 = $2231;
      }
     }
     break;
    }
    default: {
     $base$0 = $base$1;
     continue L3;
    }
    }
   } while(0);
   $2091 = ((($ra$1)) + 24|0);
   $2092 = HEAP32[$2091>>2]|0;
   $2093 = ($2092|0)==(0);
   if ($2093) {
    $base$0 = $base$2;
    continue;
   }
   $2094 = ((($ra$1)) + 16|0);
   ;HEAP32[$ra$1>>2]=HEAP32[$2094>>2]|0;HEAP32[$ra$1+4>>2]=HEAP32[$2094+4>>2]|0;HEAP32[$ra$1+8>>2]=HEAP32[$2094+8>>2]|0;HEAP32[$ra$1+12>>2]=HEAP32[$2094+12>>2]|0;
   $2095 = $i$0 >>> 14;
   $2096 = (($2095) + -131071)|0;
   $2097 = HEAP32[$34>>2]|0;
   $2098 = (($2097) + ($2096<<2)|0);
   HEAP32[$34>>2] = $2098;
   $base$0 = $base$2;
  }
  if ((label|0) == 407) {
   label = 0;
   $1718 = HEAP32[$0>>2]|0;
   $1719 = ((($1718)) + 34|0);
   $1720 = HEAP8[$1719>>0]|0;
   $1721 = $1720&255;
   $1722 = $1721 | 8;
   $1723 = $1722&255;
   HEAP8[$1719>>0] = $1723;
   $ci$0 = $1718;
   continue;
  }
  else if ((label|0) == 412) {
   label = 0;
   $1730 = HEAP32[$0>>2]|0;
   $1731 = ((($1730)) + 8|0);
   $1732 = HEAP32[$1731>>2]|0;
   $1733 = HEAP32[$1730>>2]|0;
   $1734 = HEAP32[$1732>>2]|0;
   $1735 = ((($1730)) + 16|0);
   $1736 = HEAP32[$1735>>2]|0;
   $1737 = HEAP32[$1733>>2]|0;
   $1738 = ((($1737)) + 12|0);
   $1739 = HEAP32[$1738>>2]|0;
   $1740 = ((($1739)) + 6|0);
   $1741 = HEAP8[$1740>>0]|0;
   $1742 = $1741&255;
   $1743 = (($1736) + ($1742<<4)|0);
   $1744 = HEAP32[$28>>2]|0;
   $1745 = ((($1744)) + 28|0);
   $1746 = HEAP32[$1745>>2]|0;
   $1747 = ($1746|0)>(0);
   if ($1747) {
    $1748 = ((($1732)) + 16|0);
    $1749 = HEAP32[$1748>>2]|0;
    _luaF_close($L,$1749);
   }
   $1750 = ($1733>>>0)<($1743>>>0);
   if ($1750) {
    $1752 = $1733;$aux$0521 = 0;
    while(1) {
     $1751 = (($1734) + ($aux$0521<<4)|0);
     ;HEAP32[$1751>>2]=HEAP32[$1752>>2]|0;HEAP32[$1751+4>>2]=HEAP32[$1752+4>>2]|0;HEAP32[$1751+8>>2]=HEAP32[$1752+8>>2]|0;HEAP32[$1751+12>>2]=HEAP32[$1752+12>>2]|0;
     $1753 = (($aux$0521) + 1)|0;
     $1754 = (($1733) + ($1753<<4)|0);
     $1755 = ($1754>>>0)<($1743>>>0);
     if ($1755) {
      $1752 = $1754;$aux$0521 = $1753;
     } else {
      break;
     }
    }
   }
   $1756 = HEAP32[$1735>>2]|0;
   $1757 = $1756;
   $1758 = $1733;
   $1759 = (($1757) - ($1758))|0;
   $1760 = $1759 >> 4;
   $1761 = (($1734) + ($1760<<4)|0);
   $1762 = ((($1732)) + 16|0);
   HEAP32[$1762>>2] = $1761;
   $1763 = HEAP32[$4>>2]|0;
   $1764 = $1763;
   $1765 = (($1764) - ($1758))|0;
   $1766 = $1765 >> 4;
   $1767 = (($1734) + ($1766<<4)|0);
   HEAP32[$4>>2] = $1767;
   $1768 = ((($1732)) + 4|0);
   HEAP32[$1768>>2] = $1767;
   $1769 = ((($1730)) + 20|0);
   $1770 = HEAP32[$1769>>2]|0;
   $1771 = ((($1732)) + 20|0);
   HEAP32[$1771>>2] = $1770;
   $1772 = ((($1732)) + 34|0);
   $1773 = HEAP8[$1772>>0]|0;
   $1774 = $1773&255;
   $1775 = $1774 | 32;
   $1776 = $1775&255;
   HEAP8[$1772>>0] = $1776;
   HEAP32[$0>>2] = $1732;
   $ci$0 = $1732;
   continue;
  }
  else if ((label|0) == 417) {
   label = 0;
   $1777 = $$lcssa >>> 23;
   $1778 = ($1777|0)==(0);
   if (!($1778)) {
    $$sum19 = (($1777) + -1)|0;
    $$sum20 = (($$sum19) + ($$lcssa977))|0;
    $1779 = (($base$1$lcssa) + ($$sum20<<4)|0);
    HEAP32[$4>>2] = $1779;
   }
   $1780 = HEAP32[$28>>2]|0;
   $1781 = ((($1780)) + 28|0);
   $1782 = HEAP32[$1781>>2]|0;
   $1783 = ($1782|0)>(0);
   if ($1783) {
    _luaF_close($L,$base$1$lcssa);
   }
   $1784 = (_luaD_poscall($L,$$lcssa985)|0);
   $1785 = ((($ci$0)) + 34|0);
   $1786 = HEAP8[$1785>>0]|0;
   $1787 = $1786 & 8;
   $1788 = ($1787<<24>>24)==(0);
   if ($1788) {
    label = 422;
    break;
   }
   $1789 = HEAP32[$0>>2]|0;
   $1790 = ($1784|0)==(0);
   if ($1790) {
    $ci$0 = $1789;
    continue;
   }
   $1791 = ((($1789)) + 4|0);
   $1792 = HEAP32[$1791>>2]|0;
   HEAP32[$4>>2] = $1792;
   $ci$0 = $1789;
   continue;
  }
 }
 if ((label|0) == 260) {
  _luaG_runerror($L,4656,$vararg_buffer);
  // unreachable;
 }
 else if ((label|0) == 285) {
  _luaG_runerror($L,4624,$vararg_buffer1);
  // unreachable;
 }
 else if ((label|0) == 422) {
  STACKTOP = sp;return;
 }
 else if ((label|0) == 466) {
  _luaG_runerror($L,4688,$vararg_buffer3);
  // unreachable;
 }
 else if ((label|0) == 475) {
  _luaG_runerror($L,4720,$vararg_buffer5);
  // unreachable;
 }
 else if ((label|0) == 484) {
  _luaG_runerror($L,4752,$vararg_buffer7);
  // unreachable;
 }
}
function _luaZ_fill($z) {
 $z = $z|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $size = sp;
 $0 = ((($z)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($z)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($z)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiii[$3 & 15]($1,$5,$size)|0);
 $7 = ($6|0)==(0|0);
 $8 = HEAP32[$size>>2]|0;
 $9 = ($8|0)==(0);
 $or$cond = $7 | $9;
 if ($or$cond) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($8) + -1)|0;
 HEAP32[$z>>2] = $10;
 $11 = ((($z)) + 4|0);
 $12 = ((($6)) + 1|0);
 HEAP32[$11>>2] = $12;
 $13 = HEAP8[$6>>0]|0;
 $14 = $13&255;
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function _luaZ_init($L,$z,$reader,$data) {
 $L = $L|0;
 $z = $z|0;
 $reader = $reader|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($z)) + 16|0);
 HEAP32[$0>>2] = $L;
 $1 = ((($z)) + 8|0);
 HEAP32[$1>>2] = $reader;
 $2 = ((($z)) + 12|0);
 HEAP32[$2>>2] = $data;
 HEAP32[$z>>2] = 0;
 $3 = ((($z)) + 4|0);
 HEAP32[$3>>2] = 0;
 return;
}
function _luaZ_read($z,$b,$n) {
 $z = $z|0;
 $b = $b|0;
 $n = $n|0;
 var $$$01 = 0, $$0 = 0, $$015 = 0, $$024 = 0, $$pre = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $size$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $size$i = sp;
 $0 = ($n|0)==(0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ((($z)) + 16|0);
 $2 = ((($z)) + 8|0);
 $3 = ((($z)) + 12|0);
 $4 = ((($z)) + 4|0);
 $$pre = HEAP32[$z>>2]|0;
 $$015 = $n;$$024 = $b;$6 = $$pre;
 while(1) {
  $5 = ($6|0)==(0);
  if ($5) {
   $7 = HEAP32[$1>>2]|0;
   $8 = HEAP32[$2>>2]|0;
   $9 = HEAP32[$3>>2]|0;
   $10 = (FUNCTION_TABLE_iiii[$8 & 15]($7,$9,$size$i)|0);
   $11 = ($10|0)==(0|0);
   $12 = HEAP32[$size$i>>2]|0;
   $13 = ($12|0)==(0);
   $or$cond$i = $11 | $13;
   if ($or$cond$i) {
    $$0 = $$015;
    label = 8;
    break;
   }
   HEAP32[$z>>2] = $12;
   HEAP32[$4>>2] = $10;
   $15 = $12;$16 = $10;
  } else {
   $$pre7 = HEAP32[$4>>2]|0;
   $15 = $6;$16 = $$pre7;
  }
  $14 = ($$015>>>0)>($15>>>0);
  $$$01 = $14 ? $15 : $$015;
  _memcpy(($$024|0),($16|0),($$$01|0))|0;
  $17 = HEAP32[$z>>2]|0;
  $18 = (($17) - ($$$01))|0;
  HEAP32[$z>>2] = $18;
  $19 = HEAP32[$4>>2]|0;
  $20 = (($19) + ($$$01)|0);
  HEAP32[$4>>2] = $20;
  $21 = (($$024) + ($$$01)|0);
  $22 = (($$015) - ($$$01))|0;
  $23 = ($$015|0)==($$$01|0);
  if ($23) {
   $$0 = 0;
   label = 8;
   break;
  } else {
   $$015 = $22;$$024 = $21;$6 = $18;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _luaZ_openspace($L,$buff,$n) {
 $L = $L|0;
 $buff = $buff|0;
 $n = $n|0;
 var $$n = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($buff)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<($n>>>0);
 if ($2) {
  $3 = ($n>>>0)<(32);
  $$n = $3 ? 32 : $n;
  $4 = HEAP32[$buff>>2]|0;
  $5 = (_luaM_realloc_($L,$4,$1,$$n)|0);
  HEAP32[$buff>>2] = $5;
  HEAP32[$0>>2] = $$n;
  $6 = $5;
  return ($6|0);
 } else {
  $$pre = HEAP32[$buff>>2]|0;
  $6 = $$pre;
  return ($6|0);
 }
 return (0)|0;
}
function _luaL_loadfilex($L,$filename,$mode) {
 $L = $L|0;
 $filename = $filename|0;
 $mode = $mode|0;
 var $$0 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c = 0, $lf = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer6 = 0, $vararg_ptr10 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr4 = 0;
 var $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1088|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer11 = sp + 40|0;
 $vararg_buffer6 = sp + 24|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $lf = sp + 56|0;
 $c = sp + 52|0;
 $0 = (_lua_gettop($L)|0);
 $1 = (($0) + 1)|0;
 $2 = ($filename|0)==(0|0);
 if ($2) {
  (_lua_pushlstring($L,4792,6)|0);
  $3 = HEAP32[_stdin>>2]|0;
  $4 = ((($lf)) + 4|0);
  HEAP32[$4>>2] = $3;
 } else {
  HEAP32[$vararg_buffer>>2] = $filename;
  (_lua_pushfstring($L,4800,$vararg_buffer)|0);
  $5 = (_fopen(($filename|0),(4808|0))|0);
  $6 = ((($lf)) + 4|0);
  HEAP32[$6>>2] = $5;
  $7 = ($5|0)==(0|0);
  if ($7) {
   $8 = (___errno_location()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (_strerror(($9|0))|0);
   $11 = (_lua_tolstring($L,$1,0)|0);
   $12 = ((($11)) + 1|0);
   HEAP32[$vararg_buffer1>>2] = 4840;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = $12;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $10;
   (_lua_pushfstring($L,4816,$vararg_buffer1)|0);
   _lua_rotate($L,$1,-1);
   _lua_settop($L,-2);
   $$0 = 7;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $13 = (_skipcomment($lf,$c)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = HEAP32[$lf>>2]|0;
  $16 = (($15) + 1)|0;
  HEAP32[$lf>>2] = $16;
  $17 = (((($lf)) + 8|0) + ($15)|0);
  HEAP8[$17>>0] = 10;
 }
 $18 = HEAP32[$c>>2]|0;
 $19 = ($18|0)==(27);
 $20 = ($filename|0)!=(0|0);
 $or$cond = $20 & $19;
 do {
  if ($or$cond) {
   $21 = ((($lf)) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (_freopen(($filename|0),(4848|0),($22|0))|0);
   HEAP32[$21>>2] = $23;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    (_skipcomment($lf,$c)|0);
    $$pr = HEAP32[$c>>2]|0;
    $31 = $$pr;
    break;
   }
   $25 = (___errno_location()|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (_strerror(($26|0))|0);
   $28 = (_lua_tolstring($L,$1,0)|0);
   $29 = ((($28)) + 1|0);
   HEAP32[$vararg_buffer6>>2] = 4856;
   $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
   HEAP32[$vararg_ptr9>>2] = $29;
   $vararg_ptr10 = ((($vararg_buffer6)) + 8|0);
   HEAP32[$vararg_ptr10>>2] = $27;
   (_lua_pushfstring($L,4816,$vararg_buffer6)|0);
   _lua_rotate($L,$1,-1);
   _lua_settop($L,-2);
   $$0 = 7;
   STACKTOP = sp;return ($$0|0);
  } else {
   $31 = $18;
  }
 } while(0);
 $30 = ($31|0)==(-1);
 if (!($30)) {
  $32 = $31&255;
  $33 = HEAP32[$lf>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$lf>>2] = $34;
  $35 = (((($lf)) + 8|0) + ($33)|0);
  HEAP8[$35>>0] = $32;
 }
 $36 = (_lua_tolstring($L,-1,0)|0);
 $37 = (_lua_load($L,11,$lf,$36,$mode)|0);
 $38 = ((($lf)) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (_ferror(($39|0))|0);
 if ($20) {
  (_fclose(($39|0))|0);
 }
 $41 = ($40|0)==(0);
 if ($41) {
  _lua_rotate($L,$1,-1);
  _lua_settop($L,-2);
  $$0 = $37;
  STACKTOP = sp;return ($$0|0);
 } else {
  _lua_settop($L,$1);
  $42 = (___errno_location()|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (_strerror(($43|0))|0);
  $45 = (_lua_tolstring($L,$1,0)|0);
  $46 = ((($45)) + 1|0);
  HEAP32[$vararg_buffer11>>2] = 4864;
  $vararg_ptr14 = ((($vararg_buffer11)) + 4|0);
  HEAP32[$vararg_ptr14>>2] = $46;
  $vararg_ptr15 = ((($vararg_buffer11)) + 8|0);
  HEAP32[$vararg_ptr15>>2] = $44;
  (_lua_pushfstring($L,4816,$vararg_buffer11)|0);
  _lua_rotate($L,$1,-1);
  _lua_settop($L,-2);
  $$0 = 7;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _luaL_newstate() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_newstate(12,0)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  return ($0|0);
 }
 (_lua_atpanic($0,13)|0);
 return ($0|0);
}
function _skipcomment($lf,$cp) {
 $lf = $lf|0;
 $cp = $cp|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$lf>>2] = 0;
 $0 = ((($lf)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_getc(($1|0))|0);
 do {
  if ((($2|0) == 239)) {
   $3 = HEAP32[$lf>>2]|0;
   $4 = (($3) + 1)|0;
   HEAP32[$lf>>2] = $4;
   $5 = (((($lf)) + 8|0) + ($3)|0);
   HEAP8[$5>>0] = -17;
   $6 = HEAP32[$0>>2]|0;
   $7 = (_getc(($6|0))|0);
   if ((($7|0) == -1)) {
    label = 5;
    break;
   } else if (!((($7|0) == 187))) {
    $$0$i = $7;
    break;
   }
   $8 = HEAP32[$lf>>2]|0;
   $9 = (($8) + 1)|0;
   HEAP32[$lf>>2] = $9;
   $10 = (((($lf)) + 8|0) + ($8)|0);
   HEAP8[$10>>0] = -69;
   $11 = HEAP32[$0>>2]|0;
   $12 = (_getc(($11|0))|0);
   if ((($12|0) == -1)) {
    label = 5;
    break;
   } else if (!((($12|0) == 191))) {
    $$0$i = $12;
    break;
   }
   $13 = HEAP32[$lf>>2]|0;
   $14 = (((($lf)) + 8|0) + ($13)|0);
   HEAP8[$14>>0] = -65;
   HEAP32[$lf>>2] = 0;
   $15 = HEAP32[$0>>2]|0;
   $16 = (_getc(($15|0))|0);
   $$0$i = $16;
  } else if ((($2|0) == -1)) {
   label = 5;
  } else {
   $$0$i = $2;
  }
 } while(0);
 if ((label|0) == 5) {
  HEAP32[$cp>>2] = -1;
  $$0 = 0;
  return ($$0|0);
 }
 HEAP32[$cp>>2] = $$0$i;
 $17 = ($$0$i|0)==(35);
 if (!($17)) {
  $$0 = 0;
  return ($$0|0);
 }
 while(1) {
  $18 = HEAP32[$0>>2]|0;
  $19 = (_getc(($18|0))|0);
  if ((($19|0) == 10) | (($19|0) == -1)) {
   break;
  }
 }
 $20 = HEAP32[$0>>2]|0;
 $21 = (_getc(($20|0))|0);
 HEAP32[$cp>>2] = $21;
 $$0 = 1;
 return ($$0|0);
}
function _getF($L,$ud,$size) {
 $L = $L|0;
 $ud = $ud|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ud>>2]|0;
 $1 = ($0|0)>(0);
 if ($1) {
  HEAP32[$size>>2] = $0;
  HEAP32[$ud>>2] = 0;
  $$pre = ((($ud)) + 8|0);
  $$0 = $$pre;
  return ($$0|0);
 }
 $2 = ((($ud)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_feof(($3|0))|0);
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = 0;
  return ($$0|0);
 }
 $6 = ((($ud)) + 8|0);
 $7 = HEAP32[$2>>2]|0;
 $8 = (_fread(($6|0),1,1024,($7|0))|0);
 HEAP32[$size>>2] = $8;
 $$0 = $6;
 return ($$0|0);
}
function _l_alloc($ud,$ptr,$osize,$nsize) {
 $ud = $ud|0;
 $ptr = $ptr|0;
 $osize = $osize|0;
 $nsize = $nsize|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nsize|0)==(0);
 if ($0) {
  _free($ptr);
  $$0 = 0;
  return ($$0|0);
 } else {
  $1 = (_realloc($ptr,$nsize)|0);
  $$0 = $1;
  return ($$0|0);
 }
 return (0)|0;
}
function _panic($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[_stderr>>2]|0;
 $1 = (_lua_tolstring($L,-1,0)|0);
 HEAP32[$vararg_buffer>>2] = $1;
 (_fprintf(($0|0),(4872|0),($vararg_buffer|0))|0);
 (_fflush(($0|0))|0);
 STACKTOP = sp;return 0;
}
function _luaK_nil($fs,$from,$n) {
 $fs = $fs|0;
 $from = $from|0;
 $n = $n|0;
 var $$from = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$0 = 0;
 var $or$cond = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($n) + ($from))|0;
 $1 = (($0) + -1)|0;
 $2 = ((($fs)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($fs)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)>($5|0);
 do {
  if ($6) {
   $7 = (($3) + -1)|0;
   $8 = HEAP32[$fs>>2]|0;
   $9 = ((($8)) + 48|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + ($7<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = $12 & 63;
   $14 = ($13|0)==(4);
   if ($14) {
    $15 = $12 >>> 6;
    $16 = $15 & 255;
    $17 = $12 >>> 23;
    $18 = (($16) + ($17))|0;
    $19 = ($16|0)>($from|0);
    $20 = (($18) + 1)|0;
    $21 = ($20|0)<($from|0);
    $or$cond = $19 | $21;
    if ($or$cond) {
     $22 = ($16|0)<($from|0);
     $23 = ($16|0)>($0|0);
     $or$cond2 = $22 | $23;
     if ($or$cond2) {
      break;
     }
    }
    $24 = ($16|0)<($from|0);
    $$from = $24 ? $16 : $from;
    $25 = ($18|0)>($1|0);
    $l$0 = $25 ? $18 : $1;
    $26 = $12 & 8372287;
    $27 = $$from << 6;
    $28 = $27 & 16320;
    $29 = (($l$0) - ($$from))|0;
    $30 = $29 << 23;
    $31 = $30 | $28;
    $32 = $31 | $26;
    HEAP32[$11>>2] = $32;
    return;
   }
  }
 } while(0);
 $33 = $from << 6;
 $34 = $n << 23;
 $35 = (($34) + -8388608)|0;
 $36 = $33 | $35;
 $37 = $36 | 4;
 (_luaK_code($fs,$37)|0);
 return;
}
function _luaK_codeABC($fs,$o,$a,$b,$c) {
 $fs = $fs|0;
 $o = $o|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $a << 6;
 $1 = $0 | $o;
 $2 = $b << 23;
 $3 = $1 | $2;
 $4 = $c << 14;
 $5 = $3 | $4;
 $6 = (_luaK_code($fs,$5)|0);
 return ($6|0);
}
function _luaK_jump($fs) {
 $fs = $fs|0;
 var $$0$i$i = 0, $$lcssa = 0, $$lcssa6 = 0, $$neg$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fs$idx$val$i = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$val$i = 0, $ispos$i$i = 0, $list$0$i = 0, $list$0$i$lcssa = 0, $neg$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = -1;
 $2 = (_luaK_code($fs,2147450910)|0);
 $3 = ($1|0)==(-1);
 if ($3) {
  $22 = $2;
  return ($22|0);
 }
 $4 = ($2|0)==(-1);
 if ($4) {
  $22 = $1;
  return ($22|0);
 }
 $fs$idx$val$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
 $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
 $list$0$i = $2;
 while(1) {
  $5 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 >>> 14;
  $8 = (($7) + -131071)|0;
  $9 = ($8|0)==(-1);
  $10 = (($list$0$i) + 1)|0;
  $11 = (($10) + ($8))|0;
  $$0$i$i = $9 ? -1 : $11;
  $12 = ($$0$i$i|0)==(-1);
  if ($12) {
   $$lcssa = $5;$$lcssa6 = $6;$list$0$i$lcssa = $list$0$i;
   break;
  } else {
   $list$0$i = $$0$i$i;
  }
 }
 $$neg$i$i = $list$0$i$lcssa ^ -1;
 $13 = (($1) + ($$neg$i$i))|0;
 $ispos$i$i = ($13|0)>(-1);
 $neg$i$i = (0 - ($13))|0;
 $14 = $ispos$i$i ? $13 : $neg$i$i;
 $15 = ($14|0)>(131071);
 if ($15) {
  $16 = ((($fs)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  _luaX_syntaxerror($17,4928);
  // unreachable;
 }
 $18 = $$lcssa6 & 16383;
 $19 = $13 << 14;
 $20 = (($19) + 2147467264)|0;
 $21 = $20 | $18;
 HEAP32[$$lcssa>>2] = $21;
 $22 = $2;
 return ($22|0);
}
function _luaK_codeABx($fs,$o,$a,$bc) {
 $fs = $fs|0;
 $o = $o|0;
 $a = $a|0;
 $bc = $bc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $a << 6;
 $1 = $0 | $o;
 $2 = $bc << 14;
 $3 = $1 | $2;
 $4 = (_luaK_code($fs,$3)|0);
 return ($4|0);
}
function _luaK_concat($fs,$l1,$l2) {
 $fs = $fs|0;
 $l1 = $l1|0;
 $l2 = $l2|0;
 var $$0$i = 0, $$lcssa = 0, $$lcssa4 = 0, $$neg$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fs$idx$val = 0, $fs$idx$val$idx = 0, $fs$idx$val$idx$val = 0, $ispos$i = 0, $list$0 = 0, $list$0$lcssa = 0, $neg$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($l2|0)==(-1);
 if ($0) {
  return;
 }
 $1 = HEAP32[$l1>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  HEAP32[$l1>>2] = $l2;
  return;
 }
 $fs$idx$val = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx = ((($fs$idx$val)) + 48|0);
 $fs$idx$val$idx$val = HEAP32[$fs$idx$val$idx>>2]|0;
 $list$0 = $1;
 while(1) {
  $3 = (($fs$idx$val$idx$val) + ($list$0<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4 >>> 14;
  $6 = (($5) + -131071)|0;
  $7 = ($6|0)==(-1);
  $8 = (($list$0) + 1)|0;
  $9 = (($8) + ($6))|0;
  $$0$i = $7 ? -1 : $9;
  $10 = ($$0$i|0)==(-1);
  if ($10) {
   $$lcssa = $3;$$lcssa4 = $4;$list$0$lcssa = $list$0;
   break;
  } else {
   $list$0 = $$0$i;
  }
 }
 $$neg$i = $list$0$lcssa ^ -1;
 $11 = (($$neg$i) + ($l2))|0;
 $ispos$i = ($11|0)>(-1);
 $neg$i = (0 - ($11))|0;
 $12 = $ispos$i ? $11 : $neg$i;
 $13 = ($12|0)>(131071);
 if ($13) {
  $14 = ((($fs)) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  _luaX_syntaxerror($15,4928);
  // unreachable;
 }
 $16 = $$lcssa4 & 16383;
 $17 = $11 << 14;
 $18 = (($17) + 2147467264)|0;
 $19 = $16 | $18;
 HEAP32[$$lcssa>>2] = $19;
 return;
}
function _luaK_ret($fs,$first,$nret) {
 $fs = $fs|0;
 $first = $first|0;
 $nret = $nret|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $first << 6;
 $1 = $nret << 23;
 $2 = (($1) + 8388608)|0;
 $3 = $0 | $2;
 $4 = $3 | 38;
 (_luaK_code($fs,$4)|0);
 return;
}
function _luaK_getlabel($fs) {
 $fs = $fs|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($fs)) + 20|0);
 HEAP32[$2>>2] = $1;
 return ($1|0);
}
function _luaK_patchlist($fs,$list,$target) {
 $fs = $fs|0;
 $list = $list|0;
 $target = $target|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i1 = 0, $$02$i = 0, $$lcssa = 0, $$lcssa10 = 0, $$neg$i = 0, $$neg$i$i = 0, $$neg$i$i$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $fs$idx$val$i$i = 0, $fs$idx$val$i$pre = 0;
 var $fs$idx$val$idx$i$i = 0, $fs$idx$val$idx$i$phi$trans$insert = 0, $fs$idx$val$idx$val$i$i = 0, $fs$idx$val$idx$val$i$pre = 0, $ispos$i = 0, $ispos$i$i = 0, $ispos$i$i$i = 0, $list$0$i$i = 0, $list$0$i$i$lcssa = 0, $neg$i = 0, $neg$i$i = 0, $neg$i$i$i = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($target|0);
 if ($2) {
  $3 = ((($fs)) + 20|0);
  HEAP32[$3>>2] = $target;
  $4 = ((($fs)) + 24|0);
  $5 = ($list|0)==(-1);
  if ($5) {
   return;
  }
  $6 = HEAP32[$4>>2]|0;
  $7 = ($6|0)==(-1);
  if ($7) {
   HEAP32[$4>>2] = $list;
   return;
  }
  $fs$idx$val$i$i = HEAP32[$fs>>2]|0;
  $fs$idx$val$idx$i$i = ((($fs$idx$val$i$i)) + 48|0);
  $fs$idx$val$idx$val$i$i = HEAP32[$fs$idx$val$idx$i$i>>2]|0;
  $list$0$i$i = $6;
  while(1) {
   $8 = (($fs$idx$val$idx$val$i$i) + ($list$0$i$i<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 >>> 14;
   $11 = (($10) + -131071)|0;
   $12 = ($11|0)==(-1);
   $13 = (($list$0$i$i) + 1)|0;
   $14 = (($13) + ($11))|0;
   $$0$i$i$i = $12 ? -1 : $14;
   $15 = ($$0$i$i$i|0)==(-1);
   if ($15) {
    $$lcssa = $8;$$lcssa10 = $9;$list$0$i$i$lcssa = $list$0$i$i;
    break;
   } else {
    $list$0$i$i = $$0$i$i$i;
   }
  }
  $$neg$i$i$i = $list$0$i$i$lcssa ^ -1;
  $16 = (($$neg$i$i$i) + ($list))|0;
  $ispos$i$i$i = ($16|0)>(-1);
  $neg$i$i$i = (0 - ($16))|0;
  $17 = $ispos$i$i$i ? $16 : $neg$i$i$i;
  $18 = ($17|0)>(131071);
  if ($18) {
   $19 = ((($fs)) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   _luaX_syntaxerror($20,4928);
   // unreachable;
  }
  $21 = $$lcssa10 & 16383;
  $22 = $16 << 14;
  $23 = (($22) + 2147467264)|0;
  $24 = $23 | $21;
  HEAP32[$$lcssa>>2] = $24;
  return;
 }
 $25 = ($list|0)==(-1);
 if ($25) {
  return;
 }
 $fs$idx$val$i$pre = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i$phi$trans$insert = ((($fs$idx$val$i$pre)) + 48|0);
 $fs$idx$val$idx$val$i$pre = HEAP32[$fs$idx$val$idx$i$phi$trans$insert>>2]|0;
 $$02$i = $list;
 while(1) {
  $26 = (($fs$idx$val$idx$val$i$pre) + ($$02$i<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 >>> 14;
  $29 = (($28) + -131071)|0;
  $30 = ($29|0)==(-1);
  $31 = (($$02$i) + 1)|0;
  $32 = (($31) + ($29))|0;
  $$0$i$i = $30 ? -1 : $32;
  $33 = ($$02$i|0)>(0);
  if ($33) {
   $$sum$i$i = (($$02$i) + -1)|0;
   $34 = (($fs$idx$val$idx$val$i$pre) + ($$sum$i$i<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $35 & 63;
   $37 = (2360 + ($36)|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = ($38<<24>>24)<(0);
   if ($39) {
    $$0$i$i1 = $34;$41 = $35;
   } else {
    label = 14;
   }
  } else {
   label = 14;
  }
  if ((label|0) == 14) {
   label = 0;
   $$0$i$i1 = $26;$41 = $27;
  }
  $40 = $41 & 63;
  $42 = ($40|0)==(35);
  if ($42) {
   $43 = $41 >>> 23;
   $44 = $43 << 6;
   $45 = $41 & 8372224;
   $46 = $45 | $44;
   $47 = $46 | 34;
   HEAP32[$$0$i$i1>>2] = $47;
   $$neg$i = $$02$i ^ -1;
   $48 = (($$neg$i) + ($target))|0;
   $ispos$i = ($48|0)>(-1);
   $neg$i = (0 - ($48))|0;
   $49 = $ispos$i ? $48 : $neg$i;
   $50 = ($49|0)>(131071);
   if ($50) {
    label = 17;
    break;
   }
   $53 = HEAP32[$26>>2]|0;
   $54 = $53 & 16383;
   $55 = $48 << 14;
   $56 = (($55) + 2147467264)|0;
   $57 = $54 | $56;
   $storemerge = $57;
  } else {
   $$neg$i$i = $$02$i ^ -1;
   $58 = (($$neg$i$i) + ($target))|0;
   $ispos$i$i = ($58|0)>(-1);
   $neg$i$i = (0 - ($58))|0;
   $59 = $ispos$i$i ? $58 : $neg$i$i;
   $60 = ($59|0)>(131071);
   if ($60) {
    label = 20;
    break;
   }
   $63 = $27 & 16383;
   $64 = $58 << 14;
   $65 = (($64) + 2147467264)|0;
   $66 = $63 | $65;
   $storemerge = $66;
  }
  HEAP32[$26>>2] = $storemerge;
  $67 = ($$0$i$i|0)==(-1);
  if ($67) {
   label = 23;
   break;
  } else {
   $$02$i = $$0$i$i;
  }
 }
 if ((label|0) == 17) {
  $51 = ((($fs)) + 8|0);
  $52 = HEAP32[$51>>2]|0;
  _luaX_syntaxerror($52,4928);
  // unreachable;
 }
 else if ((label|0) == 20) {
  $61 = ((($fs)) + 8|0);
  $62 = HEAP32[$61>>2]|0;
  _luaX_syntaxerror($62,4928);
  // unreachable;
 }
 else if ((label|0) == 23) {
  return;
 }
}
function _luaK_patchtohere($fs,$list) {
 $fs = $fs|0;
 $list = $list|0;
 var $$0$i$i = 0, $$lcssa = 0, $$lcssa6 = 0, $$neg$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fs$idx$val$i = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$val$i = 0, $ispos$i$i = 0, $list$0$i = 0, $list$0$i$lcssa = 0, $neg$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($fs)) + 20|0);
 HEAP32[$2>>2] = $1;
 $3 = ((($fs)) + 24|0);
 $4 = ($list|0)==(-1);
 if ($4) {
  return;
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = ($5|0)==(-1);
 if ($6) {
  HEAP32[$3>>2] = $list;
  return;
 }
 $fs$idx$val$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
 $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
 $list$0$i = $5;
 while(1) {
  $7 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 >>> 14;
  $10 = (($9) + -131071)|0;
  $11 = ($10|0)==(-1);
  $12 = (($list$0$i) + 1)|0;
  $13 = (($12) + ($10))|0;
  $$0$i$i = $11 ? -1 : $13;
  $14 = ($$0$i$i|0)==(-1);
  if ($14) {
   $$lcssa = $7;$$lcssa6 = $8;$list$0$i$lcssa = $list$0$i;
   break;
  } else {
   $list$0$i = $$0$i$i;
  }
 }
 $$neg$i$i = $list$0$i$lcssa ^ -1;
 $15 = (($$neg$i$i) + ($list))|0;
 $ispos$i$i = ($15|0)>(-1);
 $neg$i$i = (0 - ($15))|0;
 $16 = $ispos$i$i ? $15 : $neg$i$i;
 $17 = ($16|0)>(131071);
 if ($17) {
  $18 = ((($fs)) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  _luaX_syntaxerror($19,4928);
  // unreachable;
 }
 $20 = $$lcssa6 & 16383;
 $21 = $15 << 14;
 $22 = (($21) + 2147467264)|0;
 $23 = $22 | $20;
 HEAP32[$$lcssa>>2] = $23;
 return;
}
function _luaK_patchclose($fs,$list,$level) {
 $fs = $fs|0;
 $list = $list|0;
 $level = $level|0;
 var $$ = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fs$idx$val = 0, $fs$idx$val$idx = 0, $fs$idx$val$idx$val = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($list|0)==(-1);
 if ($0) {
  return;
 }
 $fs$idx$val = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx = ((($fs$idx$val)) + 48|0);
 $fs$idx$val$idx$val = HEAP32[$fs$idx$val$idx>>2]|0;
 $1 = $level << 6;
 $2 = (($1) + 64)|0;
 $3 = $2 & 16320;
 $$01 = $list;
 while(1) {
  $4 = (($fs$idx$val$idx$val) + ($$01<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 >>> 14;
  $7 = (($6) + -131071)|0;
  $8 = ($7|0)==(-1);
  $9 = (($$01) + 1)|0;
  $10 = (($9) + ($7))|0;
  $11 = $5 & -16321;
  $12 = $11 | $3;
  HEAP32[$4>>2] = $12;
  $$ = $8 ? -1 : $10;
  $13 = ($$|0)==(-1);
  if ($13) {
   break;
  } else {
   $$01 = $$;
  }
 }
 return;
}
function _luaK_codek($fs,$reg,$k) {
 $fs = $fs|0;
 $reg = $reg|0;
 $k = $k|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($k|0)<(262144);
 $1 = $reg << 6;
 if ($0) {
  $2 = $k << 14;
  $3 = $1 | $2;
  $4 = $3 | 1;
  $5 = (_luaK_code($fs,$4)|0);
  $$0 = $5;
  return ($$0|0);
 } else {
  $6 = $1 | 2;
  $7 = (_luaK_code($fs,$6)|0);
  $8 = $k << 6;
  $9 = $8 | 46;
  (_luaK_code($fs,$9)|0);
  $$0 = $7;
  return ($$0|0);
 }
 return (0)|0;
}
function _luaK_checkstack($fs,$n) {
 $fs = $fs|0;
 $n = $n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 44|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = (($2) + ($n))|0;
 $4 = HEAP32[$fs>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = ($3|0)>($7|0);
 if (!($8)) {
  return;
 }
 $9 = ($3|0)>(249);
 if ($9) {
  $10 = ((($fs)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  _luaX_syntaxerror($11,4960);
  // unreachable;
 }
 $12 = $3&255;
 HEAP8[$5>>0] = $12;
 return;
}
function _luaK_reserveregs($fs,$n) {
 $fs = $fs|0;
 $n = $n|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 44|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = (($2) + ($n))|0;
 $4 = HEAP32[$fs>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = ($3|0)>($7|0);
 if (!($8)) {
  $$pre = $3&255;
  $$pre$phiZ2D = $$pre;
  HEAP8[$0>>0] = $$pre$phiZ2D;
  return;
 }
 $9 = ($3|0)>(249);
 if ($9) {
  $10 = ((($fs)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  _luaX_syntaxerror($11,4960);
  // unreachable;
 }
 $12 = $3&255;
 HEAP8[$5>>0] = $12;
 $$pre$phiZ2D = $12;
 HEAP8[$0>>0] = $$pre$phiZ2D;
 return;
}
function _luaK_stringK($fs,$s) {
 $fs = $fs|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $o = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $o = sp;
 HEAP32[$o>>2] = $s;
 $0 = ((($s)) + 4|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 | 64;
 $4 = ((($o)) + 8|0);
 HEAP32[$4>>2] = $3;
 $5 = (_addk($fs,$o,$o)|0);
 STACKTOP = sp;return ($5|0);
}
function _luaK_intK($fs,$0,$1) {
 $fs = $fs|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $k = 0, $o = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $k = sp + 16|0;
 $o = sp;
 $2 = $0;
 HEAP32[$k>>2] = $2;
 $3 = ((($k)) + 8|0);
 HEAP32[$3>>2] = 2;
 $4 = $o;
 $5 = $4;
 HEAP32[$5>>2] = $0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $1;
 $8 = ((($o)) + 8|0);
 HEAP32[$8>>2] = 19;
 $9 = (_addk($fs,$k,$o)|0);
 STACKTOP = sp;return ($9|0);
}
function _luaK_setreturns($fs,$e,$nresults) {
 $fs = $fs|0;
 $e = $e|0;
 $nresults = $nresults|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$e>>2]|0;
 if ((($0|0) == 14)) {
  $13 = ((($e)) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$fs>>2]|0;
  $16 = ((($15)) + 48|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + ($14<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & 8388607;
  $21 = $nresults << 23;
  $22 = (($21) + 8388608)|0;
  $23 = $20 | $22;
  HEAP32[$18>>2] = $23;
  $24 = HEAP32[$13>>2]|0;
  $25 = (($17) + ($24<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $26 & -16321;
  $28 = ((($fs)) + 44|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = $30 << 6;
  $32 = $31 | $27;
  HEAP32[$25>>2] = $32;
  $33 = (($30) + 1)|0;
  $34 = ((($15)) + 8|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35&255;
  $37 = ($33>>>0)>($36>>>0);
  do {
   if ($37) {
    $38 = ($33>>>0)>(249);
    if ($38) {
     $39 = ((($fs)) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     _luaX_syntaxerror($40,4960);
     // unreachable;
    } else {
     $41 = $33&255;
     HEAP8[$34>>0] = $41;
     $$pre$phi$iZ2D = $41;
     break;
    }
   } else {
    $$pre$i = $33&255;
    $$pre$phi$iZ2D = $$pre$i;
   }
  } while(0);
  HEAP8[$28>>0] = $$pre$phi$iZ2D;
  return;
 } else if ((($0|0) == 13)) {
  $1 = ((($e)) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = HEAP32[$fs>>2]|0;
  $4 = ((($3)) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($2<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 & -8372225;
  $9 = $nresults << 14;
  $10 = (($9) + 16384)|0;
  $11 = $10 & 8372224;
  $12 = $8 | $11;
  HEAP32[$6>>2] = $12;
  return;
 } else {
  return;
 }
}
function _luaK_setoneret($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$e>>2]|0;
 if ((($0|0) == 13)) {
  HEAP32[$e>>2] = 7;
  $1 = ((($e)) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = HEAP32[$fs>>2]|0;
  $4 = ((($3)) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($2<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 >>> 6;
  $9 = $8 & 255;
  HEAP32[$1>>2] = $9;
  return;
 } else if ((($0|0) == 14)) {
  $10 = ((($e)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$fs>>2]|0;
  $13 = ((($12)) + 48|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16 & 8388607;
  $18 = $17 | 16777216;
  HEAP32[$15>>2] = $18;
  HEAP32[$e>>2] = 12;
  return;
 } else {
  return;
 }
}
function _luaK_dischargevars($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $op$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$e>>2]|0;
 switch ($0|0) {
 case 9:  {
  $1 = ((($e)) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = $2 << 23;
  $4 = $3 | 5;
  $5 = (_luaK_code($fs,$4)|0);
  HEAP32[$1>>2] = $5;
  HEAP32[$e>>2] = 12;
  return;
  break;
 }
 case 8:  {
  HEAP32[$e>>2] = 7;
  return;
  break;
 }
 case 14:  {
  $44 = ((($e)) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = HEAP32[$fs>>2]|0;
  $47 = ((($46)) + 48|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + ($45<<2)|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 & 8388607;
  $52 = $51 | 16777216;
  HEAP32[$49>>2] = $52;
  HEAP32[$e>>2] = 12;
  return;
  break;
 }
 case 13:  {
  HEAP32[$e>>2] = 7;
  $35 = ((($e)) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = HEAP32[$fs>>2]|0;
  $38 = ((($37)) + 48|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + ($36<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = $41 >>> 6;
  $43 = $42 & 255;
  HEAP32[$35>>2] = $43;
  return;
  break;
 }
 case 10:  {
  $6 = ((($e)) + 8|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = $7 << 16 >> 16;
  $9 = $8 & 256;
  $10 = ($9|0)==(0);
  if ($10) {
   $11 = ((($fs)) + 42|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = $12&255;
   $14 = ($13|0)>($8|0);
   if (!($14)) {
    $15 = ((($fs)) + 44|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = (($16) + -1)<<24>>24;
    HEAP8[$15>>0] = $17;
   }
  }
  $18 = ((($6)) + 3|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)==(8);
  $21 = ((($6)) + 2|0);
  $22 = HEAP8[$21>>0]|0;
  if ($20) {
   $23 = ((($fs)) + 42|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24&255)>($22&255);
   if ($25) {
    $op$0 = 7;
   } else {
    $26 = ((($fs)) + 44|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = (($27) + -1)<<24>>24;
    HEAP8[$26>>0] = $28;
    $op$0 = 7;
   }
  } else {
   $op$0 = 6;
  }
  $29 = $22&255;
  $30 = $29 << 23;
  $31 = $30 | $op$0;
  $32 = $8 << 14;
  $33 = $31 | $32;
  $34 = (_luaK_code($fs,$33)|0);
  HEAP32[$6>>2] = $34;
  HEAP32[$e>>2] = 12;
  return;
  break;
 }
 default: {
  return;
 }
 }
}
function _luaK_exp2nextreg($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaK_dischargevars($fs,$e);
 $0 = HEAP32[$e>>2]|0;
 $1 = ($0|0)==(7);
 if ($1) {
  $2 = ((($e)) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = $3 & 256;
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = ((($fs)) + 42|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = $7&255;
   $9 = ($8|0)>($3|0);
   if (!($9)) {
    $10 = ((($fs)) + 44|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = (($11) + -1)<<24>>24;
    HEAP8[$10>>0] = $12;
   }
  }
 }
 $13 = ((($fs)) + 44|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = (($15) + 1)|0;
 $17 = HEAP32[$fs>>2]|0;
 $18 = ((($17)) + 8|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = ($16>>>0)>($20>>>0);
 if (!($21)) {
  $$pre$i = $16&255;
  $$pre$phi$iZ2D = $$pre$i;
  HEAP8[$13>>0] = $$pre$phi$iZ2D;
  $26 = $$pre$phi$iZ2D&255;
  $27 = (($26) + -1)|0;
  _exp2reg($fs,$e,$27);
  return;
 }
 $22 = ($16>>>0)>(249);
 if ($22) {
  $23 = ((($fs)) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  _luaX_syntaxerror($24,4960);
  // unreachable;
 }
 $25 = $16&255;
 HEAP8[$18>>0] = $25;
 $$pre$phi$iZ2D = $25;
 HEAP8[$13>>0] = $$pre$phi$iZ2D;
 $26 = $$pre$phi$iZ2D&255;
 $27 = (($26) + -1)|0;
 _exp2reg($fs,$e,$27);
 return;
}
function _luaK_exp2anyreg($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $$0 = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaK_dischargevars($fs,$e);
 $0 = HEAP32[$e>>2]|0;
 $1 = ($0|0)==(7);
 if ($1) {
  $2 = ((($e)) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ((($e)) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)==($5|0);
  $7 = ((($e)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  if ($6) {
   $$0 = $8;
   return ($$0|0);
  }
  $9 = ((($fs)) + 42|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = ($8|0)<($11|0);
  if (!($12)) {
   _exp2reg($fs,$e,$8);
   $13 = HEAP32[$7>>2]|0;
   $$0 = $13;
   return ($$0|0);
  }
 }
 _luaK_dischargevars($fs,$e);
 $14 = HEAP32[$e>>2]|0;
 $15 = ($14|0)==(7);
 if ($15) {
  $16 = ((($e)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17 & 256;
  $19 = ($18|0)==(0);
  if ($19) {
   $20 = ((($fs)) + 42|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = $21&255;
   $23 = ($22|0)>($17|0);
   if (!($23)) {
    $24 = ((($fs)) + 44|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = (($25) + -1)<<24>>24;
    HEAP8[$24>>0] = $26;
   }
  }
 }
 $27 = ((($fs)) + 44|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = $28&255;
 $30 = (($29) + 1)|0;
 $31 = HEAP32[$fs>>2]|0;
 $32 = ((($31)) + 8|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33&255;
 $35 = ($30>>>0)>($34>>>0);
 do {
  if ($35) {
   $36 = ($30>>>0)>(249);
   if ($36) {
    $37 = ((($fs)) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    _luaX_syntaxerror($38,4960);
    // unreachable;
   } else {
    $39 = $30&255;
    HEAP8[$32>>0] = $39;
    $$pre$phi$i$iZ2D = $39;
    break;
   }
  } else {
   $$pre$i$i = $30&255;
   $$pre$phi$i$iZ2D = $$pre$i$i;
  }
 } while(0);
 HEAP8[$27>>0] = $$pre$phi$i$iZ2D;
 $40 = $$pre$phi$i$iZ2D&255;
 $41 = (($40) + -1)|0;
 _exp2reg($fs,$e,$41);
 $42 = ((($e)) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $$0 = $43;
 return ($$0|0);
}
function _luaK_exp2anyregup($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$e>>2]|0;
 $1 = ($0|0)==(9);
 if ($1) {
  $2 = ((($e)) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ((($e)) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)==($5|0);
  if ($6) {
   return;
  }
 }
 (_luaK_exp2anyreg($fs,$e)|0);
 return;
}
function _luaK_exp2val($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($e)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($e)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  _luaK_dischargevars($fs,$e);
  return;
 } else {
  (_luaK_exp2anyreg($fs,$e)|0);
  return;
 }
}
function _luaK_exp2RK($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $k$i = 0, $k$i1 = 0, $o$i = 0, $o$i2 = 0, $o$i3 = 0, $v$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $o$i3 = sp + 80|0;
 $k$i1 = sp + 64|0;
 $o$i2 = sp + 48|0;
 $o$i = sp + 32|0;
 $k$i = sp + 16|0;
 $v$i = sp;
 $0 = ((($e)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($e)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  _luaK_dischargevars($fs,$e);
 } else {
  (_luaK_exp2anyreg($fs,$e)|0);
 }
 $5 = HEAP32[$e>>2]|0;
 switch ($5|0) {
 case 6:  {
  $24 = ((($e)) + 8|0);
  $25 = $24;
  $26 = $25;
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 4)|0;
  $29 = $28;
  $30 = HEAP32[$29>>2]|0;
  $31 = $27;
  HEAP32[$k$i1>>2] = $31;
  $32 = ((($k$i1)) + 8|0);
  HEAP32[$32>>2] = 2;
  $33 = $o$i2;
  $34 = $33;
  HEAP32[$34>>2] = $27;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = $30;
  $37 = ((($o$i2)) + 8|0);
  HEAP32[$37>>2] = 19;
  $38 = (_addk($fs,$k$i1,$o$i2)|0);
  HEAP32[$24>>2] = $38;
  HEAP32[$e>>2] = 4;
  $44 = $38;
  label = 13;
  break;
 }
 case 1: case 3: case 2:  {
  $6 = ((($fs)) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)<(256);
  if ($8) {
   $9 = ($5|0)==(1);
   if ($9) {
    $10 = ((($v$i)) + 8|0);
    HEAP32[$10>>2] = 0;
    $11 = ((($fs)) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ((($12)) + 64|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$k$i>>2] = $14;
    $15 = ((($k$i)) + 8|0);
    HEAP32[$15>>2] = 69;
    $16 = (_addk($fs,$k$i,$v$i)|0);
    $22 = $16;
   } else {
    $17 = ($5|0)==(2);
    $18 = $17&1;
    HEAP32[$o$i>>2] = $18;
    $19 = ((($o$i)) + 8|0);
    HEAP32[$19>>2] = 1;
    $20 = (_addk($fs,$o$i,$o$i)|0);
    $22 = $20;
   }
   $21 = ((($e)) + 8|0);
   HEAP32[$21>>2] = $22;
   HEAP32[$e>>2] = 4;
   $23 = $22 | 256;
   $$0 = $23;
   STACKTOP = sp;return ($$0|0);
  }
  break;
 }
 case 4:  {
  $$phi$trans$insert = ((($e)) + 8|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $44 = $$pre;
  label = 13;
  break;
 }
 case 5:  {
  $39 = ((($e)) + 8|0);
  $40 = +HEAPF64[$39>>3];
  HEAPF64[$o$i3>>3] = $40;
  $41 = ((($o$i3)) + 8|0);
  HEAP32[$41>>2] = 3;
  $42 = (_addk($fs,$o$i3,$o$i3)|0);
  HEAP32[$39>>2] = $42;
  HEAP32[$e>>2] = 4;
  $44 = $42;
  label = 13;
  break;
 }
 default: {
 }
 }
 if ((label|0) == 13) {
  $43 = ($44|0)<(256);
  if ($43) {
   $45 = $44 | 256;
   $$0 = $45;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $46 = (_luaK_exp2anyreg($fs,$e)|0);
 $$0 = $46;
 STACKTOP = sp;return ($$0|0);
}
function _luaK_storevar($fs,$var,$ex) {
 $fs = $fs|0;
 $var = $var|0;
 $ex = $ex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$var>>2]|0;
 if ((($0|0) == 10)) {
  $23 = ((($var)) + 8|0);
  $24 = ((($23)) + 3|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(8);
  $27 = $26 ? 10 : 8;
  $28 = (_luaK_exp2RK($fs,$ex)|0);
  $29 = ((($23)) + 2|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = HEAP16[$23>>1]|0;
  $33 = $32&65535;
  $34 = $31 << 6;
  $35 = $33 << 23;
  $36 = $28 << 14;
  $37 = $36 | $27;
  $38 = $37 | $34;
  $39 = $38 | $35;
  (_luaK_code($fs,$39)|0);
 } else if ((($0|0) == 9)) {
  $16 = (_luaK_exp2anyreg($fs,$ex)|0);
  $17 = ((($var)) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $16 << 6;
  $20 = $18 << 23;
  $21 = $19 | $20;
  $22 = $21 | 9;
  (_luaK_code($fs,$22)|0);
 } else if ((($0|0) == 8)) {
  $1 = HEAP32[$ex>>2]|0;
  $2 = ($1|0)==(7);
  if ($2) {
   $3 = ((($ex)) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = $4 & 256;
   $6 = ($5|0)==(0);
   if ($6) {
    $7 = ((($fs)) + 42|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8&255;
    $10 = ($9|0)>($4|0);
    if (!($10)) {
     $11 = ((($fs)) + 44|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = (($12) + -1)<<24>>24;
     HEAP8[$11>>0] = $13;
    }
   }
  }
  $14 = ((($var)) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  _exp2reg($fs,$ex,$15);
  return;
 }
 $40 = HEAP32[$ex>>2]|0;
 $41 = ($40|0)==(7);
 if (!($41)) {
  return;
 }
 $42 = ((($ex)) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43 & 256;
 $45 = ($44|0)==(0);
 if (!($45)) {
  return;
 }
 $46 = ((($fs)) + 42|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = $47&255;
 $49 = ($48|0)>($43|0);
 if ($49) {
  return;
 }
 $50 = ((($fs)) + 44|0);
 $51 = HEAP8[$50>>0]|0;
 $52 = (($51) + -1)<<24>>24;
 HEAP8[$50>>0] = $52;
 return;
}
function _luaK_self($fs,$e,$key) {
 $fs = $fs|0;
 $e = $e|0;
 $key = $key|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_luaK_exp2anyreg($fs,$e)|0);
 $0 = ((($e)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$e>>2]|0;
 $3 = ($2|0)==(7);
 $4 = $1 & 256;
 $5 = ($4|0)==(0);
 $or$cond = $3 & $5;
 if ($or$cond) {
  $6 = ((($fs)) + 42|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7&255;
  $9 = ($8|0)>($1|0);
  if (!($9)) {
   $10 = ((($fs)) + 44|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = (($11) + -1)<<24>>24;
   HEAP8[$10>>0] = $12;
  }
 }
 $13 = ((($fs)) + 44|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 HEAP32[$0>>2] = $15;
 HEAP32[$e>>2] = 7;
 $16 = (($15) + 2)|0;
 $17 = HEAP32[$fs>>2]|0;
 $18 = ((($17)) + 8|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = ($16>>>0)>($20>>>0);
 do {
  if ($21) {
   $22 = ($16>>>0)>(249);
   if ($22) {
    $23 = ((($fs)) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    _luaX_syntaxerror($24,4960);
    // unreachable;
   } else {
    $25 = $16&255;
    HEAP8[$18>>0] = $25;
    $$pre$phi$iZ2D = $25;
    break;
   }
  } else {
   $$pre$i = $16&255;
   $$pre$phi$iZ2D = $$pre$i;
  }
 } while(0);
 HEAP8[$13>>0] = $$pre$phi$iZ2D;
 $26 = (_luaK_exp2RK($fs,$key)|0);
 $27 = $15 << 6;
 $28 = $1 << 23;
 $29 = $26 << 14;
 $30 = $28 | $27;
 $31 = $30 | $29;
 $32 = $31 | 12;
 (_luaK_code($fs,$32)|0);
 $33 = HEAP32[$key>>2]|0;
 $34 = ($33|0)==(7);
 if (!($34)) {
  return;
 }
 $35 = ((($key)) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 256;
 $38 = ($37|0)==(0);
 if (!($38)) {
  return;
 }
 $39 = ((($fs)) + 42|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = $40&255;
 $42 = ($41|0)>($36|0);
 if ($42) {
  return;
 }
 $43 = HEAP8[$13>>0]|0;
 $44 = (($43) + -1)<<24>>24;
 HEAP8[$13>>0] = $44;
 return;
}
function _luaK_goiftrue($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i8 = 0, $$0$i$i1 = 0, $$lcssa = 0, $$lcssa52 = 0, $$lcssa53 = 0, $$lcssa54 = 0, $$lcssa55 = 0, $$lcssa56 = 0, $$lcssa57 = 0, $$lcssa58 = 0, $$neg$i$i = 0, $$neg$i$i$i = 0, $$neg$i$i$i$i = 0, $$neg$i$i$i$i9 = 0, $$pr = 0, $$pre = 0, $$pre$i = 0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $fs$idx$val = 0, $fs$idx$val$i = 0, $fs$idx$val$i$i = 0;
 var $fs$idx$val$i$i$i = 0, $fs$idx$val$i$i$i3 = 0, $fs$idx$val$idx = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$i$i = 0, $fs$idx$val$idx$i$i$i = 0, $fs$idx$val$idx$i$i$i4 = 0, $fs$idx$val$idx$val = 0, $fs$idx$val$idx$val$i = 0, $fs$idx$val$idx$val$i$i = 0, $fs$idx$val$idx$val$i$i$i = 0, $fs$idx$val$idx$val$i$i$i5 = 0, $ispos$i$i = 0, $ispos$i$i$i = 0, $ispos$i$i$i$i = 0, $ispos$i$i$i$i10 = 0, $list$0$i = 0, $list$0$i$i = 0, $list$0$i$i$i = 0, $list$0$i$i$i$lcssa = 0;
 var $list$0$i$i$i7 = 0, $list$0$i$i$i7$lcssa = 0, $list$0$i$i$lcssa = 0, $list$0$i$lcssa = 0, $neg$i$i = 0, $neg$i$i$i = 0, $neg$i$i$i$i = 0, $neg$i$i$i$i11 = 0, $pc$0 = 0, $pc$014 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaK_dischargevars($fs,$e);
 $0 = HEAP32[$e>>2]|0;
 L1: do {
  switch ($0|0) {
  case 11:  {
   $fs$idx$val = HEAP32[$fs>>2]|0;
   $fs$idx$val$idx = ((($fs$idx$val)) + 48|0);
   $fs$idx$val$idx$val = HEAP32[$fs$idx$val$idx>>2]|0;
   $1 = ((($e)) + 8|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = (($fs$idx$val$idx$val) + ($2<<2)|0);
   $4 = ($2|0)>(0);
   if ($4) {
    $$sum$i$i = (($2) + -1)|0;
    $5 = (($fs$idx$val$idx$val) + ($$sum$i$i<<2)|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = $6 & 63;
    $8 = (2360 + ($7)|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)<(0);
    if ($10) {
     $$0$i$i = $5;$12 = $6;
    } else {
     label = 4;
    }
   } else {
    label = 4;
   }
   if ((label|0) == 4) {
    $$pre$i = HEAP32[$3>>2]|0;
    $$0$i$i = $3;$12 = $$pre$i;
   }
   $11 = $12 & -16321;
   $13 = $12 & 16320;
   $14 = ($13|0)==(0);
   $15 = $14&1;
   $16 = $15 << 6;
   $17 = $16 | $11;
   HEAP32[$$0$i$i>>2] = $17;
   $18 = HEAP32[$1>>2]|0;
   $pc$0 = $18;
   label = 32;
   break;
  }
  case 2: case 6: case 5: case 4:  {
   break;
  }
  default: {
   $19 = ((($e)) + 8|0);
   if ((($0|0) == 12)) {
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$fs>>2]|0;
    $22 = ((($21)) + 48|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + ($20<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = $25 & 63;
    $27 = ($26|0)==(27);
    if ($27) {
     $28 = ((($fs)) + 16|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($29) + -1)|0;
     HEAP32[$28>>2] = $30;
     $31 = $25 >>> 23;
     $32 = $31 << 6;
     $33 = $32 | 16418;
     (_luaK_code($fs,$33)|0);
     $34 = ((($fs)) + 24|0);
     $35 = HEAP32[$34>>2]|0;
     HEAP32[$34>>2] = -1;
     $36 = (_luaK_code($fs,2147450910)|0);
     $37 = ($35|0)==(-1);
     if ($37) {
      $pc$0 = $36;
      label = 32;
      break L1;
     }
     $38 = ($36|0)==(-1);
     if ($38) {
      $pc$014 = $35;
      label = 33;
      break L1;
     }
     $fs$idx$val$i$i$i3 = HEAP32[$fs>>2]|0;
     $fs$idx$val$idx$i$i$i4 = ((($fs$idx$val$i$i$i3)) + 48|0);
     $fs$idx$val$idx$val$i$i$i5 = HEAP32[$fs$idx$val$idx$i$i$i4>>2]|0;
     $list$0$i$i$i7 = $36;
     while(1) {
      $39 = (($fs$idx$val$idx$val$i$i$i5) + ($list$0$i$i$i7<<2)|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = $40 >>> 14;
      $42 = (($41) + -131071)|0;
      $43 = ($42|0)==(-1);
      $44 = (($list$0$i$i$i7) + 1)|0;
      $45 = (($44) + ($42))|0;
      $$0$i$i$i$i8 = $43 ? -1 : $45;
      $46 = ($$0$i$i$i$i8|0)==(-1);
      if ($46) {
       $$lcssa57 = $39;$$lcssa58 = $40;$list$0$i$i$i7$lcssa = $list$0$i$i$i7;
       break;
      } else {
       $list$0$i$i$i7 = $$0$i$i$i$i8;
      }
     }
     $$neg$i$i$i$i9 = $list$0$i$i$i7$lcssa ^ -1;
     $47 = (($35) + ($$neg$i$i$i$i9))|0;
     $ispos$i$i$i$i10 = ($47|0)>(-1);
     $neg$i$i$i$i11 = (0 - ($47))|0;
     $48 = $ispos$i$i$i$i10 ? $47 : $neg$i$i$i$i11;
     $49 = ($48|0)>(131071);
     if ($49) {
      $50 = ((($fs)) + 8|0);
      $51 = HEAP32[$50>>2]|0;
      _luaX_syntaxerror($51,4928);
      // unreachable;
     } else {
      $52 = $$lcssa58 & 16383;
      $53 = $47 << 14;
      $54 = (($53) + 2147467264)|0;
      $55 = $54 | $52;
      HEAP32[$$lcssa57>>2] = $55;
      $pc$0 = $36;
      label = 32;
      break L1;
     }
    } else {
     label = 15;
    }
   } else if ((($0|0) == 7)) {
    label = 22;
   } else {
    label = 15;
   }
   if ((label|0) == 15) {
    $56 = ((($fs)) + 44|0);
    $57 = HEAP8[$56>>0]|0;
    $58 = $57&255;
    $59 = (($58) + 1)|0;
    $60 = HEAP32[$fs>>2]|0;
    $61 = ((($60)) + 8|0);
    $62 = HEAP8[$61>>0]|0;
    $63 = $62&255;
    $64 = ($59>>>0)>($63>>>0);
    do {
     if ($64) {
      $65 = ($59>>>0)>(249);
      if ($65) {
       $66 = ((($fs)) + 8|0);
       $67 = HEAP32[$66>>2]|0;
       _luaX_syntaxerror($67,4960);
       // unreachable;
      } else {
       $68 = $59&255;
       HEAP8[$61>>0] = $68;
       $$pre$phi$i$iZ2D = $68;
       break;
      }
     } else {
      $$pre$i$i = $59&255;
      $$pre$phi$i$iZ2D = $$pre$i$i;
     }
    } while(0);
    HEAP8[$56>>0] = $$pre$phi$i$iZ2D;
    $69 = $$pre$phi$i$iZ2D&255;
    $70 = (($69) + -1)|0;
    _discharge2reg($fs,$e,$70);
    $$pr = HEAP32[$e>>2]|0;
    $71 = ($$pr|0)==(7);
    if ($71) {
     label = 22;
    } else {
     $$pre = HEAP32[$19>>2]|0;
     $83 = $$pre;
    }
   }
   if ((label|0) == 22) {
    $72 = HEAP32[$19>>2]|0;
    $73 = $72 & 256;
    $74 = ($73|0)==(0);
    if ($74) {
     $75 = ((($fs)) + 42|0);
     $76 = HEAP8[$75>>0]|0;
     $77 = $76&255;
     $78 = ($77|0)>($72|0);
     if ($78) {
      $83 = $72;
     } else {
      $79 = ((($fs)) + 44|0);
      $80 = HEAP8[$79>>0]|0;
      $81 = (($80) + -1)<<24>>24;
      HEAP8[$79>>0] = $81;
      $83 = $72;
     }
    } else {
     $83 = $72;
    }
   }
   $82 = $83 << 23;
   $84 = $82 | 16355;
   (_luaK_code($fs,$84)|0);
   $85 = ((($fs)) + 24|0);
   $86 = HEAP32[$85>>2]|0;
   HEAP32[$85>>2] = -1;
   $87 = (_luaK_code($fs,2147450910)|0);
   $88 = ($86|0)==(-1);
   if ($88) {
    $pc$0 = $87;
    label = 32;
   } else {
    $89 = ($87|0)==(-1);
    if ($89) {
     $pc$014 = $86;
     label = 33;
    } else {
     $fs$idx$val$i$i$i = HEAP32[$fs>>2]|0;
     $fs$idx$val$idx$i$i$i = ((($fs$idx$val$i$i$i)) + 48|0);
     $fs$idx$val$idx$val$i$i$i = HEAP32[$fs$idx$val$idx$i$i$i>>2]|0;
     $list$0$i$i$i = $87;
     while(1) {
      $90 = (($fs$idx$val$idx$val$i$i$i) + ($list$0$i$i$i<<2)|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = $91 >>> 14;
      $93 = (($92) + -131071)|0;
      $94 = ($93|0)==(-1);
      $95 = (($list$0$i$i$i) + 1)|0;
      $96 = (($95) + ($93))|0;
      $$0$i$i$i$i = $94 ? -1 : $96;
      $97 = ($$0$i$i$i$i|0)==(-1);
      if ($97) {
       $$lcssa55 = $90;$$lcssa56 = $91;$list$0$i$i$i$lcssa = $list$0$i$i$i;
       break;
      } else {
       $list$0$i$i$i = $$0$i$i$i$i;
      }
     }
     $$neg$i$i$i$i = $list$0$i$i$i$lcssa ^ -1;
     $98 = (($86) + ($$neg$i$i$i$i))|0;
     $ispos$i$i$i$i = ($98|0)>(-1);
     $neg$i$i$i$i = (0 - ($98))|0;
     $99 = $ispos$i$i$i$i ? $98 : $neg$i$i$i$i;
     $100 = ($99|0)>(131071);
     if ($100) {
      $101 = ((($fs)) + 8|0);
      $102 = HEAP32[$101>>2]|0;
      _luaX_syntaxerror($102,4928);
      // unreachable;
     } else {
      $103 = $$lcssa56 & 16383;
      $104 = $98 << 14;
      $105 = (($104) + 2147467264)|0;
      $106 = $105 | $103;
      HEAP32[$$lcssa55>>2] = $106;
      $pc$0 = $87;
      label = 32;
      break L1;
     }
    }
   }
  }
  }
 } while(0);
 if ((label|0) == 32) {
  $107 = ($pc$0|0)==(-1);
  if (!($107)) {
   $pc$014 = $pc$0;
   label = 33;
  }
 }
 do {
  if ((label|0) == 33) {
   $108 = ((($e)) + 20|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = ($109|0)==(-1);
   if ($110) {
    HEAP32[$108>>2] = $pc$014;
    break;
   }
   $fs$idx$val$i = HEAP32[$fs>>2]|0;
   $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
   $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
   $list$0$i = $109;
   while(1) {
    $111 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = $112 >>> 14;
    $114 = (($113) + -131071)|0;
    $115 = ($114|0)==(-1);
    $116 = (($list$0$i) + 1)|0;
    $117 = (($116) + ($114))|0;
    $$0$i$i1 = $115 ? -1 : $117;
    $118 = ($$0$i$i1|0)==(-1);
    if ($118) {
     $$lcssa53 = $111;$$lcssa54 = $112;$list$0$i$lcssa = $list$0$i;
     break;
    } else {
     $list$0$i = $$0$i$i1;
    }
   }
   $$neg$i$i = $list$0$i$lcssa ^ -1;
   $119 = (($pc$014) + ($$neg$i$i))|0;
   $ispos$i$i = ($119|0)>(-1);
   $neg$i$i = (0 - ($119))|0;
   $120 = $ispos$i$i ? $119 : $neg$i$i;
   $121 = ($120|0)>(131071);
   if ($121) {
    $122 = ((($fs)) + 8|0);
    $123 = HEAP32[$122>>2]|0;
    _luaX_syntaxerror($123,4928);
    // unreachable;
   } else {
    $124 = $$lcssa54 & 16383;
    $125 = $119 << 14;
    $126 = (($125) + 2147467264)|0;
    $127 = $126 | $124;
    HEAP32[$$lcssa53>>2] = $127;
    break;
   }
  }
 } while(0);
 $128 = ((($e)) + 16|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ((($fs)) + 16|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = ((($fs)) + 20|0);
 HEAP32[$132>>2] = $131;
 $133 = ((($fs)) + 24|0);
 $134 = ($129|0)==(-1);
 if ($134) {
  HEAP32[$128>>2] = -1;
  return;
 }
 $135 = HEAP32[$133>>2]|0;
 $136 = ($135|0)==(-1);
 if ($136) {
  HEAP32[$133>>2] = $129;
  HEAP32[$128>>2] = -1;
  return;
 }
 $fs$idx$val$i$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i$i = ((($fs$idx$val$i$i)) + 48|0);
 $fs$idx$val$idx$val$i$i = HEAP32[$fs$idx$val$idx$i$i>>2]|0;
 $list$0$i$i = $135;
 while(1) {
  $137 = (($fs$idx$val$idx$val$i$i) + ($list$0$i$i<<2)|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = $138 >>> 14;
  $140 = (($139) + -131071)|0;
  $141 = ($140|0)==(-1);
  $142 = (($list$0$i$i) + 1)|0;
  $143 = (($142) + ($140))|0;
  $$0$i$i$i = $141 ? -1 : $143;
  $144 = ($$0$i$i$i|0)==(-1);
  if ($144) {
   $$lcssa = $137;$$lcssa52 = $138;$list$0$i$i$lcssa = $list$0$i$i;
   break;
  } else {
   $list$0$i$i = $$0$i$i$i;
  }
 }
 $$neg$i$i$i = $list$0$i$i$lcssa ^ -1;
 $145 = (($129) + ($$neg$i$i$i))|0;
 $ispos$i$i$i = ($145|0)>(-1);
 $neg$i$i$i = (0 - ($145))|0;
 $146 = $ispos$i$i$i ? $145 : $neg$i$i$i;
 $147 = ($146|0)>(131071);
 if ($147) {
  $148 = ((($fs)) + 8|0);
  $149 = HEAP32[$148>>2]|0;
  _luaX_syntaxerror($149,4928);
  // unreachable;
 }
 $150 = $$lcssa52 & 16383;
 $151 = $145 << 14;
 $152 = (($151) + 2147467264)|0;
 $153 = $152 | $150;
 HEAP32[$$lcssa>>2] = $153;
 HEAP32[$128>>2] = -1;
 return;
}
function _luaK_goiffalse($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i7 = 0, $$lcssa = 0, $$lcssa51 = 0, $$lcssa52 = 0, $$lcssa53 = 0, $$lcssa54 = 0, $$lcssa55 = 0, $$lcssa56 = 0, $$lcssa57 = 0, $$neg$i$i = 0, $$neg$i$i$i = 0, $$neg$i$i$i$i = 0, $$neg$i$i$i$i8 = 0, $$pr = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $fs$idx$val$i = 0, $fs$idx$val$i$i = 0;
 var $fs$idx$val$i$i$i = 0, $fs$idx$val$i$i$i2 = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$i$i = 0, $fs$idx$val$idx$i$i$i = 0, $fs$idx$val$idx$i$i$i3 = 0, $fs$idx$val$idx$val$i = 0, $fs$idx$val$idx$val$i$i = 0, $fs$idx$val$idx$val$i$i$i = 0, $fs$idx$val$idx$val$i$i$i4 = 0, $ispos$i$i = 0, $ispos$i$i$i = 0, $ispos$i$i$i$i = 0, $ispos$i$i$i$i9 = 0, $list$0$i = 0, $list$0$i$i = 0, $list$0$i$i$i = 0, $list$0$i$i$i$lcssa = 0, $list$0$i$i$i6 = 0, $list$0$i$i$i6$lcssa = 0;
 var $list$0$i$i$lcssa = 0, $list$0$i$lcssa = 0, $neg$i$i = 0, $neg$i$i$i = 0, $neg$i$i$i$i = 0, $neg$i$i$i$i10 = 0, $pc$0 = 0, $pc$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaK_dischargevars($fs,$e);
 $0 = HEAP32[$e>>2]|0;
 do {
  if ((($0|0) == 11)) {
   $1 = ((($e)) + 8|0);
   $2 = HEAP32[$1>>2]|0;
   $pc$0 = $2;
   label = 29;
  } else if (!((($0|0) == 3) | (($0|0) == 1))) {
   $3 = ((($e)) + 8|0);
   if ((($0|0) == 7)) {
    label = 19;
   } else if ((($0|0) == 12)) {
    $4 = HEAP32[$3>>2]|0;
    $5 = HEAP32[$fs>>2]|0;
    $6 = ((($5)) + 48|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($7) + ($4<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = $9 & 63;
    $11 = ($10|0)==(27);
    if ($11) {
     $12 = ((($fs)) + 16|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($13) + -1)|0;
     HEAP32[$12>>2] = $14;
     $15 = $9 >>> 23;
     $16 = $15 << 6;
     $17 = $16 | 34;
     (_luaK_code($fs,$17)|0);
     $18 = ((($fs)) + 24|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$18>>2] = -1;
     $20 = (_luaK_code($fs,2147450910)|0);
     $21 = ($19|0)==(-1);
     if ($21) {
      $pc$0 = $20;
      label = 29;
      break;
     }
     $22 = ($20|0)==(-1);
     if ($22) {
      $pc$013 = $19;
      label = 30;
      break;
     }
     $fs$idx$val$i$i$i2 = HEAP32[$fs>>2]|0;
     $fs$idx$val$idx$i$i$i3 = ((($fs$idx$val$i$i$i2)) + 48|0);
     $fs$idx$val$idx$val$i$i$i4 = HEAP32[$fs$idx$val$idx$i$i$i3>>2]|0;
     $list$0$i$i$i6 = $20;
     while(1) {
      $23 = (($fs$idx$val$idx$val$i$i$i4) + ($list$0$i$i$i6<<2)|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = $24 >>> 14;
      $26 = (($25) + -131071)|0;
      $27 = ($26|0)==(-1);
      $28 = (($list$0$i$i$i6) + 1)|0;
      $29 = (($28) + ($26))|0;
      $$0$i$i$i$i7 = $27 ? -1 : $29;
      $30 = ($$0$i$i$i$i7|0)==(-1);
      if ($30) {
       $$lcssa56 = $23;$$lcssa57 = $24;$list$0$i$i$i6$lcssa = $list$0$i$i$i6;
       break;
      } else {
       $list$0$i$i$i6 = $$0$i$i$i$i7;
      }
     }
     $$neg$i$i$i$i8 = $list$0$i$i$i6$lcssa ^ -1;
     $31 = (($19) + ($$neg$i$i$i$i8))|0;
     $ispos$i$i$i$i9 = ($31|0)>(-1);
     $neg$i$i$i$i10 = (0 - ($31))|0;
     $32 = $ispos$i$i$i$i9 ? $31 : $neg$i$i$i$i10;
     $33 = ($32|0)>(131071);
     if ($33) {
      $34 = ((($fs)) + 8|0);
      $35 = HEAP32[$34>>2]|0;
      _luaX_syntaxerror($35,4928);
      // unreachable;
     } else {
      $36 = $$lcssa57 & 16383;
      $37 = $31 << 14;
      $38 = (($37) + 2147467264)|0;
      $39 = $38 | $36;
      HEAP32[$$lcssa56>>2] = $39;
      $pc$0 = $20;
      label = 29;
      break;
     }
    } else {
     label = 12;
    }
   } else {
    label = 12;
   }
   if ((label|0) == 12) {
    $40 = ((($fs)) + 44|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = $41&255;
    $43 = (($42) + 1)|0;
    $44 = HEAP32[$fs>>2]|0;
    $45 = ((($44)) + 8|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = $46&255;
    $48 = ($43>>>0)>($47>>>0);
    do {
     if ($48) {
      $49 = ($43>>>0)>(249);
      if ($49) {
       $50 = ((($fs)) + 8|0);
       $51 = HEAP32[$50>>2]|0;
       _luaX_syntaxerror($51,4960);
       // unreachable;
      } else {
       $52 = $43&255;
       HEAP8[$45>>0] = $52;
       $$pre$phi$i$iZ2D = $52;
       break;
      }
     } else {
      $$pre$i$i = $43&255;
      $$pre$phi$i$iZ2D = $$pre$i$i;
     }
    } while(0);
    HEAP8[$40>>0] = $$pre$phi$i$iZ2D;
    $53 = $$pre$phi$i$iZ2D&255;
    $54 = (($53) + -1)|0;
    _discharge2reg($fs,$e,$54);
    $$pr = HEAP32[$e>>2]|0;
    $55 = ($$pr|0)==(7);
    if ($55) {
     label = 19;
    } else {
     $$pre = HEAP32[$3>>2]|0;
     $67 = $$pre;
    }
   }
   if ((label|0) == 19) {
    $56 = HEAP32[$3>>2]|0;
    $57 = $56 & 256;
    $58 = ($57|0)==(0);
    if ($58) {
     $59 = ((($fs)) + 42|0);
     $60 = HEAP8[$59>>0]|0;
     $61 = $60&255;
     $62 = ($61|0)>($56|0);
     if ($62) {
      $67 = $56;
     } else {
      $63 = ((($fs)) + 44|0);
      $64 = HEAP8[$63>>0]|0;
      $65 = (($64) + -1)<<24>>24;
      HEAP8[$63>>0] = $65;
      $67 = $56;
     }
    } else {
     $67 = $56;
    }
   }
   $66 = $67 << 23;
   $68 = $66 | 32739;
   (_luaK_code($fs,$68)|0);
   $69 = ((($fs)) + 24|0);
   $70 = HEAP32[$69>>2]|0;
   HEAP32[$69>>2] = -1;
   $71 = (_luaK_code($fs,2147450910)|0);
   $72 = ($70|0)==(-1);
   if ($72) {
    $pc$0 = $71;
    label = 29;
   } else {
    $73 = ($71|0)==(-1);
    if ($73) {
     $pc$013 = $70;
     label = 30;
    } else {
     $fs$idx$val$i$i$i = HEAP32[$fs>>2]|0;
     $fs$idx$val$idx$i$i$i = ((($fs$idx$val$i$i$i)) + 48|0);
     $fs$idx$val$idx$val$i$i$i = HEAP32[$fs$idx$val$idx$i$i$i>>2]|0;
     $list$0$i$i$i = $71;
     while(1) {
      $74 = (($fs$idx$val$idx$val$i$i$i) + ($list$0$i$i$i<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = $75 >>> 14;
      $77 = (($76) + -131071)|0;
      $78 = ($77|0)==(-1);
      $79 = (($list$0$i$i$i) + 1)|0;
      $80 = (($79) + ($77))|0;
      $$0$i$i$i$i = $78 ? -1 : $80;
      $81 = ($$0$i$i$i$i|0)==(-1);
      if ($81) {
       $$lcssa54 = $74;$$lcssa55 = $75;$list$0$i$i$i$lcssa = $list$0$i$i$i;
       break;
      } else {
       $list$0$i$i$i = $$0$i$i$i$i;
      }
     }
     $$neg$i$i$i$i = $list$0$i$i$i$lcssa ^ -1;
     $82 = (($70) + ($$neg$i$i$i$i))|0;
     $ispos$i$i$i$i = ($82|0)>(-1);
     $neg$i$i$i$i = (0 - ($82))|0;
     $83 = $ispos$i$i$i$i ? $82 : $neg$i$i$i$i;
     $84 = ($83|0)>(131071);
     if ($84) {
      $85 = ((($fs)) + 8|0);
      $86 = HEAP32[$85>>2]|0;
      _luaX_syntaxerror($86,4928);
      // unreachable;
     } else {
      $87 = $$lcssa55 & 16383;
      $88 = $82 << 14;
      $89 = (($88) + 2147467264)|0;
      $90 = $89 | $87;
      HEAP32[$$lcssa54>>2] = $90;
      $pc$0 = $71;
      label = 29;
      break;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 29) {
  $91 = ($pc$0|0)==(-1);
  if (!($91)) {
   $pc$013 = $pc$0;
   label = 30;
  }
 }
 do {
  if ((label|0) == 30) {
   $92 = ((($e)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(-1);
   if ($94) {
    HEAP32[$92>>2] = $pc$013;
    break;
   }
   $fs$idx$val$i = HEAP32[$fs>>2]|0;
   $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
   $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
   $list$0$i = $93;
   while(1) {
    $95 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = $96 >>> 14;
    $98 = (($97) + -131071)|0;
    $99 = ($98|0)==(-1);
    $100 = (($list$0$i) + 1)|0;
    $101 = (($100) + ($98))|0;
    $$0$i$i = $99 ? -1 : $101;
    $102 = ($$0$i$i|0)==(-1);
    if ($102) {
     $$lcssa52 = $95;$$lcssa53 = $96;$list$0$i$lcssa = $list$0$i;
     break;
    } else {
     $list$0$i = $$0$i$i;
    }
   }
   $$neg$i$i = $list$0$i$lcssa ^ -1;
   $103 = (($pc$013) + ($$neg$i$i))|0;
   $ispos$i$i = ($103|0)>(-1);
   $neg$i$i = (0 - ($103))|0;
   $104 = $ispos$i$i ? $103 : $neg$i$i;
   $105 = ($104|0)>(131071);
   if ($105) {
    $106 = ((($fs)) + 8|0);
    $107 = HEAP32[$106>>2]|0;
    _luaX_syntaxerror($107,4928);
    // unreachable;
   } else {
    $108 = $$lcssa53 & 16383;
    $109 = $103 << 14;
    $110 = (($109) + 2147467264)|0;
    $111 = $110 | $108;
    HEAP32[$$lcssa52>>2] = $111;
    break;
   }
  }
 } while(0);
 $112 = ((($e)) + 20|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = ((($fs)) + 16|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ((($fs)) + 20|0);
 HEAP32[$116>>2] = $115;
 $117 = ((($fs)) + 24|0);
 $118 = ($113|0)==(-1);
 if ($118) {
  HEAP32[$112>>2] = -1;
  return;
 }
 $119 = HEAP32[$117>>2]|0;
 $120 = ($119|0)==(-1);
 if ($120) {
  HEAP32[$117>>2] = $113;
  HEAP32[$112>>2] = -1;
  return;
 }
 $fs$idx$val$i$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i$i = ((($fs$idx$val$i$i)) + 48|0);
 $fs$idx$val$idx$val$i$i = HEAP32[$fs$idx$val$idx$i$i>>2]|0;
 $list$0$i$i = $119;
 while(1) {
  $121 = (($fs$idx$val$idx$val$i$i) + ($list$0$i$i<<2)|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = $122 >>> 14;
  $124 = (($123) + -131071)|0;
  $125 = ($124|0)==(-1);
  $126 = (($list$0$i$i) + 1)|0;
  $127 = (($126) + ($124))|0;
  $$0$i$i$i = $125 ? -1 : $127;
  $128 = ($$0$i$i$i|0)==(-1);
  if ($128) {
   $$lcssa = $121;$$lcssa51 = $122;$list$0$i$i$lcssa = $list$0$i$i;
   break;
  } else {
   $list$0$i$i = $$0$i$i$i;
  }
 }
 $$neg$i$i$i = $list$0$i$i$lcssa ^ -1;
 $129 = (($113) + ($$neg$i$i$i))|0;
 $ispos$i$i$i = ($129|0)>(-1);
 $neg$i$i$i = (0 - ($129))|0;
 $130 = $ispos$i$i$i ? $129 : $neg$i$i$i;
 $131 = ($130|0)>(131071);
 if ($131) {
  $132 = ((($fs)) + 8|0);
  $133 = HEAP32[$132>>2]|0;
  _luaX_syntaxerror($133,4928);
  // unreachable;
 }
 $134 = $$lcssa51 & 16383;
 $135 = $129 << 14;
 $136 = (($135) + 2147467264)|0;
 $137 = $136 | $134;
 HEAP32[$$lcssa>>2] = $137;
 HEAP32[$112>>2] = -1;
 return;
}
function _luaK_indexed($fs,$t,$k) {
 $fs = $fs|0;
 $t = $t|0;
 $k = $k|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($t)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1&255;
 $3 = ((($0)) + 2|0);
 HEAP8[$3>>0] = $2;
 $4 = (_luaK_exp2RK($fs,$k)|0);
 $5 = $4&65535;
 HEAP16[$0>>1] = $5;
 $6 = HEAP32[$t>>2]|0;
 $7 = ($6|0)==(9);
 $8 = $7 ? 9 : 8;
 $9 = ((($0)) + 3|0);
 HEAP8[$9>>0] = $8;
 HEAP32[$t>>2] = 10;
 return;
}
function _luaK_prefix($fs,$op,$e,$line) {
 $fs = $fs|0;
 $op = $op|0;
 $e = $e|0;
 $line = $line|0;
 var $$$i$i = 0, $$$i11$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i9$i = 0, $$03$i$i = 0, $$03$i6$i = 0, $$phi$trans$insert$i = 0, $$pr$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i14$i = 0, $$pre$i$i8$i = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi17$iZ2D = 0, $$pre16$i = 0, $$sum$i$i$i = 0, $$sum$i$i$i$i = 0, $$sum$i$i$i7$i = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $e2 = 0, $fs$idx$val$i = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$val$i = 0, $fs$idx1$val$idx$phi$trans$insert$i$i = 0, $fs$idx1$val$idx$phi$trans$insert$i3$i = 0, $fs$idx1$val$idx$val$pre$i$i = 0, $fs$idx1$val$idx$val$pre$i4$i = 0, $fs$idx1$val$pre$i$i = 0, $fs$idx1$val$pre$i2$i = 0, $phitmp$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $e2 = sp;
 $0 = ((($e2)) + 20|0);
 HEAP32[$0>>2] = -1;
 $1 = ((($e2)) + 16|0);
 HEAP32[$1>>2] = -1;
 HEAP32[$e2>>2] = 6;
 $2 = ((($e2)) + 8|0);
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 if ((($op|0) == 3) | (($op|0) == 1) | (($op|0) == 0)) {
  $7 = (($op) + 25)|0;
  _codeexpval($fs,$7,$e,$e2,$line);
  STACKTOP = sp;return;
 } else if ((($op|0) == 2)) {
  _luaK_dischargevars($fs,$e);
  $8 = HEAP32[$e>>2]|0;
  switch ($8|0) {
  case 7:  {
   label = 17;
   break;
  }
  case 11:  {
   $fs$idx$val$i = HEAP32[$fs>>2]|0;
   $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
   $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
   $9 = ((($e)) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($fs$idx$val$idx$val$i) + ($10<<2)|0);
   $12 = ($10|0)>(0);
   if ($12) {
    $$sum$i$i$i = (($10) + -1)|0;
    $13 = (($fs$idx$val$idx$val$i) + ($$sum$i$i$i<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14 & 63;
    $16 = (2360 + ($15)|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($17<<24>>24)<(0);
    if ($18) {
     $$0$i$i$i = $13;$20 = $14;
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
   if ((label|0) == 8) {
    $$pre$i$i = HEAP32[$11>>2]|0;
    $$0$i$i$i = $11;$20 = $$pre$i$i;
   }
   $19 = $20 & -16321;
   $21 = $20 & 16320;
   $22 = ($21|0)==(0);
   $23 = $22&1;
   $24 = $23 << 6;
   $25 = $24 | $19;
   HEAP32[$$0$i$i$i>>2] = $25;
   break;
  }
  case 2: case 6: case 5: case 4:  {
   HEAP32[$e>>2] = 3;
   break;
  }
  case 3: case 1:  {
   HEAP32[$e>>2] = 2;
   break;
  }
  case 12:  {
   $26 = ((($fs)) + 44|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27&255;
   $29 = (($28) + 1)|0;
   $30 = HEAP32[$fs>>2]|0;
   $31 = ((($30)) + 8|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = $32&255;
   $34 = ($29>>>0)>($33>>>0);
   do {
    if ($34) {
     $35 = ($29>>>0)>(249);
     if ($35) {
      $36 = ((($fs)) + 8|0);
      $37 = HEAP32[$36>>2]|0;
      _luaX_syntaxerror($37,4960);
      // unreachable;
     } else {
      $38 = $29&255;
      HEAP8[$31>>0] = $38;
      $$pre$phi$i$i$iZ2D = $38;
      break;
     }
    } else {
     $$pre$i$i14$i = $29&255;
     $$pre$phi$i$i$iZ2D = $$pre$i$i14$i;
    }
   } while(0);
   HEAP8[$26>>0] = $$pre$phi$i$i$iZ2D;
   $39 = $$pre$phi$i$i$iZ2D&255;
   $40 = (($39) + -1)|0;
   _discharge2reg($fs,$e,$40);
   $$pre$i = HEAP32[$e>>2]|0;
   $phitmp$i = ($$pre$i|0)==(7);
   if ($phitmp$i) {
    label = 17;
   } else {
    $$phi$trans$insert$i = ((($e)) + 8|0);
    $$pre16$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$pre$phi17$iZ2D = $$phi$trans$insert$i;$53 = $$pre16$i;
    label = 20;
   }
   break;
  }
  default: {
  }
  }
  if ((label|0) == 17) {
   $41 = ((($e)) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = $42 & 256;
   $44 = ($43|0)==(0);
   if ($44) {
    $45 = ((($fs)) + 42|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = $46&255;
    $48 = ($47|0)>($42|0);
    if ($48) {
     $$pre$phi17$iZ2D = $41;$53 = $42;
     label = 20;
    } else {
     $49 = ((($fs)) + 44|0);
     $50 = HEAP8[$49>>0]|0;
     $51 = (($50) + -1)<<24>>24;
     HEAP8[$49>>0] = $51;
     $$pre$phi17$iZ2D = $41;$53 = $42;
     label = 20;
    }
   } else {
    $$pre$phi17$iZ2D = $41;$53 = $42;
    label = 20;
   }
  }
  if ((label|0) == 20) {
   $52 = $53 << 23;
   $54 = $52 | 27;
   $55 = (_luaK_code($fs,$54)|0);
   HEAP32[$$pre$phi17$iZ2D>>2] = $55;
   HEAP32[$e>>2] = 12;
  }
  $56 = ((($e)) + 20|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ((($e)) + 16|0);
  $59 = HEAP32[$58>>2]|0;
  HEAP32[$56>>2] = $59;
  HEAP32[$58>>2] = $57;
  $60 = ($59|0)==(-1);
  if ($60) {
   $85 = $57;
  } else {
   $fs$idx1$val$pre$i2$i = HEAP32[$fs>>2]|0;
   $fs$idx1$val$idx$phi$trans$insert$i3$i = ((($fs$idx1$val$pre$i2$i)) + 48|0);
   $fs$idx1$val$idx$val$pre$i4$i = HEAP32[$fs$idx1$val$idx$phi$trans$insert$i3$i>>2]|0;
   $$03$i6$i = $59;
   while(1) {
    $61 = (($fs$idx1$val$idx$val$pre$i4$i) + ($$03$i6$i<<2)|0);
    $62 = ($$03$i6$i|0)>(0);
    if ($62) {
     $$sum$i$i$i7$i = (($$03$i6$i) + -1)|0;
     $63 = (($fs$idx1$val$idx$val$pre$i4$i) + ($$sum$i$i$i7$i<<2)|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = $64 & 63;
     $66 = (2360 + ($65)|0);
     $67 = HEAP8[$66>>0]|0;
     $68 = ($67<<24>>24)<(0);
     if ($68) {
      $$0$i$i$i9$i = $63;$70 = $64;
     } else {
      label = 25;
     }
    } else {
     label = 25;
    }
    if ((label|0) == 25) {
     label = 0;
     $$pre$i$i8$i = HEAP32[$61>>2]|0;
     $$0$i$i$i9$i = $61;$70 = $$pre$i$i8$i;
    }
    $69 = $70 & 63;
    $71 = ($69|0)==(35);
    if ($71) {
     $72 = $70 >>> 23;
     $73 = $72 << 6;
     $74 = $70 & 8372224;
     $75 = $74 | $73;
     $76 = $75 | 34;
     HEAP32[$$0$i$i$i9$i>>2] = $76;
    }
    $77 = HEAP32[$61>>2]|0;
    $78 = $77 >>> 14;
    $79 = (($78) + -131071)|0;
    $80 = ($79|0)==(-1);
    $81 = (($$03$i6$i) + 1)|0;
    $82 = (($81) + ($79))|0;
    $$$i11$i = $80 ? -1 : $82;
    $83 = ($$$i11$i|0)==(-1);
    if ($83) {
     break;
    } else {
     $$03$i6$i = $$$i11$i;
    }
   }
   $$pr$i = HEAP32[$58>>2]|0;
   $85 = $$pr$i;
  }
  $84 = ($85|0)==(-1);
  if ($84) {
   STACKTOP = sp;return;
  }
  $fs$idx1$val$pre$i$i = HEAP32[$fs>>2]|0;
  $fs$idx1$val$idx$phi$trans$insert$i$i = ((($fs$idx1$val$pre$i$i)) + 48|0);
  $fs$idx1$val$idx$val$pre$i$i = HEAP32[$fs$idx1$val$idx$phi$trans$insert$i$i>>2]|0;
  $$03$i$i = $85;
  while(1) {
   $86 = (($fs$idx1$val$idx$val$pre$i$i) + ($$03$i$i<<2)|0);
   $87 = ($$03$i$i|0)>(0);
   if ($87) {
    $$sum$i$i$i$i = (($$03$i$i) + -1)|0;
    $88 = (($fs$idx1$val$idx$val$pre$i$i) + ($$sum$i$i$i$i<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = $89 & 63;
    $91 = (2360 + ($90)|0);
    $92 = HEAP8[$91>>0]|0;
    $93 = ($92<<24>>24)<(0);
    if ($93) {
     $$0$i$i$i$i = $88;$95 = $89;
    } else {
     label = 34;
    }
   } else {
    label = 34;
   }
   if ((label|0) == 34) {
    label = 0;
    $$pre$i$i$i = HEAP32[$86>>2]|0;
    $$0$i$i$i$i = $86;$95 = $$pre$i$i$i;
   }
   $94 = $95 & 63;
   $96 = ($94|0)==(35);
   if ($96) {
    $97 = $95 >>> 23;
    $98 = $97 << 6;
    $99 = $95 & 8372224;
    $100 = $99 | $98;
    $101 = $100 | 34;
    HEAP32[$$0$i$i$i$i>>2] = $101;
   }
   $102 = HEAP32[$86>>2]|0;
   $103 = $102 >>> 14;
   $104 = (($103) + -131071)|0;
   $105 = ($104|0)==(-1);
   $106 = (($$03$i$i) + 1)|0;
   $107 = (($106) + ($104))|0;
   $$$i$i = $105 ? -1 : $107;
   $108 = ($$$i$i|0)==(-1);
   if ($108) {
    break;
   } else {
    $$03$i$i = $$$i$i;
   }
  }
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function _luaK_infix($fs,$op,$v) {
 $fs = $fs|0;
 $op = $op|0;
 $v = $v|0;
 var $$off = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $switch = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 switch ($op|0) {
 case 19:  {
  _luaK_goiftrue($fs,$v);
  return;
  break;
 }
 case 20:  {
  _luaK_goiffalse($fs,$v);
  return;
  break;
 }
 case 12:  {
  _luaK_dischargevars($fs,$v);
  $0 = HEAP32[$v>>2]|0;
  $1 = ($0|0)==(7);
  if ($1) {
   $2 = ((($v)) + 8|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = $3 & 256;
   $5 = ($4|0)==(0);
   if ($5) {
    $6 = ((($fs)) + 42|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = $7&255;
    $9 = ($8|0)>($3|0);
    if (!($9)) {
     $10 = ((($fs)) + 44|0);
     $11 = HEAP8[$10>>0]|0;
     $12 = (($11) + -1)<<24>>24;
     HEAP8[$10>>0] = $12;
    }
   }
  }
  $13 = ((($fs)) + 44|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14&255;
  $16 = (($15) + 1)|0;
  $17 = HEAP32[$fs>>2]|0;
  $18 = ((($17)) + 8|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = $19&255;
  $21 = ($16>>>0)>($20>>>0);
  do {
   if ($21) {
    $22 = ($16>>>0)>(249);
    if ($22) {
     $23 = ((($fs)) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     _luaX_syntaxerror($24,4960);
     // unreachable;
    } else {
     $25 = $16&255;
     HEAP8[$18>>0] = $25;
     $$pre$phi$i$iZ2D = $25;
     break;
    }
   } else {
    $$pre$i$i = $16&255;
    $$pre$phi$i$iZ2D = $$pre$i$i;
   }
  } while(0);
  HEAP8[$13>>0] = $$pre$phi$i$iZ2D;
  $26 = $$pre$phi$i$iZ2D&255;
  $27 = (($26) + -1)|0;
  _exp2reg($fs,$v,$27);
  return;
  break;
 }
 case 11: case 10: case 9: case 8: case 7: case 4: case 3: case 6: case 5: case 2: case 1: case 0:  {
  $28 = ((($v)) + 16|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(-1);
  if ($30) {
   $31 = ((($v)) + 20|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(-1);
   if ($33) {
    $34 = HEAP32[$v>>2]|0;
    $$off = (($34) + -5)|0;
    $switch = ($$off>>>0)<(2);
    if ($switch) {
     return;
    }
   }
  }
  (_luaK_exp2RK($fs,$v)|0);
  return;
  break;
 }
 default: {
  (_luaK_exp2RK($fs,$v)|0);
  return;
 }
 }
}
function _luaK_posfix($fs,$op,$e1,$e2,$line) {
 $fs = $fs|0;
 $op = $op|0;
 $e1 = $e1|0;
 $e2 = $e2|0;
 $line = $line|0;
 var $$0$i$i = 0, $$0$i$i7 = 0, $$lcssa = 0, $$lcssa31 = 0, $$lcssa32 = 0, $$lcssa33 = 0, $$neg$i$i = 0, $$neg$i$i8 = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $fs$idx$val$i = 0, $fs$idx$val$i2 = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$i3 = 0, $fs$idx$val$idx$val$i = 0, $fs$idx$val$idx$val$i4 = 0, $ispos$i$i = 0, $ispos$i$i9 = 0, $list$0$i = 0, $list$0$i$lcssa = 0, $list$0$i6 = 0, $list$0$i6$lcssa = 0, $neg$i$i = 0, $neg$i$i10 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($op|0) {
 case 19:  {
  _luaK_dischargevars($fs,$e2);
  $0 = ((($e2)) + 20|0);
  $1 = ((($e1)) + 20|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(-1);
  do {
   if (!($3)) {
    $4 = HEAP32[$0>>2]|0;
    $5 = ($4|0)==(-1);
    if ($5) {
     HEAP32[$0>>2] = $2;
     break;
    }
    $fs$idx$val$i = HEAP32[$fs>>2]|0;
    $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
    $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
    $list$0$i = $4;
    while(1) {
     $6 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
     $7 = HEAP32[$6>>2]|0;
     $8 = $7 >>> 14;
     $9 = (($8) + -131071)|0;
     $10 = ($9|0)==(-1);
     $11 = (($list$0$i) + 1)|0;
     $12 = (($11) + ($9))|0;
     $$0$i$i = $10 ? -1 : $12;
     $13 = ($$0$i$i|0)==(-1);
     if ($13) {
      $$lcssa = $6;$$lcssa31 = $7;$list$0$i$lcssa = $list$0$i;
      break;
     } else {
      $list$0$i = $$0$i$i;
     }
    }
    $$neg$i$i = $list$0$i$lcssa ^ -1;
    $14 = (($2) + ($$neg$i$i))|0;
    $ispos$i$i = ($14|0)>(-1);
    $neg$i$i = (0 - ($14))|0;
    $15 = $ispos$i$i ? $14 : $neg$i$i;
    $16 = ($15|0)>(131071);
    if ($16) {
     $17 = ((($fs)) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     _luaX_syntaxerror($18,4928);
     // unreachable;
    } else {
     $19 = $$lcssa31 & 16383;
     $20 = $14 << 14;
     $21 = (($20) + 2147467264)|0;
     $22 = $21 | $19;
     HEAP32[$$lcssa>>2] = $22;
     break;
    }
   }
  } while(0);
  ;HEAP32[$e1>>2]=HEAP32[$e2>>2]|0;HEAP32[$e1+4>>2]=HEAP32[$e2+4>>2]|0;HEAP32[$e1+8>>2]=HEAP32[$e2+8>>2]|0;HEAP32[$e1+12>>2]=HEAP32[$e2+12>>2]|0;HEAP32[$e1+16>>2]=HEAP32[$e2+16>>2]|0;HEAP32[$e1+20>>2]=HEAP32[$e2+20>>2]|0;
  return;
  break;
 }
 case 11: case 10: case 9: case 8: case 7: case 4: case 3: case 6: case 5: case 2: case 1: case 0:  {
  $107 = (($op) + 13)|0;
  _codeexpval($fs,$107,$e1,$e2,$line);
  return;
  break;
 }
 case 12:  {
  $46 = ((($e2)) + 16|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ((($e2)) + 20|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($47|0)==($49|0);
  if ($50) {
   _luaK_dischargevars($fs,$e2);
  } else {
   (_luaK_exp2anyreg($fs,$e2)|0);
  }
  $51 = HEAP32[$e2>>2]|0;
  $52 = ($51|0)==(12);
  if ($52) {
   $53 = ((($e2)) + 8|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = HEAP32[$fs>>2]|0;
   $56 = ((($55)) + 48|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + ($54<<2)|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = $59 & 63;
   $61 = ($60|0)==(29);
   if ($61) {
    $62 = HEAP32[$e1>>2]|0;
    $63 = ($62|0)==(7);
    $64 = ((($e1)) + 8|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = $65 & 256;
    $67 = ($66|0)==(0);
    $or$cond = $63 & $67;
    if ($or$cond) {
     $68 = ((($fs)) + 42|0);
     $69 = HEAP8[$68>>0]|0;
     $70 = $69&255;
     $71 = ($70|0)>($65|0);
     if (!($71)) {
      $72 = ((($fs)) + 44|0);
      $73 = HEAP8[$72>>0]|0;
      $74 = (($73) + -1)<<24>>24;
      HEAP8[$72>>0] = $74;
     }
    }
    $75 = $59 & 8388607;
    $76 = $65 << 23;
    $77 = $76 | $75;
    HEAP32[$58>>2] = $77;
    HEAP32[$e1>>2] = 12;
    $78 = HEAP32[$53>>2]|0;
    HEAP32[$64>>2] = $78;
    return;
   }
  }
  _luaK_dischargevars($fs,$e2);
  $79 = HEAP32[$e2>>2]|0;
  $80 = ($79|0)==(7);
  if ($80) {
   $81 = ((($e2)) + 8|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = $82 & 256;
   $84 = ($83|0)==(0);
   if ($84) {
    $85 = ((($fs)) + 42|0);
    $86 = HEAP8[$85>>0]|0;
    $87 = $86&255;
    $88 = ($87|0)>($82|0);
    if (!($88)) {
     $89 = ((($fs)) + 44|0);
     $90 = HEAP8[$89>>0]|0;
     $91 = (($90) + -1)<<24>>24;
     HEAP8[$89>>0] = $91;
    }
   }
  }
  $92 = ((($fs)) + 44|0);
  $93 = HEAP8[$92>>0]|0;
  $94 = $93&255;
  $95 = (($94) + 1)|0;
  $96 = HEAP32[$fs>>2]|0;
  $97 = ((($96)) + 8|0);
  $98 = HEAP8[$97>>0]|0;
  $99 = $98&255;
  $100 = ($95>>>0)>($99>>>0);
  do {
   if ($100) {
    $101 = ($95>>>0)>(249);
    if ($101) {
     $102 = ((($fs)) + 8|0);
     $103 = HEAP32[$102>>2]|0;
     _luaX_syntaxerror($103,4960);
     // unreachable;
    } else {
     $104 = $95&255;
     HEAP8[$97>>0] = $104;
     $$pre$phi$i$iZ2D = $104;
     break;
    }
   } else {
    $$pre$i$i = $95&255;
    $$pre$phi$i$iZ2D = $$pre$i$i;
   }
  } while(0);
  HEAP8[$92>>0] = $$pre$phi$i$iZ2D;
  $105 = $$pre$phi$i$iZ2D&255;
  $106 = (($105) + -1)|0;
  _exp2reg($fs,$e2,$106);
  _codeexpval($fs,29,$e1,$e2,$line);
  return;
  break;
 }
 case 15: case 14: case 13:  {
  $108 = (($op) + 18)|0;
  _codecomp($fs,$108,1,$e1,$e2);
  return;
  break;
 }
 case 18: case 17: case 16:  {
  $109 = (($op) + 15)|0;
  _codecomp($fs,$109,0,$e1,$e2);
  return;
  break;
 }
 case 20:  {
  _luaK_dischargevars($fs,$e2);
  $23 = ((($e2)) + 16|0);
  $24 = ((($e1)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(-1);
  do {
   if (!($26)) {
    $27 = HEAP32[$23>>2]|0;
    $28 = ($27|0)==(-1);
    if ($28) {
     HEAP32[$23>>2] = $25;
     break;
    }
    $fs$idx$val$i2 = HEAP32[$fs>>2]|0;
    $fs$idx$val$idx$i3 = ((($fs$idx$val$i2)) + 48|0);
    $fs$idx$val$idx$val$i4 = HEAP32[$fs$idx$val$idx$i3>>2]|0;
    $list$0$i6 = $27;
    while(1) {
     $29 = (($fs$idx$val$idx$val$i4) + ($list$0$i6<<2)|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = $30 >>> 14;
     $32 = (($31) + -131071)|0;
     $33 = ($32|0)==(-1);
     $34 = (($list$0$i6) + 1)|0;
     $35 = (($34) + ($32))|0;
     $$0$i$i7 = $33 ? -1 : $35;
     $36 = ($$0$i$i7|0)==(-1);
     if ($36) {
      $$lcssa32 = $29;$$lcssa33 = $30;$list$0$i6$lcssa = $list$0$i6;
      break;
     } else {
      $list$0$i6 = $$0$i$i7;
     }
    }
    $$neg$i$i8 = $list$0$i6$lcssa ^ -1;
    $37 = (($25) + ($$neg$i$i8))|0;
    $ispos$i$i9 = ($37|0)>(-1);
    $neg$i$i10 = (0 - ($37))|0;
    $38 = $ispos$i$i9 ? $37 : $neg$i$i10;
    $39 = ($38|0)>(131071);
    if ($39) {
     $40 = ((($fs)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     _luaX_syntaxerror($41,4928);
     // unreachable;
    } else {
     $42 = $$lcssa33 & 16383;
     $43 = $37 << 14;
     $44 = (($43) + 2147467264)|0;
     $45 = $44 | $42;
     HEAP32[$$lcssa32>>2] = $45;
     break;
    }
   }
  } while(0);
  ;HEAP32[$e1>>2]=HEAP32[$e2>>2]|0;HEAP32[$e1+4>>2]=HEAP32[$e2+4>>2]|0;HEAP32[$e1+8>>2]=HEAP32[$e2+8>>2]|0;HEAP32[$e1+12>>2]=HEAP32[$e2+12>>2]|0;HEAP32[$e1+16>>2]=HEAP32[$e2+16>>2]|0;HEAP32[$e1+20>>2]=HEAP32[$e2+20>>2]|0;
  return;
  break;
 }
 default: {
  return;
 }
 }
}
function _luaK_fixline($fs,$line) {
 $fs = $fs|0;
 $line = $line|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = HEAP32[$fs>>2]|0;
 $4 = ((($3)) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 HEAP32[$6>>2] = $line;
 return;
}
function _luaK_setlist($fs,$base,$nelems,$tostore) {
 $fs = $fs|0;
 $base = $base|0;
 $nelems = $nelems|0;
 $tostore = $tostore|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($nelems) + -1)|0;
 $1 = (($0|0) / 50)&-1;
 $2 = (($1) + 1)|0;
 $3 = ($tostore|0)==(-1);
 $4 = $3 ? 0 : $tostore;
 $5 = ($2|0)<(512);
 if ($5) {
  $6 = $base << 6;
  $7 = $4 << 23;
  $8 = $2 << 14;
  $9 = $6 | $7;
  $10 = $9 | $8;
  $11 = $10 | 43;
  (_luaK_code($fs,$11)|0);
  $21 = (($base) + 1)|0;
  $22 = $21&255;
  $23 = ((($fs)) + 44|0);
  HEAP8[$23>>0] = $22;
  return;
 }
 $12 = ($2|0)<(67108864);
 if (!($12)) {
  $19 = ((($fs)) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  _luaX_syntaxerror($20,5000);
  // unreachable;
 }
 $13 = $base << 6;
 $14 = $4 << 23;
 $15 = $13 | $14;
 $16 = $15 | 43;
 (_luaK_code($fs,$16)|0);
 $17 = $2 << 6;
 $18 = $17 | 46;
 (_luaK_code($fs,$18)|0);
 $21 = (($base) + 1)|0;
 $22 = $21&255;
 $23 = ((($fs)) + 44|0);
 HEAP8[$23>>0] = $22;
 return;
}
function _luaK_code($fs,$i) {
 $fs = $fs|0;
 $i = $i|0;
 var $$0$i$i$i = 0, $$0$i$i1$i = 0, $$02$i$i = 0, $$neg$i$i = 0, $$neg$i$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phi7Z2D = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $$pre6 = 0, $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $fs$idx$val$idx$i$phi$trans$insert$i = 0, $fs$idx$val$idx$val$i$pre$i = 0, $ispos$i$i = 0, $ispos$i$i$i = 0, $neg$i$i = 0, $neg$i$i$i = 0;
 var $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$fs>>2]|0;
 $1 = ((($fs)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($fs)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==(-1);
 do {
  if ($5) {
   $51 = $4;
  } else {
   $fs$idx$val$idx$i$phi$trans$insert$i = ((($0)) + 48|0);
   $fs$idx$val$idx$val$i$pre$i = HEAP32[$fs$idx$val$idx$i$phi$trans$insert$i>>2]|0;
   $$02$i$i = $2;
   while(1) {
    $6 = (($fs$idx$val$idx$val$i$pre$i) + ($$02$i$i<<2)|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = $7 >>> 14;
    $9 = (($8) + -131071)|0;
    $10 = ($9|0)==(-1);
    $11 = (($$02$i$i) + 1)|0;
    $12 = (($11) + ($9))|0;
    $$0$i$i$i = $10 ? -1 : $12;
    $13 = ($$02$i$i|0)>(0);
    if ($13) {
     $$sum$i$i$i = (($$02$i$i) + -1)|0;
     $14 = (($fs$idx$val$idx$val$i$pre$i) + ($$sum$i$i$i<<2)|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = $15 & 63;
     $17 = (2360 + ($16)|0);
     $18 = HEAP8[$17>>0]|0;
     $19 = ($18<<24>>24)<(0);
     if ($19) {
      $$0$i$i1$i = $14;$21 = $15;
     } else {
      label = 5;
     }
    } else {
     label = 5;
    }
    if ((label|0) == 5) {
     label = 0;
     $$0$i$i1$i = $6;$21 = $7;
    }
    $20 = $21 & 63;
    $22 = ($20|0)==(35);
    if ($22) {
     $23 = $21 >>> 23;
     $24 = $23 << 6;
     $25 = $21 & 8372224;
     $26 = $25 | $24;
     $27 = $26 | 34;
     HEAP32[$$0$i$i1$i>>2] = $27;
     $$neg$i$i = $$02$i$i ^ -1;
     $28 = (($4) + ($$neg$i$i))|0;
     $ispos$i$i = ($28|0)>(-1);
     $neg$i$i = (0 - ($28))|0;
     $29 = $ispos$i$i ? $28 : $neg$i$i;
     $30 = ($29|0)>(131071);
     if ($30) {
      label = 8;
      break;
     }
     $33 = HEAP32[$6>>2]|0;
     $34 = $33 & 16383;
     $35 = $28 << 14;
     $36 = (($35) + 2147467264)|0;
     $37 = $34 | $36;
     $storemerge$i = $37;
    } else {
     $$neg$i$i$i = $$02$i$i ^ -1;
     $38 = (($4) + ($$neg$i$i$i))|0;
     $ispos$i$i$i = ($38|0)>(-1);
     $neg$i$i$i = (0 - ($38))|0;
     $39 = $ispos$i$i$i ? $38 : $neg$i$i$i;
     $40 = ($39|0)>(131071);
     if ($40) {
      label = 11;
      break;
     }
     $43 = $7 & 16383;
     $44 = $38 << 14;
     $45 = (($44) + 2147467264)|0;
     $46 = $45 | $43;
     $storemerge$i = $46;
    }
    HEAP32[$6>>2] = $storemerge$i;
    $47 = ($$0$i$i$i|0)==(-1);
    if ($47) {
     label = 14;
     break;
    } else {
     $$02$i$i = $$0$i$i$i;
    }
   }
   if ((label|0) == 8) {
    $31 = ((($fs)) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    _luaX_syntaxerror($32,4928);
    // unreachable;
   }
   else if ((label|0) == 11) {
    $41 = ((($fs)) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    _luaX_syntaxerror($42,4928);
    // unreachable;
   }
   else if ((label|0) == 14) {
    $$pre = HEAP32[$3>>2]|0;
    $51 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$1>>2] = -1;
 $48 = ((($0)) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($51|0)<($49|0);
 if ($50) {
  $$phi$trans$insert = ((($0)) + 48|0);
  $$pre2 = HEAP32[$$phi$trans$insert>>2]|0;
  $60 = $$pre2;$61 = $51;
 } else {
  $52 = ((($fs)) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ((($53)) + 52|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ((($0)) + 48|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (_luaM_growaux_($55,$57,$48,4,2147483647,5040)|0);
  HEAP32[$56>>2] = $58;
  $$pre1 = HEAP32[$3>>2]|0;
  $60 = $58;$61 = $$pre1;
 }
 $59 = (($60) + ($61<<2)|0);
 HEAP32[$59>>2] = $i;
 $62 = HEAP32[$3>>2]|0;
 $63 = ((($0)) + 24|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($62|0)<($64|0);
 $$pre4 = ((($fs)) + 8|0);
 if ($65) {
  $$pre6 = ((($0)) + 56|0);
  $$pre$phi7Z2D = $$pre6;$77 = $62;
  $72 = HEAP32[$$pre4>>2]|0;
  $73 = ((($72)) + 8|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = HEAP32[$$pre$phi7Z2D>>2]|0;
  $76 = (($75) + ($77<<2)|0);
  HEAP32[$76>>2] = $74;
  $78 = HEAP32[$3>>2]|0;
  $79 = (($78) + 1)|0;
  HEAP32[$3>>2] = $79;
  return ($78|0);
 } else {
  $66 = HEAP32[$$pre4>>2]|0;
  $67 = ((($66)) + 52|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ((($0)) + 56|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (_luaM_growaux_($68,$70,$63,4,2147483647,5040)|0);
  HEAP32[$69>>2] = $71;
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre$phi7Z2D = $69;$77 = $$pre3;
  $72 = HEAP32[$$pre4>>2]|0;
  $73 = ((($72)) + 8|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = HEAP32[$$pre$phi7Z2D>>2]|0;
  $76 = (($75) + ($77<<2)|0);
  HEAP32[$76>>2] = $74;
  $78 = HEAP32[$3>>2]|0;
  $79 = (($78) + 1)|0;
  HEAP32[$3>>2] = $79;
  return ($78|0);
 }
 return (0)|0;
}
function _addk($fs,$key,$v) {
 $fs = $fs|0;
 $key = $key|0;
 $v = $v|0;
 var $$0 = 0, $$pre = 0, $$pre$phi5Z2D = 0, $$pre$phi7Z2D = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $oldsize$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$fs>>2]|0;
 $5 = ((($1)) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (_luaH_set($3,$6,$key)|0);
 $8 = ((($7)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(19);
 if ($10) {
  $11 = $7;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 4)|0;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($fs)) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($13|0)<($18|0);
  if ($19) {
   $20 = ((($4)) + 44|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (((($21) + ($13<<4)|0)) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($v)) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25 ^ $23;
   $27 = $26 & 63;
   $28 = ($27|0)==(0);
   if ($28) {
    $29 = (($21) + ($13<<4)|0);
    $30 = (_luaV_equalobj(0,$29,$v)|0);
    $31 = ($30|0)==(0);
    if ($31) {
     $$pre$phi5Z2D = $17;$$pre$phi7Z2D = $7;
    } else {
     $$0 = $13;
     return ($$0|0);
    }
   } else {
    $$pre$phi5Z2D = $17;$$pre$phi7Z2D = $7;
   }
  } else {
   $$pre$phi5Z2D = $17;$$pre$phi7Z2D = $7;
  }
 } else {
  $$pre4 = ((($fs)) + 28|0);
  $$pre$phi5Z2D = $$pre4;$$pre$phi7Z2D = $7;
 }
 $32 = ((($4)) + 16|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$$pre$phi5Z2D>>2]|0;
 $35 = ($34|0)<(0);
 $36 = $35 << 31 >> 31;
 $37 = $$pre$phi7Z2D;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 HEAP32[$8>>2] = 19;
 $41 = ($34|0)<($33|0);
 if ($41) {
  $46 = $33;
 } else {
  $42 = ((($4)) + 44|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (_luaM_growaux_($3,$43,$32,16,67108863,5024)|0);
  HEAP32[$42>>2] = $44;
  $$pre = HEAP32[$32>>2]|0;
  $46 = $$pre;
 }
 $45 = ($33|0)<($46|0);
 $47 = ((($4)) + 44|0);
 $48 = HEAP32[$47>>2]|0;
 if ($45) {
  $oldsize$01 = $33;
  while(1) {
   $49 = (($oldsize$01) + 1)|0;
   $50 = (((($48) + ($oldsize$01<<4)|0)) + 8|0);
   HEAP32[$50>>2] = 0;
   $51 = ($49|0)<($46|0);
   if ($51) {
    $oldsize$01 = $49;
   } else {
    break;
   }
  }
 }
 $52 = (($48) + ($34<<4)|0);
 ;HEAP32[$52>>2]=HEAP32[$v>>2]|0;HEAP32[$52+4>>2]=HEAP32[$v+4>>2]|0;HEAP32[$52+8>>2]=HEAP32[$v+8>>2]|0;HEAP32[$52+12>>2]=HEAP32[$v+12>>2]|0;
 $53 = HEAP32[$$pre$phi5Z2D>>2]|0;
 $54 = (($53) + 1)|0;
 HEAP32[$$pre$phi5Z2D>>2] = $54;
 $55 = ((($v)) + 8|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = $56 & 64;
 $58 = ($57|0)==(0);
 if ($58) {
  $$0 = $34;
  return ($$0|0);
 }
 $59 = ((($4)) + 5|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = $60 & 4;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $$0 = $34;
  return ($$0|0);
 }
 $63 = HEAP32[$v>>2]|0;
 $64 = ((($63)) + 5|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = $65 & 3;
 $67 = ($66<<24>>24)==(0);
 if ($67) {
  $$0 = $34;
  return ($$0|0);
 }
 _luaC_barrier_($3,$4,$63);
 $$0 = $34;
 return ($$0|0);
}
function _exp2reg($fs,$e,$reg) {
 $fs = $fs|0;
 $e = $e|0;
 $reg = $reg|0;
 var $$$i = 0, $$$i20 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i35 = 0, $$0$i$i26 = 0, $$0$i$i26$us = 0, $$0$i$i46 = 0, $$0$i$i59 = 0, $$0$i$i6 = 0, $$0$i$i6$us = 0, $$014$i = 0, $$014$i16 = 0, $$02$i = 0, $$02$i$us = 0, $$02$i42 = 0, $$lcssa = 0, $$lcssa119 = 0, $$lcssa120 = 0, $$lcssa121 = 0;
 var $$lcssa122 = 0, $$lcssa123 = 0, $$neg$i = 0, $$neg$i$i = 0, $$neg$i$i$i = 0, $$neg$i$i$i36 = 0, $$neg$i$i47 = 0, $$neg$i$i7 = 0, $$neg$i$i7$us = 0, $$neg$i$us = 0, $$neg$i53 = 0, $$pre$i = 0, $$pre$i18 = 0, $$pre88 = 0, $$sum$i$i = 0, $$sum$i$i17 = 0, $$sum$i$i24 = 0, $$sum$i$i24$us = 0, $$sum$i$i57 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $fs$idx$val$i = 0;
 var $fs$idx$val$i$i = 0, $fs$idx$val$i$i30 = 0, $fs$idx$val$i3$us$pre = 0, $fs$idx$val$i43$pre = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$i$i = 0, $fs$idx$val$idx$i$i31 = 0, $fs$idx$val$idx$i4$us$phi$trans$insert = 0, $fs$idx$val$idx$i44$phi$trans$insert = 0, $fs$idx$val$idx$val$i = 0, $fs$idx$val$idx$val$i$i = 0, $fs$idx$val$idx$val$i$i32 = 0, $fs$idx$val$idx$val$i45$pre = 0, $fs$idx$val$idx$val$i5$us$pre = 0, $fs$idx2$val$i = 0, $fs$idx2$val$i12 = 0, $fs$idx2$val$idx$i = 0, $fs$idx2$val$idx$i13 = 0, $fs$idx2$val$idx$val$i = 0, $fs$idx2$val$idx$val$i14 = 0;
 var $ispos$i = 0, $ispos$i$i = 0, $ispos$i$i$i = 0, $ispos$i$i$i37 = 0, $ispos$i$i48 = 0, $ispos$i$i8 = 0, $ispos$i$i8$us = 0, $ispos$i$us = 0, $ispos$i54 = 0, $list$0$i = 0, $list$0$i$i = 0, $list$0$i$i$lcssa = 0, $list$0$i$i34 = 0, $list$0$i$i34$lcssa = 0, $list$0$i$lcssa = 0, $neg$i = 0, $neg$i$i = 0, $neg$i$i$i = 0, $neg$i$i$i38 = 0, $neg$i$i49 = 0;
 var $neg$i$i9 = 0, $neg$i$i9$us = 0, $neg$i$us = 0, $neg$i55 = 0, $or$cond$i61 = 0, $p_f$0 = 0, $p_t$0 = 0, $storemerge = 0, $storemerge$i = 0, $storemerge$i62 = 0, $storemerge90 = 0, $storemerge91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _discharge2reg($fs,$e,$reg);
 $0 = HEAP32[$e>>2]|0;
 $1 = ($0|0)==(11);
 $2 = ((($e)) + 16|0);
 do {
  if ($1) {
   $3 = ((($e)) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(-1);
   if (!($5)) {
    $6 = HEAP32[$2>>2]|0;
    $7 = ($6|0)==(-1);
    if ($7) {
     HEAP32[$2>>2] = $4;
     break;
    }
    $fs$idx$val$i = HEAP32[$fs>>2]|0;
    $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
    $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
    $list$0$i = $6;
    while(1) {
     $8 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = $9 >>> 14;
     $11 = (($10) + -131071)|0;
     $12 = ($11|0)==(-1);
     $13 = (($list$0$i) + 1)|0;
     $14 = (($13) + ($11))|0;
     $$0$i$i = $12 ? -1 : $14;
     $15 = ($$0$i$i|0)==(-1);
     if ($15) {
      $$lcssa122 = $8;$$lcssa123 = $9;$list$0$i$lcssa = $list$0$i;
      break;
     } else {
      $list$0$i = $$0$i$i;
     }
    }
    $$neg$i$i = $list$0$i$lcssa ^ -1;
    $16 = (($4) + ($$neg$i$i))|0;
    $ispos$i$i = ($16|0)>(-1);
    $neg$i$i = (0 - ($16))|0;
    $17 = $ispos$i$i ? $16 : $neg$i$i;
    $18 = ($17|0)>(131071);
    if ($18) {
     $19 = ((($fs)) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     _luaX_syntaxerror($20,4928);
     // unreachable;
    } else {
     $21 = $$lcssa123 & 16383;
     $22 = $16 << 14;
     $23 = (($22) + 2147467264)|0;
     $24 = $23 | $21;
     HEAP32[$$lcssa122>>2] = $24;
     break;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$2>>2]|0;
 $26 = ((($e)) + 20|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($25|0)==($27|0);
 if ($28) {
  HEAP32[$2>>2] = -1;
  HEAP32[$26>>2] = -1;
  $259 = ((($e)) + 8|0);
  HEAP32[$259>>2] = $reg;
  HEAP32[$e>>2] = 7;
  return;
 }
 $29 = ($25|0)==(-1);
 L17: do {
  if ($29) {
   label = 18;
  } else {
   $fs$idx2$val$i = HEAP32[$fs>>2]|0;
   $fs$idx2$val$idx$i = ((($fs$idx2$val$i)) + 48|0);
   $fs$idx2$val$idx$val$i = HEAP32[$fs$idx2$val$idx$i>>2]|0;
   $$014$i = $25;
   while(1) {
    $30 = (($fs$idx2$val$idx$val$i) + ($$014$i<<2)|0);
    $31 = ($$014$i|0)>(0);
    if ($31) {
     $$sum$i$i = (($$014$i) + -1)|0;
     $32 = (($fs$idx2$val$idx$val$i) + ($$sum$i$i<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = $33 & 63;
     $35 = (2360 + ($34)|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = ($36<<24>>24)<(0);
     if ($37) {
      $39 = $33;
     } else {
      label = 15;
     }
    } else {
     label = 15;
    }
    if ((label|0) == 15) {
     label = 0;
     $$pre$i = HEAP32[$30>>2]|0;
     $39 = $$pre$i;
    }
    $38 = $39 & 63;
    $40 = ($38|0)==(35);
    if (!($40)) {
     label = 25;
     break L17;
    }
    $41 = HEAP32[$30>>2]|0;
    $42 = $41 >>> 14;
    $43 = (($42) + -131071)|0;
    $44 = ($43|0)==(-1);
    $45 = (($$014$i) + 1)|0;
    $46 = (($45) + ($43))|0;
    $$$i = $44 ? -1 : $46;
    $47 = ($$$i|0)==(-1);
    if ($47) {
     label = 18;
     break;
    } else {
     $$014$i = $$$i;
    }
   }
  }
 } while(0);
 L27: do {
  if ((label|0) == 18) {
   $48 = ($27|0)==(-1);
   if ($48) {
    $p_f$0 = -1;$p_t$0 = -1;
   } else {
    $fs$idx2$val$i12 = HEAP32[$fs>>2]|0;
    $fs$idx2$val$idx$i13 = ((($fs$idx2$val$i12)) + 48|0);
    $fs$idx2$val$idx$val$i14 = HEAP32[$fs$idx2$val$idx$i13>>2]|0;
    $$014$i16 = $27;
    while(1) {
     $49 = (($fs$idx2$val$idx$val$i14) + ($$014$i16<<2)|0);
     $50 = ($$014$i16|0)>(0);
     if ($50) {
      $$sum$i$i17 = (($$014$i16) + -1)|0;
      $51 = (($fs$idx2$val$idx$val$i14) + ($$sum$i$i17<<2)|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = $52 & 63;
      $54 = (2360 + ($53)|0);
      $55 = HEAP8[$54>>0]|0;
      $56 = ($55<<24>>24)<(0);
      if ($56) {
       $58 = $52;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     if ((label|0) == 22) {
      label = 0;
      $$pre$i18 = HEAP32[$49>>2]|0;
      $58 = $$pre$i18;
     }
     $57 = $58 & 63;
     $59 = ($57|0)==(35);
     if (!($59)) {
      label = 25;
      break L27;
     }
     $60 = HEAP32[$49>>2]|0;
     $61 = $60 >>> 14;
     $62 = (($61) + -131071)|0;
     $63 = ($62|0)==(-1);
     $64 = (($$014$i16) + 1)|0;
     $65 = (($64) + ($62))|0;
     $$$i20 = $63 ? -1 : $65;
     $66 = ($$$i20|0)==(-1);
     if ($66) {
      $p_f$0 = -1;$p_t$0 = -1;
      break;
     } else {
      $$014$i16 = $$$i20;
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 25) {
   $$pre88 = ((($fs)) + 24|0);
   do {
    if ($1) {
     $99 = -1;
    } else {
     $67 = HEAP32[$$pre88>>2]|0;
     HEAP32[$$pre88>>2] = -1;
     $68 = (_luaK_code($fs,2147450910)|0);
     $69 = ($67|0)==(-1);
     if ($69) {
      $99 = $68;
     } else {
      $70 = ($68|0)==(-1);
      if ($70) {
       $99 = $67;
      } else {
       $fs$idx$val$i$i = HEAP32[$fs>>2]|0;
       $fs$idx$val$idx$i$i = ((($fs$idx$val$i$i)) + 48|0);
       $fs$idx$val$idx$val$i$i = HEAP32[$fs$idx$val$idx$i$i>>2]|0;
       $list$0$i$i = $68;
       while(1) {
        $71 = (($fs$idx$val$idx$val$i$i) + ($list$0$i$i<<2)|0);
        $72 = HEAP32[$71>>2]|0;
        $73 = $72 >>> 14;
        $74 = (($73) + -131071)|0;
        $75 = ($74|0)==(-1);
        $76 = (($list$0$i$i) + 1)|0;
        $77 = (($76) + ($74))|0;
        $$0$i$i$i = $75 ? -1 : $77;
        $78 = ($$0$i$i$i|0)==(-1);
        if ($78) {
         $$lcssa120 = $71;$$lcssa121 = $72;$list$0$i$i$lcssa = $list$0$i$i;
         break;
        } else {
         $list$0$i$i = $$0$i$i$i;
        }
       }
       $$neg$i$i$i = $list$0$i$i$lcssa ^ -1;
       $79 = (($67) + ($$neg$i$i$i))|0;
       $ispos$i$i$i = ($79|0)>(-1);
       $neg$i$i$i = (0 - ($79))|0;
       $80 = $ispos$i$i$i ? $79 : $neg$i$i$i;
       $81 = ($80|0)>(131071);
       if ($81) {
        $82 = ((($fs)) + 8|0);
        $83 = HEAP32[$82>>2]|0;
        _luaX_syntaxerror($83,4928);
        // unreachable;
       } else {
        $84 = $$lcssa121 & 16383;
        $85 = $79 << 14;
        $86 = (($85) + 2147467264)|0;
        $87 = $86 | $84;
        HEAP32[$$lcssa120>>2] = $87;
        $99 = $68;
        break;
       }
      }
     }
    }
   } while(0);
   $88 = ((($fs)) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ((($fs)) + 20|0);
   HEAP32[$90>>2] = $89;
   $91 = $reg << 6;
   $92 = $91 | 16387;
   $93 = (_luaK_code($fs,$92)|0);
   $94 = HEAP32[$88>>2]|0;
   HEAP32[$90>>2] = $94;
   $95 = $91 | 8388611;
   $96 = (_luaK_code($fs,$95)|0);
   $97 = HEAP32[$88>>2]|0;
   HEAP32[$90>>2] = $97;
   $98 = ($99|0)==(-1);
   if ($98) {
    $p_f$0 = $93;$p_t$0 = $96;
   } else {
    $100 = HEAP32[$$pre88>>2]|0;
    $101 = ($100|0)==(-1);
    if ($101) {
     HEAP32[$$pre88>>2] = $99;
     $p_f$0 = $93;$p_t$0 = $96;
     break;
    }
    $fs$idx$val$i$i30 = HEAP32[$fs>>2]|0;
    $fs$idx$val$idx$i$i31 = ((($fs$idx$val$i$i30)) + 48|0);
    $fs$idx$val$idx$val$i$i32 = HEAP32[$fs$idx$val$idx$i$i31>>2]|0;
    $list$0$i$i34 = $100;
    while(1) {
     $102 = (($fs$idx$val$idx$val$i$i32) + ($list$0$i$i34<<2)|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = $103 >>> 14;
     $105 = (($104) + -131071)|0;
     $106 = ($105|0)==(-1);
     $107 = (($list$0$i$i34) + 1)|0;
     $108 = (($107) + ($105))|0;
     $$0$i$i$i35 = $106 ? -1 : $108;
     $109 = ($$0$i$i$i35|0)==(-1);
     if ($109) {
      $$lcssa = $102;$$lcssa119 = $103;$list$0$i$i34$lcssa = $list$0$i$i34;
      break;
     } else {
      $list$0$i$i34 = $$0$i$i$i35;
     }
    }
    $$neg$i$i$i36 = $list$0$i$i34$lcssa ^ -1;
    $110 = (($99) + ($$neg$i$i$i36))|0;
    $ispos$i$i$i37 = ($110|0)>(-1);
    $neg$i$i$i38 = (0 - ($110))|0;
    $111 = $ispos$i$i$i37 ? $110 : $neg$i$i$i38;
    $112 = ($111|0)>(131071);
    if ($112) {
     $113 = ((($fs)) + 8|0);
     $114 = HEAP32[$113>>2]|0;
     _luaX_syntaxerror($114,4928);
     // unreachable;
    } else {
     $115 = $$lcssa119 & 16383;
     $116 = $110 << 14;
     $117 = (($116) + 2147467264)|0;
     $118 = $117 | $115;
     HEAP32[$$lcssa>>2] = $118;
     $p_f$0 = $93;$p_t$0 = $96;
     break;
    }
   }
  }
 } while(0);
 $119 = ((($fs)) + 16|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ((($fs)) + 20|0);
 HEAP32[$121>>2] = $120;
 $122 = HEAP32[$26>>2]|0;
 $123 = ($122|0)==(-1);
 L62: do {
  if (!($123)) {
   $124 = ($reg|0)==(255);
   $125 = $reg << 6;
   $126 = $125 & 16320;
   $fs$idx$val$i43$pre = HEAP32[$fs>>2]|0;
   $fs$idx$val$idx$i44$phi$trans$insert = ((($fs$idx$val$i43$pre)) + 48|0);
   $fs$idx$val$idx$val$i45$pre = HEAP32[$fs$idx$val$idx$i44$phi$trans$insert>>2]|0;
   $$02$i42 = $122;
   while(1) {
    $127 = (($fs$idx$val$idx$val$i45$pre) + ($$02$i42<<2)|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = $128 >>> 14;
    $130 = (($129) + -131071)|0;
    $131 = ($130|0)==(-1);
    $132 = (($$02$i42) + 1)|0;
    $133 = (($132) + ($130))|0;
    $$0$i$i46 = $131 ? -1 : $133;
    $134 = ($$02$i42|0)>(0);
    if ($134) {
     $$sum$i$i57 = (($$02$i42) + -1)|0;
     $135 = (($fs$idx$val$idx$val$i45$pre) + ($$sum$i$i57<<2)|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = $136 & 63;
     $138 = (2360 + ($137)|0);
     $139 = HEAP8[$138>>0]|0;
     $140 = ($139<<24>>24)<(0);
     if ($140) {
      $$0$i$i59 = $135;$142 = $136;
     } else {
      label = 45;
     }
    } else {
     label = 45;
    }
    if ((label|0) == 45) {
     label = 0;
     $$0$i$i59 = $127;$142 = $128;
    }
    $141 = $142 & 63;
    $143 = ($141|0)==(35);
    if ($143) {
     $144 = $142 >>> 23;
     $145 = ($144|0)==($reg|0);
     $or$cond$i61 = $124 | $145;
     if ($or$cond$i61) {
      $148 = $144 << 6;
      $149 = $142 & 8372224;
      $150 = $149 | $148;
      $151 = $150 | 34;
      $storemerge$i62 = $151;
     } else {
      $146 = $142 & -16321;
      $147 = $146 | $126;
      $storemerge$i62 = $147;
     }
     HEAP32[$$0$i$i59>>2] = $storemerge$i62;
     $$neg$i53 = $$02$i42 ^ -1;
     $152 = (($120) + ($$neg$i53))|0;
     $ispos$i54 = ($152|0)>(-1);
     $neg$i55 = (0 - ($152))|0;
     $153 = $ispos$i54 ? $152 : $neg$i55;
     $154 = ($153|0)>(131071);
     if ($154) {
      label = 51;
      break;
     }
     $157 = HEAP32[$127>>2]|0;
     $158 = $157 & 16383;
     $159 = $152 << 14;
     $160 = (($159) + 2147467264)|0;
     $161 = $158 | $160;
     $storemerge = $161;
    } else {
     $$neg$i$i47 = $$02$i42 ^ -1;
     $162 = (($p_f$0) + ($$neg$i$i47))|0;
     $ispos$i$i48 = ($162|0)>(-1);
     $neg$i$i49 = (0 - ($162))|0;
     $163 = $ispos$i$i48 ? $162 : $neg$i$i49;
     $164 = ($163|0)>(131071);
     if ($164) {
      label = 54;
      break;
     }
     $167 = $128 & 16383;
     $168 = $162 << 14;
     $169 = (($168) + 2147467264)|0;
     $170 = $167 | $169;
     $storemerge = $170;
    }
    HEAP32[$127>>2] = $storemerge;
    $171 = ($$0$i$i46|0)==(-1);
    if ($171) {
     break L62;
    } else {
     $$02$i42 = $$0$i$i46;
    }
   }
   if ((label|0) == 51) {
    $155 = ((($fs)) + 8|0);
    $156 = HEAP32[$155>>2]|0;
    _luaX_syntaxerror($156,4928);
    // unreachable;
   }
   else if ((label|0) == 54) {
    $165 = ((($fs)) + 8|0);
    $166 = HEAP32[$165>>2]|0;
    _luaX_syntaxerror($166,4928);
    // unreachable;
   }
  }
 } while(0);
 $172 = HEAP32[$2>>2]|0;
 $173 = ($172|0)==(-1);
 if ($173) {
  HEAP32[$2>>2] = -1;
  HEAP32[$26>>2] = -1;
  $259 = ((($e)) + 8|0);
  HEAP32[$259>>2] = $reg;
  HEAP32[$e>>2] = 7;
  return;
 }
 $174 = ($reg|0)==(255);
 $175 = $reg << 6;
 $176 = $175 & 16320;
 $fs$idx$val$i3$us$pre = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i4$us$phi$trans$insert = ((($fs$idx$val$i3$us$pre)) + 48|0);
 $fs$idx$val$idx$val$i5$us$pre = HEAP32[$fs$idx$val$idx$i4$us$phi$trans$insert>>2]|0;
 if ($174) {
  $$02$i$us = $172;
  while(1) {
   $177 = (($fs$idx$val$idx$val$i5$us$pre) + ($$02$i$us<<2)|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = $178 >>> 14;
   $180 = (($179) + -131071)|0;
   $181 = ($180|0)==(-1);
   $182 = (($$02$i$us) + 1)|0;
   $183 = (($182) + ($180))|0;
   $$0$i$i6$us = $181 ? -1 : $183;
   $184 = ($$02$i$us|0)>(0);
   if ($184) {
    $$sum$i$i24$us = (($$02$i$us) + -1)|0;
    $185 = (($fs$idx$val$idx$val$i5$us$pre) + ($$sum$i$i24$us<<2)|0);
    $186 = HEAP32[$185>>2]|0;
    $187 = $186 & 63;
    $188 = (2360 + ($187)|0);
    $189 = HEAP8[$188>>0]|0;
    $190 = ($189<<24>>24)<(0);
    if ($190) {
     $$0$i$i26$us = $185;$192 = $186;
    } else {
     label = 61;
    }
   } else {
    label = 61;
   }
   if ((label|0) == 61) {
    label = 0;
    $$0$i$i26$us = $177;$192 = $178;
   }
   $191 = $192 & 63;
   $193 = ($191|0)==(35);
   if ($193) {
    $201 = $192 >>> 23;
    $202 = $201 << 6;
    $203 = $192 & 8372224;
    $204 = $203 | $202;
    $205 = $204 | 34;
    HEAP32[$$0$i$i26$us>>2] = $205;
    $$neg$i$us = $$02$i$us ^ -1;
    $206 = (($120) + ($$neg$i$us))|0;
    $ispos$i$us = ($206|0)>(-1);
    $neg$i$us = (0 - ($206))|0;
    $207 = $ispos$i$us ? $206 : $neg$i$us;
    $208 = ($207|0)>(131071);
    if ($208) {
     label = 76;
     break;
    }
    $209 = HEAP32[$177>>2]|0;
    $210 = $209 & 16383;
    $211 = $206 << 14;
    $212 = (($211) + 2147467264)|0;
    $213 = $210 | $212;
    $storemerge91 = $213;
   } else {
    $$neg$i$i7$us = $$02$i$us ^ -1;
    $194 = (($p_t$0) + ($$neg$i$i7$us))|0;
    $ispos$i$i8$us = ($194|0)>(-1);
    $neg$i$i9$us = (0 - ($194))|0;
    $195 = $ispos$i$i8$us ? $194 : $neg$i$i9$us;
    $196 = ($195|0)>(131071);
    if ($196) {
     label = 79;
     break;
    }
    $197 = $178 & 16383;
    $198 = $194 << 14;
    $199 = (($198) + 2147467264)|0;
    $200 = $197 | $199;
    $storemerge91 = $200;
   }
   HEAP32[$177>>2] = $storemerge91;
   $214 = ($$0$i$i6$us|0)==(-1);
   if ($214) {
    label = 82;
    break;
   } else {
    $$02$i$us = $$0$i$i6$us;
   }
  }
  if ((label|0) == 76) {
   $242 = ((($fs)) + 8|0);
   $243 = HEAP32[$242>>2]|0;
   _luaX_syntaxerror($243,4928);
   // unreachable;
  }
  else if ((label|0) == 79) {
   $252 = ((($fs)) + 8|0);
   $253 = HEAP32[$252>>2]|0;
   _luaX_syntaxerror($253,4928);
   // unreachable;
  }
  else if ((label|0) == 82) {
   HEAP32[$2>>2] = -1;
   HEAP32[$26>>2] = -1;
   $259 = ((($e)) + 8|0);
   HEAP32[$259>>2] = $reg;
   HEAP32[$e>>2] = 7;
   return;
  }
 } else {
  $$02$i = $172;
 }
 while(1) {
  $215 = (($fs$idx$val$idx$val$i5$us$pre) + ($$02$i<<2)|0);
  $216 = HEAP32[$215>>2]|0;
  $217 = $216 >>> 14;
  $218 = (($217) + -131071)|0;
  $219 = ($218|0)==(-1);
  $220 = (($$02$i) + 1)|0;
  $221 = (($220) + ($218))|0;
  $$0$i$i6 = $219 ? -1 : $221;
  $222 = ($$02$i|0)>(0);
  if ($222) {
   $$sum$i$i24 = (($$02$i) + -1)|0;
   $223 = (($fs$idx$val$idx$val$i5$us$pre) + ($$sum$i$i24<<2)|0);
   $224 = HEAP32[$223>>2]|0;
   $225 = $224 & 63;
   $226 = (2360 + ($225)|0);
   $227 = HEAP8[$226>>0]|0;
   $228 = ($227<<24>>24)<(0);
   if ($228) {
    $$0$i$i26 = $223;$230 = $224;
   } else {
    label = 70;
   }
  } else {
   label = 70;
  }
  if ((label|0) == 70) {
   label = 0;
   $$0$i$i26 = $215;$230 = $216;
  }
  $229 = $230 & 63;
  $231 = ($229|0)==(35);
  if ($231) {
   $232 = $230 >>> 23;
   $233 = ($232|0)==($reg|0);
   if ($233) {
    $236 = $230 & 8372224;
    $237 = $236 | $175;
    $238 = $237 | 34;
    $storemerge$i = $238;
   } else {
    $234 = $230 & -16321;
    $235 = $234 | $176;
    $storemerge$i = $235;
   }
   HEAP32[$$0$i$i26>>2] = $storemerge$i;
   $$neg$i = $$02$i ^ -1;
   $239 = (($120) + ($$neg$i))|0;
   $ispos$i = ($239|0)>(-1);
   $neg$i = (0 - ($239))|0;
   $240 = $ispos$i ? $239 : $neg$i;
   $241 = ($240|0)>(131071);
   if ($241) {
    label = 76;
    break;
   }
   $244 = HEAP32[$215>>2]|0;
   $245 = $244 & 16383;
   $246 = $239 << 14;
   $247 = (($246) + 2147467264)|0;
   $248 = $245 | $247;
   $storemerge90 = $248;
  } else {
   $$neg$i$i7 = $$02$i ^ -1;
   $249 = (($p_t$0) + ($$neg$i$i7))|0;
   $ispos$i$i8 = ($249|0)>(-1);
   $neg$i$i9 = (0 - ($249))|0;
   $250 = $ispos$i$i8 ? $249 : $neg$i$i9;
   $251 = ($250|0)>(131071);
   if ($251) {
    label = 79;
    break;
   }
   $254 = $216 & 16383;
   $255 = $249 << 14;
   $256 = (($255) + 2147467264)|0;
   $257 = $254 | $256;
   $storemerge90 = $257;
  }
  HEAP32[$215>>2] = $storemerge90;
  $258 = ($$0$i$i6|0)==(-1);
  if ($258) {
   label = 82;
   break;
  } else {
   $$02$i = $$0$i$i6;
  }
 }
 if ((label|0) == 76) {
  $242 = ((($fs)) + 8|0);
  $243 = HEAP32[$242>>2]|0;
  _luaX_syntaxerror($243,4928);
  // unreachable;
 }
 else if ((label|0) == 79) {
  $252 = ((($fs)) + 8|0);
  $253 = HEAP32[$252>>2]|0;
  _luaX_syntaxerror($253,4928);
  // unreachable;
 }
 else if ((label|0) == 82) {
  HEAP32[$2>>2] = -1;
  HEAP32[$26>>2] = -1;
  $259 = ((($e)) + 8|0);
  HEAP32[$259>>2] = $reg;
  HEAP32[$e>>2] = 7;
  return;
 }
}
function _discharge2reg($fs,$e,$reg) {
 $fs = $fs|0;
 $e = $e|0;
 $reg = $reg|0;
 var $$from$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $k$i = 0, $l$0$i = 0, $o$i = 0, $o$i3 = 0, $or$cond$i = 0, $or$cond2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $k$i = sp + 32|0;
 $o$i3 = sp + 16|0;
 $o$i = sp;
 _luaK_dischargevars($fs,$e);
 $0 = HEAP32[$e>>2]|0;
 L1: do {
  switch ($0|0) {
  case 5:  {
   $51 = ((($e)) + 8|0);
   $52 = +HEAPF64[$51>>3];
   HEAPF64[$o$i>>3] = $52;
   $53 = ((($o$i)) + 8|0);
   HEAP32[$53>>2] = 3;
   $54 = (_addk($fs,$o$i,$o$i)|0);
   $55 = ($54|0)<(262144);
   $56 = $reg << 6;
   if ($55) {
    $57 = $54 << 14;
    $58 = $56 | $57;
    $59 = $58 | 1;
    (_luaK_code($fs,$59)|0);
    break L1;
   } else {
    $60 = $56 | 2;
    (_luaK_code($fs,$60)|0);
    $61 = $54 << 6;
    $62 = $61 | 46;
    (_luaK_code($fs,$62)|0);
    break L1;
   }
   break;
  }
  case 2: case 3:  {
   $35 = ($0|0)==(2);
   $36 = $35&1;
   $37 = $reg << 6;
   $38 = $36 << 23;
   $39 = $37 | $38;
   $40 = $39 | 3;
   (_luaK_code($fs,$40)|0);
   break;
  }
  case 1:  {
   $1 = (($reg) + 1)|0;
   $2 = ((($fs)) + 16|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ((($fs)) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($3|0)>($5|0);
   do {
    if ($6) {
     $7 = (($3) + -1)|0;
     $8 = HEAP32[$fs>>2]|0;
     $9 = ((($8)) + 48|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = (($10) + ($7<<2)|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = $12 & 63;
     $14 = ($13|0)==(4);
     if ($14) {
      $15 = $12 >>> 6;
      $16 = $15 & 255;
      $17 = $12 >>> 23;
      $18 = (($16) + ($17))|0;
      $19 = ($16|0)>($reg|0);
      $20 = (($18) + 1)|0;
      $21 = ($20|0)<($reg|0);
      $or$cond$i = $19 | $21;
      if ($or$cond$i) {
       $22 = ($16|0)<($reg|0);
       $23 = ($16|0)>($1|0);
       $or$cond2$i = $22 | $23;
       if ($or$cond2$i) {
        break;
       }
      }
      $24 = ($16|0)<($reg|0);
      $$from$i = $24 ? $16 : $reg;
      $25 = ($18|0)>($reg|0);
      $l$0$i = $25 ? $18 : $reg;
      $26 = $12 & 8372287;
      $27 = $$from$i << 6;
      $28 = $27 & 16320;
      $29 = (($l$0$i) - ($$from$i))|0;
      $30 = $29 << 23;
      $31 = $28 | $26;
      $32 = $31 | $30;
      HEAP32[$11>>2] = $32;
      break L1;
     }
    }
   } while(0);
   $33 = $reg << 6;
   $34 = $33 | 4;
   (_luaK_code($fs,$34)|0);
   break;
  }
  case 7:  {
   $97 = ((($e)) + 8|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==($reg|0);
   if (!($99)) {
    $100 = $reg << 6;
    $101 = $98 << 23;
    $102 = $101 | $100;
    (_luaK_code($fs,$102)|0);
   }
   break;
  }
  case 4:  {
   $41 = ((($e)) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)<(262144);
   $44 = $reg << 6;
   if ($43) {
    $45 = $42 << 14;
    $46 = $44 | $45;
    $47 = $46 | 1;
    (_luaK_code($fs,$47)|0);
    break L1;
   } else {
    $48 = $44 | 2;
    (_luaK_code($fs,$48)|0);
    $49 = $42 << 6;
    $50 = $49 | 46;
    (_luaK_code($fs,$50)|0);
    break L1;
   }
   break;
  }
  case 6:  {
   $63 = ((($e)) + 8|0);
   $64 = $63;
   $65 = $64;
   $66 = HEAP32[$65>>2]|0;
   $67 = (($64) + 4)|0;
   $68 = $67;
   $69 = HEAP32[$68>>2]|0;
   $70 = $66;
   HEAP32[$k$i>>2] = $70;
   $71 = ((($k$i)) + 8|0);
   HEAP32[$71>>2] = 2;
   $72 = $o$i3;
   $73 = $72;
   HEAP32[$73>>2] = $66;
   $74 = (($72) + 4)|0;
   $75 = $74;
   HEAP32[$75>>2] = $69;
   $76 = ((($o$i3)) + 8|0);
   HEAP32[$76>>2] = 19;
   $77 = (_addk($fs,$k$i,$o$i3)|0);
   $78 = ($77|0)<(262144);
   $79 = $reg << 6;
   if ($78) {
    $80 = $77 << 14;
    $81 = $79 | $80;
    $82 = $81 | 1;
    (_luaK_code($fs,$82)|0);
    break L1;
   } else {
    $83 = $79 | 2;
    (_luaK_code($fs,$83)|0);
    $84 = $77 << 6;
    $85 = $84 | 46;
    (_luaK_code($fs,$85)|0);
    break L1;
   }
   break;
  }
  case 12:  {
   $86 = ((($e)) + 8|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = HEAP32[$fs>>2]|0;
   $89 = ((($88)) + 48|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($90) + ($87<<2)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = $92 & -16321;
   $94 = $reg << 6;
   $95 = $94 & 16320;
   $96 = $93 | $95;
   HEAP32[$91>>2] = $96;
   break;
  }
  default: {
   STACKTOP = sp;return;
  }
  }
 } while(0);
 $103 = ((($e)) + 8|0);
 HEAP32[$103>>2] = $reg;
 HEAP32[$e>>2] = 7;
 STACKTOP = sp;return;
}
function _codeexpval($fs,$op,$e1,$e2,$line) {
 $fs = $fs|0;
 $op = $op|0;
 $e1 = $e1|0;
 $e2 = $e2|0;
 $line = $line|0;
 var $$phi$trans$insert$i = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$i$i = 0, $o1$0 = 0, $o2$0 = 0, $or$cond$i = 0, $phitmp$i$i = 0, $res$i = 0, $v1$i = 0, $v2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $i$i$i = sp + 48|0;
 $v1$i = sp + 32|0;
 $v2$i = sp + 16|0;
 $res$i = sp;
 $0 = ($op>>>0)<(27);
 L1: do {
  if ($0) {
   $1 = (($op) + -13)|0;
   $2 = ((($e1)) + 16|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(-1);
   L3: do {
    if ($4) {
     $5 = ((($e1)) + 20|0);
     $6 = HEAP32[$5>>2]|0;
     $7 = ($6|0)==(-1);
     if ($7) {
      $8 = HEAP32[$e1>>2]|0;
      if ((($8|0) == 6)) {
       $9 = ((($e1)) + 8|0);
       $10 = $9;
       $11 = $10;
       $12 = HEAP32[$11>>2]|0;
       $13 = (($10) + 4)|0;
       $14 = $13;
       $15 = HEAP32[$14>>2]|0;
       $16 = $v1$i;
       $17 = $16;
       HEAP32[$17>>2] = $12;
       $18 = (($16) + 4)|0;
       $19 = $18;
       HEAP32[$19>>2] = $15;
       $20 = ((($v1$i)) + 8|0);
       HEAP32[$20>>2] = 19;
       $51 = 19;$54 = $12;$57 = $15;
      } else if ((($8|0) == 5)) {
       $21 = ((($e1)) + 8|0);
       $22 = +HEAPF64[$21>>3];
       HEAPF64[$v1$i>>3] = $22;
       $23 = ((($v1$i)) + 8|0);
       HEAP32[$23>>2] = 3;
       HEAPF64[tempDoublePtr>>3] = $22;$24 = HEAP32[tempDoublePtr>>2]|0;
       $25 = HEAP32[tempDoublePtr+4>>2]|0;
       $51 = 3;$54 = $24;$57 = $25;
      } else {
       break;
      }
      $26 = ((($e2)) + 16|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==(-1);
      if ($28) {
       $29 = ((($e2)) + 20|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30|0)==(-1);
       if ($31) {
        $32 = HEAP32[$e2>>2]|0;
        if ((($32|0) == 6)) {
         $33 = ((($e2)) + 8|0);
         $34 = $33;
         $35 = $34;
         $36 = HEAP32[$35>>2]|0;
         $37 = (($34) + 4)|0;
         $38 = $37;
         $39 = HEAP32[$38>>2]|0;
         $40 = $v2$i;
         $41 = $40;
         HEAP32[$41>>2] = $36;
         $42 = (($40) + 4)|0;
         $43 = $42;
         HEAP32[$43>>2] = $39;
         $44 = ((($v2$i)) + 8|0);
         HEAP32[$44>>2] = 19;
         $63 = 19;$65 = $36;$66 = $39;
        } else if ((($32|0) == 5)) {
         $45 = ((($e2)) + 8|0);
         $46 = +HEAPF64[$45>>3];
         HEAPF64[$v2$i>>3] = $46;
         $47 = ((($v2$i)) + 8|0);
         HEAP32[$47>>2] = 3;
         HEAPF64[tempDoublePtr>>3] = $46;$48 = HEAP32[tempDoublePtr>>2]|0;
         $49 = HEAP32[tempDoublePtr+4>>2]|0;
         $63 = 3;$65 = $48;$66 = $49;
        } else {
         break;
        }
        L16: do {
         switch ($op|0) {
         case 16: case 19: case 18:  {
          $62 = ($63|0)==(19);
          $64 = (+($65>>>0)) + (4294967296.0*(+($66|0)));
          HEAP32[tempDoublePtr>>2] = $65;HEAP32[tempDoublePtr+4>>2] = $66;$67 = +HEAPF64[tempDoublePtr>>3];
          $68 = $62 ? $64 : $67;
          $69 = $68 != 0.0;
          if (!($69)) {
           break L3;
          }
          break;
         }
         case 26: case 24: case 23: case 22: case 21: case 20:  {
          $50 = ($51|0)==(19);
          do {
           if ($50) {
            $52 = $i$i$i;
            $53 = $52;
            HEAP32[$53>>2] = $54;
            $55 = (($52) + 4)|0;
            $56 = $55;
            HEAP32[$56>>2] = $57;
            $61 = $63;
           } else {
            $58 = (_luaV_tointeger_($v1$i,$i$i$i)|0);
            $59 = ($58|0)==(0);
            if ($59) {
             break L3;
            } else {
             $$phi$trans$insert$i = ((($v2$i)) + 8|0);
             $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
             $61 = $$pre$i;
             break;
            }
           }
          } while(0);
          $60 = ($61|0)==(19);
          if ($60) {
           break L16;
          }
          $70 = (_luaV_tointeger_($v2$i,$i$i$i)|0);
          $phitmp$i$i = ($70|0)==(0);
          if ($phitmp$i$i) {
           break L1;
          }
          break;
         }
         default: {
         }
         }
        } while(0);
        $71 = ((($fs)) + 8|0);
        $72 = HEAP32[$71>>2]|0;
        $73 = ((($72)) + 52|0);
        $74 = HEAP32[$73>>2]|0;
        _luaO_arith($74,$1,$v1$i,$v2$i,$res$i);
        $75 = ((($res$i)) + 8|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = ($76|0)==(19);
        if ($77) {
         HEAP32[$e1>>2] = 6;
         $78 = $res$i;
         $79 = $78;
         $80 = HEAP32[$79>>2]|0;
         $81 = (($78) + 4)|0;
         $82 = $81;
         $83 = HEAP32[$82>>2]|0;
         $84 = ((($e1)) + 8|0);
         $85 = $84;
         $86 = $85;
         HEAP32[$86>>2] = $80;
         $87 = (($85) + 4)|0;
         $88 = $87;
         HEAP32[$88>>2] = $83;
         STACKTOP = sp;return;
        }
        $89 = +HEAPF64[$res$i>>3];
        $90 = ($89 != $89) | (0.0 != 0.0);
        $91 = $89 == 0.0;
        $or$cond$i = $90 | $91;
        if ($or$cond$i) {
         break L1;
        }
        HEAP32[$e1>>2] = 5;
        $92 = ((($e1)) + 8|0);
        HEAPF64[$92>>3] = $89;
        STACKTOP = sp;return;
       }
      }
     }
    }
   } while(0);
  }
 } while(0);
 if ((($op|0) == 25) | (($op|0) == 26) | (($op|0) == 28)) {
  $93 = (_luaK_exp2anyreg($fs,$e1)|0);
  $o1$0 = $93;$o2$0 = 0;
 } else {
  $94 = (_luaK_exp2RK($fs,$e2)|0);
  $95 = (_luaK_exp2RK($fs,$e1)|0);
  $o1$0 = $95;$o2$0 = $94;
 }
 $96 = ($o1$0|0)>($o2$0|0);
 if ($96) {
  $97 = HEAP32[$e1>>2]|0;
  $98 = ($97|0)==(7);
  if ($98) {
   $99 = ((($e1)) + 8|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = $100 & 256;
   $102 = ($101|0)==(0);
   if ($102) {
    $103 = ((($fs)) + 42|0);
    $104 = HEAP8[$103>>0]|0;
    $105 = $104&255;
    $106 = ($105|0)>($100|0);
    if (!($106)) {
     $107 = ((($fs)) + 44|0);
     $108 = HEAP8[$107>>0]|0;
     $109 = (($108) + -1)<<24>>24;
     HEAP8[$107>>0] = $109;
    }
   }
  }
  $110 = HEAP32[$e2>>2]|0;
  $111 = ($110|0)==(7);
  if ($111) {
   $112 = ((($e2)) + 8|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = $113 & 256;
   $115 = ($114|0)==(0);
   if ($115) {
    $116 = ((($fs)) + 42|0);
    $117 = HEAP8[$116>>0]|0;
    $118 = $117&255;
    $119 = ($118|0)>($113|0);
    if ($119) {
     $$pre$phiZ2D = $e1;
    } else {
     $120 = ((($fs)) + 44|0);
     $121 = HEAP8[$120>>0]|0;
     $122 = (($121) + -1)<<24>>24;
     HEAP8[$120>>0] = $122;
     $$pre$phiZ2D = $e1;
    }
   } else {
    $$pre$phiZ2D = $e1;
   }
  } else {
   $$pre$phiZ2D = $e1;
  }
 } else {
  $123 = HEAP32[$e2>>2]|0;
  $124 = ($123|0)==(7);
  if ($124) {
   $125 = ((($e2)) + 8|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = $126 & 256;
   $128 = ($127|0)==(0);
   if ($128) {
    $129 = ((($fs)) + 42|0);
    $130 = HEAP8[$129>>0]|0;
    $131 = $130&255;
    $132 = ($131|0)>($126|0);
    if (!($132)) {
     $133 = ((($fs)) + 44|0);
     $134 = HEAP8[$133>>0]|0;
     $135 = (($134) + -1)<<24>>24;
     HEAP8[$133>>0] = $135;
    }
   }
  }
  $136 = HEAP32[$e1>>2]|0;
  $137 = ($136|0)==(7);
  if ($137) {
   $138 = ((($e1)) + 8|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = $139 & 256;
   $141 = ($140|0)==(0);
   if ($141) {
    $142 = ((($fs)) + 42|0);
    $143 = HEAP8[$142>>0]|0;
    $144 = $143&255;
    $145 = ($144|0)>($139|0);
    if ($145) {
     $$pre$phiZ2D = $e1;
    } else {
     $146 = ((($fs)) + 44|0);
     $147 = HEAP8[$146>>0]|0;
     $148 = (($147) + -1)<<24>>24;
     HEAP8[$146>>0] = $148;
     $$pre$phiZ2D = $e1;
    }
   } else {
    $$pre$phiZ2D = $e1;
   }
  } else {
   $$pre$phiZ2D = $e1;
  }
 }
 $149 = $o1$0 << 23;
 $150 = $149 | $op;
 $151 = $o2$0 << 14;
 $152 = $150 | $151;
 $153 = (_luaK_code($fs,$152)|0);
 $154 = ((($e1)) + 8|0);
 HEAP32[$154>>2] = $153;
 HEAP32[$$pre$phiZ2D>>2] = 12;
 $155 = ((($fs)) + 16|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = (($156) + -1)|0;
 $158 = HEAP32[$fs>>2]|0;
 $159 = ((($158)) + 56|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = (($160) + ($157<<2)|0);
 HEAP32[$161>>2] = $line;
 STACKTOP = sp;return;
}
function _codecomp($fs,$op,$cond,$e1,$e2) {
 $fs = $fs|0;
 $op = $op|0;
 $cond = $cond|0;
 $e1 = $e1|0;
 $e2 = $e2|0;
 var $$ = 0, $$0$i$i$i$i = 0, $$2 = 0, $$lcssa = 0, $$lcssa9 = 0, $$neg$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond$op = 0, $fs$idx$val$i$i$i = 0, $fs$idx$val$idx$i$i$i = 0, $fs$idx$val$idx$val$i$i$i = 0, $ispos$i$i$i$i = 0, $list$0$i$i$i = 0, $list$0$i$i$i$lcssa = 0, $neg$i$i$i$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaK_exp2RK($fs,$e1)|0);
 $1 = (_luaK_exp2RK($fs,$e2)|0);
 $2 = HEAP32[$e2>>2]|0;
 $3 = ($2|0)==(7);
 if ($3) {
  $4 = ((($e2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 & 256;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = ((($fs)) + 42|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = $9&255;
   $11 = ($10|0)>($5|0);
   if (!($11)) {
    $12 = ((($fs)) + 44|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = (($13) + -1)<<24>>24;
    HEAP8[$12>>0] = $14;
   }
  }
 }
 $15 = HEAP32[$e1>>2]|0;
 $16 = ($15|0)==(7);
 if ($16) {
  $17 = ((($e1)) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & 256;
  $20 = ($19|0)==(0);
  if ($20) {
   $21 = ((($fs)) + 42|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = $22&255;
   $24 = ($23|0)>($18|0);
   if (!($24)) {
    $25 = ((($fs)) + 44|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = (($26) + -1)<<24>>24;
    HEAP8[$25>>0] = $27;
   }
  }
 }
 $28 = ($cond|0)==(0);
 $29 = ($op|0)!=(31);
 $or$cond = $29 & $28;
 $$ = $or$cond ? $1 : $0;
 $$2 = $or$cond ? $0 : $1;
 $cond$op = $cond << 6;
 $30 = $or$cond ? 64 : $cond$op;
 $31 = $30 | $op;
 $32 = $$ << 23;
 $33 = $31 | $32;
 $34 = $$2 << 14;
 $35 = $33 | $34;
 (_luaK_code($fs,$35)|0);
 $36 = ((($fs)) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$36>>2] = -1;
 $38 = (_luaK_code($fs,2147450910)|0);
 $39 = ($37|0)==(-1);
 if ($39) {
  $59 = $38;
  $58 = ((($e1)) + 8|0);
  HEAP32[$58>>2] = $59;
  HEAP32[$e1>>2] = 11;
  return;
 }
 $40 = ($38|0)==(-1);
 if ($40) {
  $59 = $37;
  $58 = ((($e1)) + 8|0);
  HEAP32[$58>>2] = $59;
  HEAP32[$e1>>2] = 11;
  return;
 }
 $fs$idx$val$i$i$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i$i$i = ((($fs$idx$val$i$i$i)) + 48|0);
 $fs$idx$val$idx$val$i$i$i = HEAP32[$fs$idx$val$idx$i$i$i>>2]|0;
 $list$0$i$i$i = $38;
 while(1) {
  $41 = (($fs$idx$val$idx$val$i$i$i) + ($list$0$i$i$i<<2)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 >>> 14;
  $44 = (($43) + -131071)|0;
  $45 = ($44|0)==(-1);
  $46 = (($list$0$i$i$i) + 1)|0;
  $47 = (($46) + ($44))|0;
  $$0$i$i$i$i = $45 ? -1 : $47;
  $48 = ($$0$i$i$i$i|0)==(-1);
  if ($48) {
   $$lcssa = $41;$$lcssa9 = $42;$list$0$i$i$i$lcssa = $list$0$i$i$i;
   break;
  } else {
   $list$0$i$i$i = $$0$i$i$i$i;
  }
 }
 $$neg$i$i$i$i = $list$0$i$i$i$lcssa ^ -1;
 $49 = (($37) + ($$neg$i$i$i$i))|0;
 $ispos$i$i$i$i = ($49|0)>(-1);
 $neg$i$i$i$i = (0 - ($49))|0;
 $50 = $ispos$i$i$i$i ? $49 : $neg$i$i$i$i;
 $51 = ($50|0)>(131071);
 if ($51) {
  $52 = ((($fs)) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  _luaX_syntaxerror($53,4928);
  // unreachable;
 }
 $54 = $$lcssa9 & 16383;
 $55 = $49 << 14;
 $56 = (($55) + 2147467264)|0;
 $57 = $56 | $54;
 HEAP32[$$lcssa>>2] = $57;
 $59 = $38;
 $58 = ((($e1)) + 8|0);
 HEAP32[$58>>2] = $59;
 HEAP32[$e1>>2] = 11;
 return;
}
function _luaX_init($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaS_new($L,5312)|0);
 _luaC_fix($L,$0);
 $i$01 = 0;
 while(1) {
  $1 = (5320 + ($i$01<<2)|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (_luaS_new($L,$2)|0);
  _luaC_fix($L,$3);
  $4 = (($i$01) + 1)|0;
  $5 = $4&255;
  $6 = ((($3)) + 6|0);
  HEAP8[$6>>0] = $5;
  $exitcond = ($4|0)==(22);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $4;
  }
 }
 return;
}
function _luaX_token2str($ls,$token) {
 $ls = $ls|0;
 $token = $token|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ($token|0)<(257);
 if ($0) {
  $1 = ((($ls)) + 52|0);
  $2 = HEAP32[$1>>2]|0;
  HEAP32[$vararg_buffer>>2] = $token;
  $3 = (_luaO_pushfstring($2,5472,$vararg_buffer)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($token) + -257)|0;
 $5 = (5320 + ($4<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($token|0)<(289);
 if (!($7)) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = ((($ls)) + 52|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$vararg_buffer1>>2] = $6;
 $10 = (_luaO_pushfstring($9,5480,$vararg_buffer1)|0);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function _luaX_syntaxerror($ls,$msg) {
 $ls = $ls|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 _lexerror($ls,$msg,$1);
 // unreachable;
}
function _luaX_newstring($ls,$str,$l) {
 $ls = $ls|0;
 $str = $str|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ts$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaS_newlstr($1,$str,$l)|0);
 $3 = ((($1)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 16|0);
 HEAP32[$3>>2] = $5;
 HEAP32[$4>>2] = $2;
 $6 = ((($2)) + 4|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 | 64;
 $10 = ((($4)) + 8|0);
 HEAP32[$10>>2] = $9;
 $11 = ((($ls)) + 64|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$3>>2]|0;
 $14 = ((($13)) + -16|0);
 $15 = (_luaH_set($1,$12,$14)|0);
 $16 = ((($15)) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  HEAP32[$15>>2] = 1;
  HEAP32[$16>>2] = 1;
  $19 = ((($1)) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($20)) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)>(0);
  if ($23) {
   _luaC_step($1);
   $ts$0 = $2;
  } else {
   $ts$0 = $2;
  }
 } else {
  $24 = ((($15)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $ts$0 = $25;
 }
 $26 = HEAP32[$3>>2]|0;
 $27 = ((($26)) + -16|0);
 HEAP32[$3>>2] = $27;
 return ($ts$0|0);
}
function _luaX_setinput($L,$ls,$z,$source,$firstchar) {
 $L = $L|0;
 $ls = $ls|0;
 $z = $z|0;
 $source = $source|0;
 $firstchar = $firstchar|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 16|0);
 HEAP32[$0>>2] = 0;
 $1 = ((($ls)) + 80|0);
 HEAP8[$1>>0] = 46;
 $2 = ((($ls)) + 52|0);
 HEAP32[$2>>2] = $L;
 HEAP32[$ls>>2] = $firstchar;
 $3 = ((($ls)) + 32|0);
 HEAP32[$3>>2] = 289;
 $4 = ((($ls)) + 56|0);
 HEAP32[$4>>2] = $z;
 $5 = ((($ls)) + 48|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($ls)) + 4|0);
 HEAP32[$6>>2] = 1;
 $7 = ((($ls)) + 8|0);
 HEAP32[$7>>2] = 1;
 $8 = ((($ls)) + 72|0);
 HEAP32[$8>>2] = $source;
 $9 = (_luaS_new($L,5312)|0);
 $10 = ((($ls)) + 76|0);
 HEAP32[$10>>2] = $9;
 $11 = HEAP32[$2>>2]|0;
 $12 = ((($ls)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($13)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (_luaM_realloc_($11,$14,$16,32)|0);
 $18 = HEAP32[$12>>2]|0;
 HEAP32[$18>>2] = $17;
 $19 = ((($18)) + 8|0);
 HEAP32[$19>>2] = 32;
 return;
}
function _luaX_next($ls) {
 $ls = $ls|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 8|0);
 HEAP32[$2>>2] = $1;
 $3 = ((($ls)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(289);
 if ($5) {
  $7 = ((($ls)) + 24|0);
  $8 = (_llex($ls,$7)|0);
  $9 = ((($ls)) + 16|0);
  HEAP32[$9>>2] = $8;
  return;
 } else {
  $6 = ((($ls)) + 16|0);
  ;HEAP32[$6>>2]=HEAP32[$3>>2]|0;HEAP32[$6+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$3+12>>2]|0;
  HEAP32[$3>>2] = 289;
  return;
 }
}
function _luaX_lookahead($ls) {
 $ls = $ls|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 40|0);
 $1 = (_llex($ls,$0)|0);
 $2 = ((($ls)) + 32|0);
 HEAP32[$2>>2] = $1;
 return ($1|0);
}
function _lexerror($ls,$msg,$token) {
 $ls = $ls|0;
 $msg = $msg|0;
 $token = $token|0;
 var $$0$i = 0, $$off$i = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $buff = 0, $switch$i = 0, $vararg_buffer = 0, $vararg_buffer12 = 0, $vararg_buffer3 = 0, $vararg_buffer6 = 0, $vararg_buffer9 = 0, $vararg_ptr1 = 0, $vararg_ptr15 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer12 = sp + 40|0;
 $vararg_buffer9 = sp + 32|0;
 $vararg_buffer6 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $buff = sp + 48|0;
 $0 = ((($ls)) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 24|0);
 _luaO_chunkid($buff,$2,60);
 $3 = ((($ls)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($ls)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$vararg_buffer>>2] = $buff;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $6;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $msg;
 $7 = (_luaO_pushfstring($4,5856,$vararg_buffer)|0);
 $8 = ($token|0)==(0);
 if ($8) {
  $37 = HEAP32[$3>>2]|0;
  _luaD_throw($37,3);
  // unreachable;
 }
 $9 = HEAP32[$3>>2]|0;
 $$off$i = (($token) + -290)|0;
 $switch$i = ($$off$i>>>0)<(4);
 do {
  if ($switch$i) {
   $10 = ((($ls)) + 60|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($11)) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 1)|0;
   $15 = ((($11)) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($14>>>0)>($16>>>0);
   do {
    if ($17) {
     $18 = ($16>>>0)>(2147483646);
     if ($18) {
      _lexerror($ls,5552,0);
      // unreachable;
     } else {
      $19 = $16 << 1;
      $20 = HEAP32[$11>>2]|0;
      $21 = (_luaM_realloc_($9,$20,$16,$19)|0);
      HEAP32[$11>>2] = $21;
      HEAP32[$15>>2] = $19;
      $$pre = HEAP32[$12>>2]|0;
      $23 = $$pre;$25 = $21;
      break;
     }
    } else {
     $$pre1 = HEAP32[$11>>2]|0;
     $23 = $13;$25 = $$pre1;
    }
   } while(0);
   $22 = (($23) + 1)|0;
   HEAP32[$12>>2] = $22;
   $24 = (($25) + ($23)|0);
   HEAP8[$24>>0] = 0;
   $26 = HEAP32[$3>>2]|0;
   $27 = HEAP32[$10>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   HEAP32[$vararg_buffer3>>2] = $28;
   $29 = (_luaO_pushfstring($26,5480,$vararg_buffer3)|0);
   $$0$i = $29;
  } else {
   $30 = ($token|0)<(257);
   if ($30) {
    HEAP32[$vararg_buffer6>>2] = $token;
    $31 = (_luaO_pushfstring($9,5472,$vararg_buffer6)|0);
    $$0$i = $31;
    break;
   }
   $32 = (($token) + -257)|0;
   $33 = (5320 + ($32<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($token|0)<(289);
   if ($35) {
    HEAP32[$vararg_buffer9>>2] = $34;
    $36 = (_luaO_pushfstring($9,5480,$vararg_buffer9)|0);
    $$0$i = $36;
   } else {
    $$0$i = $34;
   }
  }
 } while(0);
 HEAP32[$vararg_buffer12>>2] = $7;
 $vararg_ptr15 = ((($vararg_buffer12)) + 4|0);
 HEAP32[$vararg_ptr15>>2] = $$0$i;
 (_luaO_pushfstring($9,5872,$vararg_buffer12)|0);
 $37 = HEAP32[$3>>2]|0;
 _luaD_throw($37,3);
 // unreachable;
}
function _llex($ls,$seminfo) {
 $ls = $ls|0;
 $seminfo = $seminfo|0;
 var $$0 = 0, $$be$i = 0, $$be43$i = 0, $$lcssa = 0, $$lcssa$lcssa = 0, $$lcssa376 = 0, $$lcssa380 = 0, $$lcssa389 = 0, $$lcssa395 = 0, $$lcssa398 = 0, $$lcssa399 = 0, $$lcssa400 = 0, $$lcssa401 = 0, $$lcssa410 = 0, $$pr = 0, $$pr$i = 0, $$pr166 = 0, $$pr40$i = 0, $$pre$i = 0, $$pre$i$i = 0;
 var $$pre$i$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i17$i = 0, $$pre$i$i9$i = 0, $$pre$i11$i$i = 0, $$pre$i11$i$i$i = 0, $$pre$i16$i$i = 0, $$pre$i16$i$i$i = 0, $$pre$i22$i$i$i = 0, $$pre$i23$i = 0, $$pre$i27$i$i$i = 0, $$pre$i28$i = 0, $$pre$i30 = 0, $$pre$i32$i$i$i = 0, $$pre$i33$i = 0, $$pre$i38$i = 0, $$pre$i4$i = 0, $$pre$i4$i$i = 0, $$pre$i4$i$i$i = 0, $$pre$i5$i$i = 0;
 var $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i$i = 0, $$pre1$i$i$i$i = 0, $$pre1$i$i15$i = 0, $$pre1$i$i7$i = 0, $$pre1$i14$i$i = 0, $$pre1$i14$i$i$i = 0, $$pre1$i2$i = 0, $$pre1$i2$i$i = 0, $$pre1$i2$i$i$i = 0, $$pre1$i20$i$i$i = 0, $$pre1$i21$i = 0, $$pre1$i25$i$i$i = 0, $$pre1$i26$i = 0, $$pre1$i28 = 0, $$pre1$i3$i$i = 0, $$pre1$i30$i$i$i = 0, $$pre1$i31$i = 0, $$pre1$i36$i = 0;
 var $$pre1$i9$i$i = 0, $$pre1$i9$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0;
 var $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0;
 var $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0;
 var $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0;
 var $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0;
 var $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0;
 var $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0;
 var $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0;
 var $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0;
 var $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0;
 var $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0;
 var $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0;
 var $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0;
 var $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0;
 var $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0;
 var $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0;
 var $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0;
 var $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0;
 var $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0;
 var $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0;
 var $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0;
 var $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0;
 var $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0;
 var $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0;
 var $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0;
 var $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0;
 var $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0;
 var $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0;
 var $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $buff$i$i = 0, $c$0$i = 0, $c$1$i = 0, $i$0$i$i$i = 0;
 var $i$0$i$i$i$lcssa355 = 0, $i$0$lcssa$i$i = 0, $i$08$i$i = 0, $n$06$i$i = 0, $r$0$i$i$i = 0, $r$0$i$i$i$lcssa353 = 0, $r$0$lcssa$i$i = 0, $r$09$i$i = 0, $ts$0$i = 0, $ts$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $buff$i$i = sp;
 $0 = ((($ls)) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($ls)) + 56|0);
 $4 = ((($ls)) + 4|0);
 L1: while(1) {
  $$pr166 = HEAP32[$ls>>2]|0;
  $5 = $$pr166;
  L3: while(1) {
   switch ($5|0) {
   case 13: case 10:  {
    $$lcssa401 = $5;
    label = 4;
    break L3;
    break;
   }
   case 91:  {
    label = 35;
    break L1;
    break;
   }
   case 45:  {
    break L3;
    break;
   }
   case 126:  {
    label = 79;
    break L1;
    break;
   }
   case 58:  {
    label = 87;
    break L1;
    break;
   }
   case 61:  {
    label = 39;
    break L1;
    break;
   }
   case 60:  {
    label = 47;
    break L1;
    break;
   }
   case 39: case 34:  {
    $$lcssa410 = $5;
    label = 95;
    break L1;
    break;
   }
   case 62:  {
    label = 59;
    break L1;
    break;
   }
   case 11: case 9: case 12: case 32:  {
    break;
   }
   case 46:  {
    label = 349;
    break L1;
    break;
   }
   case 57: case 56: case 55: case 54: case 53: case 52: case 51: case 50: case 49: case 48:  {
    label = 368;
    break L1;
    break;
   }
   case -1:  {
    $$0 = 289;
    label = 391;
    break L1;
    break;
   }
   case 47:  {
    label = 71;
    break L1;
    break;
   }
   default: {
    $$lcssa400 = $5;
    label = 369;
    break L1;
   }
   }
   $32 = HEAP32[$3>>2]|0;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   HEAP32[$32>>2] = $34;
   $35 = ($33|0)==(0);
   if ($35) {
    $41 = (_luaZ_fill($32)|0);
    $42 = $41;
   } else {
    $36 = ((($32)) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ((($37)) + 1|0);
    HEAP32[$36>>2] = $38;
    $39 = HEAP8[$37>>0]|0;
    $40 = $39&255;
    $42 = $40;
   }
   HEAP32[$ls>>2] = $42;
   $5 = $42;
  }
  if ((label|0) == 4) {
   label = 0;
   $6 = HEAP32[$3>>2]|0;
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + -1)|0;
   HEAP32[$6>>2] = $8;
   $9 = ($7|0)==(0);
   if ($9) {
    $15 = (_luaZ_fill($6)|0);
    $16 = $15;
   } else {
    $10 = ((($6)) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($11)) + 1|0);
    HEAP32[$10>>2] = $12;
    $13 = HEAP8[$11>>0]|0;
    $14 = $13&255;
    $16 = $14;
   }
   HEAP32[$ls>>2] = $16;
   if ((($16|0) == 13) | (($16|0) == 10)) {
    $17 = ($16|0)==($$lcssa401|0);
    if (!($17)) {
     $18 = HEAP32[$3>>2]|0;
     $19 = HEAP32[$18>>2]|0;
     $20 = (($19) + -1)|0;
     HEAP32[$18>>2] = $20;
     $21 = ($19|0)==(0);
     if ($21) {
      $27 = (_luaZ_fill($18)|0);
      $28 = $27;
     } else {
      $22 = ((($18)) + 4|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = ((($23)) + 1|0);
      HEAP32[$22>>2] = $24;
      $25 = HEAP8[$23>>0]|0;
      $26 = $25&255;
      $28 = $26;
     }
     HEAP32[$ls>>2] = $28;
    }
   }
   $29 = HEAP32[$4>>2]|0;
   $30 = (($29) + 1)|0;
   HEAP32[$4>>2] = $30;
   $31 = ($30|0)==(2147483647);
   if ($31) {
    label = 14;
    break;
   } else {
    continue;
   }
  }
  $43 = HEAP32[$3>>2]|0;
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + -1)|0;
  HEAP32[$43>>2] = $45;
  $46 = ($44|0)==(0);
  if ($46) {
   $52 = (_luaZ_fill($43)|0);
   $53 = $52;
  } else {
   $47 = ((($43)) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ((($48)) + 1|0);
   HEAP32[$47>>2] = $49;
   $50 = HEAP8[$48>>0]|0;
   $51 = $50&255;
   $53 = $51;
  }
  HEAP32[$ls>>2] = $53;
  $54 = ($53|0)==(45);
  if (!($54)) {
   $$0 = 45;
   label = 391;
   break;
  }
  $55 = HEAP32[$3>>2]|0;
  $56 = HEAP32[$55>>2]|0;
  $57 = (($56) + -1)|0;
  HEAP32[$55>>2] = $57;
  $58 = ($56|0)==(0);
  if ($58) {
   $64 = (_luaZ_fill($55)|0);
   $65 = $64;
  } else {
   $59 = ((($55)) + 4|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ((($60)) + 1|0);
   HEAP32[$59>>2] = $61;
   $62 = HEAP8[$60>>0]|0;
   $63 = $62&255;
   $65 = $63;
  }
  HEAP32[$ls>>2] = $65;
  $66 = ($65|0)==(91);
  do {
   if ($66) {
    $67 = (_skip_sep($ls)|0);
    $68 = HEAP32[$0>>2]|0;
    $69 = ((($68)) + 4|0);
    HEAP32[$69>>2] = 0;
    $70 = ($67|0)>(-1);
    if ($70) {
     _read_long_string($ls,0,$67);
     $71 = HEAP32[$0>>2]|0;
     $72 = ((($71)) + 4|0);
     HEAP32[$72>>2] = 0;
     continue L1;
    } else {
     $$pr = HEAP32[$ls>>2]|0;
     $1152 = $$pr;
     break;
    }
   } else {
    $1152 = $65;
   }
  } while(0);
  while(1) {
   if ((($1152|0) == -1) | (($1152|0) == 13) | (($1152|0) == 10)) {
    continue L1;
   }
   $73 = HEAP32[$3>>2]|0;
   $74 = HEAP32[$73>>2]|0;
   $75 = (($74) + -1)|0;
   HEAP32[$73>>2] = $75;
   $76 = ($74|0)==(0);
   if ($76) {
    $82 = (_luaZ_fill($73)|0);
    $83 = $82;
   } else {
    $77 = ((($73)) + 4|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ((($78)) + 1|0);
    HEAP32[$77>>2] = $79;
    $80 = HEAP8[$78>>0]|0;
    $81 = $80&255;
    $83 = $81;
   }
   HEAP32[$ls>>2] = $83;
   $1152 = $83;
  }
 }
 switch (label|0) {
  case 14: {
   _lexerror($ls,5488,0);
   // unreachable;
   break;
  }
  case 35: {
   $84 = (_skip_sep($ls)|0);
   $85 = ($84|0)>(-1);
   if ($85) {
    _read_long_string($ls,$seminfo,$84);
    $$0 = 293;
    STACKTOP = sp;return ($$0|0);
   }
   $86 = ($84|0)==(-1);
   if ($86) {
    $$0 = 91;
    STACKTOP = sp;return ($$0|0);
   } else {
    _lexerror($ls,5520,293);
    // unreachable;
   }
   break;
  }
  case 39: {
   $87 = HEAP32[$3>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   $89 = (($88) + -1)|0;
   HEAP32[$87>>2] = $89;
   $90 = ($88|0)==(0);
   if ($90) {
    $96 = (_luaZ_fill($87)|0);
    $97 = $96;
   } else {
    $91 = ((($87)) + 4|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ((($92)) + 1|0);
    HEAP32[$91>>2] = $93;
    $94 = HEAP8[$92>>0]|0;
    $95 = $94&255;
    $97 = $95;
   }
   HEAP32[$ls>>2] = $97;
   $98 = ($97|0)==(61);
   if (!($98)) {
    $$0 = 61;
    STACKTOP = sp;return ($$0|0);
   }
   $99 = HEAP32[$3>>2]|0;
   $100 = HEAP32[$99>>2]|0;
   $101 = (($100) + -1)|0;
   HEAP32[$99>>2] = $101;
   $102 = ($100|0)==(0);
   if ($102) {
    $108 = (_luaZ_fill($99)|0);
    $109 = $108;
   } else {
    $103 = ((($99)) + 4|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ((($104)) + 1|0);
    HEAP32[$103>>2] = $105;
    $106 = HEAP8[$104>>0]|0;
    $107 = $106&255;
    $109 = $107;
   }
   HEAP32[$ls>>2] = $109;
   $$0 = 282;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 47: {
   $110 = HEAP32[$3>>2]|0;
   $111 = HEAP32[$110>>2]|0;
   $112 = (($111) + -1)|0;
   HEAP32[$110>>2] = $112;
   $113 = ($111|0)==(0);
   if ($113) {
    $119 = (_luaZ_fill($110)|0);
    $120 = $119;
   } else {
    $114 = ((($110)) + 4|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = ((($115)) + 1|0);
    HEAP32[$114>>2] = $116;
    $117 = HEAP8[$115>>0]|0;
    $118 = $117&255;
    $120 = $118;
   }
   HEAP32[$ls>>2] = $120;
   if ((($120|0) == 61)) {
    $121 = HEAP32[$3>>2]|0;
    $122 = HEAP32[$121>>2]|0;
    $123 = (($122) + -1)|0;
    HEAP32[$121>>2] = $123;
    $124 = ($122|0)==(0);
    if ($124) {
     $130 = (_luaZ_fill($121)|0);
     $131 = $130;
    } else {
     $125 = ((($121)) + 4|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = ((($126)) + 1|0);
     HEAP32[$125>>2] = $127;
     $128 = HEAP8[$126>>0]|0;
     $129 = $128&255;
     $131 = $129;
    }
    HEAP32[$ls>>2] = $131;
    $$0 = 284;
    STACKTOP = sp;return ($$0|0);
   } else if ((($120|0) == 60)) {
    $132 = HEAP32[$3>>2]|0;
    $133 = HEAP32[$132>>2]|0;
    $134 = (($133) + -1)|0;
    HEAP32[$132>>2] = $134;
    $135 = ($133|0)==(0);
    if ($135) {
     $141 = (_luaZ_fill($132)|0);
     $142 = $141;
    } else {
     $136 = ((($132)) + 4|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = ((($137)) + 1|0);
     HEAP32[$136>>2] = $138;
     $139 = HEAP8[$137>>0]|0;
     $140 = $139&255;
     $142 = $140;
    }
    HEAP32[$ls>>2] = $142;
    $$0 = 286;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$0 = 60;
    STACKTOP = sp;return ($$0|0);
   }
   break;
  }
  case 59: {
   $143 = HEAP32[$3>>2]|0;
   $144 = HEAP32[$143>>2]|0;
   $145 = (($144) + -1)|0;
   HEAP32[$143>>2] = $145;
   $146 = ($144|0)==(0);
   if ($146) {
    $152 = (_luaZ_fill($143)|0);
    $153 = $152;
   } else {
    $147 = ((($143)) + 4|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ((($148)) + 1|0);
    HEAP32[$147>>2] = $149;
    $150 = HEAP8[$148>>0]|0;
    $151 = $150&255;
    $153 = $151;
   }
   HEAP32[$ls>>2] = $153;
   if ((($153|0) == 61)) {
    $154 = HEAP32[$3>>2]|0;
    $155 = HEAP32[$154>>2]|0;
    $156 = (($155) + -1)|0;
    HEAP32[$154>>2] = $156;
    $157 = ($155|0)==(0);
    if ($157) {
     $163 = (_luaZ_fill($154)|0);
     $164 = $163;
    } else {
     $158 = ((($154)) + 4|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = ((($159)) + 1|0);
     HEAP32[$158>>2] = $160;
     $161 = HEAP8[$159>>0]|0;
     $162 = $161&255;
     $164 = $162;
    }
    HEAP32[$ls>>2] = $164;
    $$0 = 283;
    STACKTOP = sp;return ($$0|0);
   } else if ((($153|0) == 62)) {
    $165 = HEAP32[$3>>2]|0;
    $166 = HEAP32[$165>>2]|0;
    $167 = (($166) + -1)|0;
    HEAP32[$165>>2] = $167;
    $168 = ($166|0)==(0);
    if ($168) {
     $174 = (_luaZ_fill($165)|0);
     $175 = $174;
    } else {
     $169 = ((($165)) + 4|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = ((($170)) + 1|0);
     HEAP32[$169>>2] = $171;
     $172 = HEAP8[$170>>0]|0;
     $173 = $172&255;
     $175 = $173;
    }
    HEAP32[$ls>>2] = $175;
    $$0 = 287;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$0 = 62;
    STACKTOP = sp;return ($$0|0);
   }
   break;
  }
  case 71: {
   $176 = HEAP32[$3>>2]|0;
   $177 = HEAP32[$176>>2]|0;
   $178 = (($177) + -1)|0;
   HEAP32[$176>>2] = $178;
   $179 = ($177|0)==(0);
   if ($179) {
    $185 = (_luaZ_fill($176)|0);
    $186 = $185;
   } else {
    $180 = ((($176)) + 4|0);
    $181 = HEAP32[$180>>2]|0;
    $182 = ((($181)) + 1|0);
    HEAP32[$180>>2] = $182;
    $183 = HEAP8[$181>>0]|0;
    $184 = $183&255;
    $186 = $184;
   }
   HEAP32[$ls>>2] = $186;
   $187 = ($186|0)==(47);
   if (!($187)) {
    $$0 = 47;
    STACKTOP = sp;return ($$0|0);
   }
   $188 = HEAP32[$3>>2]|0;
   $189 = HEAP32[$188>>2]|0;
   $190 = (($189) + -1)|0;
   HEAP32[$188>>2] = $190;
   $191 = ($189|0)==(0);
   if ($191) {
    $197 = (_luaZ_fill($188)|0);
    $198 = $197;
   } else {
    $192 = ((($188)) + 4|0);
    $193 = HEAP32[$192>>2]|0;
    $194 = ((($193)) + 1|0);
    HEAP32[$192>>2] = $194;
    $195 = HEAP8[$193>>0]|0;
    $196 = $195&255;
    $198 = $196;
   }
   HEAP32[$ls>>2] = $198;
   $$0 = 279;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 79: {
   $199 = HEAP32[$3>>2]|0;
   $200 = HEAP32[$199>>2]|0;
   $201 = (($200) + -1)|0;
   HEAP32[$199>>2] = $201;
   $202 = ($200|0)==(0);
   if ($202) {
    $208 = (_luaZ_fill($199)|0);
    $209 = $208;
   } else {
    $203 = ((($199)) + 4|0);
    $204 = HEAP32[$203>>2]|0;
    $205 = ((($204)) + 1|0);
    HEAP32[$203>>2] = $205;
    $206 = HEAP8[$204>>0]|0;
    $207 = $206&255;
    $209 = $207;
   }
   HEAP32[$ls>>2] = $209;
   $210 = ($209|0)==(61);
   if (!($210)) {
    $$0 = 126;
    STACKTOP = sp;return ($$0|0);
   }
   $211 = HEAP32[$3>>2]|0;
   $212 = HEAP32[$211>>2]|0;
   $213 = (($212) + -1)|0;
   HEAP32[$211>>2] = $213;
   $214 = ($212|0)==(0);
   if ($214) {
    $220 = (_luaZ_fill($211)|0);
    $221 = $220;
   } else {
    $215 = ((($211)) + 4|0);
    $216 = HEAP32[$215>>2]|0;
    $217 = ((($216)) + 1|0);
    HEAP32[$215>>2] = $217;
    $218 = HEAP8[$216>>0]|0;
    $219 = $218&255;
    $221 = $219;
   }
   HEAP32[$ls>>2] = $221;
   $$0 = 285;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 87: {
   $222 = HEAP32[$3>>2]|0;
   $223 = HEAP32[$222>>2]|0;
   $224 = (($223) + -1)|0;
   HEAP32[$222>>2] = $224;
   $225 = ($223|0)==(0);
   if ($225) {
    $231 = (_luaZ_fill($222)|0);
    $232 = $231;
   } else {
    $226 = ((($222)) + 4|0);
    $227 = HEAP32[$226>>2]|0;
    $228 = ((($227)) + 1|0);
    HEAP32[$226>>2] = $228;
    $229 = HEAP8[$227>>0]|0;
    $230 = $229&255;
    $232 = $230;
   }
   HEAP32[$ls>>2] = $232;
   $233 = ($232|0)==(58);
   if (!($233)) {
    $$0 = 58;
    STACKTOP = sp;return ($$0|0);
   }
   $234 = HEAP32[$3>>2]|0;
   $235 = HEAP32[$234>>2]|0;
   $236 = (($235) + -1)|0;
   HEAP32[$234>>2] = $236;
   $237 = ($235|0)==(0);
   if ($237) {
    $243 = (_luaZ_fill($234)|0);
    $244 = $243;
   } else {
    $238 = ((($234)) + 4|0);
    $239 = HEAP32[$238>>2]|0;
    $240 = ((($239)) + 1|0);
    HEAP32[$238>>2] = $240;
    $241 = HEAP8[$239>>0]|0;
    $242 = $241&255;
    $244 = $242;
   }
   HEAP32[$ls>>2] = $244;
   $$0 = 288;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 95: {
   $245 = HEAP32[$0>>2]|0;
   $246 = ((($245)) + 4|0);
   $247 = HEAP32[$246>>2]|0;
   $248 = (($247) + 1)|0;
   $249 = ((($245)) + 8|0);
   $250 = HEAP32[$249>>2]|0;
   $251 = ($248>>>0)>($250>>>0);
   do {
    if ($251) {
     $252 = ($250>>>0)>(2147483646);
     if ($252) {
      _lexerror($ls,5552,0);
      // unreachable;
     } else {
      $253 = $250 << 1;
      $254 = ((($ls)) + 52|0);
      $255 = HEAP32[$254>>2]|0;
      $256 = HEAP32[$245>>2]|0;
      $257 = (_luaM_realloc_($255,$256,$250,$253)|0);
      HEAP32[$245>>2] = $257;
      HEAP32[$249>>2] = $253;
      $$pre$i$i = HEAP32[$246>>2]|0;
      $260 = $$pre$i$i;$262 = $257;
      break;
     }
    } else {
     $$pre1$i$i = HEAP32[$245>>2]|0;
     $260 = $247;$262 = $$pre1$i$i;
    }
   } while(0);
   $258 = $$lcssa410&255;
   $259 = (($260) + 1)|0;
   HEAP32[$246>>2] = $259;
   $261 = (($262) + ($260)|0);
   HEAP8[$261>>0] = $258;
   $263 = HEAP32[$3>>2]|0;
   $264 = HEAP32[$263>>2]|0;
   $265 = (($264) + -1)|0;
   HEAP32[$263>>2] = $265;
   $266 = ($264|0)==(0);
   if ($266) {
    $272 = (_luaZ_fill($263)|0);
    $273 = $272;
   } else {
    $267 = ((($263)) + 4|0);
    $268 = HEAP32[$267>>2]|0;
    $269 = ((($268)) + 1|0);
    HEAP32[$267>>2] = $269;
    $270 = HEAP8[$268>>0]|0;
    $271 = $270&255;
    $273 = $271;
   }
   HEAP32[$ls>>2] = $273;
   $274 = ($273|0)==($$lcssa410|0);
   L125: do {
    if (!($274)) {
     $275 = ((($ls)) + 52|0);
     $925 = $273;
     L127: while(1) {
      L129: do {
       if ((($925|0) == 13) | (($925|0) == 10)) {
        label = 108;
        break L127;
       } else if ((($925|0) == 92)) {
        $276 = HEAP32[$0>>2]|0;
        $277 = ((($276)) + 4|0);
        $278 = HEAP32[$277>>2]|0;
        $279 = (($278) + 1)|0;
        $280 = ((($276)) + 8|0);
        $281 = HEAP32[$280>>2]|0;
        $282 = ($279>>>0)>($281>>>0);
        if ($282) {
         $283 = ($281>>>0)>(2147483646);
         if ($283) {
          label = 112;
          break L127;
         }
         $284 = $281 << 1;
         $285 = HEAP32[$275>>2]|0;
         $286 = HEAP32[$276>>2]|0;
         $287 = (_luaM_realloc_($285,$286,$281,$284)|0);
         HEAP32[$276>>2] = $287;
         HEAP32[$280>>2] = $284;
         $$pre$i4$i = HEAP32[$277>>2]|0;
         $289 = $$pre$i4$i;$291 = $287;
        } else {
         $$pre1$i2$i = HEAP32[$276>>2]|0;
         $289 = $278;$291 = $$pre1$i2$i;
        }
        $288 = (($289) + 1)|0;
        HEAP32[$277>>2] = $288;
        $290 = (($291) + ($289)|0);
        HEAP8[$290>>0] = 92;
        $292 = HEAP32[$3>>2]|0;
        $293 = HEAP32[$292>>2]|0;
        $294 = (($293) + -1)|0;
        HEAP32[$292>>2] = $294;
        $295 = ($293|0)==(0);
        if ($295) {
         $301 = (_luaZ_fill($292)|0);
         $302 = $301;
        } else {
         $296 = ((($292)) + 4|0);
         $297 = HEAP32[$296>>2]|0;
         $298 = ((($297)) + 1|0);
         HEAP32[$296>>2] = $298;
         $299 = HEAP8[$297>>0]|0;
         $300 = $299&255;
         $302 = $300;
        }
        HEAP32[$ls>>2] = $302;
        do {
         switch ($302|0) {
         case -1:  {
          $$be43$i = -1;
          break L129;
          break;
         }
         case 98:  {
          $c$0$i = 8;
          label = 317;
          break;
         }
         case 102:  {
          $c$0$i = 12;
          label = 317;
          break;
         }
         case 110:  {
          $c$0$i = 10;
          label = 317;
          break;
         }
         case 114:  {
          $c$0$i = 13;
          label = 317;
          break;
         }
         case 116:  {
          $c$0$i = 9;
          label = 317;
          break;
         }
         case 118:  {
          $c$0$i = 11;
          label = 317;
          break;
         }
         case 117:  {
          $436 = HEAP32[$0>>2]|0;
          $437 = ((($436)) + 4|0);
          $438 = HEAP32[$437>>2]|0;
          $439 = (($438) + 1)|0;
          $440 = ((($436)) + 8|0);
          $441 = HEAP32[$440>>2]|0;
          $442 = ($439>>>0)>($441>>>0);
          if ($442) {
           $443 = ($441>>>0)>(2147483646);
           if ($443) {
            label = 169;
            break L127;
           }
           $444 = $441 << 1;
           $445 = HEAP32[$275>>2]|0;
           $446 = HEAP32[$436>>2]|0;
           $447 = (_luaM_realloc_($445,$446,$441,$444)|0);
           HEAP32[$436>>2] = $447;
           HEAP32[$440>>2] = $444;
           $$pre$i$i$i$i = HEAP32[$437>>2]|0;
           $449 = $$pre$i$i$i$i;$451 = $447;
          } else {
           $$pre1$i$i$i$i = HEAP32[$436>>2]|0;
           $449 = $438;$451 = $$pre1$i$i$i$i;
          }
          $448 = (($449) + 1)|0;
          HEAP32[$437>>2] = $448;
          $450 = (($451) + ($449)|0);
          HEAP8[$450>>0] = 117;
          $452 = HEAP32[$3>>2]|0;
          $453 = HEAP32[$452>>2]|0;
          $454 = (($453) + -1)|0;
          HEAP32[$452>>2] = $454;
          $455 = ($453|0)==(0);
          if ($455) {
           $461 = (_luaZ_fill($452)|0);
           $462 = $461;
          } else {
           $456 = ((($452)) + 4|0);
           $457 = HEAP32[$456>>2]|0;
           $458 = ((($457)) + 1|0);
           HEAP32[$456>>2] = $458;
           $459 = HEAP8[$457>>0]|0;
           $460 = $459&255;
           $462 = $460;
          }
          HEAP32[$ls>>2] = $462;
          if ((($462|0) == -1)) {
           label = 184;
           break L127;
          } else if (!((($462|0) == 123))) {
           $$lcssa380 = $462;
           label = 175;
           break L127;
          }
          $491 = HEAP32[$0>>2]|0;
          $492 = ((($491)) + 4|0);
          $493 = HEAP32[$492>>2]|0;
          $494 = (($493) + 1)|0;
          $495 = ((($491)) + 8|0);
          $496 = HEAP32[$495>>2]|0;
          $497 = ($494>>>0)>($496>>>0);
          if ($497) {
           $498 = ($496>>>0)>(2147483646);
           if ($498) {
            label = 188;
            break L127;
           }
           $499 = $496 << 1;
           $500 = HEAP32[$275>>2]|0;
           $501 = HEAP32[$491>>2]|0;
           $502 = (_luaM_realloc_($500,$501,$496,$499)|0);
           HEAP32[$491>>2] = $502;
           HEAP32[$495>>2] = $499;
           $$pre$i16$i$i$i = HEAP32[$492>>2]|0;
           $504 = $$pre$i16$i$i$i;$506 = $502;
          } else {
           $$pre1$i14$i$i$i = HEAP32[$491>>2]|0;
           $504 = $493;$506 = $$pre1$i14$i$i$i;
          }
          $503 = (($504) + 1)|0;
          HEAP32[$492>>2] = $503;
          $505 = (($506) + ($504)|0);
          HEAP8[$505>>0] = 123;
          $507 = HEAP32[$3>>2]|0;
          $508 = HEAP32[$507>>2]|0;
          $509 = (($508) + -1)|0;
          HEAP32[$507>>2] = $509;
          $510 = ($508|0)==(0);
          if ($510) {
           $516 = (_luaZ_fill($507)|0);
           $517 = $516;
          } else {
           $511 = ((($507)) + 4|0);
           $512 = HEAP32[$511>>2]|0;
           $513 = ((($512)) + 1|0);
           HEAP32[$511>>2] = $513;
           $514 = HEAP8[$512>>0]|0;
           $515 = $514&255;
           $517 = $515;
          }
          HEAP32[$ls>>2] = $517;
          $518 = (($517) + 1)|0;
          $519 = (5048 + ($518)|0);
          $520 = HEAP8[$519>>0]|0;
          $521 = $520 & 16;
          $522 = ($521<<24>>24)==(0);
          if ($522) {
           $$lcssa389 = $517;
           label = 194;
           break L127;
          }
          $552 = (_luaO_hexavalue($517)|0);
          $i$0$i$i$i = 4;$r$0$i$i$i = $552;
          while(1) {
           $553 = HEAP32[$ls>>2]|0;
           $554 = HEAP32[$0>>2]|0;
           $555 = ((($554)) + 4|0);
           $556 = HEAP32[$555>>2]|0;
           $557 = (($556) + 1)|0;
           $558 = ((($554)) + 8|0);
           $559 = HEAP32[$558>>2]|0;
           $560 = ($557>>>0)>($559>>>0);
           if ($560) {
            $561 = ($559>>>0)>(2147483646);
            if ($561) {
             label = 209;
             break L127;
            }
            $562 = $559 << 1;
            $563 = HEAP32[$275>>2]|0;
            $564 = HEAP32[$554>>2]|0;
            $565 = (_luaM_realloc_($563,$564,$559,$562)|0);
            HEAP32[$554>>2] = $565;
            HEAP32[$558>>2] = $562;
            $$pre$i4$i$i$i = HEAP32[$555>>2]|0;
            $568 = $$pre$i4$i$i$i;$570 = $565;
           } else {
            $$pre1$i2$i$i$i = HEAP32[$554>>2]|0;
            $568 = $556;$570 = $$pre1$i2$i$i$i;
           }
           $566 = $553&255;
           $567 = (($568) + 1)|0;
           HEAP32[$555>>2] = $567;
           $569 = (($570) + ($568)|0);
           HEAP8[$569>>0] = $566;
           $571 = HEAP32[$3>>2]|0;
           $572 = HEAP32[$571>>2]|0;
           $573 = (($572) + -1)|0;
           HEAP32[$571>>2] = $573;
           $574 = ($572|0)==(0);
           if ($574) {
            $580 = (_luaZ_fill($571)|0);
            $581 = $580;
           } else {
            $575 = ((($571)) + 4|0);
            $576 = HEAP32[$575>>2]|0;
            $577 = ((($576)) + 1|0);
            HEAP32[$575>>2] = $577;
            $578 = HEAP8[$576>>0]|0;
            $579 = $578&255;
            $581 = $579;
           }
           HEAP32[$ls>>2] = $581;
           $582 = (($581) + 1)|0;
           $583 = (5048 + ($582)|0);
           $584 = HEAP8[$583>>0]|0;
           $585 = $584 & 16;
           $586 = ($585<<24>>24)==(0);
           if ($586) {
            $$lcssa = $581;$i$0$i$i$i$lcssa355 = $i$0$i$i$i;$r$0$i$i$i$lcssa353 = $r$0$i$i$i;
            break;
           }
           $587 = (($i$0$i$i$i) + 1)|0;
           $588 = $r$0$i$i$i << 4;
           $589 = (_luaO_hexavalue($581)|0);
           $590 = (($589) + ($588))|0;
           $591 = ($590>>>0)<(1114112);
           if ($591) {
            $i$0$i$i$i = $587;$r$0$i$i$i = $590;
           } else {
            label = 216;
            break L127;
           }
          }
          if ((($$lcssa|0) == -1)) {
           label = 237;
           break L127;
          } else if (!((($$lcssa|0) == 125))) {
           $$lcssa$lcssa = $$lcssa;
           label = 228;
           break L127;
          }
          $650 = HEAP32[$3>>2]|0;
          $651 = HEAP32[$650>>2]|0;
          $652 = (($651) + -1)|0;
          HEAP32[$650>>2] = $652;
          $653 = ($651|0)==(0);
          if ($653) {
           $659 = (_luaZ_fill($650)|0);
           $660 = $659;
          } else {
           $654 = ((($650)) + 4|0);
           $655 = HEAP32[$654>>2]|0;
           $656 = ((($655)) + 1|0);
           HEAP32[$654>>2] = $656;
           $657 = HEAP8[$655>>0]|0;
           $658 = $657&255;
           $660 = $658;
          }
          HEAP32[$ls>>2] = $660;
          $661 = HEAP32[$0>>2]|0;
          $662 = ((($661)) + 4|0);
          $663 = HEAP32[$662>>2]|0;
          $664 = (($663) - ($i$0$i$i$i$lcssa355))|0;
          HEAP32[$662>>2] = $664;
          $665 = (_luaO_utf8esc($buff$i$i,$r$0$i$i$i$lcssa353)|0);
          $666 = ($665|0)>(0);
          if ($666) {
           $n$06$i$i = $665;
           while(1) {
            $667 = (8 - ($n$06$i$i))|0;
            $668 = (($buff$i$i) + ($667)|0);
            $669 = HEAP8[$668>>0]|0;
            $670 = HEAP32[$0>>2]|0;
            $671 = ((($670)) + 4|0);
            $672 = HEAP32[$671>>2]|0;
            $673 = (($672) + 1)|0;
            $674 = ((($670)) + 8|0);
            $675 = HEAP32[$674>>2]|0;
            $676 = ($673>>>0)>($675>>>0);
            if ($676) {
             $677 = ($675>>>0)>(2147483646);
             if ($677) {
              label = 245;
              break L127;
             }
             $678 = $675 << 1;
             $679 = HEAP32[$275>>2]|0;
             $680 = HEAP32[$670>>2]|0;
             $681 = (_luaM_realloc_($679,$680,$675,$678)|0);
             HEAP32[$670>>2] = $681;
             HEAP32[$674>>2] = $678;
             $$pre$i$i9$i = HEAP32[$671>>2]|0;
             $683 = $$pre$i$i9$i;$685 = $681;
            } else {
             $$pre1$i$i7$i = HEAP32[$670>>2]|0;
             $683 = $672;$685 = $$pre1$i$i7$i;
            }
            $682 = (($683) + 1)|0;
            HEAP32[$671>>2] = $682;
            $684 = (($685) + ($683)|0);
            HEAP8[$684>>0] = $669;
            $686 = (($n$06$i$i) + -1)|0;
            $687 = ($n$06$i$i|0)>(1);
            if ($687) {
             $n$06$i$i = $686;
            } else {
             break;
            }
           }
          }
          break;
         }
         case 120:  {
          $304 = HEAP32[$0>>2]|0;
          $305 = ((($304)) + 4|0);
          $306 = HEAP32[$305>>2]|0;
          $307 = (($306) + 1)|0;
          $308 = ((($304)) + 8|0);
          $309 = HEAP32[$308>>2]|0;
          $310 = ($307>>>0)>($309>>>0);
          if ($310) {
           $311 = ($309>>>0)>(2147483646);
           if ($311) {
            label = 128;
            break L127;
           }
           $312 = $309 << 1;
           $313 = HEAP32[$275>>2]|0;
           $314 = HEAP32[$304>>2]|0;
           $315 = (_luaM_realloc_($313,$314,$309,$312)|0);
           HEAP32[$304>>2] = $315;
           HEAP32[$308>>2] = $312;
           $$pre$i$i$i = HEAP32[$305>>2]|0;
           $317 = $$pre$i$i$i;$319 = $315;
          } else {
           $$pre1$i$i$i = HEAP32[$304>>2]|0;
           $317 = $306;$319 = $$pre1$i$i$i;
          }
          $316 = (($317) + 1)|0;
          HEAP32[$305>>2] = $316;
          $318 = (($319) + ($317)|0);
          HEAP8[$318>>0] = 120;
          $320 = HEAP32[$3>>2]|0;
          $321 = HEAP32[$320>>2]|0;
          $322 = (($321) + -1)|0;
          HEAP32[$320>>2] = $322;
          $323 = ($321|0)==(0);
          if ($323) {
           $329 = (_luaZ_fill($320)|0);
           $330 = $329;
          } else {
           $324 = ((($320)) + 4|0);
           $325 = HEAP32[$324>>2]|0;
           $326 = ((($325)) + 1|0);
           HEAP32[$324>>2] = $326;
           $327 = HEAP8[$325>>0]|0;
           $328 = $327&255;
           $330 = $328;
          }
          HEAP32[$ls>>2] = $330;
          $331 = (($330) + 1)|0;
          $332 = (5048 + ($331)|0);
          $333 = HEAP8[$332>>0]|0;
          $334 = $333 & 16;
          $335 = ($334<<24>>24)==(0);
          if ($335) {
           $$lcssa395 = $330;
           label = 134;
           break L127;
          }
          $365 = (_luaO_hexavalue($330)|0);
          $366 = $365 << 4;
          $367 = HEAP32[$ls>>2]|0;
          $368 = HEAP32[$0>>2]|0;
          $369 = ((($368)) + 4|0);
          $370 = HEAP32[$369>>2]|0;
          $371 = (($370) + 1)|0;
          $372 = ((($368)) + 8|0);
          $373 = HEAP32[$372>>2]|0;
          $374 = ($371>>>0)>($373>>>0);
          if ($374) {
           $375 = ($373>>>0)>(2147483646);
           if ($375) {
            label = 148;
            break L127;
           }
           $376 = $373 << 1;
           $377 = HEAP32[$275>>2]|0;
           $378 = HEAP32[$368>>2]|0;
           $379 = (_luaM_realloc_($377,$378,$373,$376)|0);
           HEAP32[$368>>2] = $379;
           HEAP32[$372>>2] = $376;
           $$pre$i5$i$i = HEAP32[$369>>2]|0;
           $382 = $$pre$i5$i$i;$384 = $379;
          } else {
           $$pre1$i3$i$i = HEAP32[$368>>2]|0;
           $382 = $370;$384 = $$pre1$i3$i$i;
          }
          $380 = $367&255;
          $381 = (($382) + 1)|0;
          HEAP32[$369>>2] = $381;
          $383 = (($384) + ($382)|0);
          HEAP8[$383>>0] = $380;
          $385 = HEAP32[$3>>2]|0;
          $386 = HEAP32[$385>>2]|0;
          $387 = (($386) + -1)|0;
          HEAP32[$385>>2] = $387;
          $388 = ($386|0)==(0);
          if ($388) {
           $394 = (_luaZ_fill($385)|0);
           $395 = $394;
          } else {
           $389 = ((($385)) + 4|0);
           $390 = HEAP32[$389>>2]|0;
           $391 = ((($390)) + 1|0);
           HEAP32[$389>>2] = $391;
           $392 = HEAP8[$390>>0]|0;
           $393 = $392&255;
           $395 = $393;
          }
          HEAP32[$ls>>2] = $395;
          $396 = (($395) + 1)|0;
          $397 = (5048 + ($396)|0);
          $398 = HEAP8[$397>>0]|0;
          $399 = $398 & 16;
          $400 = ($399<<24>>24)==(0);
          if ($400) {
           $$lcssa398 = $395;
           label = 154;
           break L127;
          }
          $430 = (_luaO_hexavalue($395)|0);
          $431 = (($430) + ($366))|0;
          $432 = HEAP32[$0>>2]|0;
          $433 = ((($432)) + 4|0);
          $434 = HEAP32[$433>>2]|0;
          $435 = (($434) + -2)|0;
          HEAP32[$433>>2] = $435;
          $c$0$i = $431;
          label = 317;
          break;
         }
         case 13: case 10:  {
          $688 = HEAP32[$3>>2]|0;
          $689 = HEAP32[$688>>2]|0;
          $690 = (($689) + -1)|0;
          HEAP32[$688>>2] = $690;
          $691 = ($689|0)==(0);
          if ($691) {
           $697 = (_luaZ_fill($688)|0);
           $698 = $697;
          } else {
           $692 = ((($688)) + 4|0);
           $693 = HEAP32[$692>>2]|0;
           $694 = ((($693)) + 1|0);
           HEAP32[$692>>2] = $694;
           $695 = HEAP8[$693>>0]|0;
           $696 = $695&255;
           $698 = $696;
          }
          HEAP32[$ls>>2] = $698;
          if ((($698|0) == 13) | (($698|0) == 10)) {
           $699 = ($698|0)==($302|0);
           if (!($699)) {
            $700 = HEAP32[$3>>2]|0;
            $701 = HEAP32[$700>>2]|0;
            $702 = (($701) + -1)|0;
            HEAP32[$700>>2] = $702;
            $703 = ($701|0)==(0);
            if ($703) {
             $709 = (_luaZ_fill($700)|0);
             $710 = $709;
            } else {
             $704 = ((($700)) + 4|0);
             $705 = HEAP32[$704>>2]|0;
             $706 = ((($705)) + 1|0);
             HEAP32[$704>>2] = $706;
             $707 = HEAP8[$705>>0]|0;
             $708 = $707&255;
             $710 = $708;
            }
            HEAP32[$ls>>2] = $710;
           }
          }
          $711 = HEAP32[$4>>2]|0;
          $712 = (($711) + 1)|0;
          HEAP32[$4>>2] = $712;
          $713 = ($712|0)==(2147483647);
          if ($713) {
           label = 259;
           break L127;
          } else {
           $c$1$i = 10;
           label = 321;
          }
          break;
         }
         case 39: case 34: case 92:  {
          $c$0$i = $302;
          label = 317;
          break;
         }
         case 122:  {
          $714 = HEAP32[$0>>2]|0;
          $715 = ((($714)) + 4|0);
          $716 = HEAP32[$715>>2]|0;
          $717 = (($716) + -1)|0;
          HEAP32[$715>>2] = $717;
          $718 = HEAP32[$3>>2]|0;
          $719 = HEAP32[$718>>2]|0;
          $720 = (($719) + -1)|0;
          HEAP32[$718>>2] = $720;
          $721 = ($719|0)==(0);
          if ($721) {
           $727 = (_luaZ_fill($718)|0);
           $728 = $727;
          } else {
           $722 = ((($718)) + 4|0);
           $723 = HEAP32[$722>>2]|0;
           $724 = ((($723)) + 1|0);
           HEAP32[$722>>2] = $724;
           $725 = HEAP8[$723>>0]|0;
           $726 = $725&255;
           $728 = $726;
          }
          HEAP32[$ls>>2] = $728;
          $729 = (($728) + 1)|0;
          $730 = (5048 + ($729)|0);
          $731 = HEAP8[$730>>0]|0;
          $732 = $731 & 8;
          $733 = ($732<<24>>24)==(0);
          if (!($733)) {
           $746 = $728;
           while(1) {
            if ((($746|0) == 13) | (($746|0) == 10)) {
             $734 = HEAP32[$3>>2]|0;
             $735 = HEAP32[$734>>2]|0;
             $736 = (($735) + -1)|0;
             HEAP32[$734>>2] = $736;
             $737 = ($735|0)==(0);
             if ($737) {
              $743 = (_luaZ_fill($734)|0);
              $744 = $743;
             } else {
              $738 = ((($734)) + 4|0);
              $739 = HEAP32[$738>>2]|0;
              $740 = ((($739)) + 1|0);
              HEAP32[$738>>2] = $740;
              $741 = HEAP8[$739>>0]|0;
              $742 = $741&255;
              $744 = $742;
             }
             HEAP32[$ls>>2] = $744;
             if ((($744|0) == 13) | (($744|0) == 10)) {
              $745 = ($744|0)==($746|0);
              if ($745) {
               $$pr40$i = $746;
              } else {
               $747 = HEAP32[$3>>2]|0;
               $748 = HEAP32[$747>>2]|0;
               $749 = (($748) + -1)|0;
               HEAP32[$747>>2] = $749;
               $750 = ($748|0)==(0);
               if ($750) {
                $756 = (_luaZ_fill($747)|0);
                $757 = $756;
               } else {
                $751 = ((($747)) + 4|0);
                $752 = HEAP32[$751>>2]|0;
                $753 = ((($752)) + 1|0);
                HEAP32[$751>>2] = $753;
                $754 = HEAP8[$752>>0]|0;
                $755 = $754&255;
                $757 = $755;
               }
               HEAP32[$ls>>2] = $757;
               $$pr40$i = $757;
              }
             } else {
              $$pr40$i = $744;
             }
             $758 = HEAP32[$4>>2]|0;
             $759 = (($758) + 1)|0;
             HEAP32[$4>>2] = $759;
             $760 = ($759|0)==(2147483647);
             if ($760) {
              label = 276;
              break L127;
             } else {
              $$be$i = $$pr40$i;
             }
            } else {
             $761 = HEAP32[$3>>2]|0;
             $762 = HEAP32[$761>>2]|0;
             $763 = (($762) + -1)|0;
             HEAP32[$761>>2] = $763;
             $764 = ($762|0)==(0);
             if ($764) {
              $770 = (_luaZ_fill($761)|0);
              $771 = $770;
             } else {
              $765 = ((($761)) + 4|0);
              $766 = HEAP32[$765>>2]|0;
              $767 = ((($766)) + 1|0);
              HEAP32[$765>>2] = $767;
              $768 = HEAP8[$766>>0]|0;
              $769 = $768&255;
              $771 = $769;
             }
             HEAP32[$ls>>2] = $771;
             $$be$i = $771;
            }
            $772 = (($$be$i) + 1)|0;
            $773 = (5048 + ($772)|0);
            $774 = HEAP8[$773>>0]|0;
            $775 = $774 & 8;
            $776 = ($775<<24>>24)==(0);
            if ($776) {
             break;
            } else {
             $746 = $$be$i;
            }
           }
          }
          break;
         }
         case 97:  {
          $c$0$i = 7;
          label = 317;
          break;
         }
         default: {
          $777 = (($302) + 1)|0;
          $778 = (5048 + ($777)|0);
          $779 = HEAP8[$778>>0]|0;
          $780 = $779 & 2;
          $781 = ($780<<24>>24)==(0);
          if ($781) {
           $$lcssa376 = $302;
           label = 283;
           break L127;
          } else {
           $812 = $302;$i$08$i$i = 0;$r$09$i$i = 0;
          }
          while(1) {
           $811 = (($812) + 1)|0;
           $813 = (5048 + ($811)|0);
           $814 = HEAP8[$813>>0]|0;
           $815 = $814 & 2;
           $816 = ($815<<24>>24)==(0);
           if ($816) {
            $1153 = $812;$i$0$lcssa$i$i = $i$08$i$i;$r$0$lcssa$i$i = $r$09$i$i;
            break;
           }
           $817 = ($r$09$i$i*10)|0;
           $818 = (($812) + -48)|0;
           $819 = (($818) + ($817))|0;
           $820 = HEAP32[$0>>2]|0;
           $821 = ((($820)) + 4|0);
           $822 = HEAP32[$821>>2]|0;
           $823 = (($822) + 1)|0;
           $824 = ((($820)) + 8|0);
           $825 = HEAP32[$824>>2]|0;
           $826 = ($823>>>0)>($825>>>0);
           if ($826) {
            $827 = ($825>>>0)>(2147483646);
            if ($827) {
             label = 298;
             break L127;
            }
            $828 = $825 << 1;
            $829 = HEAP32[$275>>2]|0;
            $830 = HEAP32[$820>>2]|0;
            $831 = (_luaM_realloc_($829,$830,$825,$828)|0);
            HEAP32[$820>>2] = $831;
            HEAP32[$824>>2] = $828;
            $$pre$i$i17$i = HEAP32[$821>>2]|0;
            $834 = $$pre$i$i17$i;$836 = $831;
           } else {
            $$pre1$i$i15$i = HEAP32[$820>>2]|0;
            $834 = $822;$836 = $$pre1$i$i15$i;
           }
           $832 = $812&255;
           $833 = (($834) + 1)|0;
           HEAP32[$821>>2] = $833;
           $835 = (($836) + ($834)|0);
           HEAP8[$835>>0] = $832;
           $837 = HEAP32[$3>>2]|0;
           $838 = HEAP32[$837>>2]|0;
           $839 = (($838) + -1)|0;
           HEAP32[$837>>2] = $839;
           $840 = ($838|0)==(0);
           if ($840) {
            $846 = (_luaZ_fill($837)|0);
            $847 = $846;
           } else {
            $841 = ((($837)) + 4|0);
            $842 = HEAP32[$841>>2]|0;
            $843 = ((($842)) + 1|0);
            HEAP32[$841>>2] = $843;
            $844 = HEAP8[$842>>0]|0;
            $845 = $844&255;
            $847 = $845;
           }
           HEAP32[$ls>>2] = $847;
           $848 = (($i$08$i$i) + 1)|0;
           $849 = ($848|0)<(3);
           if ($849) {
            $812 = $847;$i$08$i$i = $848;$r$09$i$i = $819;
           } else {
            $1153 = $847;$i$0$lcssa$i$i = $848;$r$0$lcssa$i$i = $819;
            break;
           }
          }
          $850 = ($r$0$lcssa$i$i|0)<(256);
          if (!($850)) {
           $$lcssa399 = $1153;
           label = 305;
           break L127;
          }
          $880 = HEAP32[$0>>2]|0;
          $881 = ((($880)) + 4|0);
          $882 = HEAP32[$881>>2]|0;
          $883 = (($882) - ($i$0$lcssa$i$i))|0;
          HEAP32[$881>>2] = $883;
          $c$1$i = $r$0$lcssa$i$i;
          label = 321;
         }
         }
        } while(0);
        if ((label|0) == 317) {
         label = 0;
         $884 = HEAP32[$3>>2]|0;
         $885 = HEAP32[$884>>2]|0;
         $886 = (($885) + -1)|0;
         HEAP32[$884>>2] = $886;
         $887 = ($885|0)==(0);
         if ($887) {
          $893 = (_luaZ_fill($884)|0);
          $894 = $893;
         } else {
          $888 = ((($884)) + 4|0);
          $889 = HEAP32[$888>>2]|0;
          $890 = ((($889)) + 1|0);
          HEAP32[$888>>2] = $890;
          $891 = HEAP8[$889>>0]|0;
          $892 = $891&255;
          $894 = $892;
         }
         HEAP32[$ls>>2] = $894;
         $c$1$i = $c$0$i;
         label = 321;
        }
        if ((label|0) == 321) {
         label = 0;
         $895 = HEAP32[$0>>2]|0;
         $896 = ((($895)) + 4|0);
         $897 = HEAP32[$896>>2]|0;
         $898 = (($897) + -1)|0;
         HEAP32[$896>>2] = $898;
         $899 = ((($895)) + 8|0);
         $900 = HEAP32[$899>>2]|0;
         $901 = ($897>>>0)>($900>>>0);
         if ($901) {
          $902 = ($900>>>0)>(2147483646);
          if ($902) {
           label = 324;
           break L127;
          }
          $903 = $900 << 1;
          $904 = HEAP32[$275>>2]|0;
          $905 = HEAP32[$895>>2]|0;
          $906 = (_luaM_realloc_($904,$905,$900,$903)|0);
          HEAP32[$895>>2] = $906;
          HEAP32[$899>>2] = $903;
          $$pre$i23$i = HEAP32[$896>>2]|0;
          $909 = $$pre$i23$i;$911 = $906;
         } else {
          $$pre1$i21$i = HEAP32[$895>>2]|0;
          $909 = $898;$911 = $$pre1$i21$i;
         }
         $907 = $c$1$i&255;
         $908 = (($909) + 1)|0;
         HEAP32[$896>>2] = $908;
         $910 = (($911) + ($909)|0);
         HEAP8[$910>>0] = $907;
        }
        $$pr$i = HEAP32[$ls>>2]|0;
        $$be43$i = $$pr$i;
       } else if ((($925|0) == -1)) {
        label = 107;
        break L127;
       } else {
        $912 = HEAP32[$0>>2]|0;
        $913 = ((($912)) + 4|0);
        $914 = HEAP32[$913>>2]|0;
        $915 = (($914) + 1)|0;
        $916 = ((($912)) + 8|0);
        $917 = HEAP32[$916>>2]|0;
        $918 = ($915>>>0)>($917>>>0);
        if ($918) {
         $919 = ($917>>>0)>(2147483646);
         if ($919) {
          label = 330;
          break L127;
         }
         $920 = $917 << 1;
         $921 = HEAP32[$275>>2]|0;
         $922 = HEAP32[$912>>2]|0;
         $923 = (_luaM_realloc_($921,$922,$917,$920)|0);
         HEAP32[$912>>2] = $923;
         HEAP32[$916>>2] = $920;
         $$pre$i28$i = HEAP32[$913>>2]|0;
         $927 = $$pre$i28$i;$929 = $923;
        } else {
         $$pre1$i26$i = HEAP32[$912>>2]|0;
         $927 = $914;$929 = $$pre1$i26$i;
        }
        $924 = $925&255;
        $926 = (($927) + 1)|0;
        HEAP32[$913>>2] = $926;
        $928 = (($929) + ($927)|0);
        HEAP8[$928>>0] = $924;
        $930 = HEAP32[$3>>2]|0;
        $931 = HEAP32[$930>>2]|0;
        $932 = (($931) + -1)|0;
        HEAP32[$930>>2] = $932;
        $933 = ($931|0)==(0);
        if ($933) {
         $939 = (_luaZ_fill($930)|0);
         $940 = $939;
        } else {
         $934 = ((($930)) + 4|0);
         $935 = HEAP32[$934>>2]|0;
         $936 = ((($935)) + 1|0);
         HEAP32[$934>>2] = $936;
         $937 = HEAP8[$935>>0]|0;
         $938 = $937&255;
         $940 = $938;
        }
        HEAP32[$ls>>2] = $940;
        $$be43$i = $940;
       }
      } while(0);
      $303 = ($$be43$i|0)==($$lcssa410|0);
      if ($303) {
       break L125;
      } else {
       $925 = $$be43$i;
      }
     }
     switch (label|0) {
      case 107: {
       _lexerror($ls,5584,289);
       // unreachable;
       break;
      }
      case 108: {
       _lexerror($ls,5584,293);
       // unreachable;
       break;
      }
      case 112: {
       _lexerror($ls,5552,0);
       // unreachable;
       break;
      }
      case 128: {
       _lexerror($ls,5552,0);
       // unreachable;
       break;
      }
      case 134: {
       $336 = ($$lcssa395|0)==(-1);
       if ($336) {
        _lexerror($ls,5608,293);
        // unreachable;
       }
       $337 = HEAP32[$0>>2]|0;
       $338 = ((($337)) + 4|0);
       $339 = HEAP32[$338>>2]|0;
       $340 = (($339) + 1)|0;
       $341 = ((($337)) + 8|0);
       $342 = HEAP32[$341>>2]|0;
       $343 = ($340>>>0)>($342>>>0);
       do {
        if ($343) {
         $344 = ($342>>>0)>(2147483646);
         if ($344) {
          _lexerror($ls,5552,0);
          // unreachable;
         } else {
          $345 = $342 << 1;
          $346 = HEAP32[$275>>2]|0;
          $347 = HEAP32[$337>>2]|0;
          $348 = (_luaM_realloc_($346,$347,$342,$345)|0);
          HEAP32[$337>>2] = $348;
          HEAP32[$341>>2] = $345;
          $$pre$i11$i$i = HEAP32[$338>>2]|0;
          $351 = $$pre$i11$i$i;$353 = $348;
          break;
         }
        } else {
         $$pre1$i9$i$i = HEAP32[$337>>2]|0;
         $351 = $339;$353 = $$pre1$i9$i$i;
        }
       } while(0);
       $349 = $$lcssa395&255;
       $350 = (($351) + 1)|0;
       HEAP32[$338>>2] = $350;
       $352 = (($353) + ($351)|0);
       HEAP8[$352>>0] = $349;
       $354 = HEAP32[$3>>2]|0;
       $355 = HEAP32[$354>>2]|0;
       $356 = (($355) + -1)|0;
       HEAP32[$354>>2] = $356;
       $357 = ($355|0)==(0);
       if ($357) {
        $363 = (_luaZ_fill($354)|0);
        $364 = $363;
       } else {
        $358 = ((($354)) + 4|0);
        $359 = HEAP32[$358>>2]|0;
        $360 = ((($359)) + 1|0);
        HEAP32[$358>>2] = $360;
        $361 = HEAP8[$359>>0]|0;
        $362 = $361&255;
        $364 = $362;
       }
       HEAP32[$ls>>2] = $364;
       _lexerror($ls,5608,293);
       // unreachable;
       break;
      }
      case 148: {
       _lexerror($ls,5552,0);
       // unreachable;
       break;
      }
      case 154: {
       $401 = ($$lcssa398|0)==(-1);
       if ($401) {
        _lexerror($ls,5608,293);
        // unreachable;
       }
       $402 = HEAP32[$0>>2]|0;
       $403 = ((($402)) + 4|0);
       $404 = HEAP32[$403>>2]|0;
       $405 = (($404) + 1)|0;
       $406 = ((($402)) + 8|0);
       $407 = HEAP32[$406>>2]|0;
       $408 = ($405>>>0)>($407>>>0);
       do {
        if ($408) {
         $409 = ($407>>>0)>(2147483646);
         if ($409) {
          _lexerror($ls,5552,0);
          // unreachable;
         } else {
          $410 = $407 << 1;
          $411 = HEAP32[$275>>2]|0;
          $412 = HEAP32[$402>>2]|0;
          $413 = (_luaM_realloc_($411,$412,$407,$410)|0);
          HEAP32[$402>>2] = $413;
          HEAP32[$406>>2] = $410;
          $$pre$i16$i$i = HEAP32[$403>>2]|0;
          $416 = $$pre$i16$i$i;$418 = $413;
          break;
         }
        } else {
         $$pre1$i14$i$i = HEAP32[$402>>2]|0;
         $416 = $404;$418 = $$pre1$i14$i$i;
        }
       } while(0);
       $414 = $$lcssa398&255;
       $415 = (($416) + 1)|0;
       HEAP32[$403>>2] = $415;
       $417 = (($418) + ($416)|0);
       HEAP8[$417>>0] = $414;
       $419 = HEAP32[$3>>2]|0;
       $420 = HEAP32[$419>>2]|0;
       $421 = (($420) + -1)|0;
       HEAP32[$419>>2] = $421;
       $422 = ($420|0)==(0);
       if ($422) {
        $428 = (_luaZ_fill($419)|0);
        $429 = $428;
       } else {
        $423 = ((($419)) + 4|0);
        $424 = HEAP32[$423>>2]|0;
        $425 = ((($424)) + 1|0);
        HEAP32[$423>>2] = $425;
        $426 = HEAP8[$424>>0]|0;
        $427 = $426&255;
        $429 = $427;
       }
       HEAP32[$ls>>2] = $429;
       _lexerror($ls,5608,293);
       // unreachable;
       break;
      }
      case 169: {
       _lexerror($ls,5552,0);
       // unreachable;
       break;
      }
      case 175: {
       $463 = HEAP32[$0>>2]|0;
       $464 = ((($463)) + 4|0);
       $465 = HEAP32[$464>>2]|0;
       $466 = (($465) + 1)|0;
       $467 = ((($463)) + 8|0);
       $468 = HEAP32[$467>>2]|0;
       $469 = ($466>>>0)>($468>>>0);
       do {
        if ($469) {
         $470 = ($468>>>0)>(2147483646);
         if ($470) {
          _lexerror($ls,5552,0);
          // unreachable;
         } else {
          $471 = $468 << 1;
          $472 = HEAP32[$275>>2]|0;
          $473 = HEAP32[$463>>2]|0;
          $474 = (_luaM_realloc_($472,$473,$468,$471)|0);
          HEAP32[$463>>2] = $474;
          HEAP32[$467>>2] = $471;
          $$pre$i11$i$i$i = HEAP32[$464>>2]|0;
          $477 = $$pre$i11$i$i$i;$479 = $474;
          break;
         }
        } else {
         $$pre1$i9$i$i$i = HEAP32[$463>>2]|0;
         $477 = $465;$479 = $$pre1$i9$i$i$i;
        }
       } while(0);
       $475 = $$lcssa380&255;
       $476 = (($477) + 1)|0;
       HEAP32[$464>>2] = $476;
       $478 = (($479) + ($477)|0);
       HEAP8[$478>>0] = $475;
       $480 = HEAP32[$3>>2]|0;
       $481 = HEAP32[$480>>2]|0;
       $482 = (($481) + -1)|0;
       HEAP32[$480>>2] = $482;
       $483 = ($481|0)==(0);
       if ($483) {
        $489 = (_luaZ_fill($480)|0);
        $490 = $489;
       } else {
        $484 = ((($480)) + 4|0);
        $485 = HEAP32[$484>>2]|0;
        $486 = ((($485)) + 1|0);
        HEAP32[$484>>2] = $486;
        $487 = HEAP8[$485>>0]|0;
        $488 = $487&255;
        $490 = $488;
       }
       HEAP32[$ls>>2] = $490;
       _lexerror($ls,5640,293);
       // unreachable;
       break;
      }
      case 184: {
       _lexerror($ls,5640,293);
       // unreachable;
       break;
      }
      case 188: {
       _lexerror($ls,5552,0);
       // unreachable;
       break;
      }
      case 194: {
       $523 = ($$lcssa389|0)==(-1);
       if ($523) {
        _lexerror($ls,5608,293);
        // unreachable;
       }
       $524 = HEAP32[$0>>2]|0;
       $525 = ((($524)) + 4|0);
       $526 = HEAP32[$525>>2]|0;
       $527 = (($526) + 1)|0;
       $528 = ((($524)) + 8|0);
       $529 = HEAP32[$528>>2]|0;
       $530 = ($527>>>0)>($529>>>0);
       do {
        if ($530) {
         $531 = ($529>>>0)>(2147483646);
         if ($531) {
          _lexerror($ls,5552,0);
          // unreachable;
         } else {
          $532 = $529 << 1;
          $533 = HEAP32[$275>>2]|0;
          $534 = HEAP32[$524>>2]|0;
          $535 = (_luaM_realloc_($533,$534,$529,$532)|0);
          HEAP32[$524>>2] = $535;
          HEAP32[$528>>2] = $532;
          $$pre$i32$i$i$i = HEAP32[$525>>2]|0;
          $538 = $$pre$i32$i$i$i;$540 = $535;
          break;
         }
        } else {
         $$pre1$i30$i$i$i = HEAP32[$524>>2]|0;
         $538 = $526;$540 = $$pre1$i30$i$i$i;
        }
       } while(0);
       $536 = $$lcssa389&255;
       $537 = (($538) + 1)|0;
       HEAP32[$525>>2] = $537;
       $539 = (($540) + ($538)|0);
       HEAP8[$539>>0] = $536;
       $541 = HEAP32[$3>>2]|0;
       $542 = HEAP32[$541>>2]|0;
       $543 = (($542) + -1)|0;
       HEAP32[$541>>2] = $543;
       $544 = ($542|0)==(0);
       if ($544) {
        $550 = (_luaZ_fill($541)|0);
        $551 = $550;
       } else {
        $545 = ((($541)) + 4|0);
        $546 = HEAP32[$545>>2]|0;
        $547 = ((($546)) + 1|0);
        HEAP32[$545>>2] = $547;
        $548 = HEAP8[$546>>0]|0;
        $549 = $548&255;
        $551 = $549;
       }
       HEAP32[$ls>>2] = $551;
       _lexerror($ls,5608,293);
       // unreachable;
       break;
      }
      case 209: {
       _lexerror($ls,5552,0);
       // unreachable;
       break;
      }
      case 216: {
       $592 = HEAP32[$ls>>2]|0;
       $593 = ($592|0)==(-1);
       if ($593) {
        _lexerror($ls,5656,293);
        // unreachable;
       }
       $594 = HEAP32[$0>>2]|0;
       $595 = ((($594)) + 4|0);
       $596 = HEAP32[$595>>2]|0;
       $597 = (($596) + 1)|0;
       $598 = ((($594)) + 8|0);
       $599 = HEAP32[$598>>2]|0;
       $600 = ($597>>>0)>($599>>>0);
       do {
        if ($600) {
         $601 = ($599>>>0)>(2147483646);
         if ($601) {
          _lexerror($ls,5552,0);
          // unreachable;
         } else {
          $602 = $599 << 1;
          $603 = HEAP32[$275>>2]|0;
          $604 = HEAP32[$594>>2]|0;
          $605 = (_luaM_realloc_($603,$604,$599,$602)|0);
          HEAP32[$594>>2] = $605;
          HEAP32[$598>>2] = $602;
          $$pre$i22$i$i$i = HEAP32[$595>>2]|0;
          $608 = $$pre$i22$i$i$i;$610 = $605;
          break;
         }
        } else {
         $$pre1$i20$i$i$i = HEAP32[$594>>2]|0;
         $608 = $596;$610 = $$pre1$i20$i$i$i;
        }
       } while(0);
       $606 = $592&255;
       $607 = (($608) + 1)|0;
       HEAP32[$595>>2] = $607;
       $609 = (($610) + ($608)|0);
       HEAP8[$609>>0] = $606;
       $611 = HEAP32[$3>>2]|0;
       $612 = HEAP32[$611>>2]|0;
       $613 = (($612) + -1)|0;
       HEAP32[$611>>2] = $613;
       $614 = ($612|0)==(0);
       if ($614) {
        $620 = (_luaZ_fill($611)|0);
        $621 = $620;
       } else {
        $615 = ((($611)) + 4|0);
        $616 = HEAP32[$615>>2]|0;
        $617 = ((($616)) + 1|0);
        HEAP32[$615>>2] = $617;
        $618 = HEAP8[$616>>0]|0;
        $619 = $618&255;
        $621 = $619;
       }
       HEAP32[$ls>>2] = $621;
       _lexerror($ls,5656,293);
       // unreachable;
       break;
      }
      case 228: {
       $622 = HEAP32[$0>>2]|0;
       $623 = ((($622)) + 4|0);
       $624 = HEAP32[$623>>2]|0;
       $625 = (($624) + 1)|0;
       $626 = ((($622)) + 8|0);
       $627 = HEAP32[$626>>2]|0;
       $628 = ($625>>>0)>($627>>>0);
       do {
        if ($628) {
         $629 = ($627>>>0)>(2147483646);
         if ($629) {
          _lexerror($ls,5552,0);
          // unreachable;
         } else {
          $630 = $627 << 1;
          $631 = HEAP32[$275>>2]|0;
          $632 = HEAP32[$622>>2]|0;
          $633 = (_luaM_realloc_($631,$632,$627,$630)|0);
          HEAP32[$622>>2] = $633;
          HEAP32[$626>>2] = $630;
          $$pre$i27$i$i$i = HEAP32[$623>>2]|0;
          $636 = $$pre$i27$i$i$i;$638 = $633;
          break;
         }
        } else {
         $$pre1$i25$i$i$i = HEAP32[$622>>2]|0;
         $636 = $624;$638 = $$pre1$i25$i$i$i;
        }
       } while(0);
       $634 = $$lcssa$lcssa&255;
       $635 = (($636) + 1)|0;
       HEAP32[$623>>2] = $635;
       $637 = (($638) + ($636)|0);
       HEAP8[$637>>0] = $634;
       $639 = HEAP32[$3>>2]|0;
       $640 = HEAP32[$639>>2]|0;
       $641 = (($640) + -1)|0;
       HEAP32[$639>>2] = $641;
       $642 = ($640|0)==(0);
       if ($642) {
        $648 = (_luaZ_fill($639)|0);
        $649 = $648;
       } else {
        $643 = ((($639)) + 4|0);
        $644 = HEAP32[$643>>2]|0;
        $645 = ((($644)) + 1|0);
        HEAP32[$643>>2] = $645;
        $646 = HEAP8[$644>>0]|0;
        $647 = $646&255;
        $649 = $647;
       }
       HEAP32[$ls>>2] = $649;
       _lexerror($ls,5680,293);
       // unreachable;
       break;
      }
      case 237: {
       _lexerror($ls,5680,293);
       // unreachable;
       break;
      }
      case 245: {
       _lexerror($ls,5552,0);
       // unreachable;
       break;
      }
      case 259: {
       _lexerror($ls,5488,0);
       // unreachable;
       break;
      }
      case 276: {
       _lexerror($ls,5488,0);
       // unreachable;
       break;
      }
      case 283: {
       $782 = ($$lcssa376|0)==(-1);
       if ($782) {
        _lexerror($ls,5696,293);
        // unreachable;
       }
       $783 = HEAP32[$0>>2]|0;
       $784 = ((($783)) + 4|0);
       $785 = HEAP32[$784>>2]|0;
       $786 = (($785) + 1)|0;
       $787 = ((($783)) + 8|0);
       $788 = HEAP32[$787>>2]|0;
       $789 = ($786>>>0)>($788>>>0);
       do {
        if ($789) {
         $790 = ($788>>>0)>(2147483646);
         if ($790) {
          _lexerror($ls,5552,0);
          // unreachable;
         } else {
          $791 = $788 << 1;
          $792 = HEAP32[$275>>2]|0;
          $793 = HEAP32[$783>>2]|0;
          $794 = (_luaM_realloc_($792,$793,$788,$791)|0);
          HEAP32[$783>>2] = $794;
          HEAP32[$787>>2] = $791;
          $$pre$i38$i = HEAP32[$784>>2]|0;
          $797 = $$pre$i38$i;$799 = $794;
          break;
         }
        } else {
         $$pre1$i36$i = HEAP32[$783>>2]|0;
         $797 = $785;$799 = $$pre1$i36$i;
        }
       } while(0);
       $795 = $$lcssa376&255;
       $796 = (($797) + 1)|0;
       HEAP32[$784>>2] = $796;
       $798 = (($799) + ($797)|0);
       HEAP8[$798>>0] = $795;
       $800 = HEAP32[$3>>2]|0;
       $801 = HEAP32[$800>>2]|0;
       $802 = (($801) + -1)|0;
       HEAP32[$800>>2] = $802;
       $803 = ($801|0)==(0);
       if ($803) {
        $809 = (_luaZ_fill($800)|0);
        $810 = $809;
       } else {
        $804 = ((($800)) + 4|0);
        $805 = HEAP32[$804>>2]|0;
        $806 = ((($805)) + 1|0);
        HEAP32[$804>>2] = $806;
        $807 = HEAP8[$805>>0]|0;
        $808 = $807&255;
        $810 = $808;
       }
       HEAP32[$ls>>2] = $810;
       _lexerror($ls,5696,293);
       // unreachable;
       break;
      }
      case 298: {
       _lexerror($ls,5552,0);
       // unreachable;
       break;
      }
      case 305: {
       $851 = ($$lcssa399|0)==(-1);
       if ($851) {
        _lexerror($ls,5720,293);
        // unreachable;
       }
       $852 = HEAP32[$0>>2]|0;
       $853 = ((($852)) + 4|0);
       $854 = HEAP32[$853>>2]|0;
       $855 = (($854) + 1)|0;
       $856 = ((($852)) + 8|0);
       $857 = HEAP32[$856>>2]|0;
       $858 = ($855>>>0)>($857>>>0);
       do {
        if ($858) {
         $859 = ($857>>>0)>(2147483646);
         if ($859) {
          _lexerror($ls,5552,0);
          // unreachable;
         } else {
          $860 = $857 << 1;
          $861 = HEAP32[$275>>2]|0;
          $862 = HEAP32[$852>>2]|0;
          $863 = (_luaM_realloc_($861,$862,$857,$860)|0);
          HEAP32[$852>>2] = $863;
          HEAP32[$856>>2] = $860;
          $$pre$i4$i$i = HEAP32[$853>>2]|0;
          $866 = $$pre$i4$i$i;$868 = $863;
          break;
         }
        } else {
         $$pre1$i2$i$i = HEAP32[$852>>2]|0;
         $866 = $854;$868 = $$pre1$i2$i$i;
        }
       } while(0);
       $864 = $$lcssa399&255;
       $865 = (($866) + 1)|0;
       HEAP32[$853>>2] = $865;
       $867 = (($868) + ($866)|0);
       HEAP8[$867>>0] = $864;
       $869 = HEAP32[$3>>2]|0;
       $870 = HEAP32[$869>>2]|0;
       $871 = (($870) + -1)|0;
       HEAP32[$869>>2] = $871;
       $872 = ($870|0)==(0);
       if ($872) {
        $878 = (_luaZ_fill($869)|0);
        $879 = $878;
       } else {
        $873 = ((($869)) + 4|0);
        $874 = HEAP32[$873>>2]|0;
        $875 = ((($874)) + 1|0);
        HEAP32[$873>>2] = $875;
        $876 = HEAP8[$874>>0]|0;
        $877 = $876&255;
        $879 = $877;
       }
       HEAP32[$ls>>2] = $879;
       _lexerror($ls,5720,293);
       // unreachable;
       break;
      }
      case 324: {
       _lexerror($ls,5552,0);
       // unreachable;
       break;
      }
      case 330: {
       _lexerror($ls,5552,0);
       // unreachable;
       break;
      }
     }
    }
   } while(0);
   $941 = HEAP32[$0>>2]|0;
   $942 = ((($941)) + 4|0);
   $943 = HEAP32[$942>>2]|0;
   $944 = (($943) + 1)|0;
   $945 = ((($941)) + 8|0);
   $946 = HEAP32[$945>>2]|0;
   $947 = ($944>>>0)>($946>>>0);
   do {
    if ($947) {
     $948 = ($946>>>0)>(2147483646);
     if ($948) {
      _lexerror($ls,5552,0);
      // unreachable;
     } else {
      $949 = $946 << 1;
      $950 = ((($ls)) + 52|0);
      $951 = HEAP32[$950>>2]|0;
      $952 = HEAP32[$941>>2]|0;
      $953 = (_luaM_realloc_($951,$952,$946,$949)|0);
      HEAP32[$941>>2] = $953;
      HEAP32[$945>>2] = $949;
      $$pre$i33$i = HEAP32[$942>>2]|0;
      $955 = $$pre$i33$i;$957 = $953;
      break;
     }
    } else {
     $$pre1$i31$i = HEAP32[$941>>2]|0;
     $955 = $943;$957 = $$pre1$i31$i;
    }
   } while(0);
   $954 = (($955) + 1)|0;
   HEAP32[$942>>2] = $954;
   $956 = (($957) + ($955)|0);
   HEAP8[$956>>0] = $258;
   $958 = HEAP32[$3>>2]|0;
   $959 = HEAP32[$958>>2]|0;
   $960 = (($959) + -1)|0;
   HEAP32[$958>>2] = $960;
   $961 = ($959|0)==(0);
   if ($961) {
    $967 = (_luaZ_fill($958)|0);
    $968 = $967;
   } else {
    $962 = ((($958)) + 4|0);
    $963 = HEAP32[$962>>2]|0;
    $964 = ((($963)) + 1|0);
    HEAP32[$962>>2] = $964;
    $965 = HEAP8[$963>>0]|0;
    $966 = $965&255;
    $968 = $966;
   }
   HEAP32[$ls>>2] = $968;
   $969 = HEAP32[$0>>2]|0;
   $970 = HEAP32[$969>>2]|0;
   $971 = ((($970)) + 1|0);
   $972 = ((($969)) + 4|0);
   $973 = HEAP32[$972>>2]|0;
   $974 = (($973) + -2)|0;
   $975 = ((($ls)) + 52|0);
   $976 = HEAP32[$975>>2]|0;
   $977 = (_luaS_newlstr($976,$971,$974)|0);
   $978 = ((($976)) + 8|0);
   $979 = HEAP32[$978>>2]|0;
   $980 = ((($979)) + 16|0);
   HEAP32[$978>>2] = $980;
   HEAP32[$979>>2] = $977;
   $981 = ((($977)) + 4|0);
   $982 = HEAP8[$981>>0]|0;
   $983 = $982&255;
   $984 = $983 | 64;
   $985 = ((($979)) + 8|0);
   HEAP32[$985>>2] = $984;
   $986 = ((($ls)) + 64|0);
   $987 = HEAP32[$986>>2]|0;
   $988 = HEAP32[$978>>2]|0;
   $989 = ((($988)) + -16|0);
   $990 = (_luaH_set($976,$987,$989)|0);
   $991 = ((($990)) + 8|0);
   $992 = HEAP32[$991>>2]|0;
   $993 = ($992|0)==(0);
   if ($993) {
    HEAP32[$990>>2] = 1;
    HEAP32[$991>>2] = 1;
    $994 = ((($976)) + 12|0);
    $995 = HEAP32[$994>>2]|0;
    $996 = ((($995)) + 12|0);
    $997 = HEAP32[$996>>2]|0;
    $998 = ($997|0)>(0);
    if ($998) {
     _luaC_step($976);
     $ts$0$i$i = $977;
    } else {
     $ts$0$i$i = $977;
    }
   } else {
    $999 = ((($990)) + 16|0);
    $1000 = HEAP32[$999>>2]|0;
    $ts$0$i$i = $1000;
   }
   $1001 = HEAP32[$978>>2]|0;
   $1002 = ((($1001)) + -16|0);
   HEAP32[$978>>2] = $1002;
   HEAP32[$seminfo>>2] = $ts$0$i$i;
   $$0 = 293;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 349: {
   $1003 = HEAP32[$0>>2]|0;
   $1004 = ((($1003)) + 4|0);
   $1005 = HEAP32[$1004>>2]|0;
   $1006 = (($1005) + 1)|0;
   $1007 = ((($1003)) + 8|0);
   $1008 = HEAP32[$1007>>2]|0;
   $1009 = ($1006>>>0)>($1008>>>0);
   do {
    if ($1009) {
     $1010 = ($1008>>>0)>(2147483646);
     if ($1010) {
      _lexerror($ls,5552,0);
      // unreachable;
     } else {
      $1011 = $1008 << 1;
      $1012 = ((($ls)) + 52|0);
      $1013 = HEAP32[$1012>>2]|0;
      $1014 = HEAP32[$1003>>2]|0;
      $1015 = (_luaM_realloc_($1013,$1014,$1008,$1011)|0);
      HEAP32[$1003>>2] = $1015;
      HEAP32[$1007>>2] = $1011;
      $$pre$i = HEAP32[$1004>>2]|0;
      $1017 = $$pre$i;$1019 = $1015;
      break;
     }
    } else {
     $$pre1$i = HEAP32[$1003>>2]|0;
     $1017 = $1005;$1019 = $$pre1$i;
    }
   } while(0);
   $1016 = (($1017) + 1)|0;
   HEAP32[$1004>>2] = $1016;
   $1018 = (($1019) + ($1017)|0);
   HEAP8[$1018>>0] = 46;
   $1020 = HEAP32[$3>>2]|0;
   $1021 = HEAP32[$1020>>2]|0;
   $1022 = (($1021) + -1)|0;
   HEAP32[$1020>>2] = $1022;
   $1023 = ($1021|0)==(0);
   if ($1023) {
    $1029 = (_luaZ_fill($1020)|0);
    $1030 = $1029;
   } else {
    $1024 = ((($1020)) + 4|0);
    $1025 = HEAP32[$1024>>2]|0;
    $1026 = ((($1025)) + 1|0);
    HEAP32[$1024>>2] = $1026;
    $1027 = HEAP8[$1025>>0]|0;
    $1028 = $1027&255;
    $1030 = $1028;
   }
   HEAP32[$ls>>2] = $1030;
   $1031 = ($1030|0)==(46);
   if (!($1031)) {
    $1055 = (($1030) + 1)|0;
    $1056 = (5048 + ($1055)|0);
    $1057 = HEAP8[$1056>>0]|0;
    $1058 = $1057 & 2;
    $1059 = ($1058<<24>>24)==(0);
    if ($1059) {
     $$0 = 46;
     STACKTOP = sp;return ($$0|0);
    }
    $1060 = (_read_numeral($ls,$seminfo)|0);
    $$0 = $1060;
    STACKTOP = sp;return ($$0|0);
   }
   $1032 = HEAP32[$3>>2]|0;
   $1033 = HEAP32[$1032>>2]|0;
   $1034 = (($1033) + -1)|0;
   HEAP32[$1032>>2] = $1034;
   $1035 = ($1033|0)==(0);
   if ($1035) {
    $1041 = (_luaZ_fill($1032)|0);
    $1042 = $1041;
   } else {
    $1036 = ((($1032)) + 4|0);
    $1037 = HEAP32[$1036>>2]|0;
    $1038 = ((($1037)) + 1|0);
    HEAP32[$1036>>2] = $1038;
    $1039 = HEAP8[$1037>>0]|0;
    $1040 = $1039&255;
    $1042 = $1040;
   }
   HEAP32[$ls>>2] = $1042;
   $1043 = ($1042|0)==(46);
   if (!($1043)) {
    $$0 = 280;
    STACKTOP = sp;return ($$0|0);
   }
   $1044 = HEAP32[$3>>2]|0;
   $1045 = HEAP32[$1044>>2]|0;
   $1046 = (($1045) + -1)|0;
   HEAP32[$1044>>2] = $1046;
   $1047 = ($1045|0)==(0);
   if ($1047) {
    $1053 = (_luaZ_fill($1044)|0);
    $1054 = $1053;
   } else {
    $1048 = ((($1044)) + 4|0);
    $1049 = HEAP32[$1048>>2]|0;
    $1050 = ((($1049)) + 1|0);
    HEAP32[$1048>>2] = $1050;
    $1051 = HEAP8[$1049>>0]|0;
    $1052 = $1051&255;
    $1054 = $1052;
   }
   HEAP32[$ls>>2] = $1054;
   $$0 = 281;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 368: {
   $1061 = (_read_numeral($ls,$seminfo)|0);
   $$0 = $1061;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 369: {
   $1062 = (($$lcssa400) + 1)|0;
   $1063 = (5048 + ($1062)|0);
   $1064 = HEAP8[$1063>>0]|0;
   $1065 = $1064 & 1;
   $1066 = ($1065<<24>>24)==(0);
   if ($1066) {
    $1141 = HEAP32[$3>>2]|0;
    $1142 = HEAP32[$1141>>2]|0;
    $1143 = (($1142) + -1)|0;
    HEAP32[$1141>>2] = $1143;
    $1144 = ($1142|0)==(0);
    if ($1144) {
     $1150 = (_luaZ_fill($1141)|0);
     $1151 = $1150;
    } else {
     $1145 = ((($1141)) + 4|0);
     $1146 = HEAP32[$1145>>2]|0;
     $1147 = ((($1146)) + 1|0);
     HEAP32[$1145>>2] = $1147;
     $1148 = HEAP8[$1146>>0]|0;
     $1149 = $1148&255;
     $1151 = $1149;
    }
    HEAP32[$ls>>2] = $1151;
    $$0 = $$lcssa400;
    STACKTOP = sp;return ($$0|0);
   }
   $1067 = ((($ls)) + 52|0);
   $1081 = $$lcssa400;
   while(1) {
    $1068 = HEAP32[$0>>2]|0;
    $1069 = ((($1068)) + 4|0);
    $1070 = HEAP32[$1069>>2]|0;
    $1071 = (($1070) + 1)|0;
    $1072 = ((($1068)) + 8|0);
    $1073 = HEAP32[$1072>>2]|0;
    $1074 = ($1071>>>0)>($1073>>>0);
    if ($1074) {
     $1075 = ($1073>>>0)>(2147483646);
     if ($1075) {
      label = 374;
      break;
     }
     $1076 = $1073 << 1;
     $1077 = HEAP32[$1067>>2]|0;
     $1078 = HEAP32[$1068>>2]|0;
     $1079 = (_luaM_realloc_($1077,$1078,$1073,$1076)|0);
     HEAP32[$1068>>2] = $1079;
     HEAP32[$1072>>2] = $1076;
     $$pre$i30 = HEAP32[$1069>>2]|0;
     $1083 = $$pre$i30;$1085 = $1079;
    } else {
     $$pre1$i28 = HEAP32[$1068>>2]|0;
     $1083 = $1070;$1085 = $$pre1$i28;
    }
    $1080 = $1081&255;
    $1082 = (($1083) + 1)|0;
    HEAP32[$1069>>2] = $1082;
    $1084 = (($1085) + ($1083)|0);
    HEAP8[$1084>>0] = $1080;
    $1086 = HEAP32[$3>>2]|0;
    $1087 = HEAP32[$1086>>2]|0;
    $1088 = (($1087) + -1)|0;
    HEAP32[$1086>>2] = $1088;
    $1089 = ($1087|0)==(0);
    if ($1089) {
     $1095 = (_luaZ_fill($1086)|0);
     $1096 = $1095;
    } else {
     $1090 = ((($1086)) + 4|0);
     $1091 = HEAP32[$1090>>2]|0;
     $1092 = ((($1091)) + 1|0);
     HEAP32[$1090>>2] = $1092;
     $1093 = HEAP8[$1091>>0]|0;
     $1094 = $1093&255;
     $1096 = $1094;
    }
    HEAP32[$ls>>2] = $1096;
    $1097 = (($1096) + 1)|0;
    $1098 = (5048 + ($1097)|0);
    $1099 = HEAP8[$1098>>0]|0;
    $1100 = $1099 & 3;
    $1101 = ($1100<<24>>24)==(0);
    if ($1101) {
     break;
    } else {
     $1081 = $1096;
    }
   }
   if ((label|0) == 374) {
    _lexerror($ls,5552,0);
    // unreachable;
   }
   $1102 = HEAP32[$0>>2]|0;
   $1103 = HEAP32[$1102>>2]|0;
   $1104 = ((($1102)) + 4|0);
   $1105 = HEAP32[$1104>>2]|0;
   $1106 = HEAP32[$1067>>2]|0;
   $1107 = (_luaS_newlstr($1106,$1103,$1105)|0);
   $1108 = ((($1106)) + 8|0);
   $1109 = HEAP32[$1108>>2]|0;
   $1110 = ((($1109)) + 16|0);
   HEAP32[$1108>>2] = $1110;
   HEAP32[$1109>>2] = $1107;
   $1111 = ((($1107)) + 4|0);
   $1112 = HEAP8[$1111>>0]|0;
   $1113 = $1112&255;
   $1114 = $1113 | 64;
   $1115 = ((($1109)) + 8|0);
   HEAP32[$1115>>2] = $1114;
   $1116 = ((($ls)) + 64|0);
   $1117 = HEAP32[$1116>>2]|0;
   $1118 = HEAP32[$1108>>2]|0;
   $1119 = ((($1118)) + -16|0);
   $1120 = (_luaH_set($1106,$1117,$1119)|0);
   $1121 = ((($1120)) + 8|0);
   $1122 = HEAP32[$1121>>2]|0;
   $1123 = ($1122|0)==(0);
   if ($1123) {
    HEAP32[$1120>>2] = 1;
    HEAP32[$1121>>2] = 1;
    $1124 = ((($1106)) + 12|0);
    $1125 = HEAP32[$1124>>2]|0;
    $1126 = ((($1125)) + 12|0);
    $1127 = HEAP32[$1126>>2]|0;
    $1128 = ($1127|0)>(0);
    if ($1128) {
     _luaC_step($1106);
     $ts$0$i = $1107;
    } else {
     $ts$0$i = $1107;
    }
   } else {
    $1129 = ((($1120)) + 16|0);
    $1130 = HEAP32[$1129>>2]|0;
    $ts$0$i = $1130;
   }
   $1131 = HEAP32[$1108>>2]|0;
   $1132 = ((($1131)) + -16|0);
   HEAP32[$1108>>2] = $1132;
   HEAP32[$seminfo>>2] = $ts$0$i;
   $1133 = ((($ts$0$i)) + 4|0);
   $1134 = HEAP8[$1133>>0]|0;
   $1135 = ($1134<<24>>24)==(4);
   if (!($1135)) {
    $$0 = 292;
    STACKTOP = sp;return ($$0|0);
   }
   $1136 = ((($ts$0$i)) + 6|0);
   $1137 = HEAP8[$1136>>0]|0;
   $1138 = ($1137<<24>>24)==(0);
   if ($1138) {
    $$0 = 292;
    STACKTOP = sp;return ($$0|0);
   }
   $1139 = $1137&255;
   $1140 = $1139 | 256;
   $$0 = $1140;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 391: {
   STACKTOP = sp;return ($$0|0);
   break;
  }
 }
 return (0)|0;
}
function _skip_sep($ls) {
 $ls = $ls|0;
 var $$lcssa = 0, $$pre$i = 0, $$pre$i4 = 0, $$pre1$i = 0, $$pre1$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0$lcssa = 0, $count$08 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ls>>2]|0;
 $1 = ((($ls)) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 $6 = ((($2)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 do {
  if ($8) {
   $9 = ($7>>>0)>(2147483646);
   if ($9) {
    _lexerror($ls,5552,0);
    // unreachable;
   } else {
    $10 = $7 << 1;
    $11 = ((($ls)) + 52|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = HEAP32[$2>>2]|0;
    $14 = (_luaM_realloc_($12,$13,$7,$10)|0);
    HEAP32[$2>>2] = $14;
    HEAP32[$6>>2] = $10;
    $$pre$i = HEAP32[$3>>2]|0;
    $17 = $$pre$i;$19 = $14;
    break;
   }
  } else {
   $$pre1$i = HEAP32[$2>>2]|0;
   $17 = $4;$19 = $$pre1$i;
  }
 } while(0);
 $15 = $0&255;
 $16 = (($17) + 1)|0;
 HEAP32[$3>>2] = $16;
 $18 = (($19) + ($17)|0);
 HEAP8[$18>>0] = $15;
 $20 = ((($ls)) + 56|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + -1)|0;
 HEAP32[$21>>2] = $23;
 $24 = ($22|0)==(0);
 if ($24) {
  $30 = (_luaZ_fill($21)|0);
  $31 = $30;
 } else {
  $25 = ((($21)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($26)) + 1|0);
  HEAP32[$25>>2] = $27;
  $28 = HEAP8[$26>>0]|0;
  $29 = $28&255;
  $31 = $29;
 }
 HEAP32[$ls>>2] = $31;
 $32 = ($31|0)==(61);
 if (!($32)) {
  $$lcssa = $31;$count$0$lcssa = 0;
  $not$ = ($$lcssa|0)!=($0|0);
  $63 = $not$ << 31 >> 31;
  $64 = $63 ^ $count$0$lcssa;
  return ($64|0);
 }
 $33 = ((($ls)) + 52|0);
 $count$08 = 0;
 while(1) {
  $34 = HEAP32[$1>>2]|0;
  $35 = ((($34)) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 1)|0;
  $38 = ((($34)) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   $41 = ($39>>>0)>(2147483646);
   if ($41) {
    label = 14;
    break;
   }
   $42 = $39 << 1;
   $43 = HEAP32[$33>>2]|0;
   $44 = HEAP32[$34>>2]|0;
   $45 = (_luaM_realloc_($43,$44,$39,$42)|0);
   HEAP32[$34>>2] = $45;
   HEAP32[$38>>2] = $42;
   $$pre$i4 = HEAP32[$35>>2]|0;
   $47 = $$pre$i4;$49 = $45;
  } else {
   $$pre1$i2 = HEAP32[$34>>2]|0;
   $47 = $36;$49 = $$pre1$i2;
  }
  $46 = (($47) + 1)|0;
  HEAP32[$35>>2] = $46;
  $48 = (($49) + ($47)|0);
  HEAP8[$48>>0] = 61;
  $50 = HEAP32[$20>>2]|0;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($51) + -1)|0;
  HEAP32[$50>>2] = $52;
  $53 = ($51|0)==(0);
  if ($53) {
   $59 = (_luaZ_fill($50)|0);
   $60 = $59;
  } else {
   $54 = ((($50)) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ((($55)) + 1|0);
   HEAP32[$54>>2] = $56;
   $57 = HEAP8[$55>>0]|0;
   $58 = $57&255;
   $60 = $58;
  }
  HEAP32[$ls>>2] = $60;
  $61 = (($count$08) + 1)|0;
  $62 = ($60|0)==(61);
  if ($62) {
   $count$08 = $61;
  } else {
   $$lcssa = $60;$count$0$lcssa = $61;
   label = 20;
   break;
  }
 }
 if ((label|0) == 14) {
  _lexerror($ls,5552,0);
  // unreachable;
 }
 else if ((label|0) == 20) {
  $not$ = ($$lcssa|0)!=($0|0);
  $63 = $not$ << 31 >> 31;
  $64 = $63 ^ $count$0$lcssa;
  return ($64|0);
 }
 return (0)|0;
}
function _read_long_string($ls,$seminfo,$sep) {
 $ls = $ls|0;
 $seminfo = $seminfo|0;
 $sep = $sep|0;
 var $$lcssa = 0, $$ph = 0, $$ph$ph = 0, $$pr21 = 0, $$pr22 = 0, $$pre$i = 0, $$pre$i15 = 0, $$pre$i4 = 0, $$pre$i9 = 0, $$pre1$i = 0, $$pre1$i13 = 0, $$pre1$i2 = 0, $$pre1$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ts$0$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($ls)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$ls>>2]|0;
 $3 = ((($ls)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 1)|0;
 $8 = ((($4)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 do {
  if ($10) {
   $11 = ($9>>>0)>(2147483646);
   if ($11) {
    _lexerror($ls,5552,0);
    // unreachable;
   } else {
    $12 = $9 << 1;
    $13 = ((($ls)) + 52|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$4>>2]|0;
    $16 = (_luaM_realloc_($14,$15,$9,$12)|0);
    HEAP32[$4>>2] = $16;
    HEAP32[$8>>2] = $12;
    $$pre$i = HEAP32[$5>>2]|0;
    $19 = $$pre$i;$21 = $16;
    break;
   }
  } else {
   $$pre1$i = HEAP32[$4>>2]|0;
   $19 = $6;$21 = $$pre1$i;
  }
 } while(0);
 $17 = $2&255;
 $18 = (($19) + 1)|0;
 HEAP32[$5>>2] = $18;
 $20 = (($21) + ($19)|0);
 HEAP8[$20>>0] = $17;
 $22 = ((($ls)) + 56|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + -1)|0;
 HEAP32[$23>>2] = $25;
 $26 = ($24|0)==(0);
 if ($26) {
  $32 = (_luaZ_fill($23)|0);
  $33 = $32;
 } else {
  $27 = ((($23)) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ((($28)) + 1|0);
  HEAP32[$27>>2] = $29;
  $30 = HEAP8[$28>>0]|0;
  $31 = $30&255;
  $33 = $31;
 }
 HEAP32[$ls>>2] = $33;
 if ((($33|0) == 13) | (($33|0) == 10)) {
  $34 = HEAP32[$22>>2]|0;
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + -1)|0;
  HEAP32[$34>>2] = $36;
  $37 = ($35|0)==(0);
  if ($37) {
   $43 = (_luaZ_fill($34)|0);
   $44 = $43;
  } else {
   $38 = ((($34)) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39)) + 1|0);
   HEAP32[$38>>2] = $40;
   $41 = HEAP8[$39>>0]|0;
   $42 = $41&255;
   $44 = $42;
  }
  HEAP32[$ls>>2] = $44;
  if ((($44|0) == 13) | (($44|0) == 10)) {
   $45 = ($44|0)==($33|0);
   if ($45) {
    $$pr21 = $33;
   } else {
    $46 = HEAP32[$22>>2]|0;
    $47 = HEAP32[$46>>2]|0;
    $48 = (($47) + -1)|0;
    HEAP32[$46>>2] = $48;
    $49 = ($47|0)==(0);
    if ($49) {
     $55 = (_luaZ_fill($46)|0);
     $56 = $55;
    } else {
     $50 = ((($46)) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($51)) + 1|0);
     HEAP32[$50>>2] = $52;
     $53 = HEAP8[$51>>0]|0;
     $54 = $53&255;
     $56 = $54;
    }
    HEAP32[$ls>>2] = $56;
    $$pr21 = $56;
   }
  } else {
   $$pr21 = $44;
  }
  $57 = HEAP32[$0>>2]|0;
  $58 = (($57) + 1)|0;
  HEAP32[$0>>2] = $58;
  $59 = ($58|0)==(2147483647);
  if ($59) {
   _lexerror($ls,5488,0);
   // unreachable;
  } else {
   $$ph$ph = $$pr21;
  }
 } else {
  $$ph$ph = $33;
 }
 $60 = ($seminfo|0)==(0|0);
 $61 = ((($ls)) + 52|0);
 $$ph = $$ph$ph;
 L28: while(1) {
  L30: do {
   if ($60) {
    $217 = $$ph;
    while(1) {
     if ((($217|0) == 93)) {
      label = 30;
      break L30;
     } else if ((($217|0) == 13) | (($217|0) == 10)) {
      break L30;
     } else if ((($217|0) == -1)) {
      label = 29;
      break L28;
     }
     $62 = HEAP32[$22>>2]|0;
     $63 = HEAP32[$62>>2]|0;
     $64 = (($63) + -1)|0;
     HEAP32[$62>>2] = $64;
     $65 = ($63|0)==(0);
     if ($65) {
      $71 = (_luaZ_fill($62)|0);
      $72 = $71;
     } else {
      $66 = ((($62)) + 4|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ((($67)) + 1|0);
      HEAP32[$66>>2] = $68;
      $69 = HEAP8[$67>>0]|0;
      $70 = $69&255;
      $72 = $70;
     }
     HEAP32[$ls>>2] = $72;
     $217 = $72;
    }
   } else {
    $166 = $$ph;
    while(1) {
     if ((($166|0) == 93)) {
      label = 30;
      break L30;
     } else if ((($166|0) == 13) | (($166|0) == 10)) {
      break L30;
     } else if ((($166|0) == -1)) {
      label = 29;
      break L28;
     }
     $153 = HEAP32[$3>>2]|0;
     $154 = ((($153)) + 4|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = (($155) + 1)|0;
     $157 = ((($153)) + 8|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = ($156>>>0)>($158>>>0);
     if ($159) {
      $160 = ($158>>>0)>(2147483646);
      if ($160) {
       label = 61;
       break L28;
      }
      $161 = $158 << 1;
      $162 = HEAP32[$61>>2]|0;
      $163 = HEAP32[$153>>2]|0;
      $164 = (_luaM_realloc_($162,$163,$158,$161)|0);
      HEAP32[$153>>2] = $164;
      HEAP32[$157>>2] = $161;
      $$pre$i15 = HEAP32[$154>>2]|0;
      $168 = $$pre$i15;$170 = $164;
     } else {
      $$pre1$i13 = HEAP32[$153>>2]|0;
      $168 = $155;$170 = $$pre1$i13;
     }
     $165 = $166&255;
     $167 = (($168) + 1)|0;
     HEAP32[$154>>2] = $167;
     $169 = (($170) + ($168)|0);
     HEAP8[$169>>0] = $165;
     $171 = HEAP32[$22>>2]|0;
     $172 = HEAP32[$171>>2]|0;
     $173 = (($172) + -1)|0;
     HEAP32[$171>>2] = $173;
     $174 = ($172|0)==(0);
     if ($174) {
      $180 = (_luaZ_fill($171)|0);
      $181 = $180;
     } else {
      $175 = ((($171)) + 4|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = ((($176)) + 1|0);
      HEAP32[$175>>2] = $177;
      $178 = HEAP8[$176>>0]|0;
      $179 = $178&255;
      $181 = $179;
     }
     HEAP32[$ls>>2] = $181;
     $166 = $181;
    }
   }
  } while(0);
  if ((label|0) == 30) {
   label = 0;
   $77 = (_skip_sep($ls)|0);
   $78 = ($77|0)==($sep|0);
   $79 = HEAP32[$ls>>2]|0;
   if ($78) {
    $$lcssa = $79;
    label = 31;
    break;
   } else {
    $$ph = $79;
    continue;
   }
  }
  $108 = HEAP32[$3>>2]|0;
  $109 = ((($108)) + 4|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = (($110) + 1)|0;
  $112 = ((($108)) + 8|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = ($111>>>0)>($113>>>0);
  if ($114) {
   $115 = ($113>>>0)>(2147483646);
   if ($115) {
    label = 43;
    break;
   }
   $116 = $113 << 1;
   $117 = HEAP32[$61>>2]|0;
   $118 = HEAP32[$108>>2]|0;
   $119 = (_luaM_realloc_($117,$118,$113,$116)|0);
   HEAP32[$108>>2] = $119;
   HEAP32[$112>>2] = $116;
   $$pre$i9 = HEAP32[$109>>2]|0;
   $121 = $$pre$i9;$123 = $119;
  } else {
   $$pre1$i7 = HEAP32[$108>>2]|0;
   $121 = $110;$123 = $$pre1$i7;
  }
  $120 = (($121) + 1)|0;
  HEAP32[$109>>2] = $120;
  $122 = (($123) + ($121)|0);
  HEAP8[$122>>0] = 10;
  $124 = HEAP32[$ls>>2]|0;
  $125 = HEAP32[$22>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + -1)|0;
  HEAP32[$125>>2] = $127;
  $128 = ($126|0)==(0);
  if ($128) {
   $134 = (_luaZ_fill($125)|0);
   $135 = $134;
  } else {
   $129 = ((($125)) + 4|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = ((($130)) + 1|0);
   HEAP32[$129>>2] = $131;
   $132 = HEAP8[$130>>0]|0;
   $133 = $132&255;
   $135 = $133;
  }
  HEAP32[$ls>>2] = $135;
  if ((($135|0) == 13) | (($135|0) == 10)) {
   $136 = ($135|0)==($124|0);
   if ($136) {
    $$pr22 = $124;
   } else {
    $137 = HEAP32[$22>>2]|0;
    $138 = HEAP32[$137>>2]|0;
    $139 = (($138) + -1)|0;
    HEAP32[$137>>2] = $139;
    $140 = ($138|0)==(0);
    if ($140) {
     $146 = (_luaZ_fill($137)|0);
     $147 = $146;
    } else {
     $141 = ((($137)) + 4|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = ((($142)) + 1|0);
     HEAP32[$141>>2] = $143;
     $144 = HEAP8[$142>>0]|0;
     $145 = $144&255;
     $147 = $145;
    }
    HEAP32[$ls>>2] = $147;
    $$pr22 = $147;
   }
  } else {
   $$pr22 = $135;
  }
  $148 = HEAP32[$0>>2]|0;
  $149 = (($148) + 1)|0;
  HEAP32[$0>>2] = $149;
  $150 = ($149|0)==(2147483647);
  if ($150) {
   label = 55;
   break;
  }
  if (!($60)) {
   $$ph = $$pr22;
   continue;
  }
  $151 = HEAP32[$3>>2]|0;
  $152 = ((($151)) + 4|0);
  HEAP32[$152>>2] = 0;
  $$ph = $$pr22;
 }
 if ((label|0) == 29) {
  $73 = ($seminfo|0)!=(0|0);
  $74 = $73 ? 5792 : 5800;
  $75 = HEAP32[$61>>2]|0;
  HEAP32[$vararg_buffer>>2] = $74;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $1;
  $76 = (_luaO_pushfstring($75,5808,$vararg_buffer)|0);
  _lexerror($ls,$76,289);
  // unreachable;
 }
 else if ((label|0) == 31) {
  $80 = HEAP32[$3>>2]|0;
  $81 = ((($80)) + 4|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (($82) + 1)|0;
  $84 = ((($80)) + 8|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($83>>>0)>($85>>>0);
  do {
   if ($86) {
    $87 = ($85>>>0)>(2147483646);
    if ($87) {
     _lexerror($ls,5552,0);
     // unreachable;
    } else {
     $88 = $85 << 1;
     $89 = HEAP32[$61>>2]|0;
     $90 = HEAP32[$80>>2]|0;
     $91 = (_luaM_realloc_($89,$90,$85,$88)|0);
     HEAP32[$80>>2] = $91;
     HEAP32[$84>>2] = $88;
     $$pre$i4 = HEAP32[$81>>2]|0;
     $94 = $$pre$i4;$96 = $91;
     break;
    }
   } else {
    $$pre1$i2 = HEAP32[$80>>2]|0;
    $94 = $82;$96 = $$pre1$i2;
   }
  } while(0);
  $92 = $$lcssa&255;
  $93 = (($94) + 1)|0;
  HEAP32[$81>>2] = $93;
  $95 = (($96) + ($94)|0);
  HEAP8[$95>>0] = $92;
  $97 = HEAP32[$22>>2]|0;
  $98 = HEAP32[$97>>2]|0;
  $99 = (($98) + -1)|0;
  HEAP32[$97>>2] = $99;
  $100 = ($98|0)==(0);
  if ($100) {
   $106 = (_luaZ_fill($97)|0);
   $107 = $106;
  } else {
   $101 = ((($97)) + 4|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = ((($102)) + 1|0);
   HEAP32[$101>>2] = $103;
   $104 = HEAP8[$102>>0]|0;
   $105 = $104&255;
   $107 = $105;
  }
  HEAP32[$ls>>2] = $107;
  if ($60) {
   STACKTOP = sp;return;
  }
  $182 = HEAP32[$3>>2]|0;
  $183 = HEAP32[$182>>2]|0;
  $184 = (($sep) + 2)|0;
  $185 = (($183) + ($184)|0);
  $186 = ((($182)) + 4|0);
  $187 = HEAP32[$186>>2]|0;
  $188 = $184 << 1;
  $189 = (($187) - ($188))|0;
  $190 = HEAP32[$61>>2]|0;
  $191 = (_luaS_newlstr($190,$185,$189)|0);
  $192 = ((($190)) + 8|0);
  $193 = HEAP32[$192>>2]|0;
  $194 = ((($193)) + 16|0);
  HEAP32[$192>>2] = $194;
  HEAP32[$193>>2] = $191;
  $195 = ((($191)) + 4|0);
  $196 = HEAP8[$195>>0]|0;
  $197 = $196&255;
  $198 = $197 | 64;
  $199 = ((($193)) + 8|0);
  HEAP32[$199>>2] = $198;
  $200 = ((($ls)) + 64|0);
  $201 = HEAP32[$200>>2]|0;
  $202 = HEAP32[$192>>2]|0;
  $203 = ((($202)) + -16|0);
  $204 = (_luaH_set($190,$201,$203)|0);
  $205 = ((($204)) + 8|0);
  $206 = HEAP32[$205>>2]|0;
  $207 = ($206|0)==(0);
  if ($207) {
   HEAP32[$204>>2] = 1;
   HEAP32[$205>>2] = 1;
   $208 = ((($190)) + 12|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = ((($209)) + 12|0);
   $211 = HEAP32[$210>>2]|0;
   $212 = ($211|0)>(0);
   if ($212) {
    _luaC_step($190);
    $ts$0$i = $191;
   } else {
    $ts$0$i = $191;
   }
  } else {
   $213 = ((($204)) + 16|0);
   $214 = HEAP32[$213>>2]|0;
   $ts$0$i = $214;
  }
  $215 = HEAP32[$192>>2]|0;
  $216 = ((($215)) + -16|0);
  HEAP32[$192>>2] = $216;
  HEAP32[$seminfo>>2] = $ts$0$i;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 43) {
  _lexerror($ls,5552,0);
  // unreachable;
 }
 else if ((label|0) == 55) {
  _lexerror($ls,5488,0);
  // unreachable;
 }
 else if ((label|0) == 61) {
  _lexerror($ls,5552,0);
  // unreachable;
 }
}
function _read_numeral($ls,$seminfo) {
 $ls = $ls|0;
 $seminfo = $seminfo|0;
 var $$0 = 0, $$in$i = 0, $$in$i$i = 0, $$in$i1$i = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$i18 = 0, $$pre$i24 = 0, $$pre$i29 = 0, $$pre$i34 = 0, $$pre$i8 = 0, $$pre1$i = 0, $$pre1$i11 = 0, $$pre1$i16 = 0, $$pre1$i22 = 0, $$pre1$i27 = 0, $$pre1$i32 = 0, $$pre1$i6 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0.0, $258 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $expo$0$ph = 0, $obj = 0, $storemerge = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $obj = sp;
 $0 = HEAP32[$ls>>2]|0;
 $1 = ((($ls)) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 $6 = ((($2)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 do {
  if ($8) {
   $9 = ($7>>>0)>(2147483646);
   if ($9) {
    _lexerror($ls,5552,0);
    // unreachable;
   } else {
    $10 = $7 << 1;
    $11 = ((($ls)) + 52|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = HEAP32[$2>>2]|0;
    $14 = (_luaM_realloc_($12,$13,$7,$10)|0);
    HEAP32[$2>>2] = $14;
    HEAP32[$6>>2] = $10;
    $$pre$i = HEAP32[$3>>2]|0;
    $17 = $$pre$i;$19 = $14;
    break;
   }
  } else {
   $$pre1$i = HEAP32[$2>>2]|0;
   $17 = $4;$19 = $$pre1$i;
  }
 } while(0);
 $15 = $0&255;
 $16 = (($17) + 1)|0;
 HEAP32[$3>>2] = $16;
 $18 = (($19) + ($17)|0);
 HEAP8[$18>>0] = $15;
 $20 = ((($ls)) + 56|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + -1)|0;
 HEAP32[$21>>2] = $23;
 $24 = ($22|0)==(0);
 if ($24) {
  $30 = (_luaZ_fill($21)|0);
  $31 = $30;
 } else {
  $25 = ((($21)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($26)) + 1|0);
  HEAP32[$25>>2] = $27;
  $28 = HEAP8[$26>>0]|0;
  $29 = $28&255;
  $31 = $29;
 }
 HEAP32[$ls>>2] = $31;
 $32 = ($0|0)==(48);
 if ($32) {
  if ((($31|0) == 88) | (($31|0) == 120)) {
   $33 = HEAP32[$1>>2]|0;
   $34 = ((($33)) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + 1)|0;
   $37 = ((($33)) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($36>>>0)>($38>>>0);
   do {
    if ($39) {
     $40 = ($38>>>0)>(2147483646);
     if ($40) {
      _lexerror($ls,5552,0);
      // unreachable;
     } else {
      $41 = $38 << 1;
      $42 = ((($ls)) + 52|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = HEAP32[$33>>2]|0;
      $45 = (_luaM_realloc_($43,$44,$38,$41)|0);
      HEAP32[$33>>2] = $45;
      HEAP32[$37>>2] = $41;
      $$pre$i24 = HEAP32[$34>>2]|0;
      $48 = $$pre$i24;$50 = $45;
      break;
     }
    } else {
     $$pre1$i22 = HEAP32[$33>>2]|0;
     $48 = $35;$50 = $$pre1$i22;
    }
   } while(0);
   $46 = $31&255;
   $47 = (($48) + 1)|0;
   HEAP32[$34>>2] = $47;
   $49 = (($50) + ($48)|0);
   HEAP8[$49>>0] = $46;
   $51 = HEAP32[$20>>2]|0;
   $52 = HEAP32[$51>>2]|0;
   $53 = (($52) + -1)|0;
   HEAP32[$51>>2] = $53;
   $54 = ($52|0)==(0);
   if ($54) {
    $60 = (_luaZ_fill($51)|0);
    $61 = $60;
   } else {
    $55 = ((($51)) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ((($56)) + 1|0);
    HEAP32[$55>>2] = $57;
    $58 = HEAP8[$56>>0]|0;
    $59 = $58&255;
    $61 = $59;
   }
   HEAP32[$ls>>2] = $61;
   $258 = $61;$expo$0$ph = 5760;
  } else {
   $258 = $31;$expo$0$ph = 5752;
  }
 } else {
  $258 = $31;$expo$0$ph = 5752;
 }
 $62 = ((($ls)) + 52|0);
 $63 = ((($expo$0$ph)) + 1|0);
 $67 = $258;
 L27: while(1) {
  $64 = HEAP8[$expo$0$ph>>0]|0;
  $65 = $64 << 24 >> 24;
  $66 = ($67|0)==($65|0);
  if ($66) {
   label = 23;
  } else {
   $68 = HEAP8[$63>>0]|0;
   $69 = $68 << 24 >> 24;
   $70 = ($67|0)==($69|0);
   if ($70) {
    label = 23;
   } else {
    $128 = $67;
   }
  }
  if ((label|0) == 23) {
   label = 0;
   $71 = HEAP32[$1>>2]|0;
   $72 = ((($71)) + 4|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($73) + 1)|0;
   $75 = ((($71)) + 8|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($74>>>0)>($76>>>0);
   if ($77) {
    $78 = ($76>>>0)>(2147483646);
    if ($78) {
     label = 26;
     break;
    }
    $79 = $76 << 1;
    $80 = HEAP32[$62>>2]|0;
    $81 = HEAP32[$71>>2]|0;
    $82 = (_luaM_realloc_($80,$81,$76,$79)|0);
    HEAP32[$71>>2] = $82;
    HEAP32[$75>>2] = $79;
    $$pre$i29 = HEAP32[$72>>2]|0;
    $85 = $$pre$i29;$87 = $82;
   } else {
    $$pre1$i27 = HEAP32[$71>>2]|0;
    $85 = $73;$87 = $$pre1$i27;
   }
   $83 = $67&255;
   $84 = (($85) + 1)|0;
   HEAP32[$72>>2] = $84;
   $86 = (($87) + ($85)|0);
   HEAP8[$86>>0] = $83;
   $88 = HEAP32[$20>>2]|0;
   $89 = HEAP32[$88>>2]|0;
   $90 = (($89) + -1)|0;
   HEAP32[$88>>2] = $90;
   $91 = ($89|0)==(0);
   if ($91) {
    $97 = (_luaZ_fill($88)|0);
    $98 = $97;
   } else {
    $92 = ((($88)) + 4|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ((($93)) + 1|0);
    HEAP32[$92>>2] = $94;
    $95 = HEAP8[$93>>0]|0;
    $96 = $95&255;
    $98 = $96;
   }
   HEAP32[$ls>>2] = $98;
   if ((($98|0) == 43) | (($98|0) == 45)) {
    $99 = HEAP32[$1>>2]|0;
    $100 = ((($99)) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = (($101) + 1)|0;
    $103 = ((($99)) + 8|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ($102>>>0)>($104>>>0);
    if ($105) {
     $106 = ($104>>>0)>(2147483646);
     if ($106) {
      label = 35;
      break;
     }
     $107 = $104 << 1;
     $108 = HEAP32[$62>>2]|0;
     $109 = HEAP32[$99>>2]|0;
     $110 = (_luaM_realloc_($108,$109,$104,$107)|0);
     HEAP32[$99>>2] = $110;
     HEAP32[$103>>2] = $107;
     $$pre$i34 = HEAP32[$100>>2]|0;
     $113 = $$pre$i34;$115 = $110;
    } else {
     $$pre1$i32 = HEAP32[$99>>2]|0;
     $113 = $101;$115 = $$pre1$i32;
    }
    $111 = $98&255;
    $112 = (($113) + 1)|0;
    HEAP32[$100>>2] = $112;
    $114 = (($115) + ($113)|0);
    HEAP8[$114>>0] = $111;
    $116 = HEAP32[$20>>2]|0;
    $117 = HEAP32[$116>>2]|0;
    $118 = (($117) + -1)|0;
    HEAP32[$116>>2] = $118;
    $119 = ($117|0)==(0);
    if ($119) {
     $125 = (_luaZ_fill($116)|0);
     $126 = $125;
    } else {
     $120 = ((($116)) + 4|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = ((($121)) + 1|0);
     HEAP32[$120>>2] = $122;
     $123 = HEAP8[$121>>0]|0;
     $124 = $123&255;
     $126 = $124;
    }
    HEAP32[$ls>>2] = $126;
    $128 = $126;
   } else {
    $128 = $98;
   }
  }
  $127 = (($128) + 1)|0;
  $129 = (5048 + ($127)|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = $130 & 16;
  $132 = ($131<<24>>24)==(0);
  do {
   if ($132) {
    $160 = ($128|0)==(46);
    $161 = HEAP32[$1>>2]|0;
    $162 = ((($161)) + 4|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = (($163) + 1)|0;
    $165 = ((($161)) + 8|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = ($164>>>0)>($166>>>0);
    if (!($160)) {
     label = 60;
     break L27;
    }
    if ($167) {
     $168 = ($166>>>0)>(2147483646);
     if ($168) {
      label = 54;
      break L27;
     }
     $169 = $166 << 1;
     $170 = HEAP32[$62>>2]|0;
     $171 = HEAP32[$161>>2]|0;
     $172 = (_luaM_realloc_($170,$171,$166,$169)|0);
     HEAP32[$161>>2] = $172;
     HEAP32[$165>>2] = $169;
     $$pre$i13 = HEAP32[$162>>2]|0;
     $174 = $$pre$i13;$176 = $172;
    } else {
     $$pre1$i11 = HEAP32[$161>>2]|0;
     $174 = $163;$176 = $$pre1$i11;
    }
    $173 = (($174) + 1)|0;
    HEAP32[$162>>2] = $173;
    $175 = (($176) + ($174)|0);
    HEAP8[$175>>0] = 46;
    $177 = HEAP32[$20>>2]|0;
    $178 = HEAP32[$177>>2]|0;
    $179 = (($178) + -1)|0;
    HEAP32[$177>>2] = $179;
    $180 = ($178|0)==(0);
    if ($180) {
     $186 = (_luaZ_fill($177)|0);
     $storemerge = $186;
     break;
    } else {
     $181 = ((($177)) + 4|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = ((($182)) + 1|0);
     HEAP32[$181>>2] = $183;
     $184 = HEAP8[$182>>0]|0;
     $185 = $184&255;
     $storemerge = $185;
     break;
    }
   } else {
    $133 = HEAP32[$1>>2]|0;
    $134 = ((($133)) + 4|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = (($135) + 1)|0;
    $137 = ((($133)) + 8|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = ($136>>>0)>($138>>>0);
    if ($139) {
     $140 = ($138>>>0)>(2147483646);
     if ($140) {
      label = 45;
      break L27;
     }
     $141 = $138 << 1;
     $142 = HEAP32[$62>>2]|0;
     $143 = HEAP32[$133>>2]|0;
     $144 = (_luaM_realloc_($142,$143,$138,$141)|0);
     HEAP32[$133>>2] = $144;
     HEAP32[$137>>2] = $141;
     $$pre$i8 = HEAP32[$134>>2]|0;
     $147 = $$pre$i8;$149 = $144;
    } else {
     $$pre1$i6 = HEAP32[$133>>2]|0;
     $147 = $135;$149 = $$pre1$i6;
    }
    $145 = $128&255;
    $146 = (($147) + 1)|0;
    HEAP32[$134>>2] = $146;
    $148 = (($149) + ($147)|0);
    HEAP8[$148>>0] = $145;
    $150 = HEAP32[$20>>2]|0;
    $151 = HEAP32[$150>>2]|0;
    $152 = (($151) + -1)|0;
    HEAP32[$150>>2] = $152;
    $153 = ($151|0)==(0);
    if ($153) {
     $159 = (_luaZ_fill($150)|0);
     $storemerge = $159;
     break;
    } else {
     $154 = ((($150)) + 4|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = ((($155)) + 1|0);
     HEAP32[$154>>2] = $156;
     $157 = HEAP8[$155>>0]|0;
     $158 = $157&255;
     $storemerge = $158;
     break;
    }
   }
  } while(0);
  HEAP32[$ls>>2] = $storemerge;
  $67 = $storemerge;
 }
 if ((label|0) == 26) {
  _lexerror($ls,5552,0);
  // unreachable;
 }
 else if ((label|0) == 35) {
  _lexerror($ls,5552,0);
  // unreachable;
 }
 else if ((label|0) == 45) {
  _lexerror($ls,5552,0);
  // unreachable;
 }
 else if ((label|0) == 54) {
  _lexerror($ls,5552,0);
  // unreachable;
 }
 else if ((label|0) == 60) {
  do {
   if ($167) {
    $187 = ($166>>>0)>(2147483646);
    if ($187) {
     _lexerror($ls,5552,0);
     // unreachable;
    } else {
     $188 = $166 << 1;
     $189 = HEAP32[$62>>2]|0;
     $190 = HEAP32[$161>>2]|0;
     $191 = (_luaM_realloc_($189,$190,$166,$188)|0);
     HEAP32[$161>>2] = $191;
     HEAP32[$165>>2] = $188;
     $$pre$i18 = HEAP32[$162>>2]|0;
     $193 = $$pre$i18;$195 = $191;
     break;
    }
   } else {
    $$pre1$i16 = HEAP32[$161>>2]|0;
    $193 = $163;$195 = $$pre1$i16;
   }
  } while(0);
  $192 = (($193) + 1)|0;
  HEAP32[$162>>2] = $192;
  $194 = (($195) + ($193)|0);
  HEAP8[$194>>0] = 0;
  $196 = ((($ls)) + 80|0);
  $197 = HEAP8[$196>>0]|0;
  $198 = ($197<<24>>24)==(46);
  if (!($198)) {
   $199 = HEAP32[$1>>2]|0;
   $200 = ((($199)) + 4|0);
   $201 = HEAP32[$200>>2]|0;
   $202 = HEAP32[$199>>2]|0;
   $203 = ($201|0)==(0);
   if (!($203)) {
    $$in$i = $201;
    while(1) {
     $204 = (($$in$i) + -1)|0;
     $205 = (($202) + ($204)|0);
     $206 = HEAP8[$205>>0]|0;
     $207 = ($206<<24>>24)==(46);
     if ($207) {
      HEAP8[$205>>0] = $197;
     }
     $208 = ($204|0)==(0);
     if ($208) {
      break;
     } else {
      $$in$i = $204;
     }
    }
   }
  }
  $209 = HEAP32[$1>>2]|0;
  $210 = HEAP32[$209>>2]|0;
  $211 = (_luaO_str2num($210,$obj)|0);
  $212 = ($211|0)==(0);
  if ($212) {
   $213 = HEAP8[$196>>0]|0;
   $214 = (_localeconv()|0);
   $215 = HEAP32[$214>>2]|0;
   $216 = HEAP8[$215>>0]|0;
   HEAP8[$196>>0] = $216;
   $217 = ($213<<24>>24)==($216<<24>>24);
   if (!($217)) {
    $218 = HEAP32[$1>>2]|0;
    $219 = ((($218)) + 4|0);
    $220 = HEAP32[$219>>2]|0;
    $221 = HEAP32[$218>>2]|0;
    $222 = ($220|0)==(0);
    if (!($222)) {
     $$in$i$i = $220;
     while(1) {
      $223 = (($$in$i$i) + -1)|0;
      $224 = (($221) + ($223)|0);
      $225 = HEAP8[$224>>0]|0;
      $226 = ($225<<24>>24)==($213<<24>>24);
      if ($226) {
       HEAP8[$224>>0] = $216;
      }
      $227 = ($223|0)==(0);
      if ($227) {
       break;
      } else {
       $$in$i$i = $223;
      }
     }
    }
   }
   $228 = HEAP32[$1>>2]|0;
   $229 = HEAP32[$228>>2]|0;
   $230 = (_luaO_str2num($229,$obj)|0);
   $231 = ($230|0)==(0);
   if ($231) {
    $232 = HEAP8[$196>>0]|0;
    $233 = ($232<<24>>24)==(46);
    if ($233) {
     _lexerror($ls,5768,290);
     // unreachable;
    }
    $234 = HEAP32[$1>>2]|0;
    $235 = ((($234)) + 4|0);
    $236 = HEAP32[$235>>2]|0;
    $237 = HEAP32[$234>>2]|0;
    $238 = ($236|0)==(0);
    if ($238) {
     _lexerror($ls,5768,290);
     // unreachable;
    } else {
     $$in$i1$i = $236;
    }
    while(1) {
     $239 = (($$in$i1$i) + -1)|0;
     $240 = (($237) + ($239)|0);
     $241 = HEAP8[$240>>0]|0;
     $242 = ($241<<24>>24)==($232<<24>>24);
     if ($242) {
      HEAP8[$240>>0] = 46;
     }
     $243 = ($239|0)==(0);
     if ($243) {
      break;
     } else {
      $$in$i1$i = $239;
     }
    }
    _lexerror($ls,5768,290);
    // unreachable;
   }
  }
  $244 = ((($obj)) + 8|0);
  $245 = HEAP32[$244>>2]|0;
  $246 = ($245|0)==(19);
  if ($246) {
   $247 = $obj;
   $248 = $247;
   $249 = HEAP32[$248>>2]|0;
   $250 = (($247) + 4)|0;
   $251 = $250;
   $252 = HEAP32[$251>>2]|0;
   $253 = $seminfo;
   $254 = $253;
   HEAP32[$254>>2] = $249;
   $255 = (($253) + 4)|0;
   $256 = $255;
   HEAP32[$256>>2] = $252;
   $$0 = 291;
   STACKTOP = sp;return ($$0|0);
  } else {
   $257 = +HEAPF64[$obj>>3];
   HEAPF64[$seminfo>>3] = $257;
   $$0 = 290;
   STACKTOP = sp;return ($$0|0);
  }
 }
 return (0)|0;
}
function _isprint($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + -32)|0;
 $1 = ($0>>>0)<(95);
 $2 = $1&1;
 return ($2|0);
}
function _strcoll($l,$r) {
 $l = $l|0;
 $r = $r|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp($l,$r)|0);
 return ($0|0);
}
function _strchr($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___strchrnul($s,$c)|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $c&255;
 $3 = ($1<<24>>24)==($2<<24>>24);
 $4 = $3 ? $0 : 0;
 return ($4|0);
}
function ___strchrnul($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $$0 = 0, $$02$lcssa = 0, $$0211 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond5 = 0, $w$0$lcssa = 0, $w$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c & 255;
 $1 = ($0|0)==(0);
 if ($1) {
  $6 = (_strlen(($s|0))|0);
  $7 = (($s) + ($6)|0);
  $$0 = $7;
  return ($$0|0);
 }
 $2 = $s;
 $3 = $2 & 3;
 $4 = ($3|0)==(0);
 L5: do {
  if ($4) {
   $$02$lcssa = $s;
  } else {
   $5 = $c&255;
   $$0211 = $s;
   while(1) {
    $8 = HEAP8[$$0211>>0]|0;
    $9 = ($8<<24>>24)==(0);
    $10 = ($8<<24>>24)==($5<<24>>24);
    $or$cond = $9 | $10;
    if ($or$cond) {
     $$0 = $$0211;
     break;
    }
    $11 = ((($$0211)) + 1|0);
    $12 = $11;
    $13 = $12 & 3;
    $14 = ($13|0)==(0);
    if ($14) {
     $$02$lcssa = $11;
     break L5;
    } else {
     $$0211 = $11;
    }
   }
   return ($$0|0);
  }
 } while(0);
 $15 = Math_imul($0, 16843009)|0;
 $16 = HEAP32[$$02$lcssa>>2]|0;
 $17 = (($16) + -16843009)|0;
 $18 = $16 & -2139062144;
 $19 = $18 ^ -2139062144;
 $20 = $19 & $17;
 $21 = ($20|0)==(0);
 L12: do {
  if ($21) {
   $23 = $16;$w$08 = $$02$lcssa;
   while(1) {
    $22 = $23 ^ $15;
    $24 = (($22) + -16843009)|0;
    $25 = $22 & -2139062144;
    $26 = $25 ^ -2139062144;
    $27 = $26 & $24;
    $28 = ($27|0)==(0);
    if (!($28)) {
     $w$0$lcssa = $w$08;
     break L12;
    }
    $29 = ((($w$08)) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + -16843009)|0;
    $32 = $30 & -2139062144;
    $33 = $32 ^ -2139062144;
    $34 = $33 & $31;
    $35 = ($34|0)==(0);
    if ($35) {
     $23 = $30;$w$08 = $29;
    } else {
     $w$0$lcssa = $29;
     break;
    }
   }
  } else {
   $w$0$lcssa = $$02$lcssa;
  }
 } while(0);
 $36 = $c&255;
 $$1 = $w$0$lcssa;
 while(1) {
  $37 = HEAP8[$$1>>0]|0;
  $38 = ($37<<24>>24)==(0);
  $39 = ($37<<24>>24)==($36<<24>>24);
  $or$cond5 = $38 | $39;
  $40 = ((($$1)) + 1|0);
  if ($or$cond5) {
   $$0 = $$1;
   break;
  } else {
   $$1 = $40;
  }
 }
 return ($$0|0);
}
function _strcspn($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $$0 = 0, $$027 = 0, $$03$lcssa = 0, $$035 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $byteset = 0, $div = 0, $div4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $byteset = sp;
 $0 = HEAP8[$c>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $2 = ((($c)) + 1|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if (!($4)) {
   ;HEAP32[$byteset>>2]=0|0;HEAP32[$byteset+4>>2]=0|0;HEAP32[$byteset+8>>2]=0|0;HEAP32[$byteset+12>>2]=0|0;HEAP32[$byteset+16>>2]=0|0;HEAP32[$byteset+20>>2]=0|0;HEAP32[$byteset+24>>2]=0|0;HEAP32[$byteset+28>>2]=0|0;
   $$027 = $c;$13 = $0;
   while(1) {
    $12 = $13 & 31;
    $14 = $12&255;
    $15 = 1 << $14;
    $div4 = ($13&255) >>> 5;
    $16 = $div4&255;
    $17 = (($byteset) + ($16<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = $18 | $15;
    HEAP32[$17>>2] = $19;
    $20 = ((($$027)) + 1|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     break;
    } else {
     $$027 = $20;$13 = $21;
    }
   }
   $10 = HEAP8[$s>>0]|0;
   $11 = ($10<<24>>24)==(0);
   L7: do {
    if ($11) {
     $$03$lcssa = $s;
    } else {
     $$035 = $s;$23 = $10;
     while(1) {
      $div = ($23&255) >>> 5;
      $24 = $div&255;
      $25 = (($byteset) + ($24<<2)|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = $23 & 31;
      $28 = $27&255;
      $29 = 1 << $28;
      $30 = $26 & $29;
      $31 = ($30|0)==(0);
      if (!($31)) {
       $$03$lcssa = $$035;
       break L7;
      }
      $32 = ((($$035)) + 1|0);
      $33 = HEAP8[$32>>0]|0;
      $34 = ($33<<24>>24)==(0);
      if ($34) {
       $$03$lcssa = $32;
       break;
      } else {
       $$035 = $32;$23 = $33;
      }
     }
    }
   } while(0);
   $35 = $$03$lcssa;
   $36 = $s;
   $37 = (($35) - ($36))|0;
   $$0 = $37;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $5 = $0 << 24 >> 24;
 $6 = (___strchrnul($s,$5)|0);
 $7 = $6;
 $8 = $s;
 $9 = (($7) - ($8))|0;
 $$0 = $9;
 STACKTOP = sp;return ($$0|0);
}
function _strpbrk($s,$b) {
 $s = $s|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcspn($s,$b)|0);
 $1 = (($s) + ($0)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = $3 ? $1 : 0;
 return ($4|0);
}
function _strspn($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $$0 = 0, $$028 = 0, $$03 = 0, $$03$lcssa = 0, $$1$lcssa = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $byteset = 0, $div = 0, $div4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $byteset = sp;
 ;HEAP32[$byteset>>2]=0|0;HEAP32[$byteset+4>>2]=0|0;HEAP32[$byteset+8>>2]=0|0;HEAP32[$byteset+12>>2]=0|0;HEAP32[$byteset+16>>2]=0|0;HEAP32[$byteset+20>>2]=0|0;HEAP32[$byteset+24>>2]=0|0;HEAP32[$byteset+28>>2]=0|0;
 $0 = HEAP8[$c>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ((($c)) + 1|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $$03 = $s;
  while(1) {
   $5 = HEAP8[$$03>>0]|0;
   $6 = ($5<<24>>24)==($0<<24>>24);
   $7 = ((($$03)) + 1|0);
   if ($6) {
    $$03 = $7;
   } else {
    $$03$lcssa = $$03;
    break;
   }
  }
  $8 = $$03$lcssa;
  $9 = $s;
  $10 = (($8) - ($9))|0;
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$028 = $c;$14 = $0;
 }
 while(1) {
  $13 = $14 & 31;
  $15 = $13&255;
  $16 = 1 << $15;
  $div4 = ($14&255) >>> 5;
  $17 = $div4&255;
  $18 = (($byteset) + ($17<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 | $16;
  HEAP32[$18>>2] = $20;
  $21 = ((($$028)) + 1|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   break;
  } else {
   $$028 = $21;$14 = $22;
  }
 }
 $11 = HEAP8[$s>>0]|0;
 $12 = ($11<<24>>24)==(0);
 L12: do {
  if ($12) {
   $$1$lcssa = $s;
  } else {
   $$16 = $s;$24 = $11;
   while(1) {
    $div = ($24&255) >>> 5;
    $25 = $div&255;
    $26 = (($byteset) + ($25<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = $24 & 31;
    $29 = $28&255;
    $30 = 1 << $29;
    $31 = $27 & $30;
    $32 = ($31|0)==(0);
    if ($32) {
     $$1$lcssa = $$16;
     break L12;
    }
    $33 = ((($$16)) + 1|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)==(0);
    if ($35) {
     $$1$lcssa = $33;
     break;
    } else {
     $$16 = $33;$24 = $34;
    }
   }
  }
 } while(0);
 $36 = $$1$lcssa;
 $37 = $s;
 $38 = (($36) - ($37))|0;
 $$0 = $38;
 STACKTOP = sp;return ($$0|0);
}
function _isspace($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($c|0)==(32);
 $1 = (($c) + -9)|0;
 $2 = ($1>>>0)<(5);
 $3 = $0 | $2;
 $4 = $3&1;
 return ($4|0);
}
function ___floatscan($f,$prec,$pok) {
 $f = $f|0;
 $prec = $prec|0;
 $pok = $pok|0;
 var $$$i = 0, $$0 = 0.0, $$0$i25 = 0.0, $$010$i = 0, $$07$i = 0, $$0710$i = 0, $$0711$i = 0, $$09$i = 0, $$1$be$i = 0, $$1$ph$i = 0, $$11$i = 0, $$18$i = 0, $$2$i = 0, $$3$be$i = 0, $$3$lcssa$i = 0, $$3121$i = 0, $$in = 0, $$k$0$i = 0, $$lcssa = 0, $$lcssa288 = 0;
 var $$lcssa289 = 0, $$lcssa308 = 0, $$lcssa308$lcssa = 0, $$lcssa309 = 0, $$lcssa309$lcssa = 0, $$lcssa322 = 0, $$lcssa323 = 0, $$lcssa333 = 0, $$lcssa50$i = 0, $$lnz$0$i = 0, $$neg32$i = 0, $$not$i = 0, $$old8 = 0, $$pn$i = 0.0, $$pre$i = 0, $$pre$i17 = 0, $$pre$phi42$iZ2D = 0.0, $$pre41$i = 0.0, $$promoted = 0, $$promoted$i = 0;
 var $$promoted185 = 0, $$sink$off0$us$i = 0, $$sink$off0$us93$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0, $181 = 0, $182 = 0.0, $183 = 0.0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0.0, $253 = 0.0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0.0, $275 = 0.0;
 var $276 = 0.0, $277 = 0, $278 = 0, $279 = 0.0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0.0, $304 = 0.0, $305 = 0.0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0.0, $312 = 0.0, $313 = 0.0, $314 = 0.0, $315 = 0.0, $316 = 0.0, $317 = 0, $318 = 0, $319 = 0.0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0.0, $419 = 0.0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0.0, $436 = 0.0, $437 = 0.0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0.0, $448 = 0.0, $449 = 0.0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0.0, $46 = 0, $460 = 0.0, $461 = 0.0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0.0;
 var $474 = 0, $475 = 0.0, $476 = 0.0, $477 = 0, $478 = 0.0, $479 = 0, $48 = 0.0, $480 = 0.0, $481 = 0.0, $482 = 0, $483 = 0, $484 = 0, $485 = 0.0, $486 = 0.0, $487 = 0, $488 = 0, $489 = 0, $49 = 0.0, $490 = 0, $491 = 0;
 var $492 = 0.0, $493 = 0.0, $494 = 0.0, $495 = 0, $496 = 0, $497 = 0, $498 = 0.0, $499 = 0.0, $5 = 0, $50 = 0.0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0.0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0.0, $643 = 0.0, $644 = 0.0, $645 = 0, $646 = 0.0, $647 = 0.0, $648 = 0.0, $649 = 0.0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0.0, $661 = 0.0, $662 = 0.0, $663 = 0, $664 = 0.0, $665 = 0.0, $666 = 0, $667 = 0, $668 = 0, $669 = 0.0, $67 = 0, $670 = 0.0, $671 = 0.0;
 var $672 = 0.0, $673 = 0, $674 = 0, $675 = 0.0, $676 = 0, $677 = 0.0, $678 = 0.0, $679 = 0.0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0.0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0.0, $69 = 0;
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0.0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0.0, $702 = 0, $703 = 0, $704 = 0.0, $705 = 0.0, $706 = 0, $707 = 0;
 var $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0;
 var $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$0$lcssa177$i = 0, $a$0101$i = 0, $a$1$i = 0, $a$1$i$lcssa = 0, $a$2$ph38$i = 0, $a$3$i = 0;
 var $a$3$i$lcssa300 = 0, $a$3$i301 = 0, $a$3$ph$i = 0, $a$3$ph183$i = 0, $a$478$i = 0, $a$5$i = 0, $a$5$i$lcssa = 0, $a$5$i$lcssa$lcssa = 0, $bias$0$i = 0.0, $bias$0$i23 = 0.0, $bits$0$ph = 0, $brmerge = 0, $brmerge$i26 = 0, $brmerge187 = 0, $c$0 = 0, $c$0$i = 0, $c$1$lcssa = 0, $c$1$ph$i = 0, $c$185 = 0, $c$2 = 0;
 var $c$2$i = 0, $c$2$lcssa$i = 0, $c$4 = 0, $c$4$1 = 0, $c$6 = 0, $carry$0103$i = 0, $carry1$0$us$i = 0, $carry1$0$us89$i = 0, $carry1$1$lcssa$lcssa$i = 0, $carry1$1$us$i = 0, $carry1$1$us$i$lcssa = 0, $carry1$1$us94$i = 0, $carry1$1$us94$i$lcssa = 0, $carry3$081$i = 0, $cond$i = 0, $d$0$i = 0, $denormal$0$i = 0, $denormal$1$i = 0, $denormal$2$i = 0, $e2$0$ph$i = 0;
 var $e2$0$us$i = 0, $e2$0$us84$i = 0, $e2$1$i = 0, $e2$1$i298 = 0, $e2$1$ph$i = 0, $e2$1$ph182$i = 0, $e2$2$i = 0, $e2$3$i = 0, $emin$0$ph = 0, $exitcond$i = 0, $frac$0$i = 0.0, $frac$1$i = 0.0, $frac$2$i = 0.0, $gotdig$0$i = 0, $gotdig$0$i$lcssa294 = 0, $gotdig$0$i12 = 0, $gotdig$0$i12$lcssa331 = 0, $gotdig$2$i = 0, $gotdig$2$i$lcssa = 0, $gotdig$2$i13 = 0;
 var $gotdig$3$i = 0, $gotdig$3$lcssa$i = 0, $gotdig$3117$i = 0, $gotdig$3117$i$lcssa = 0, $gotdig$4$i = 0, $gotrad$0$i = 0, $gotrad$0$i$lcssa = 0, $gotrad$0$i14 = 0, $gotrad$1$i = 0, $gotrad$1$lcssa$i = 0, $gotrad$1118$i = 0, $gotrad$2$i = 0, $gottail$0$i = 0, $gottail$1$i = 0, $gottail$2$i = 0, $i$0$lcssa = 0, $i$084 = 0, $i$1 = 0, $i$4 = 0, $i$4$lcssa = 0;
 var $j$0$lcssa$i = 0, $j$0120$i = 0, $j$0120$i$lcssa = 0, $j$067$i = 0, $j$068$i = 0, $j$069$i = 0, $j$2$i = 0, $j$3110$i = 0, $k$0$lcssa$i = 0, $k$0119$i = 0, $k$0119$i$lcssa = 0, $k$063$i = 0, $k$064$i = 0, $k$065$i = 0, $k$2$i = 0, $k$3$i = 0, $k$4102$i = 0, $k$5$in$us$i = 0, $k$5$in$us88$i = 0, $k$5$us$i = 0;
 var $k$5$us90$i = 0, $k$5$z$2$us$i = 0, $k$5$z$2$us96$i = 0, $k$679$i = 0, $lnz$0$lcssa$i = 0, $lnz$0116$i = 0, $lnz$0116$i$lcssa = 0, $lnz$057$i = 0, $lnz$058$i = 0, $lnz$059$i = 0, $lnz$2$i = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i16 = 0, $or$cond13$i = 0, $or$cond15$i = 0, $or$cond16$i = 0, $or$cond17$us$i = 0;
 var $or$cond17$us95$i = 0, $or$cond19$i = 0, $or$cond20$i = 0, $or$cond216$i = 0, $or$cond3$i = 0, $or$cond4$i = 0, $or$cond5 = 0, $or$cond6$i = 0, $or$cond7 = 0, $or$cond8$i = 0, $or$cond9$i = 0, $or$cond9$not = 0, $rp$0$lcssa178$i = 0, $rp$0100$i = 0, $rp$1$i18 = 0, $rp$1$i18$lcssa = 0, $rp$2$ph36$i = 0, $rp$3$ph$i = 0, $rp$3$ph34$i = 0, $rp$477$i = 0;
 var $rp$5$i = 0, $rp$5$i$lcssa = 0, $rp$5$i$lcssa$lcssa = 0, $scale$0$i = 0.0, $scale$1$i = 0.0, $scale$2$i = 0.0, $sign$0 = 0, $storemerge$i = 0, $sum$i = 0, $x$0$i = 0, $x$0$i$lcssa = 0, $x$1$i = 0, $x$2$i = 0, $x$3$lcssa$i = 0, $x$324$i = 0, $x$4$lcssa$i = 0, $x$419$i = 0, $x$5$i = 0, $x$6$i = 0, $x$i = 0;
 var $y$0$i = 0.0, $y$0$i$lcssa = 0.0, $y$1$i = 0.0, $y$1$i22 = 0.0, $y$2$i = 0.0, $y$2$i24 = 0.0, $y$3$i = 0.0, $y$3$lcssa$i = 0.0, $y$320$i = 0.0, $y$4$i = 0.0, $y$5$i = 0.0, $z$0$i = 0, $z$1$ph37$i = 0, $z$1$us$i = 0, $z$1$us85$i = 0, $z$2$us$i = 0, $z$2$us87$i = 0, $z$3$lcssa$lcssa$i = 0, $z$3$us$i = 0, $z$3$us$i$lcssa = 0;
 var $z$3$us97$i = 0, $z$3$us97$i$lcssa = 0, $z$4$i = 0, $z$5$ph$i = 0, $z$7$1$i = 0, $z$7$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i = sp;
 if ((($prec|0) == 1)) {
  $bits$0$ph = 53;$emin$0$ph = -1074;
 } else if ((($prec|0) == 2)) {
  $bits$0$ph = 53;$emin$0$ph = -1074;
 } else if ((($prec|0) == 0)) {
  $bits$0$ph = 24;$emin$0$ph = -149;
 } else {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 $0 = ((($f)) + 4|0);
 $1 = ((($f)) + 100|0);
 while(1) {
  $2 = HEAP32[$0>>2]|0;
  $3 = HEAP32[$1>>2]|0;
  $4 = ($2>>>0)<($3>>>0);
  if ($4) {
   $5 = ((($2)) + 1|0);
   HEAP32[$0>>2] = $5;
   $6 = HEAP8[$2>>0]|0;
   $7 = $6&255;
   $9 = $7;
  } else {
   $8 = (___shgetc($f)|0);
   $9 = $8;
  }
  $10 = (_isspace($9)|0);
  $11 = ($10|0)==(0);
  if ($11) {
   $$lcssa333 = $9;
   break;
  }
 }
 $12 = ($$lcssa333|0)==(45);
 do {
  if ((($$lcssa333|0) == 43) | (($$lcssa333|0) == 45)) {
   $13 = $12&1;
   $14 = $13 << 1;
   $15 = (1 - ($14))|0;
   $16 = HEAP32[$0>>2]|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ($16>>>0)<($17>>>0);
   if ($18) {
    $19 = ((($16)) + 1|0);
    HEAP32[$0>>2] = $19;
    $20 = HEAP8[$16>>0]|0;
    $21 = $20&255;
    $c$0 = $21;$sign$0 = $15;
    break;
   } else {
    $22 = (___shgetc($f)|0);
    $c$0 = $22;$sign$0 = $15;
    break;
   }
  } else {
   $c$0 = $$lcssa333;$sign$0 = 1;
  }
 } while(0);
 $c$185 = $c$0;$i$084 = 0;
 while(1) {
  $23 = $c$185 | 32;
  $24 = (6216 + ($i$084)|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25 << 24 >> 24;
  $27 = ($23|0)==($26|0);
  if (!($27)) {
   $c$1$lcssa = $c$185;$i$0$lcssa = $i$084;
   break;
  }
  $28 = ($i$084>>>0)<(7);
  do {
   if ($28) {
    $29 = HEAP32[$0>>2]|0;
    $30 = HEAP32[$1>>2]|0;
    $31 = ($29>>>0)<($30>>>0);
    if ($31) {
     $32 = ((($29)) + 1|0);
     HEAP32[$0>>2] = $32;
     $33 = HEAP8[$29>>0]|0;
     $34 = $33&255;
     $c$2 = $34;
     break;
    } else {
     $35 = (___shgetc($f)|0);
     $c$2 = $35;
     break;
    }
   } else {
    $c$2 = $c$185;
   }
  } while(0);
  $36 = (($i$084) + 1)|0;
  $37 = ($36>>>0)<(8);
  if ($37) {
   $c$185 = $c$2;$i$084 = $36;
  } else {
   $c$1$lcssa = $c$2;$i$0$lcssa = $36;
   break;
  }
 }
 do {
  if ((($i$0$lcssa|0) == 3)) {
   label = 23;
  } else if (!((($i$0$lcssa|0) == 8))) {
   $38 = ($i$0$lcssa>>>0)>(3);
   $39 = ($pok|0)!=(0);
   $or$cond5 = $39 & $38;
   if ($or$cond5) {
    $40 = ($i$0$lcssa|0)==(8);
    if ($40) {
     break;
    } else {
     label = 23;
     break;
    }
   }
   $51 = ($i$0$lcssa|0)==(0);
   do {
    if ($51) {
     $52 = $c$1$lcssa | 32;
     $53 = ($52|0)==(110);
     if ($53) {
      $54 = HEAP32[$0>>2]|0;
      $55 = HEAP32[$1>>2]|0;
      $56 = ($54>>>0)<($55>>>0);
      if ($56) {
       $57 = ((($54)) + 1|0);
       HEAP32[$0>>2] = $57;
       $58 = HEAP8[$54>>0]|0;
       $59 = $58&255;
       $c$4 = $59;
      } else {
       $60 = (___shgetc($f)|0);
       $c$4 = $60;
      }
      $61 = $c$4 | 32;
      $62 = ($61|0)==(97);
      if (!($62)) {
       break;
      }
      $712 = HEAP32[$0>>2]|0;
      $713 = HEAP32[$1>>2]|0;
      $714 = ($712>>>0)<($713>>>0);
      if ($714) {
       $716 = ((($712)) + 1|0);
       HEAP32[$0>>2] = $716;
       $717 = HEAP8[$712>>0]|0;
       $718 = $717&255;
       $c$4$1 = $718;
      } else {
       $715 = (___shgetc($f)|0);
       $c$4$1 = $715;
      }
      $719 = $c$4$1 | 32;
      $720 = ($719|0)==(110);
      if (!($720)) {
       break;
      }
      $63 = HEAP32[$0>>2]|0;
      $64 = HEAP32[$1>>2]|0;
      $65 = ($63>>>0)<($64>>>0);
      if ($65) {
       $66 = ((($63)) + 1|0);
       HEAP32[$0>>2] = $66;
       $67 = HEAP8[$63>>0]|0;
       $68 = $67&255;
       $71 = $68;
      } else {
       $69 = (___shgetc($f)|0);
       $71 = $69;
      }
      $70 = ($71|0)==(40);
      if ($70) {
       $i$4 = 1;
      } else {
       $72 = HEAP32[$1>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        $$0 = nan;
        STACKTOP = sp;return (+$$0);
       }
       $74 = HEAP32[$0>>2]|0;
       $75 = ((($74)) + -1|0);
       HEAP32[$0>>2] = $75;
       $$0 = nan;
       STACKTOP = sp;return (+$$0);
      }
      while(1) {
       $76 = HEAP32[$0>>2]|0;
       $77 = HEAP32[$1>>2]|0;
       $78 = ($76>>>0)<($77>>>0);
       if ($78) {
        $79 = ((($76)) + 1|0);
        HEAP32[$0>>2] = $79;
        $80 = HEAP8[$76>>0]|0;
        $81 = $80&255;
        $84 = $81;
       } else {
        $82 = (___shgetc($f)|0);
        $84 = $82;
       }
       $83 = (($84) + -48)|0;
       $85 = ($83>>>0)<(10);
       $86 = (($84) + -65)|0;
       $87 = ($86>>>0)<(26);
       $or$cond = $85 | $87;
       if (!($or$cond)) {
        $88 = (($84) + -97)|0;
        $89 = ($88>>>0)<(26);
        $90 = ($84|0)==(95);
        $or$cond7 = $90 | $89;
        if (!($or$cond7)) {
         $$lcssa289 = $84;$i$4$lcssa = $i$4;
         break;
        }
       }
       $102 = (($i$4) + 1)|0;
       $i$4 = $102;
      }
      $91 = ($$lcssa289|0)==(41);
      if ($91) {
       $$0 = nan;
       STACKTOP = sp;return (+$$0);
      }
      $92 = HEAP32[$1>>2]|0;
      $93 = ($92|0)==(0|0);
      if (!($93)) {
       $94 = HEAP32[$0>>2]|0;
       $95 = ((($94)) + -1|0);
       HEAP32[$0>>2] = $95;
      }
      if (!($39)) {
       $97 = (___errno_location()|0);
       HEAP32[$97>>2] = 22;
       ___shlim($f,0);
       $$0 = 0.0;
       STACKTOP = sp;return (+$$0);
      }
      $96 = ($i$4$lcssa|0)==(0);
      $brmerge187 = $96 | $93;
      if ($brmerge187) {
       $$0 = nan;
       STACKTOP = sp;return (+$$0);
      }
      $$promoted185 = HEAP32[$0>>2]|0;
      $$in = $i$4$lcssa;$100 = $$promoted185;
      while(1) {
       $98 = (($$in) + -1)|0;
       $99 = ((($100)) + -1|0);
       $101 = ($98|0)==(0);
       if ($101) {
        $$lcssa288 = $99;
        break;
       } else {
        $$in = $98;$100 = $99;
       }
      }
      HEAP32[$0>>2] = $$lcssa288;
      $$0 = nan;
      STACKTOP = sp;return (+$$0);
     }
     $108 = ($c$1$lcssa|0)==(48);
     do {
      if ($108) {
       $109 = HEAP32[$0>>2]|0;
       $110 = HEAP32[$1>>2]|0;
       $111 = ($109>>>0)<($110>>>0);
       if ($111) {
        $112 = ((($109)) + 1|0);
        HEAP32[$0>>2] = $112;
        $113 = HEAP8[$109>>0]|0;
        $114 = $113&255;
        $117 = $114;
       } else {
        $115 = (___shgetc($f)|0);
        $117 = $115;
       }
       $116 = $117 | 32;
       $118 = ($116|0)==(120);
       if (!($118)) {
        $320 = HEAP32[$1>>2]|0;
        $321 = ($320|0)==(0|0);
        if ($321) {
         $c$6 = 48;
         break;
        }
        $322 = HEAP32[$0>>2]|0;
        $323 = ((($322)) + -1|0);
        HEAP32[$0>>2] = $323;
        $c$6 = 48;
        break;
       }
       $119 = HEAP32[$0>>2]|0;
       $120 = HEAP32[$1>>2]|0;
       $121 = ($119>>>0)<($120>>>0);
       if ($121) {
        $122 = ((($119)) + 1|0);
        HEAP32[$0>>2] = $122;
        $123 = HEAP8[$119>>0]|0;
        $124 = $123&255;
        $c$0$i = $124;$gotdig$0$i = 0;
       } else {
        $125 = (___shgetc($f)|0);
        $c$0$i = $125;$gotdig$0$i = 0;
       }
       while(1) {
        if ((($c$0$i|0) == 46)) {
         $gotdig$0$i$lcssa294 = $gotdig$0$i;
         label = 71;
         break;
        } else if (!((($c$0$i|0) == 48))) {
         $163 = 0;$165 = 0;$721 = 0;$722 = 0;$c$2$i = $c$0$i;$gotdig$2$i = $gotdig$0$i;$gotrad$0$i = 0;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
         break;
        }
        $126 = HEAP32[$0>>2]|0;
        $127 = HEAP32[$1>>2]|0;
        $128 = ($126>>>0)<($127>>>0);
        if ($128) {
         $129 = ((($126)) + 1|0);
         HEAP32[$0>>2] = $129;
         $130 = HEAP8[$126>>0]|0;
         $131 = $130&255;
         $c$0$i = $131;$gotdig$0$i = 1;
         continue;
        } else {
         $132 = (___shgetc($f)|0);
         $c$0$i = $132;$gotdig$0$i = 1;
         continue;
        }
       }
       if ((label|0) == 71) {
        $133 = HEAP32[$0>>2]|0;
        $134 = HEAP32[$1>>2]|0;
        $135 = ($133>>>0)<($134>>>0);
        if ($135) {
         $136 = ((($133)) + 1|0);
         HEAP32[$0>>2] = $136;
         $137 = HEAP8[$133>>0]|0;
         $138 = $137&255;
         $c$1$ph$i = $138;
        } else {
         $139 = (___shgetc($f)|0);
         $c$1$ph$i = $139;
        }
        $140 = ($c$1$ph$i|0)==(48);
        if ($140) {
         $148 = 0;$149 = 0;
         while(1) {
          $141 = HEAP32[$0>>2]|0;
          $142 = HEAP32[$1>>2]|0;
          $143 = ($141>>>0)<($142>>>0);
          if ($143) {
           $144 = ((($141)) + 1|0);
           HEAP32[$0>>2] = $144;
           $145 = HEAP8[$141>>0]|0;
           $146 = $145&255;
           $153 = $146;
          } else {
           $147 = (___shgetc($f)|0);
           $153 = $147;
          }
          $150 = (_i64Add(($148|0),($149|0),-1,-1)|0);
          $151 = tempRet0;
          $152 = ($153|0)==(48);
          if ($152) {
           $148 = $150;$149 = $151;
          } else {
           $163 = 0;$165 = 0;$721 = $150;$722 = $151;$c$2$i = $153;$gotdig$2$i = 1;$gotrad$0$i = 1;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
           break;
          }
         }
        } else {
         $163 = 0;$165 = 0;$721 = 0;$722 = 0;$c$2$i = $c$1$ph$i;$gotdig$2$i = $gotdig$0$i$lcssa294;$gotrad$0$i = 1;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
        }
       }
       while(1) {
        $154 = (($c$2$i) + -48)|0;
        $155 = ($154>>>0)<(10);
        $$pre$i = $c$2$i | 32;
        if ($155) {
         label = 83;
        } else {
         $156 = (($$pre$i) + -97)|0;
         $157 = ($156>>>0)<(6);
         $158 = ($c$2$i|0)==(46);
         $or$cond6$i = $158 | $157;
         if (!($or$cond6$i)) {
          $207 = $165;$208 = $721;$210 = $163;$211 = $722;$c$2$lcssa$i = $c$2$i;$gotdig$2$i$lcssa = $gotdig$2$i;$gotrad$0$i$lcssa = $gotrad$0$i;$x$0$i$lcssa = $x$0$i;$y$0$i$lcssa = $y$0$i;
          break;
         }
         if ($158) {
          $159 = ($gotrad$0$i|0)==(0);
          if ($159) {
           $723 = $165;$724 = $163;$725 = $165;$726 = $163;$gotdig$3$i = $gotdig$2$i;$gotrad$1$i = 1;$gottail$2$i = $gottail$0$i;$scale$2$i = $scale$0$i;$x$2$i = $x$0$i;$y$2$i = $y$0$i;
          } else {
           $207 = $165;$208 = $721;$210 = $163;$211 = $722;$c$2$lcssa$i = 46;$gotdig$2$i$lcssa = $gotdig$2$i;$gotrad$0$i$lcssa = $gotrad$0$i;$x$0$i$lcssa = $x$0$i;$y$0$i$lcssa = $y$0$i;
           break;
          }
         } else {
          label = 83;
         }
        }
        if ((label|0) == 83) {
         label = 0;
         $160 = ($c$2$i|0)>(57);
         $161 = (($$pre$i) + -87)|0;
         $d$0$i = $160 ? $161 : $154;
         $162 = ($163|0)<(0);
         $164 = ($165>>>0)<(8);
         $166 = ($163|0)==(0);
         $167 = $166 & $164;
         $168 = $162 | $167;
         do {
          if ($168) {
           $169 = $x$0$i << 4;
           $170 = (($d$0$i) + ($169))|0;
           $gottail$1$i = $gottail$0$i;$scale$1$i = $scale$0$i;$x$1$i = $170;$y$1$i = $y$0$i;
          } else {
           $171 = ($163|0)<(0);
           $172 = ($165>>>0)<(14);
           $173 = ($163|0)==(0);
           $174 = $173 & $172;
           $175 = $171 | $174;
           if ($175) {
            $176 = (+($d$0$i|0));
            $177 = $scale$0$i * 0.0625;
            $178 = $177 * $176;
            $179 = $y$0$i + $178;
            $gottail$1$i = $gottail$0$i;$scale$1$i = $177;$x$1$i = $x$0$i;$y$1$i = $179;
            break;
           }
           $180 = ($d$0$i|0)==(0);
           $181 = ($gottail$0$i|0)!=(0);
           $or$cond$i = $181 | $180;
           if ($or$cond$i) {
            $gottail$1$i = $gottail$0$i;$scale$1$i = $scale$0$i;$x$1$i = $x$0$i;$y$1$i = $y$0$i;
           } else {
            $182 = $scale$0$i * 0.5;
            $183 = $y$0$i + $182;
            $gottail$1$i = 1;$scale$1$i = $scale$0$i;$x$1$i = $x$0$i;$y$1$i = $183;
           }
          }
         } while(0);
         $184 = (_i64Add(($165|0),($163|0),1,0)|0);
         $185 = tempRet0;
         $723 = $721;$724 = $722;$725 = $184;$726 = $185;$gotdig$3$i = 1;$gotrad$1$i = $gotrad$0$i;$gottail$2$i = $gottail$1$i;$scale$2$i = $scale$1$i;$x$2$i = $x$1$i;$y$2$i = $y$1$i;
        }
        $186 = HEAP32[$0>>2]|0;
        $187 = HEAP32[$1>>2]|0;
        $188 = ($186>>>0)<($187>>>0);
        if ($188) {
         $189 = ((($186)) + 1|0);
         HEAP32[$0>>2] = $189;
         $190 = HEAP8[$186>>0]|0;
         $191 = $190&255;
         $163 = $726;$165 = $725;$721 = $723;$722 = $724;$c$2$i = $191;$gotdig$2$i = $gotdig$3$i;$gotrad$0$i = $gotrad$1$i;$gottail$0$i = $gottail$2$i;$scale$0$i = $scale$2$i;$x$0$i = $x$2$i;$y$0$i = $y$2$i;
         continue;
        } else {
         $192 = (___shgetc($f)|0);
         $163 = $726;$165 = $725;$721 = $723;$722 = $724;$c$2$i = $192;$gotdig$2$i = $gotdig$3$i;$gotrad$0$i = $gotrad$1$i;$gottail$0$i = $gottail$2$i;$scale$0$i = $scale$2$i;$x$0$i = $x$2$i;$y$0$i = $y$2$i;
         continue;
        }
       }
       $193 = ($gotdig$2$i$lcssa|0)==(0);
       if ($193) {
        $194 = HEAP32[$1>>2]|0;
        $195 = ($194|0)==(0|0);
        if (!($195)) {
         $196 = HEAP32[$0>>2]|0;
         $197 = ((($196)) + -1|0);
         HEAP32[$0>>2] = $197;
        }
        $198 = ($pok|0)==(0);
        if ($198) {
         ___shlim($f,0);
        } else {
         if (!($195)) {
          $199 = HEAP32[$0>>2]|0;
          $200 = ((($199)) + -1|0);
          HEAP32[$0>>2] = $200;
          $201 = ($gotrad$0$i$lcssa|0)==(0);
          if (!($201)) {
           $202 = ((($199)) + -2|0);
           HEAP32[$0>>2] = $202;
          }
         }
        }
        $203 = (+($sign$0|0));
        $204 = $203 * 0.0;
        $$0 = $204;
        STACKTOP = sp;return (+$$0);
       }
       $205 = ($gotrad$0$i$lcssa|0)==(0);
       $206 = $205 ? $207 : $208;
       $209 = $205 ? $210 : $211;
       $212 = ($210|0)<(0);
       $213 = ($207>>>0)<(8);
       $214 = ($210|0)==(0);
       $215 = $214 & $213;
       $216 = $212 | $215;
       if ($216) {
        $218 = $207;$219 = $210;$x$324$i = $x$0$i$lcssa;
        while(1) {
         $217 = $x$324$i << 4;
         $220 = (_i64Add(($218|0),($219|0),1,0)|0);
         $221 = tempRet0;
         $222 = ($221|0)<(0);
         $223 = ($220>>>0)<(8);
         $224 = ($221|0)==(0);
         $225 = $224 & $223;
         $226 = $222 | $225;
         if ($226) {
          $218 = $220;$219 = $221;$x$324$i = $217;
         } else {
          $x$3$lcssa$i = $217;
          break;
         }
        }
       } else {
        $x$3$lcssa$i = $x$0$i$lcssa;
       }
       $227 = $c$2$lcssa$i | 32;
       $228 = ($227|0)==(112);
       do {
        if ($228) {
         $229 = (_scanexp($f,$pok)|0);
         $230 = tempRet0;
         $231 = ($229|0)==(0);
         $232 = ($230|0)==(-2147483648);
         $233 = $231 & $232;
         if ($233) {
          $234 = ($pok|0)==(0);
          if ($234) {
           ___shlim($f,0);
           $$0 = 0.0;
           STACKTOP = sp;return (+$$0);
          } else {
           $235 = HEAP32[$1>>2]|0;
           $236 = ($235|0)==(0|0);
           if ($236) {
            $247 = 0;$248 = 0;
            break;
           }
           $237 = HEAP32[$0>>2]|0;
           $238 = ((($237)) + -1|0);
           HEAP32[$0>>2] = $238;
           $247 = 0;$248 = 0;
           break;
          }
         } else {
          $247 = $229;$248 = $230;
         }
        } else {
         $239 = HEAP32[$1>>2]|0;
         $240 = ($239|0)==(0|0);
         if ($240) {
          $247 = 0;$248 = 0;
         } else {
          $241 = HEAP32[$0>>2]|0;
          $242 = ((($241)) + -1|0);
          HEAP32[$0>>2] = $242;
          $247 = 0;$248 = 0;
         }
        }
       } while(0);
       $243 = (_bitshift64Shl(($206|0),($209|0),2)|0);
       $244 = tempRet0;
       $245 = (_i64Add(($243|0),($244|0),-32,-1)|0);
       $246 = tempRet0;
       $249 = (_i64Add(($245|0),($246|0),($247|0),($248|0))|0);
       $250 = tempRet0;
       $251 = ($x$3$lcssa$i|0)==(0);
       if ($251) {
        $252 = (+($sign$0|0));
        $253 = $252 * 0.0;
        $$0 = $253;
        STACKTOP = sp;return (+$$0);
       }
       $254 = (0 - ($emin$0$ph))|0;
       $255 = ($250|0)>(0);
       $256 = ($249>>>0)>($254>>>0);
       $257 = ($250|0)==(0);
       $258 = $257 & $256;
       $259 = $255 | $258;
       if ($259) {
        $260 = (___errno_location()|0);
        HEAP32[$260>>2] = 34;
        $261 = (+($sign$0|0));
        $262 = $261 * 1.7976931348623157E+308;
        $263 = $262 * 1.7976931348623157E+308;
        $$0 = $263;
        STACKTOP = sp;return (+$$0);
       }
       $264 = (($emin$0$ph) + -106)|0;
       $265 = ($264|0)<(0);
       $266 = $265 << 31 >> 31;
       $267 = ($250|0)<($266|0);
       $268 = ($249>>>0)<($264>>>0);
       $269 = ($250|0)==($266|0);
       $270 = $269 & $268;
       $271 = $267 | $270;
       if ($271) {
        $273 = (___errno_location()|0);
        HEAP32[$273>>2] = 34;
        $274 = (+($sign$0|0));
        $275 = $274 * 2.2250738585072014E-308;
        $276 = $275 * 2.2250738585072014E-308;
        $$0 = $276;
        STACKTOP = sp;return (+$$0);
       }
       $272 = ($x$3$lcssa$i|0)>(-1);
       if ($272) {
        $282 = $249;$283 = $250;$x$419$i = $x$3$lcssa$i;$y$320$i = $y$0$i$lcssa;
        while(1) {
         $277 = !($y$320$i >= 0.5);
         $278 = $x$419$i << 1;
         $279 = $y$320$i + -1.0;
         $280 = $277&1;
         $281 = $280 | $278;
         $x$5$i = $281 ^ 1;
         $$pn$i = $277 ? $y$320$i : $279;
         $y$4$i = $y$320$i + $$pn$i;
         $284 = (_i64Add(($282|0),($283|0),-1,-1)|0);
         $285 = tempRet0;
         $286 = ($281|0)>(-1);
         if ($286) {
          $282 = $284;$283 = $285;$x$419$i = $x$5$i;$y$320$i = $y$4$i;
         } else {
          $291 = $284;$292 = $285;$x$4$lcssa$i = $x$5$i;$y$3$lcssa$i = $y$4$i;
          break;
         }
        }
       } else {
        $291 = $249;$292 = $250;$x$4$lcssa$i = $x$3$lcssa$i;$y$3$lcssa$i = $y$0$i$lcssa;
       }
       $287 = ($emin$0$ph|0)<(0);
       $288 = $287 << 31 >> 31;
       $289 = (_i64Subtract(32,0,($emin$0$ph|0),($288|0))|0);
       $290 = tempRet0;
       $293 = (_i64Add(($291|0),($292|0),($289|0),($290|0))|0);
       $294 = tempRet0;
       $295 = (0)>($294|0);
       $296 = ($bits$0$ph>>>0)>($293>>>0);
       $297 = (0)==($294|0);
       $298 = $297 & $296;
       $299 = $295 | $298;
       if ($299) {
        $300 = ($293|0)<(0);
        if ($300) {
         $$0710$i = 0;
         label = 124;
        } else {
         $$07$i = $293;
         label = 122;
        }
       } else {
        $$07$i = $bits$0$ph;
        label = 122;
       }
       do {
        if ((label|0) == 122) {
         $301 = ($$07$i|0)<(53);
         if ($301) {
          $$0710$i = $$07$i;
          label = 124;
          break;
         }
         $$pre41$i = (+($sign$0|0));
         $$0711$i = $$07$i;$$pre$phi42$iZ2D = $$pre41$i;$bias$0$i = 0.0;
        }
       } while(0);
       if ((label|0) == 124) {
        $302 = (84 - ($$0710$i))|0;
        $303 = (+_scalbn(1.0,$302));
        $304 = (+($sign$0|0));
        $305 = (+_copysignl($303,$304));
        $$0711$i = $$0710$i;$$pre$phi42$iZ2D = $304;$bias$0$i = $305;
       }
       $306 = ($$0711$i|0)<(32);
       $307 = $y$3$lcssa$i != 0.0;
       $or$cond4$i = $307 & $306;
       $308 = $x$4$lcssa$i & 1;
       $309 = ($308|0)==(0);
       $or$cond9$i = $309 & $or$cond4$i;
       $310 = $or$cond9$i&1;
       $x$6$i = (($310) + ($x$4$lcssa$i))|0;
       $y$5$i = $or$cond9$i ? 0.0 : $y$3$lcssa$i;
       $311 = (+($x$6$i>>>0));
       $312 = $$pre$phi42$iZ2D * $311;
       $313 = $bias$0$i + $312;
       $314 = $$pre$phi42$iZ2D * $y$5$i;
       $315 = $314 + $313;
       $316 = $315 - $bias$0$i;
       $317 = $316 != 0.0;
       if (!($317)) {
        $318 = (___errno_location()|0);
        HEAP32[$318>>2] = 34;
       }
       $319 = (+_scalbnl($316,$291));
       $$0 = $319;
       STACKTOP = sp;return (+$$0);
      } else {
       $c$6 = $c$1$lcssa;
      }
     } while(0);
     $sum$i = (($emin$0$ph) + ($bits$0$ph))|0;
     $324 = (0 - ($sum$i))|0;
     $$09$i = $c$6;$gotdig$0$i12 = 0;
     while(1) {
      if ((($$09$i|0) == 46)) {
       $gotdig$0$i12$lcssa331 = $gotdig$0$i12;
       label = 135;
       break;
      } else if (!((($$09$i|0) == 48))) {
       $$2$i = $$09$i;$727 = 0;$728 = 0;$gotdig$2$i13 = $gotdig$0$i12;$gotrad$0$i14 = 0;
       break;
      }
      $325 = HEAP32[$0>>2]|0;
      $326 = HEAP32[$1>>2]|0;
      $327 = ($325>>>0)<($326>>>0);
      if ($327) {
       $328 = ((($325)) + 1|0);
       HEAP32[$0>>2] = $328;
       $329 = HEAP8[$325>>0]|0;
       $330 = $329&255;
       $$09$i = $330;$gotdig$0$i12 = 1;
       continue;
      } else {
       $331 = (___shgetc($f)|0);
       $$09$i = $331;$gotdig$0$i12 = 1;
       continue;
      }
     }
     if ((label|0) == 135) {
      $332 = HEAP32[$0>>2]|0;
      $333 = HEAP32[$1>>2]|0;
      $334 = ($332>>>0)<($333>>>0);
      if ($334) {
       $335 = ((($332)) + 1|0);
       HEAP32[$0>>2] = $335;
       $336 = HEAP8[$332>>0]|0;
       $337 = $336&255;
       $$1$ph$i = $337;
      } else {
       $338 = (___shgetc($f)|0);
       $$1$ph$i = $338;
      }
      $339 = ($$1$ph$i|0)==(48);
      if ($339) {
       $340 = 0;$341 = 0;
       while(1) {
        $342 = (_i64Add(($340|0),($341|0),-1,-1)|0);
        $343 = tempRet0;
        $344 = HEAP32[$0>>2]|0;
        $345 = HEAP32[$1>>2]|0;
        $346 = ($344>>>0)<($345>>>0);
        if ($346) {
         $347 = ((($344)) + 1|0);
         HEAP32[$0>>2] = $347;
         $348 = HEAP8[$344>>0]|0;
         $349 = $348&255;
         $$1$be$i = $349;
        } else {
         $350 = (___shgetc($f)|0);
         $$1$be$i = $350;
        }
        $351 = ($$1$be$i|0)==(48);
        if ($351) {
         $340 = $342;$341 = $343;
        } else {
         $$2$i = $$1$be$i;$727 = $342;$728 = $343;$gotdig$2$i13 = 1;$gotrad$0$i14 = 1;
         break;
        }
       }
      } else {
       $$2$i = $$1$ph$i;$727 = 0;$728 = 0;$gotdig$2$i13 = $gotdig$0$i12$lcssa331;$gotrad$0$i14 = 1;
      }
     }
     HEAP32[$x$i>>2] = 0;
     $352 = (($$2$i) + -48)|0;
     $353 = ($352>>>0)<(10);
     $354 = ($$2$i|0)==(46);
     $355 = $354 | $353;
     L214: do {
      if ($355) {
       $356 = ((($x$i)) + 496|0);
       $$3121$i = $$2$i;$359 = 0;$360 = 0;$729 = $354;$730 = $352;$731 = $727;$732 = $728;$gotdig$3117$i = $gotdig$2$i13;$gotrad$1118$i = $gotrad$0$i14;$j$0120$i = 0;$k$0119$i = 0;$lnz$0116$i = 0;
       L216: while(1) {
        do {
         if ($729) {
          $cond$i = ($gotrad$1118$i|0)==(0);
          if ($cond$i) {
           $733 = $359;$734 = $360;$735 = $359;$736 = $360;$gotdig$4$i = $gotdig$3117$i;$gotrad$2$i = 1;$j$2$i = $j$0120$i;$k$2$i = $k$0119$i;$lnz$2$i = $lnz$0116$i;
          } else {
           $737 = $731;$738 = $732;$739 = $359;$740 = $360;$gotdig$3117$i$lcssa = $gotdig$3117$i;$j$0120$i$lcssa = $j$0120$i;$k$0119$i$lcssa = $k$0119$i;$lnz$0116$i$lcssa = $lnz$0116$i;
           break L216;
          }
         } else {
          $358 = ($k$0119$i|0)<(125);
          $361 = (_i64Add(($359|0),($360|0),1,0)|0);
          $362 = tempRet0;
          $363 = ($$3121$i|0)!=(48);
          if (!($358)) {
           if (!($363)) {
            $733 = $731;$734 = $732;$735 = $361;$736 = $362;$gotdig$4$i = $gotdig$3117$i;$gotrad$2$i = $gotrad$1118$i;$j$2$i = $j$0120$i;$k$2$i = $k$0119$i;$lnz$2$i = $lnz$0116$i;
            break;
           }
           $373 = HEAP32[$356>>2]|0;
           $374 = $373 | 1;
           HEAP32[$356>>2] = $374;
           $733 = $731;$734 = $732;$735 = $361;$736 = $362;$gotdig$4$i = $gotdig$3117$i;$gotrad$2$i = $gotrad$1118$i;$j$2$i = $j$0120$i;$k$2$i = $k$0119$i;$lnz$2$i = $lnz$0116$i;
           break;
          }
          $$lnz$0$i = $363 ? $361 : $lnz$0116$i;
          $364 = ($j$0120$i|0)==(0);
          $365 = (($x$i) + ($k$0119$i<<2)|0);
          if ($364) {
           $storemerge$i = $730;
          } else {
           $366 = HEAP32[$365>>2]|0;
           $367 = ($366*10)|0;
           $368 = (($$3121$i) + -48)|0;
           $369 = (($368) + ($367))|0;
           $storemerge$i = $369;
          }
          HEAP32[$365>>2] = $storemerge$i;
          $370 = (($j$0120$i) + 1)|0;
          $371 = ($370|0)==(9);
          $372 = $371&1;
          $$k$0$i = (($372) + ($k$0119$i))|0;
          $$11$i = $371 ? 0 : $370;
          $733 = $731;$734 = $732;$735 = $361;$736 = $362;$gotdig$4$i = 1;$gotrad$2$i = $gotrad$1118$i;$j$2$i = $$11$i;$k$2$i = $$k$0$i;$lnz$2$i = $$lnz$0$i;
         }
        } while(0);
        $375 = HEAP32[$0>>2]|0;
        $376 = HEAP32[$1>>2]|0;
        $377 = ($375>>>0)<($376>>>0);
        if ($377) {
         $378 = ((($375)) + 1|0);
         HEAP32[$0>>2] = $378;
         $379 = HEAP8[$375>>0]|0;
         $380 = $379&255;
         $$3$be$i = $380;
        } else {
         $381 = (___shgetc($f)|0);
         $$3$be$i = $381;
        }
        $382 = (($$3$be$i) + -48)|0;
        $383 = ($382>>>0)<(10);
        $384 = ($$3$be$i|0)==(46);
        $385 = $384 | $383;
        if ($385) {
         $$3121$i = $$3$be$i;$359 = $735;$360 = $736;$729 = $384;$730 = $382;$731 = $733;$732 = $734;$gotdig$3117$i = $gotdig$4$i;$gotrad$1118$i = $gotrad$2$i;$j$0120$i = $j$2$i;$k$0119$i = $k$2$i;$lnz$0116$i = $lnz$2$i;
        } else {
         $$3$lcssa$i = $$3$be$i;$388 = $735;$389 = $733;$391 = $736;$392 = $734;$gotdig$3$lcssa$i = $gotdig$4$i;$gotrad$1$lcssa$i = $gotrad$2$i;$j$0$lcssa$i = $j$2$i;$k$0$lcssa$i = $k$2$i;$lnz$0$lcssa$i = $lnz$2$i;
         label = 158;
         break L214;
        }
       }
       $357 = ($gotdig$3117$i$lcssa|0)!=(0);
       $741 = $739;$742 = $740;$743 = $737;$744 = $738;$745 = $357;$j$069$i = $j$0120$i$lcssa;$k$065$i = $k$0119$i$lcssa;$lnz$059$i = $lnz$0116$i$lcssa;
       label = 166;
      } else {
       $$3$lcssa$i = $$2$i;$388 = 0;$389 = $727;$391 = 0;$392 = $728;$gotdig$3$lcssa$i = $gotdig$2$i13;$gotrad$1$lcssa$i = $gotrad$0$i14;$j$0$lcssa$i = 0;$k$0$lcssa$i = 0;$lnz$0$lcssa$i = 0;
       label = 158;
      }
     } while(0);
     do {
      if ((label|0) == 158) {
       $386 = ($gotrad$1$lcssa$i|0)==(0);
       $387 = $386 ? $388 : $389;
       $390 = $386 ? $391 : $392;
       $393 = ($gotdig$3$lcssa$i|0)!=(0);
       $394 = $$3$lcssa$i | 32;
       $395 = ($394|0)==(101);
       $or$cond13$i = $395 & $393;
       if (!($or$cond13$i)) {
        $410 = ($$3$lcssa$i|0)>(-1);
        if ($410) {
         $741 = $388;$742 = $391;$743 = $387;$744 = $390;$745 = $393;$j$069$i = $j$0$lcssa$i;$k$065$i = $k$0$lcssa$i;$lnz$059$i = $lnz$0$lcssa$i;
         label = 166;
         break;
        } else {
         $746 = $388;$747 = $391;$748 = $393;$749 = $387;$750 = $390;$j$068$i = $j$0$lcssa$i;$k$064$i = $k$0$lcssa$i;$lnz$058$i = $lnz$0$lcssa$i;
         label = 168;
         break;
        }
       }
       $396 = (_scanexp($f,$pok)|0);
       $397 = tempRet0;
       $398 = ($396|0)==(0);
       $399 = ($397|0)==(-2147483648);
       $400 = $398 & $399;
       if ($400) {
        $401 = ($pok|0)==(0);
        if ($401) {
         ___shlim($f,0);
         $$0$i25 = 0.0;
         break;
        }
        $402 = HEAP32[$1>>2]|0;
        $403 = ($402|0)==(0|0);
        if ($403) {
         $406 = 0;$407 = 0;
        } else {
         $404 = HEAP32[$0>>2]|0;
         $405 = ((($404)) + -1|0);
         HEAP32[$0>>2] = $405;
         $406 = 0;$407 = 0;
        }
       } else {
        $406 = $396;$407 = $397;
       }
       $408 = (_i64Add(($406|0),($407|0),($387|0),($390|0))|0);
       $409 = tempRet0;
       $421 = $408;$422 = $388;$424 = $409;$425 = $391;$j$067$i = $j$0$lcssa$i;$k$063$i = $k$0$lcssa$i;$lnz$057$i = $lnz$0$lcssa$i;
       label = 170;
      }
     } while(0);
     if ((label|0) == 166) {
      $411 = HEAP32[$1>>2]|0;
      $412 = ($411|0)==(0|0);
      if ($412) {
       $746 = $741;$747 = $742;$748 = $745;$749 = $743;$750 = $744;$j$068$i = $j$069$i;$k$064$i = $k$065$i;$lnz$058$i = $lnz$059$i;
       label = 168;
      } else {
       $413 = HEAP32[$0>>2]|0;
       $414 = ((($413)) + -1|0);
       HEAP32[$0>>2] = $414;
       if ($745) {
        $421 = $743;$422 = $741;$424 = $744;$425 = $742;$j$067$i = $j$069$i;$k$063$i = $k$065$i;$lnz$057$i = $lnz$059$i;
        label = 170;
       } else {
        label = 169;
       }
      }
     }
     if ((label|0) == 168) {
      if ($748) {
       $421 = $749;$422 = $746;$424 = $750;$425 = $747;$j$067$i = $j$068$i;$k$063$i = $k$064$i;$lnz$057$i = $lnz$058$i;
       label = 170;
      } else {
       label = 169;
      }
     }
     do {
      if ((label|0) == 169) {
       $415 = (___errno_location()|0);
       HEAP32[$415>>2] = 22;
       ___shlim($f,0);
       $$0$i25 = 0.0;
      }
      else if ((label|0) == 170) {
       $416 = HEAP32[$x$i>>2]|0;
       $417 = ($416|0)==(0);
       if ($417) {
        $418 = (+($sign$0|0));
        $419 = $418 * 0.0;
        $$0$i25 = $419;
        break;
       }
       $420 = ($421|0)==($422|0);
       $423 = ($424|0)==($425|0);
       $426 = $420 & $423;
       $427 = ($425|0)<(0);
       $428 = ($422>>>0)<(10);
       $429 = ($425|0)==(0);
       $430 = $429 & $428;
       $431 = $427 | $430;
       $or$cond$i16 = $431 & $426;
       if ($or$cond$i16) {
        $432 = ($bits$0$ph>>>0)>(30);
        $433 = $416 >>> $bits$0$ph;
        $434 = ($433|0)==(0);
        $or$cond15$i = $432 | $434;
        if ($or$cond15$i) {
         $435 = (+($sign$0|0));
         $436 = (+($416>>>0));
         $437 = $435 * $436;
         $$0$i25 = $437;
         break;
        }
       }
       $438 = (($emin$0$ph|0) / -2)&-1;
       $439 = ($438|0)<(0);
       $440 = $439 << 31 >> 31;
       $441 = ($424|0)>($440|0);
       $442 = ($421>>>0)>($438>>>0);
       $443 = ($424|0)==($440|0);
       $444 = $443 & $442;
       $445 = $441 | $444;
       if ($445) {
        $446 = (___errno_location()|0);
        HEAP32[$446>>2] = 34;
        $447 = (+($sign$0|0));
        $448 = $447 * 1.7976931348623157E+308;
        $449 = $448 * 1.7976931348623157E+308;
        $$0$i25 = $449;
        break;
       }
       $450 = (($emin$0$ph) + -106)|0;
       $451 = ($450|0)<(0);
       $452 = $451 << 31 >> 31;
       $453 = ($424|0)<($452|0);
       $454 = ($421>>>0)<($450>>>0);
       $455 = ($424|0)==($452|0);
       $456 = $455 & $454;
       $457 = $453 | $456;
       if ($457) {
        $458 = (___errno_location()|0);
        HEAP32[$458>>2] = 34;
        $459 = (+($sign$0|0));
        $460 = $459 * 2.2250738585072014E-308;
        $461 = $460 * 2.2250738585072014E-308;
        $$0$i25 = $461;
        break;
       }
       $462 = ($j$067$i|0)==(0);
       if ($462) {
        $k$3$i = $k$063$i;
       } else {
        $463 = ($j$067$i|0)<(9);
        if ($463) {
         $464 = (($x$i) + ($k$063$i<<2)|0);
         $$promoted$i = HEAP32[$464>>2]|0;
         $466 = $$promoted$i;$j$3110$i = $j$067$i;
         while(1) {
          $465 = ($466*10)|0;
          $467 = (($j$3110$i) + 1)|0;
          $exitcond$i = ($467|0)==(9);
          if ($exitcond$i) {
           $$lcssa323 = $465;
           break;
          } else {
           $466 = $465;$j$3110$i = $467;
          }
         }
         HEAP32[$464>>2] = $$lcssa323;
        }
        $468 = (($k$063$i) + 1)|0;
        $k$3$i = $468;
       }
       $469 = ($lnz$057$i|0)<(9);
       if ($469) {
        $470 = ($lnz$057$i|0)<=($421|0);
        $471 = ($421|0)<(18);
        $or$cond3$i = $470 & $471;
        if ($or$cond3$i) {
         $472 = ($421|0)==(9);
         if ($472) {
          $473 = (+($sign$0|0));
          $474 = HEAP32[$x$i>>2]|0;
          $475 = (+($474>>>0));
          $476 = $473 * $475;
          $$0$i25 = $476;
          break;
         }
         $477 = ($421|0)<(9);
         if ($477) {
          $478 = (+($sign$0|0));
          $479 = HEAP32[$x$i>>2]|0;
          $480 = (+($479>>>0));
          $481 = $478 * $480;
          $482 = (8 - ($421))|0;
          $483 = (6232 + ($482<<2)|0);
          $484 = HEAP32[$483>>2]|0;
          $485 = (+($484|0));
          $486 = $481 / $485;
          $$0$i25 = $486;
          break;
         }
         $$neg32$i = (($bits$0$ph) + 27)|0;
         $487 = Math_imul($421, -3)|0;
         $488 = (($$neg32$i) + ($487))|0;
         $489 = ($488|0)>(30);
         $$pre$i17 = HEAP32[$x$i>>2]|0;
         $490 = $$pre$i17 >>> $488;
         $491 = ($490|0)==(0);
         $or$cond216$i = $489 | $491;
         if ($or$cond216$i) {
          $492 = (+($sign$0|0));
          $493 = (+($$pre$i17>>>0));
          $494 = $492 * $493;
          $495 = (($421) + -10)|0;
          $496 = (6232 + ($495<<2)|0);
          $497 = HEAP32[$496>>2]|0;
          $498 = (+($497|0));
          $499 = $494 * $498;
          $$0$i25 = $499;
          break;
         }
        }
       }
       $500 = (($421|0) % 9)&-1;
       $501 = ($500|0)==(0);
       if ($501) {
        $a$2$ph38$i = 0;$e2$0$ph$i = 0;$rp$2$ph36$i = $421;$z$1$ph37$i = $k$3$i;
       } else {
        $502 = ($421|0)>(-1);
        $503 = (($500) + 9)|0;
        $504 = $502 ? $500 : $503;
        $505 = (8 - ($504))|0;
        $506 = (6232 + ($505<<2)|0);
        $507 = HEAP32[$506>>2]|0;
        $508 = ($k$3$i|0)==(0);
        if ($508) {
         $a$0$lcssa177$i = 0;$rp$0$lcssa178$i = $421;$z$0$i = 0;
        } else {
         $509 = (1000000000 / ($507|0))&-1;
         $a$0101$i = 0;$carry$0103$i = 0;$k$4102$i = 0;$rp$0100$i = $421;
         while(1) {
          $510 = (($x$i) + ($k$4102$i<<2)|0);
          $511 = HEAP32[$510>>2]|0;
          $512 = (($511>>>0) % ($507>>>0))&-1;
          $513 = (($511>>>0) / ($507>>>0))&-1;
          $514 = (($513) + ($carry$0103$i))|0;
          HEAP32[$510>>2] = $514;
          $515 = Math_imul($512, $509)|0;
          $516 = ($k$4102$i|0)==($a$0101$i|0);
          $517 = ($514|0)==(0);
          $or$cond16$i = $516 & $517;
          $518 = (($k$4102$i) + 1)|0;
          $519 = $518 & 127;
          $520 = (($rp$0100$i) + -9)|0;
          $rp$1$i18 = $or$cond16$i ? $520 : $rp$0100$i;
          $a$1$i = $or$cond16$i ? $519 : $a$0101$i;
          $521 = ($518|0)==($k$3$i|0);
          if ($521) {
           $$lcssa322 = $515;$a$1$i$lcssa = $a$1$i;$rp$1$i18$lcssa = $rp$1$i18;
           break;
          } else {
           $a$0101$i = $a$1$i;$carry$0103$i = $515;$k$4102$i = $518;$rp$0100$i = $rp$1$i18;
          }
         }
         $522 = ($$lcssa322|0)==(0);
         if ($522) {
          $a$0$lcssa177$i = $a$1$i$lcssa;$rp$0$lcssa178$i = $rp$1$i18$lcssa;$z$0$i = $k$3$i;
         } else {
          $523 = (($k$3$i) + 1)|0;
          $524 = (($x$i) + ($k$3$i<<2)|0);
          HEAP32[$524>>2] = $$lcssa322;
          $a$0$lcssa177$i = $a$1$i$lcssa;$rp$0$lcssa178$i = $rp$1$i18$lcssa;$z$0$i = $523;
         }
        }
        $525 = (9 - ($504))|0;
        $526 = (($525) + ($rp$0$lcssa178$i))|0;
        $a$2$ph38$i = $a$0$lcssa177$i;$e2$0$ph$i = 0;$rp$2$ph36$i = $526;$z$1$ph37$i = $z$0$i;
       }
       L296: while(1) {
        $527 = ($rp$2$ph36$i|0)<(18);
        $528 = (($x$i) + ($a$2$ph38$i<<2)|0);
        if ($527) {
         $e2$0$us$i = $e2$0$ph$i;$z$1$us$i = $z$1$ph37$i;
         while(1) {
          $530 = (($z$1$us$i) + 127)|0;
          $carry1$0$us$i = 0;$k$5$in$us$i = $530;$z$2$us$i = $z$1$us$i;
          while(1) {
           $k$5$us$i = $k$5$in$us$i & 127;
           $531 = (($x$i) + ($k$5$us$i<<2)|0);
           $532 = HEAP32[$531>>2]|0;
           $533 = (_bitshift64Shl(($532|0),0,29)|0);
           $534 = tempRet0;
           $535 = (_i64Add(($533|0),($534|0),($carry1$0$us$i|0),0)|0);
           $536 = tempRet0;
           $537 = ($536>>>0)>(0);
           $538 = ($535>>>0)>(1000000000);
           $539 = ($536|0)==(0);
           $540 = $539 & $538;
           $541 = $537 | $540;
           if ($541) {
            $542 = (___udivdi3(($535|0),($536|0),1000000000,0)|0);
            $543 = tempRet0;
            $544 = (___uremdi3(($535|0),($536|0),1000000000,0)|0);
            $545 = tempRet0;
            $$sink$off0$us$i = $544;$carry1$1$us$i = $542;
           } else {
            $$sink$off0$us$i = $535;$carry1$1$us$i = 0;
           }
           HEAP32[$531>>2] = $$sink$off0$us$i;
           $546 = (($z$2$us$i) + 127)|0;
           $547 = $546 & 127;
           $548 = ($k$5$us$i|0)!=($547|0);
           $549 = ($k$5$us$i|0)==($a$2$ph38$i|0);
           $or$cond17$us$i = $548 | $549;
           $550 = ($$sink$off0$us$i|0)==(0);
           $k$5$z$2$us$i = $550 ? $k$5$us$i : $z$2$us$i;
           $z$3$us$i = $or$cond17$us$i ? $z$2$us$i : $k$5$z$2$us$i;
           $551 = (($k$5$us$i) + -1)|0;
           if ($549) {
            $carry1$1$us$i$lcssa = $carry1$1$us$i;$z$3$us$i$lcssa = $z$3$us$i;
            break;
           } else {
            $carry1$0$us$i = $carry1$1$us$i;$k$5$in$us$i = $551;$z$2$us$i = $z$3$us$i;
           }
          }
          $552 = (($e2$0$us$i) + -29)|0;
          $553 = ($carry1$1$us$i$lcssa|0)==(0);
          if ($553) {
           $e2$0$us$i = $552;$z$1$us$i = $z$3$us$i$lcssa;
          } else {
           $$lcssa50$i = $552;$carry1$1$lcssa$lcssa$i = $carry1$1$us$i$lcssa;$z$3$lcssa$lcssa$i = $z$3$us$i$lcssa;
           break;
          }
         }
        } else {
         $529 = ($rp$2$ph36$i|0)==(18);
         if ($529) {
          $e2$0$us84$i = $e2$0$ph$i;$z$1$us85$i = $z$1$ph37$i;
         } else {
          $a$3$ph$i = $a$2$ph38$i;$e2$1$ph$i = $e2$0$ph$i;$rp$3$ph34$i = $rp$2$ph36$i;$z$5$ph$i = $z$1$ph37$i;
          break;
         }
         while(1) {
          $554 = HEAP32[$528>>2]|0;
          $555 = ($554>>>0)<(9007199);
          if (!($555)) {
           $a$3$ph$i = $a$2$ph38$i;$e2$1$ph$i = $e2$0$us84$i;$rp$3$ph34$i = 18;$z$5$ph$i = $z$1$us85$i;
           break L296;
          }
          $556 = (($z$1$us85$i) + 127)|0;
          $carry1$0$us89$i = 0;$k$5$in$us88$i = $556;$z$2$us87$i = $z$1$us85$i;
          while(1) {
           $k$5$us90$i = $k$5$in$us88$i & 127;
           $557 = (($x$i) + ($k$5$us90$i<<2)|0);
           $558 = HEAP32[$557>>2]|0;
           $559 = (_bitshift64Shl(($558|0),0,29)|0);
           $560 = tempRet0;
           $561 = (_i64Add(($559|0),($560|0),($carry1$0$us89$i|0),0)|0);
           $562 = tempRet0;
           $563 = ($562>>>0)>(0);
           $564 = ($561>>>0)>(1000000000);
           $565 = ($562|0)==(0);
           $566 = $565 & $564;
           $567 = $563 | $566;
           if ($567) {
            $568 = (___udivdi3(($561|0),($562|0),1000000000,0)|0);
            $569 = tempRet0;
            $570 = (___uremdi3(($561|0),($562|0),1000000000,0)|0);
            $571 = tempRet0;
            $$sink$off0$us93$i = $570;$carry1$1$us94$i = $568;
           } else {
            $$sink$off0$us93$i = $561;$carry1$1$us94$i = 0;
           }
           HEAP32[$557>>2] = $$sink$off0$us93$i;
           $572 = (($z$2$us87$i) + 127)|0;
           $573 = $572 & 127;
           $574 = ($k$5$us90$i|0)!=($573|0);
           $575 = ($k$5$us90$i|0)==($a$2$ph38$i|0);
           $or$cond17$us95$i = $574 | $575;
           $576 = ($$sink$off0$us93$i|0)==(0);
           $k$5$z$2$us96$i = $576 ? $k$5$us90$i : $z$2$us87$i;
           $z$3$us97$i = $or$cond17$us95$i ? $z$2$us87$i : $k$5$z$2$us96$i;
           $577 = (($k$5$us90$i) + -1)|0;
           if ($575) {
            $carry1$1$us94$i$lcssa = $carry1$1$us94$i;$z$3$us97$i$lcssa = $z$3$us97$i;
            break;
           } else {
            $carry1$0$us89$i = $carry1$1$us94$i;$k$5$in$us88$i = $577;$z$2$us87$i = $z$3$us97$i;
           }
          }
          $578 = (($e2$0$us84$i) + -29)|0;
          $579 = ($carry1$1$us94$i$lcssa|0)==(0);
          if ($579) {
           $e2$0$us84$i = $578;$z$1$us85$i = $z$3$us97$i$lcssa;
          } else {
           $$lcssa50$i = $578;$carry1$1$lcssa$lcssa$i = $carry1$1$us94$i$lcssa;$z$3$lcssa$lcssa$i = $z$3$us97$i$lcssa;
           break;
          }
         }
        }
        $580 = (($rp$2$ph36$i) + 9)|0;
        $581 = (($a$2$ph38$i) + 127)|0;
        $582 = $581 & 127;
        $583 = ($582|0)==($z$3$lcssa$lcssa$i|0);
        if ($583) {
         $584 = (($z$3$lcssa$lcssa$i) + 127)|0;
         $585 = $584 & 127;
         $586 = (($x$i) + ($585<<2)|0);
         $587 = HEAP32[$586>>2]|0;
         $588 = (($z$3$lcssa$lcssa$i) + 126)|0;
         $589 = $588 & 127;
         $590 = (($x$i) + ($589<<2)|0);
         $591 = HEAP32[$590>>2]|0;
         $592 = $591 | $587;
         HEAP32[$590>>2] = $592;
         $z$4$i = $585;
        } else {
         $z$4$i = $z$3$lcssa$lcssa$i;
        }
        $593 = (($x$i) + ($582<<2)|0);
        HEAP32[$593>>2] = $carry1$1$lcssa$lcssa$i;
        $a$2$ph38$i = $582;$e2$0$ph$i = $$lcssa50$i;$rp$2$ph36$i = $580;$z$1$ph37$i = $z$4$i;
       }
       L321: while(1) {
        $624 = (($z$5$ph$i) + 1)|0;
        $622 = $624 & 127;
        $625 = (($z$5$ph$i) + 127)|0;
        $626 = $625 & 127;
        $627 = (($x$i) + ($626<<2)|0);
        $a$3$ph183$i = $a$3$ph$i;$e2$1$ph182$i = $e2$1$ph$i;$rp$3$ph$i = $rp$3$ph34$i;
        while(1) {
         $628 = ($rp$3$ph$i|0)==(18);
         $629 = ($rp$3$ph$i|0)>(27);
         $$18$i = $629 ? 9 : 1;
         $$not$i = $628 ^ 1;
         $a$3$i = $a$3$ph183$i;$e2$1$i = $e2$1$ph182$i;
         while(1) {
          $594 = $a$3$i & 127;
          $595 = ($594|0)==($z$5$ph$i|0);
          do {
           if ($595) {
            label = 220;
           } else {
            $596 = (($x$i) + ($594<<2)|0);
            $597 = HEAP32[$596>>2]|0;
            $598 = ($597>>>0)<(9007199);
            if ($598) {
             label = 220;
             break;
            }
            $599 = ($597>>>0)>(9007199);
            if ($599) {
             break;
            }
            $600 = (($a$3$i) + 1)|0;
            $601 = $600 & 127;
            $602 = ($601|0)==($z$5$ph$i|0);
            if ($602) {
             label = 220;
             break;
            }
            $708 = (($x$i) + ($601<<2)|0);
            $709 = HEAP32[$708>>2]|0;
            $710 = ($709>>>0)<(254740991);
            if ($710) {
             label = 220;
             break;
            }
            $711 = ($709>>>0)>(254740991);
            $brmerge$i26 = $711 | $$not$i;
            if (!($brmerge$i26)) {
             $635 = $594;$a$3$i301 = $a$3$i;$e2$1$i298 = $e2$1$i;$z$7$i = $z$5$ph$i;
             break L321;
            }
           }
          } while(0);
          if ((label|0) == 220) {
           label = 0;
           if ($628) {
            label = 221;
            break L321;
           }
          }
          $603 = (($e2$1$i) + ($$18$i))|0;
          $604 = ($a$3$i|0)==($z$5$ph$i|0);
          if ($604) {
           $a$3$i = $z$5$ph$i;$e2$1$i = $603;
          } else {
           $$lcssa308 = $603;$a$3$i$lcssa300 = $a$3$i;
           break;
          }
         }
         $605 = 1 << $$18$i;
         $606 = (($605) + -1)|0;
         $607 = 1000000000 >>> $$18$i;
         $a$478$i = $a$3$i$lcssa300;$carry3$081$i = 0;$k$679$i = $a$3$i$lcssa300;$rp$477$i = $rp$3$ph$i;
         while(1) {
          $608 = (($x$i) + ($k$679$i<<2)|0);
          $609 = HEAP32[$608>>2]|0;
          $610 = $609 & $606;
          $611 = $609 >>> $$18$i;
          $612 = (($611) + ($carry3$081$i))|0;
          HEAP32[$608>>2] = $612;
          $613 = Math_imul($610, $607)|0;
          $614 = ($k$679$i|0)==($a$478$i|0);
          $615 = ($612|0)==(0);
          $or$cond19$i = $614 & $615;
          $616 = (($k$679$i) + 1)|0;
          $617 = $616 & 127;
          $618 = (($rp$477$i) + -9)|0;
          $rp$5$i = $or$cond19$i ? $618 : $rp$477$i;
          $a$5$i = $or$cond19$i ? $617 : $a$478$i;
          $619 = ($617|0)==($z$5$ph$i|0);
          if ($619) {
           $$lcssa309 = $613;$a$5$i$lcssa = $a$5$i;$rp$5$i$lcssa = $rp$5$i;
           break;
          } else {
           $a$478$i = $a$5$i;$carry3$081$i = $613;$k$679$i = $617;$rp$477$i = $rp$5$i;
          }
         }
         $620 = ($$lcssa309|0)==(0);
         if ($620) {
          $a$3$ph183$i = $a$5$i$lcssa;$e2$1$ph182$i = $$lcssa308;$rp$3$ph$i = $rp$5$i$lcssa;
          continue;
         }
         $621 = ($622|0)==($a$5$i$lcssa|0);
         if (!($621)) {
          $$lcssa308$lcssa = $$lcssa308;$$lcssa309$lcssa = $$lcssa309;$a$5$i$lcssa$lcssa = $a$5$i$lcssa;$rp$5$i$lcssa$lcssa = $rp$5$i$lcssa;
          break;
         }
         $630 = HEAP32[$627>>2]|0;
         $631 = $630 | 1;
         HEAP32[$627>>2] = $631;
         $a$3$ph183$i = $a$5$i$lcssa;$e2$1$ph182$i = $$lcssa308;$rp$3$ph$i = $rp$5$i$lcssa;
        }
        $623 = (($x$i) + ($z$5$ph$i<<2)|0);
        HEAP32[$623>>2] = $$lcssa309$lcssa;
        $a$3$ph$i = $a$5$i$lcssa$lcssa;$e2$1$ph$i = $$lcssa308$lcssa;$rp$3$ph34$i = $rp$5$i$lcssa$lcssa;$z$5$ph$i = $622;
       }
       if ((label|0) == 221) {
        if ($595) {
         $632 = (($622) + -1)|0;
         $633 = (($x$i) + ($632<<2)|0);
         HEAP32[$633>>2] = 0;
         $635 = $z$5$ph$i;$a$3$i301 = $a$3$i;$e2$1$i298 = $e2$1$i;$z$7$i = $622;
        } else {
         $635 = $594;$a$3$i301 = $a$3$i;$e2$1$i298 = $e2$1$i;$z$7$i = $z$5$ph$i;
        }
       }
       $634 = (($x$i) + ($635<<2)|0);
       $636 = HEAP32[$634>>2]|0;
       $637 = (+($636>>>0));
       $638 = (($a$3$i301) + 1)|0;
       $639 = $638 & 127;
       $640 = ($639|0)==($z$7$i|0);
       if ($640) {
        $697 = (($a$3$i301) + 2)|0;
        $698 = $697 & 127;
        $699 = (($698) + -1)|0;
        $700 = (($x$i) + ($699<<2)|0);
        HEAP32[$700>>2] = 0;
        $z$7$1$i = $698;
       } else {
        $z$7$1$i = $z$7$i;
       }
       $701 = $637 * 1.0E+9;
       $702 = (($x$i) + ($639<<2)|0);
       $703 = HEAP32[$702>>2]|0;
       $704 = (+($703>>>0));
       $705 = $701 + $704;
       $661 = (+($sign$0|0));
       $643 = $661 * $705;
       $681 = (($e2$1$i298) + 53)|0;
       $687 = (($681) - ($emin$0$ph))|0;
       $688 = ($687|0)<($bits$0$ph|0);
       $706 = ($687|0)<(0);
       $$$i = $706 ? 0 : $687;
       $denormal$0$i = $688&1;
       $$010$i = $688 ? $$$i : $bits$0$ph;
       $707 = ($$010$i|0)<(53);
       if ($707) {
        $641 = (105 - ($$010$i))|0;
        $642 = (+_scalbn(1.0,$641));
        $644 = (+_copysignl($642,$643));
        $645 = (53 - ($$010$i))|0;
        $646 = (+_scalbn(1.0,$645));
        $647 = (+_fmodl($643,$646));
        $648 = $643 - $647;
        $649 = $644 + $648;
        $bias$0$i23 = $644;$frac$0$i = $647;$y$1$i22 = $649;
       } else {
        $bias$0$i23 = 0.0;$frac$0$i = 0.0;$y$1$i22 = $643;
       }
       $650 = (($a$3$i301) + 2)|0;
       $651 = $650 & 127;
       $652 = ($651|0)==($z$7$1$i|0);
       do {
        if ($652) {
         $frac$2$i = $frac$0$i;
        } else {
         $653 = (($x$i) + ($651<<2)|0);
         $654 = HEAP32[$653>>2]|0;
         $655 = ($654>>>0)<(500000000);
         do {
          if ($655) {
           $656 = ($654|0)==(0);
           if ($656) {
            $657 = (($a$3$i301) + 3)|0;
            $658 = $657 & 127;
            $659 = ($658|0)==($z$7$1$i|0);
            if ($659) {
             $frac$1$i = $frac$0$i;
             break;
            }
           }
           $660 = $661 * 0.25;
           $662 = $660 + $frac$0$i;
           $frac$1$i = $662;
          } else {
           $663 = ($654>>>0)>(500000000);
           if ($663) {
            $664 = $661 * 0.75;
            $665 = $664 + $frac$0$i;
            $frac$1$i = $665;
            break;
           }
           $666 = (($a$3$i301) + 3)|0;
           $667 = $666 & 127;
           $668 = ($667|0)==($z$7$1$i|0);
           if ($668) {
            $669 = $661 * 0.5;
            $670 = $669 + $frac$0$i;
            $frac$1$i = $670;
            break;
           } else {
            $671 = $661 * 0.75;
            $672 = $671 + $frac$0$i;
            $frac$1$i = $672;
            break;
           }
          }
         } while(0);
         $673 = (53 - ($$010$i))|0;
         $674 = ($673|0)>(1);
         if (!($674)) {
          $frac$2$i = $frac$1$i;
          break;
         }
         $675 = (+_fmodl($frac$1$i,1.0));
         $676 = $675 != 0.0;
         if ($676) {
          $frac$2$i = $frac$1$i;
          break;
         }
         $677 = $frac$1$i + 1.0;
         $frac$2$i = $677;
        }
       } while(0);
       $678 = $y$1$i22 + $frac$2$i;
       $679 = $678 - $bias$0$i23;
       $680 = $681 & 2147483647;
       $682 = (-2 - ($sum$i))|0;
       $683 = ($680|0)>($682|0);
       do {
        if ($683) {
         $684 = (+Math_abs((+$679)));
         $685 = !($684 >= 9007199254740992.0);
         if ($685) {
          $denormal$2$i = $denormal$0$i;$e2$2$i = $e2$1$i298;$y$2$i24 = $679;
         } else {
          $686 = ($$010$i|0)==($687|0);
          $or$cond20$i = $688 & $686;
          $denormal$1$i = $or$cond20$i ? 0 : $denormal$0$i;
          $689 = $679 * 0.5;
          $690 = (($e2$1$i298) + 1)|0;
          $denormal$2$i = $denormal$1$i;$e2$2$i = $690;$y$2$i24 = $689;
         }
         $691 = (($e2$2$i) + 50)|0;
         $692 = ($691|0)>($324|0);
         if (!($692)) {
          $693 = ($denormal$2$i|0)!=(0);
          $694 = $frac$2$i != 0.0;
          $or$cond8$i = $694 & $693;
          if (!($or$cond8$i)) {
           $e2$3$i = $e2$2$i;$y$3$i = $y$2$i24;
           break;
          }
         }
         $695 = (___errno_location()|0);
         HEAP32[$695>>2] = 34;
         $e2$3$i = $e2$2$i;$y$3$i = $y$2$i24;
        } else {
         $e2$3$i = $e2$1$i298;$y$3$i = $679;
        }
       } while(0);
       $696 = (+_scalbnl($y$3$i,$e2$3$i));
       $$0$i25 = $696;
      }
     } while(0);
     $$0 = $$0$i25;
     STACKTOP = sp;return (+$$0);
    }
   } while(0);
   $103 = HEAP32[$1>>2]|0;
   $104 = ($103|0)==(0|0);
   if (!($104)) {
    $105 = HEAP32[$0>>2]|0;
    $106 = ((($105)) + -1|0);
    HEAP32[$0>>2] = $106;
   }
   $107 = (___errno_location()|0);
   HEAP32[$107>>2] = 22;
   ___shlim($f,0);
   $$0 = 0.0;
   STACKTOP = sp;return (+$$0);
  }
 } while(0);
 if ((label|0) == 23) {
  $41 = HEAP32[$1>>2]|0;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   $43 = HEAP32[$0>>2]|0;
   $44 = ((($43)) + -1|0);
   HEAP32[$0>>2] = $44;
  }
  $notlhs = ($pok|0)==(0);
  $notrhs = ($i$0$lcssa>>>0)<(4);
  $or$cond9$not = $notrhs | $notlhs;
  $brmerge = $or$cond9$not | $42;
  if (!($brmerge)) {
   $$promoted = HEAP32[$0>>2]|0;
   $46 = $$promoted;$i$1 = $i$0$lcssa;
   while(1) {
    $45 = ((($46)) + -1|0);
    $47 = (($i$1) + -1)|0;
    $$old8 = ($47>>>0)>(3);
    if ($$old8) {
     $46 = $45;$i$1 = $47;
    } else {
     $$lcssa = $45;
     break;
    }
   }
   HEAP32[$0>>2] = $$lcssa;
  }
 }
 $48 = (+($sign$0|0));
 $49 = $48 * inf;
 $50 = $49;
 $$0 = $50;
 STACKTOP = sp;return (+$$0);
}
function ___shlim($f,$lim) {
 $f = $f|0;
 $lim = $lim|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 104|0);
 HEAP32[$0>>2] = $lim;
 $1 = ((($f)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($f)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = ((($f)) + 108|0);
 HEAP32[$8>>2] = $7;
 $9 = ($lim|0)!=(0);
 $10 = ($7|0)>($lim|0);
 $or$cond = $9 & $10;
 if ($or$cond) {
  $11 = (($4) + ($lim)|0);
  $12 = ((($f)) + 100|0);
  HEAP32[$12>>2] = $11;
  return;
 } else {
  $13 = ((($f)) + 100|0);
  HEAP32[$13>>2] = $5;
  return;
 }
}
function ___shgetc($f) {
 $f = $f|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert3 = 0, $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  label = 3;
 } else {
  $3 = ((($f)) + 108|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)<($1|0);
  if ($5) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $6 = (___uflow($f)|0);
  $7 = ($6|0)<(0);
  if (!($7)) {
   $9 = HEAP32[$0>>2]|0;
   $10 = ($9|0)==(0);
   $$phi$trans$insert = ((($f)) + 8|0);
   if ($10) {
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $11 = $$pre;
    $26 = $$pre;$41 = $11;
    label = 9;
   } else {
    $12 = HEAP32[$$phi$trans$insert>>2]|0;
    $13 = ((($f)) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $12;
    $16 = $14;
    $17 = (($15) - ($16))|0;
    $18 = ((($f)) + 108|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($9) - ($19))|0;
    $21 = (($20) + -1)|0;
    $22 = ($17|0)>($21|0);
    if ($22) {
     $23 = (($14) + ($21)|0);
     $24 = ((($f)) + 100|0);
     HEAP32[$24>>2] = $23;
     $28 = $12;
    } else {
     $26 = $15;$41 = $12;
     label = 9;
    }
   }
   if ((label|0) == 9) {
    $25 = ((($f)) + 100|0);
    HEAP32[$25>>2] = $26;
    $28 = $41;
   }
   $27 = ($28|0)==(0|0);
   $$phi$trans$insert3 = ((($f)) + 4|0);
   $$pre4 = HEAP32[$$phi$trans$insert3>>2]|0;
   if (!($27)) {
    $29 = $28;
    $30 = $$pre4;
    $31 = ((($f)) + 108|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($29) + 1)|0;
    $34 = (($33) - ($30))|0;
    $35 = (($34) + ($32))|0;
    HEAP32[$31>>2] = $35;
   }
   $36 = ((($$pre4)) + -1|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37&255;
   $39 = ($38|0)==($6|0);
   if ($39) {
    $$0 = $6;
    return ($$0|0);
   }
   $40 = $6&255;
   HEAP8[$36>>0] = $40;
   $$0 = $6;
   return ($$0|0);
  }
 }
 $8 = ((($f)) + 100|0);
 HEAP32[$8>>2] = 0;
 $$0 = -1;
 return ($$0|0);
}
function _copysign($x,$y) {
 $x = +$x;
 $y = +$y;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $y;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 $4 = $1 & 2147483647;
 $5 = $3 & -2147483648;
 $6 = $5 | $4;
 HEAP32[tempDoublePtr>>2] = $0;HEAP32[tempDoublePtr+4>>2] = $6;$7 = +HEAPF64[tempDoublePtr>>3];
 return (+$7);
}
function _copysignl($x,$y) {
 $x = +$x;
 $y = +$y;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_copysign($x,$y));
 return (+$0);
}
function _fmod($x,$y) {
 $x = +$x;
 $y = +$y;
 var $$0 = 0.0, $$lcssa7 = 0, $$x = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0.0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0.0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0.0;
 var $ex$0$lcssa = 0, $ex$026 = 0, $ex$1 = 0, $ex$2$lcssa = 0, $ex$212 = 0, $ex$3$lcssa = 0, $ex$39 = 0, $ey$0$lcssa = 0, $ey$020 = 0, $ey$1$ph = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $y;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 $4 = (_bitshift64Lshr(($0|0),($1|0),52)|0);
 $5 = tempRet0;
 $6 = $4 & 2047;
 $7 = (_bitshift64Lshr(($2|0),($3|0),52)|0);
 $8 = tempRet0;
 $9 = $7 & 2047;
 $10 = $1 & -2147483648;
 $11 = (_bitshift64Shl(($2|0),($3|0),1)|0);
 $12 = tempRet0;
 $13 = ($11|0)==(0);
 $14 = ($12|0)==(0);
 $15 = $13 & $14;
 if (!($15)) {
  $16 = $3 & 2147483647;
  $17 = ($16>>>0)>(2146435072);
  $18 = ($2>>>0)>(0);
  $19 = ($16|0)==(2146435072);
  $20 = $19 & $18;
  $21 = $17 | $20;
  $22 = ($6|0)==(2047);
  $or$cond = $21 | $22;
  if (!($or$cond)) {
   $25 = (_bitshift64Shl(($0|0),($1|0),1)|0);
   $26 = tempRet0;
   $27 = ($26>>>0)>($12>>>0);
   $28 = ($25>>>0)>($11>>>0);
   $29 = ($26|0)==($12|0);
   $30 = $29 & $28;
   $31 = $27 | $30;
   if (!($31)) {
    $32 = ($25|0)==($11|0);
    $33 = ($26|0)==($12|0);
    $34 = $32 & $33;
    $35 = $x * 0.0;
    $$x = $34 ? $35 : $x;
    return (+$$x);
   }
   $36 = ($6|0)==(0);
   if ($36) {
    $37 = (_bitshift64Shl(($0|0),($1|0),12)|0);
    $38 = tempRet0;
    $39 = ($38|0)>(-1);
    $40 = ($37>>>0)>(4294967295);
    $41 = ($38|0)==(-1);
    $42 = $41 & $40;
    $43 = $39 | $42;
    if ($43) {
     $45 = $37;$46 = $38;$ex$026 = 0;
     while(1) {
      $44 = (($ex$026) + -1)|0;
      $47 = (_bitshift64Shl(($45|0),($46|0),1)|0);
      $48 = tempRet0;
      $49 = ($48|0)>(-1);
      $50 = ($47>>>0)>(4294967295);
      $51 = ($48|0)==(-1);
      $52 = $51 & $50;
      $53 = $49 | $52;
      if ($53) {
       $45 = $47;$46 = $48;$ex$026 = $44;
      } else {
       $ex$0$lcssa = $44;
       break;
      }
     }
    } else {
     $ex$0$lcssa = 0;
    }
    $54 = (1 - ($ex$0$lcssa))|0;
    $55 = (_bitshift64Shl(($0|0),($1|0),($54|0))|0);
    $56 = tempRet0;
    $83 = $55;$84 = $56;$ex$1 = $ex$0$lcssa;
   } else {
    $57 = $1 & 1048575;
    $58 = $57 | 1048576;
    $83 = $0;$84 = $58;$ex$1 = $6;
   }
   $59 = ($9|0)==(0);
   if ($59) {
    $60 = (_bitshift64Shl(($2|0),($3|0),12)|0);
    $61 = tempRet0;
    $62 = ($61|0)>(-1);
    $63 = ($60>>>0)>(4294967295);
    $64 = ($61|0)==(-1);
    $65 = $64 & $63;
    $66 = $62 | $65;
    if ($66) {
     $68 = $60;$69 = $61;$ey$020 = 0;
     while(1) {
      $67 = (($ey$020) + -1)|0;
      $70 = (_bitshift64Shl(($68|0),($69|0),1)|0);
      $71 = tempRet0;
      $72 = ($71|0)>(-1);
      $73 = ($70>>>0)>(4294967295);
      $74 = ($71|0)==(-1);
      $75 = $74 & $73;
      $76 = $72 | $75;
      if ($76) {
       $68 = $70;$69 = $71;$ey$020 = $67;
      } else {
       $ey$0$lcssa = $67;
       break;
      }
     }
    } else {
     $ey$0$lcssa = 0;
    }
    $77 = (1 - ($ey$0$lcssa))|0;
    $78 = (_bitshift64Shl(($2|0),($3|0),($77|0))|0);
    $79 = tempRet0;
    $85 = $78;$86 = $79;$ey$1$ph = $ey$0$lcssa;
   } else {
    $80 = $3 & 1048575;
    $81 = $80 | 1048576;
    $85 = $2;$86 = $81;$ey$1$ph = $9;
   }
   $82 = ($ex$1|0)>($ey$1$ph|0);
   $87 = (_i64Subtract(($83|0),($84|0),($85|0),($86|0))|0);
   $88 = tempRet0;
   $89 = ($88|0)>(-1);
   $90 = ($87>>>0)>(4294967295);
   $91 = ($88|0)==(-1);
   $92 = $91 & $90;
   $93 = $89 | $92;
   L23: do {
    if ($82) {
     $152 = $93;$153 = $87;$154 = $88;$95 = $83;$97 = $84;$ex$212 = $ex$1;
     while(1) {
      if ($152) {
       $94 = ($95|0)==($85|0);
       $96 = ($97|0)==($86|0);
       $98 = $94 & $96;
       if ($98) {
        break;
       } else {
        $100 = $153;$101 = $154;
       }
      } else {
       $100 = $95;$101 = $97;
      }
      $102 = (_bitshift64Shl(($100|0),($101|0),1)|0);
      $103 = tempRet0;
      $104 = (($ex$212) + -1)|0;
      $105 = ($104|0)>($ey$1$ph|0);
      $106 = (_i64Subtract(($102|0),($103|0),($85|0),($86|0))|0);
      $107 = tempRet0;
      $108 = ($107|0)>(-1);
      $109 = ($106>>>0)>(4294967295);
      $110 = ($107|0)==(-1);
      $111 = $110 & $109;
      $112 = $108 | $111;
      if ($105) {
       $152 = $112;$153 = $106;$154 = $107;$95 = $102;$97 = $103;$ex$212 = $104;
      } else {
       $$lcssa7 = $112;$114 = $102;$116 = $103;$155 = $106;$156 = $107;$ex$2$lcssa = $104;
       break L23;
      }
     }
     $99 = $x * 0.0;
     $$0 = $99;
     return (+$$0);
    } else {
     $$lcssa7 = $93;$114 = $83;$116 = $84;$155 = $87;$156 = $88;$ex$2$lcssa = $ex$1;
    }
   } while(0);
   if ($$lcssa7) {
    $113 = ($114|0)==($85|0);
    $115 = ($116|0)==($86|0);
    $117 = $113 & $115;
    if ($117) {
     $125 = $x * 0.0;
     $$0 = $125;
     return (+$$0);
    } else {
     $119 = $156;$121 = $155;
    }
   } else {
    $119 = $116;$121 = $114;
   }
   $118 = ($119>>>0)<(1048576);
   $120 = ($121>>>0)<(0);
   $122 = ($119|0)==(1048576);
   $123 = $122 & $120;
   $124 = $118 | $123;
   if ($124) {
    $126 = $121;$127 = $119;$ex$39 = $ex$2$lcssa;
    while(1) {
     $128 = (_bitshift64Shl(($126|0),($127|0),1)|0);
     $129 = tempRet0;
     $130 = (($ex$39) + -1)|0;
     $131 = ($129>>>0)<(1048576);
     $132 = ($128>>>0)<(0);
     $133 = ($129|0)==(1048576);
     $134 = $133 & $132;
     $135 = $131 | $134;
     if ($135) {
      $126 = $128;$127 = $129;$ex$39 = $130;
     } else {
      $137 = $128;$138 = $129;$ex$3$lcssa = $130;
      break;
     }
    }
   } else {
    $137 = $121;$138 = $119;$ex$3$lcssa = $ex$2$lcssa;
   }
   $136 = ($ex$3$lcssa|0)>(0);
   if ($136) {
    $139 = (_i64Add(($137|0),($138|0),0,-1048576)|0);
    $140 = tempRet0;
    $141 = (_bitshift64Shl(($ex$3$lcssa|0),0,52)|0);
    $142 = tempRet0;
    $143 = $139 | $141;
    $144 = $140 | $142;
    $149 = $144;$150 = $143;
   } else {
    $145 = (1 - ($ex$3$lcssa))|0;
    $146 = (_bitshift64Lshr(($137|0),($138|0),($145|0))|0);
    $147 = tempRet0;
    $149 = $147;$150 = $146;
   }
   $148 = $149 | $10;
   HEAP32[tempDoublePtr>>2] = $150;HEAP32[tempDoublePtr+4>>2] = $148;$151 = +HEAPF64[tempDoublePtr>>3];
   $$0 = $151;
   return (+$$0);
  }
 }
 $23 = $x * $y;
 $24 = $23 / $23;
 $$0 = $24;
 return (+$$0);
}
function _fmodl($x,$y) {
 $x = +$x;
 $y = +$y;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_fmod($x,$y));
 return (+$0);
}
function _frexp($x,$e) {
 $x = +$x;
 $e = $e|0;
 var $$0 = 0.0, $$01 = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = (_bitshift64Lshr(($0|0),($1|0),52)|0);
 $3 = tempRet0;
 $4 = $2 & 2047;
 if ((($4|0) == 2047)) {
  $$0 = $x;
  return (+$$0);
 } else if ((($4|0) == 0)) {
  $5 = $x != 0.0;
  if ($5) {
   $6 = $x * 1.8446744073709552E+19;
   $7 = (+_frexp($6,$e));
   $8 = HEAP32[$e>>2]|0;
   $9 = (($8) + -64)|0;
   $$01 = $7;$storemerge = $9;
  } else {
   $$01 = $x;$storemerge = 0;
  }
  HEAP32[$e>>2] = $storemerge;
  $$0 = $$01;
  return (+$$0);
 } else {
  $10 = (($4) + -1022)|0;
  HEAP32[$e>>2] = $10;
  $11 = $1 & -2146435073;
  $12 = $11 | 1071644672;
  HEAP32[tempDoublePtr>>2] = $0;HEAP32[tempDoublePtr+4>>2] = $12;$13 = +HEAPF64[tempDoublePtr>>3];
  $$0 = $13;
  return (+$$0);
 }
 return +(0.0);
}
function _frexpl($x,$e) {
 $x = +$x;
 $e = $e|0;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_frexp($x,$e));
 return (+$0);
}
function _scalbn($x,$n) {
 $x = +$x;
 $n = $n|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $0 = 0, $1 = 0.0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0.0, $9 = 0, $y$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)>(1023);
 if ($0) {
  $1 = $x * 8.9884656743115795E+307;
  $2 = (($n) + -1023)|0;
  $3 = ($2|0)>(1023);
  if ($3) {
   $4 = $1 * 8.9884656743115795E+307;
   $5 = (($n) + -2046)|0;
   $6 = ($5|0)>(1023);
   $$ = $6 ? 1023 : $5;
   $$0 = $$;$y$0 = $4;
  } else {
   $$0 = $2;$y$0 = $1;
  }
 } else {
  $7 = ($n|0)<(-1022);
  if ($7) {
   $8 = $x * 2.2250738585072014E-308;
   $9 = (($n) + 1022)|0;
   $10 = ($9|0)<(-1022);
   if ($10) {
    $11 = $8 * 2.2250738585072014E-308;
    $12 = (($n) + 2044)|0;
    $13 = ($12|0)<(-1022);
    $$1 = $13 ? -1022 : $12;
    $$0 = $$1;$y$0 = $11;
   } else {
    $$0 = $9;$y$0 = $8;
   }
  } else {
   $$0 = $n;$y$0 = $x;
  }
 }
 $14 = (($$0) + 1023)|0;
 $15 = (_bitshift64Shl(($14|0),0,52)|0);
 $16 = tempRet0;
 HEAP32[tempDoublePtr>>2] = $15;HEAP32[tempDoublePtr+4>>2] = $16;$17 = +HEAPF64[tempDoublePtr>>3];
 $18 = $y$0 * $17;
 return (+$18);
}
function _scalbnl($x,$n) {
 $x = +$x;
 $n = $n|0;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_scalbn($x,$n));
 return (+$0);
}
function _wctomb($s,$wc) {
 $s = $s|0;
 $wc = $wc|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($s|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (_wcrtomb($s,$wc,0)|0);
  $$0 = $1;
 }
 return ($$0|0);
}
function _wcrtomb($s,$wc,$st) {
 $s = $s|0;
 $wc = $wc|0;
 $st = $st|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($s|0)==(0|0);
 if ($0) {
  $$0 = 1;
  return ($$0|0);
 }
 $1 = ($wc>>>0)<(128);
 if ($1) {
  $2 = $wc&255;
  HEAP8[$s>>0] = $2;
  $$0 = 1;
  return ($$0|0);
 }
 $3 = ($wc>>>0)<(2048);
 if ($3) {
  $4 = $wc >>> 6;
  $5 = $4 | 192;
  $6 = $5&255;
  $7 = ((($s)) + 1|0);
  HEAP8[$s>>0] = $6;
  $8 = $wc & 63;
  $9 = $8 | 128;
  $10 = $9&255;
  HEAP8[$7>>0] = $10;
  $$0 = 2;
  return ($$0|0);
 }
 $11 = ($wc>>>0)<(55296);
 $12 = $wc & -8192;
 $13 = ($12|0)==(57344);
 $or$cond = $11 | $13;
 if ($or$cond) {
  $14 = $wc >>> 12;
  $15 = $14 | 224;
  $16 = $15&255;
  $17 = ((($s)) + 1|0);
  HEAP8[$s>>0] = $16;
  $18 = $wc >>> 6;
  $19 = $18 & 63;
  $20 = $19 | 128;
  $21 = $20&255;
  $22 = ((($s)) + 2|0);
  HEAP8[$17>>0] = $21;
  $23 = $wc & 63;
  $24 = $23 | 128;
  $25 = $24&255;
  HEAP8[$22>>0] = $25;
  $$0 = 3;
  return ($$0|0);
 }
 $26 = (($wc) + -65536)|0;
 $27 = ($26>>>0)<(1048576);
 if ($27) {
  $28 = $wc >>> 18;
  $29 = $28 | 240;
  $30 = $29&255;
  $31 = ((($s)) + 1|0);
  HEAP8[$s>>0] = $30;
  $32 = $wc >>> 12;
  $33 = $32 & 63;
  $34 = $33 | 128;
  $35 = $34&255;
  $36 = ((($s)) + 2|0);
  HEAP8[$31>>0] = $35;
  $37 = $wc >>> 6;
  $38 = $37 & 63;
  $39 = $38 | 128;
  $40 = $39&255;
  $41 = ((($s)) + 3|0);
  HEAP8[$36>>0] = $40;
  $42 = $wc & 63;
  $43 = $42 | 128;
  $44 = $43&255;
  HEAP8[$41>>0] = $44;
  $$0 = 4;
  return ($$0|0);
 } else {
  $45 = (___errno_location()|0);
  HEAP32[$45>>2] = 84;
  $$0 = -1;
  return ($$0|0);
 }
 return (0)|0;
}
function ___toread($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 74|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 << 24 >> 24;
 $3 = (($2) + 255)|0;
 $4 = $3 | $2;
 $5 = $4&255;
 HEAP8[$0>>0] = $5;
 $6 = ((($f)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($f)) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($10) {
  $11 = ((($f)) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  (FUNCTION_TABLE_iiii[$12 & 15]($f,0,0)|0);
 }
 $13 = ((($f)) + 16|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($f)) + 28|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$6>>2] = 0;
 $15 = HEAP32[$f>>2]|0;
 $16 = $15 & 20;
 $17 = ($16|0)==(0);
 if ($17) {
  $21 = HEAP32[$8>>2]|0;
  $22 = ((($f)) + 8|0);
  HEAP32[$22>>2] = $21;
  $23 = ((($f)) + 4|0);
  HEAP32[$23>>2] = $21;
  $$0 = 0;
  return ($$0|0);
 }
 $18 = $15 & 4;
 $19 = ($18|0)==(0);
 if ($19) {
  $$0 = -1;
  return ($$0|0);
 }
 $20 = $15 | 32;
 HEAP32[$f>>2] = $20;
 $$0 = -1;
 return ($$0|0);
}
function ___towrite($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 74|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 << 24 >> 24;
 $3 = (($2) + 255)|0;
 $4 = $3 | $2;
 $5 = $4&255;
 HEAP8[$0>>0] = $5;
 $6 = HEAP32[$f>>2]|0;
 $7 = $6 & 8;
 $8 = ($7|0)==(0);
 if ($8) {
  $10 = ((($f)) + 8|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($f)) + 4|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($f)) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($f)) + 28|0);
  HEAP32[$14>>2] = $13;
  $15 = ((($f)) + 20|0);
  HEAP32[$15>>2] = $13;
  $16 = $13;
  $17 = ((($f)) + 48|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16) + ($18)|0);
  $20 = ((($f)) + 16|0);
  HEAP32[$20>>2] = $19;
  $$0 = 0;
  return ($$0|0);
 } else {
  $9 = $6 | 32;
  HEAP32[$f>>2] = $9;
  $$0 = -1;
  return ($$0|0);
 }
 return (0)|0;
}
function ___uflow($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $c = sp;
 $0 = ((($f)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (___toread($f)|0);
  $4 = ($3|0)==(0);
  if ($4) {
   label = 3;
  } else {
   $$0 = -1;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $5 = ((($f)) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_iiii[$6 & 15]($f,$c,1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   $9 = HEAP8[$c>>0]|0;
   $10 = $9&255;
   $$0 = $10;
  } else {
   $$0 = -1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function ___fwritex($s,$l,$f) {
 $s = $s|0;
 $l = $l|0;
 $f = $f|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$0$lcssa10 = 0;
 var $i$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $3 = (___towrite($f)|0);
   $4 = ($3|0)==(0);
   if ($4) {
    $$pre = HEAP32[$0>>2]|0;
    $8 = $$pre;
    break;
   } else {
    $$0 = 0;
    return ($$0|0);
   }
  } else {
   $8 = $1;
  }
 } while(0);
 $5 = ((($f)) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $8;
 $9 = $6;
 $10 = (($7) - ($9))|0;
 $11 = ($10>>>0)<($l>>>0);
 if ($11) {
  $12 = ((($f)) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$13 & 15]($f,$s,$l)|0);
  $$0 = $14;
  return ($$0|0);
 }
 $15 = ((($f)) + 75|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)>(-1);
 L11: do {
  if ($17) {
   $i$0 = $l;
   while(1) {
    $18 = ($i$0|0)==(0);
    if ($18) {
     $$01 = $l;$$02 = $s;$29 = $6;$i$1 = 0;
     break L11;
    }
    $19 = (($i$0) + -1)|0;
    $20 = (($s) + ($19)|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = ($21<<24>>24)==(10);
    if ($22) {
     $i$0$lcssa10 = $i$0;
     break;
    } else {
     $i$0 = $19;
    }
   }
   $23 = ((($f)) + 36|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (FUNCTION_TABLE_iiii[$24 & 15]($f,$s,$i$0$lcssa10)|0);
   $26 = ($25>>>0)<($i$0$lcssa10>>>0);
   if ($26) {
    $$0 = $i$0$lcssa10;
    return ($$0|0);
   } else {
    $27 = (($s) + ($i$0$lcssa10)|0);
    $28 = (($l) - ($i$0$lcssa10))|0;
    $$pre6 = HEAP32[$5>>2]|0;
    $$01 = $28;$$02 = $27;$29 = $$pre6;$i$1 = $i$0$lcssa10;
    break;
   }
  } else {
   $$01 = $l;$$02 = $s;$29 = $6;$i$1 = 0;
  }
 } while(0);
 _memcpy(($29|0),($$02|0),($$01|0))|0;
 $30 = HEAP32[$5>>2]|0;
 $31 = (($30) + ($$01)|0);
 HEAP32[$5>>2] = $31;
 $32 = (($i$1) + ($$01))|0;
 $$0 = $32;
 return ($$0|0);
}
function _sprintf($s,$fmt,$varargs) {
 $s = $s|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ap = sp;
 HEAP32[$ap>>2] = $varargs;
 $0 = (_vsprintf($s,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _MUSL_vfprintf($f,$fmt,$ap) {
 $f = $f|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ap2 = 0, $internal_buf = 0, $nl_arg = 0, $nl_type = 0, $ret$1 = 0, $vacopy_currentptr = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ap2 = sp + 120|0;
 $nl_type = sp + 80|0;
 $nl_arg = sp;
 $internal_buf = sp + 136|0;
 dest=$nl_type; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $vacopy_currentptr = HEAP32[$ap>>2]|0;
 HEAP32[$ap2>>2] = $vacopy_currentptr;
 $0 = (_printf_core(0,$fmt,$ap2,$nl_arg,$nl_type)|0);
 $1 = ($0|0)<(0);
 if ($1) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ((($f)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $6 = ((($f)) + 44|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$6>>2] = $internal_buf;
  $8 = ((($f)) + 28|0);
  HEAP32[$8>>2] = $internal_buf;
  $9 = ((($f)) + 20|0);
  HEAP32[$9>>2] = $internal_buf;
  HEAP32[$2>>2] = 80;
  $10 = ((($internal_buf)) + 80|0);
  $11 = ((($f)) + 16|0);
  HEAP32[$11>>2] = $10;
  $12 = (_printf_core($f,$fmt,$ap2,$nl_arg,$nl_type)|0);
  $13 = ($7|0)==(0|0);
  if ($13) {
   $ret$1 = $12;
  } else {
   $14 = ((($f)) + 36|0);
   $15 = HEAP32[$14>>2]|0;
   (FUNCTION_TABLE_iiii[$15 & 15]($f,0,0)|0);
   $16 = HEAP32[$9>>2]|0;
   $17 = ($16|0)==(0|0);
   $$ = $17 ? -1 : $12;
   HEAP32[$6>>2] = $7;
   HEAP32[$2>>2] = 0;
   HEAP32[$11>>2] = 0;
   HEAP32[$8>>2] = 0;
   HEAP32[$9>>2] = 0;
   $ret$1 = $$;
  }
 } else {
  $5 = (_printf_core($f,$fmt,$ap2,$nl_arg,$nl_type)|0);
  $ret$1 = $5;
 }
 $$0 = $ret$1;
 STACKTOP = sp;return ($$0|0);
}
function _vsnprintf($s,$n,$fmt,$ap) {
 $s = $s|0;
 $n = $n|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$$02 = 0, $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $f = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $b = sp + 112|0;
 $f = sp;
 dest=$f; src=6264; stop=dest+112|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $0 = (($n) + -1)|0;
 $1 = ($0>>>0)>(2147483646);
 if ($1) {
  $2 = ($n|0)==(0);
  if ($2) {
   $$01 = $b;$$02 = 1;
  } else {
   $3 = (___errno_location()|0);
   HEAP32[$3>>2] = 75;
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$01 = $s;$$02 = $n;
 }
 $4 = $$01;
 $5 = (-2 - ($4))|0;
 $6 = ($$02>>>0)>($5>>>0);
 $$$02 = $6 ? $5 : $$02;
 $7 = ((($f)) + 48|0);
 HEAP32[$7>>2] = $$$02;
 $8 = ((($f)) + 20|0);
 HEAP32[$8>>2] = $$01;
 $9 = ((($f)) + 44|0);
 HEAP32[$9>>2] = $$01;
 $10 = (($$01) + ($$$02)|0);
 $11 = ((($f)) + 16|0);
 HEAP32[$11>>2] = $10;
 $12 = ((($f)) + 28|0);
 HEAP32[$12>>2] = $10;
 $13 = (_MUSL_vfprintf($f,$fmt,$ap)|0);
 $14 = ($$$02|0)==(0);
 if ($14) {
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = HEAP32[$11>>2]|0;
 $17 = ($15|0)==($16|0);
 $18 = $17 << 31 >> 31;
 $19 = (($15) + ($18)|0);
 HEAP8[$19>>0] = 0;
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function _vsprintf($s,$fmt,$ap) {
 $s = $s|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_vsnprintf($s,2147483647,$fmt,$ap)|0);
 return ($0|0);
}
function _strtod($s,$p) {
 $s = $s|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f$i = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $f$i = sp;
 dest=$f$i; stop=dest+112|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = ((($f$i)) + 4|0);
 HEAP32[$0>>2] = $s;
 $1 = ((($f$i)) + 8|0);
 HEAP32[$1>>2] = (-1);
 $2 = ((($f$i)) + 44|0);
 HEAP32[$2>>2] = $s;
 $3 = ((($f$i)) + 76|0);
 HEAP32[$3>>2] = -1;
 ___shlim($f$i,0);
 $4 = (+___floatscan($f$i,1,1));
 $5 = ((($f$i)) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$1>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = (($11) + ($6))|0;
 $13 = ($p|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return (+$4);
 }
 $14 = ($12|0)!=(0);
 $15 = (($s) + ($12)|0);
 $16 = $14 ? $15 : $s;
 HEAP32[$p>>2] = $16;
 STACKTOP = sp;return (+$4);
}
function _memchr($src,$c,$n) {
 $src = $src|0;
 $c = $c|0;
 $n = $n|0;
 var $$0$lcssa = 0, $$0$lcssa44 = 0, $$019 = 0, $$1$lcssa = 0, $$110 = 0, $$110$lcssa = 0, $$24 = 0, $$3 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond18 = 0, $s$0$lcssa = 0, $s$0$lcssa43 = 0, $s$020 = 0, $s$15 = 0, $s$2 = 0, $w$0$lcssa = 0, $w$011 = 0, $w$011$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c & 255;
 $1 = $src;
 $2 = $1 & 3;
 $3 = ($2|0)!=(0);
 $4 = ($n|0)!=(0);
 $or$cond18 = $4 & $3;
 L1: do {
  if ($or$cond18) {
   $5 = $c&255;
   $$019 = $n;$s$020 = $src;
   while(1) {
    $6 = HEAP8[$s$020>>0]|0;
    $7 = ($6<<24>>24)==($5<<24>>24);
    if ($7) {
     $$0$lcssa44 = $$019;$s$0$lcssa43 = $s$020;
     label = 6;
     break L1;
    }
    $8 = ((($s$020)) + 1|0);
    $9 = (($$019) + -1)|0;
    $10 = $8;
    $11 = $10 & 3;
    $12 = ($11|0)!=(0);
    $13 = ($9|0)!=(0);
    $or$cond = $13 & $12;
    if ($or$cond) {
     $$019 = $9;$s$020 = $8;
    } else {
     $$0$lcssa = $9;$$lcssa = $13;$s$0$lcssa = $8;
     label = 5;
     break;
    }
   }
  } else {
   $$0$lcssa = $n;$$lcssa = $4;$s$0$lcssa = $src;
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  if ($$lcssa) {
   $$0$lcssa44 = $$0$lcssa;$s$0$lcssa43 = $s$0$lcssa;
   label = 6;
  } else {
   $$3 = 0;$s$2 = $s$0$lcssa;
  }
 }
 L8: do {
  if ((label|0) == 6) {
   $14 = HEAP8[$s$0$lcssa43>>0]|0;
   $15 = $c&255;
   $16 = ($14<<24>>24)==($15<<24>>24);
   if ($16) {
    $$3 = $$0$lcssa44;$s$2 = $s$0$lcssa43;
   } else {
    $17 = Math_imul($0, 16843009)|0;
    $18 = ($$0$lcssa44>>>0)>(3);
    L11: do {
     if ($18) {
      $$110 = $$0$lcssa44;$w$011 = $s$0$lcssa43;
      while(1) {
       $19 = HEAP32[$w$011>>2]|0;
       $20 = $19 ^ $17;
       $21 = (($20) + -16843009)|0;
       $22 = $20 & -2139062144;
       $23 = $22 ^ -2139062144;
       $24 = $23 & $21;
       $25 = ($24|0)==(0);
       if (!($25)) {
        $$110$lcssa = $$110;$w$011$lcssa = $w$011;
        break;
       }
       $26 = ((($w$011)) + 4|0);
       $27 = (($$110) + -4)|0;
       $28 = ($27>>>0)>(3);
       if ($28) {
        $$110 = $27;$w$011 = $26;
       } else {
        $$1$lcssa = $27;$w$0$lcssa = $26;
        label = 11;
        break L11;
       }
      }
      $$24 = $$110$lcssa;$s$15 = $w$011$lcssa;
     } else {
      $$1$lcssa = $$0$lcssa44;$w$0$lcssa = $s$0$lcssa43;
      label = 11;
     }
    } while(0);
    if ((label|0) == 11) {
     $29 = ($$1$lcssa|0)==(0);
     if ($29) {
      $$3 = 0;$s$2 = $w$0$lcssa;
      break;
     } else {
      $$24 = $$1$lcssa;$s$15 = $w$0$lcssa;
     }
    }
    while(1) {
     $30 = HEAP8[$s$15>>0]|0;
     $31 = ($30<<24>>24)==($15<<24>>24);
     if ($31) {
      $$3 = $$24;$s$2 = $s$15;
      break L8;
     }
     $32 = ((($s$15)) + 1|0);
     $33 = (($$24) + -1)|0;
     $34 = ($33|0)==(0);
     if ($34) {
      $$3 = 0;$s$2 = $32;
      break;
     } else {
      $$24 = $33;$s$15 = $32;
     }
    }
   }
  }
 } while(0);
 $35 = ($$3|0)!=(0);
 $36 = $35 ? $s$2 : 0;
 return ($36|0);
}
function _memcmp($vl,$vr,$n) {
 $vl = $vl|0;
 $vr = $vr|0;
 $n = $n|0;
 var $$03 = 0, $$lcssa = 0, $$lcssa19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$04 = 0, $r$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if ($0) {
  $11 = 0;
  return ($11|0);
 } else {
  $$03 = $n;$l$04 = $vl;$r$05 = $vr;
 }
 while(1) {
  $1 = HEAP8[$l$04>>0]|0;
  $2 = HEAP8[$r$05>>0]|0;
  $3 = ($1<<24>>24)==($2<<24>>24);
  if (!($3)) {
   $$lcssa = $1;$$lcssa19 = $2;
   break;
  }
  $4 = (($$03) + -1)|0;
  $5 = ((($l$04)) + 1|0);
  $6 = ((($r$05)) + 1|0);
  $7 = ($4|0)==(0);
  if ($7) {
   $11 = 0;
   label = 5;
   break;
  } else {
   $$03 = $4;$l$04 = $5;$r$05 = $6;
  }
 }
 if ((label|0) == 5) {
  return ($11|0);
 }
 $8 = $$lcssa&255;
 $9 = $$lcssa19&255;
 $10 = (($8) - ($9))|0;
 $11 = $10;
 return ($11|0);
}
function _strcmp($l,$r) {
 $l = $l|0;
 $r = $r|0;
 var $$014 = 0, $$05 = 0, $$lcssa = 0, $$lcssa2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$l>>0]|0;
 $1 = HEAP8[$r>>0]|0;
 $2 = ($0<<24>>24)!=($1<<24>>24);
 $3 = ($0<<24>>24)==(0);
 $or$cond3 = $3 | $2;
 if ($or$cond3) {
  $$lcssa = $0;$$lcssa2 = $1;
 } else {
  $$014 = $l;$$05 = $r;
  while(1) {
   $4 = ((($$014)) + 1|0);
   $5 = ((($$05)) + 1|0);
   $6 = HEAP8[$4>>0]|0;
   $7 = HEAP8[$5>>0]|0;
   $8 = ($6<<24>>24)!=($7<<24>>24);
   $9 = ($6<<24>>24)==(0);
   $or$cond = $9 | $8;
   if ($or$cond) {
    $$lcssa = $6;$$lcssa2 = $7;
    break;
   } else {
    $$014 = $4;$$05 = $5;
   }
  }
 }
 $10 = $$lcssa&255;
 $11 = $$lcssa2&255;
 $12 = (($10) - ($11))|0;
 return ($12|0);
}
function _scanexp($f,$pok) {
 $f = $f|0;
 $pok = $pok|0;
 var $$lcssa22 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $c$0 = 0, $c$1$be = 0, $c$1$be$lcssa = 0, $c$112 = 0, $c$2$be = 0, $c$2$lcssa = 0, $c$27 = 0, $c$3$be = 0, $neg$0 = 0, $or$cond3 = 0, $x$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($f)) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if ($4) {
  $5 = ((($1)) + 1|0);
  HEAP32[$0>>2] = $5;
  $6 = HEAP8[$1>>0]|0;
  $7 = $6&255;
  $10 = $7;
 } else {
  $8 = (___shgetc($f)|0);
  $10 = $8;
 }
 $9 = ($10|0)==(45);
 if ((($10|0) == 43) | (($10|0) == 45)) {
  $11 = $9&1;
  $12 = HEAP32[$0>>2]|0;
  $13 = HEAP32[$2>>2]|0;
  $14 = ($12>>>0)<($13>>>0);
  if ($14) {
   $15 = ((($12)) + 1|0);
   HEAP32[$0>>2] = $15;
   $16 = HEAP8[$12>>0]|0;
   $17 = $16&255;
   $20 = $17;
  } else {
   $18 = (___shgetc($f)|0);
   $20 = $18;
  }
  $19 = (($20) + -48)|0;
  $21 = ($19>>>0)>(9);
  $22 = ($pok|0)!=(0);
  $or$cond3 = $22 & $21;
  if ($or$cond3) {
   $23 = HEAP32[$2>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    $c$0 = $20;$neg$0 = $11;
   } else {
    $25 = HEAP32[$0>>2]|0;
    $26 = ((($25)) + -1|0);
    HEAP32[$0>>2] = $26;
    $c$0 = $20;$neg$0 = $11;
   }
  } else {
   $c$0 = $20;$neg$0 = $11;
  }
 } else {
  $c$0 = $10;$neg$0 = 0;
 }
 $27 = (($c$0) + -48)|0;
 $28 = ($27>>>0)>(9);
 if ($28) {
  $29 = HEAP32[$2>>2]|0;
  $30 = ($29|0)==(0|0);
  if ($30) {
   $98 = -2147483648;$99 = 0;
   tempRet0 = ($98);
   return ($99|0);
  }
  $31 = HEAP32[$0>>2]|0;
  $32 = ((($31)) + -1|0);
  HEAP32[$0>>2] = $32;
  $98 = -2147483648;$99 = 0;
  tempRet0 = ($98);
  return ($99|0);
 } else {
  $c$112 = $c$0;$x$013 = 0;
 }
 while(1) {
  $33 = ($x$013*10)|0;
  $34 = (($c$112) + -48)|0;
  $35 = (($34) + ($33))|0;
  $36 = HEAP32[$0>>2]|0;
  $37 = HEAP32[$2>>2]|0;
  $38 = ($36>>>0)<($37>>>0);
  if ($38) {
   $39 = ((($36)) + 1|0);
   HEAP32[$0>>2] = $39;
   $40 = HEAP8[$36>>0]|0;
   $41 = $40&255;
   $c$1$be = $41;
  } else {
   $42 = (___shgetc($f)|0);
   $c$1$be = $42;
  }
  $43 = (($c$1$be) + -48)|0;
  $44 = ($43>>>0)<(10);
  $45 = ($35|0)<(214748364);
  $46 = $44 & $45;
  if ($46) {
   $c$112 = $c$1$be;$x$013 = $35;
  } else {
   $$lcssa22 = $35;$c$1$be$lcssa = $c$1$be;
   break;
  }
 }
 $47 = ($$lcssa22|0)<(0);
 $48 = $47 << 31 >> 31;
 $49 = (($c$1$be$lcssa) + -48)|0;
 $50 = ($49>>>0)<(10);
 if ($50) {
  $53 = $$lcssa22;$54 = $48;$c$27 = $c$1$be$lcssa;
  while(1) {
   $55 = (___muldi3(($53|0),($54|0),10,0)|0);
   $56 = tempRet0;
   $57 = ($c$27|0)<(0);
   $58 = $57 << 31 >> 31;
   $59 = (_i64Add(($c$27|0),($58|0),-48,-1)|0);
   $60 = tempRet0;
   $61 = (_i64Add(($59|0),($60|0),($55|0),($56|0))|0);
   $62 = tempRet0;
   $63 = HEAP32[$0>>2]|0;
   $64 = HEAP32[$2>>2]|0;
   $65 = ($63>>>0)<($64>>>0);
   if ($65) {
    $66 = ((($63)) + 1|0);
    HEAP32[$0>>2] = $66;
    $67 = HEAP8[$63>>0]|0;
    $68 = $67&255;
    $c$2$be = $68;
   } else {
    $69 = (___shgetc($f)|0);
    $c$2$be = $69;
   }
   $70 = (($c$2$be) + -48)|0;
   $71 = ($70>>>0)<(10);
   $72 = ($62|0)<(21474836);
   $73 = ($61>>>0)<(2061584302);
   $74 = ($62|0)==(21474836);
   $75 = $74 & $73;
   $76 = $72 | $75;
   $77 = $71 & $76;
   if ($77) {
    $53 = $61;$54 = $62;$c$27 = $c$2$be;
   } else {
    $92 = $61;$93 = $62;$c$2$lcssa = $c$2$be;
    break;
   }
  }
 } else {
  $92 = $$lcssa22;$93 = $48;$c$2$lcssa = $c$1$be$lcssa;
 }
 $51 = (($c$2$lcssa) + -48)|0;
 $52 = ($51>>>0)<(10);
 if ($52) {
  while(1) {
   $78 = HEAP32[$0>>2]|0;
   $79 = HEAP32[$2>>2]|0;
   $80 = ($78>>>0)<($79>>>0);
   if ($80) {
    $81 = ((($78)) + 1|0);
    HEAP32[$0>>2] = $81;
    $82 = HEAP8[$78>>0]|0;
    $83 = $82&255;
    $c$3$be = $83;
   } else {
    $84 = (___shgetc($f)|0);
    $c$3$be = $84;
   }
   $85 = (($c$3$be) + -48)|0;
   $86 = ($85>>>0)<(10);
   if (!($86)) {
    break;
   }
  }
 }
 $87 = HEAP32[$2>>2]|0;
 $88 = ($87|0)==(0|0);
 if (!($88)) {
  $89 = HEAP32[$0>>2]|0;
  $90 = ((($89)) + -1|0);
  HEAP32[$0>>2] = $90;
 }
 $91 = ($neg$0|0)!=(0);
 $94 = (_i64Subtract(0,0,($92|0),($93|0))|0);
 $95 = tempRet0;
 $96 = $91 ? $94 : $92;
 $97 = $91 ? $95 : $93;
 $98 = $97;$99 = $96;
 tempRet0 = ($98);
 return ($99|0);
}
function _printf_core($f,$fmt,$ap,$nl_arg,$nl_type) {
 $f = $f|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 $nl_arg = $nl_arg|0;
 $nl_type = $nl_type|0;
 var $$ = 0, $$$i = 0, $$0 = 0, $$0$i = 0, $$0$lcssa$i = 0, $$0$lcssa$i$i = 0, $$0$lcssa$i104$i = 0, $$0$lcssa$i128$i = 0, $$0$lcssa$i143$i = 0, $$0$lcssa$i39$i = 0, $$0$lcssa$i46 = 0, $$0$lcssa$i46$i = 0, $$0$lcssa$i48$i = 0, $$0$lcssa$i51 = 0, $$0$lcssa$i53 = 0, $$0$lcssa$i56$i = 0, $$0$lcssa$i61 = 0, $$0$lcssa$i63$i = 0, $$0$lcssa$i68 = 0, $$0$lcssa$i69$i = 0;
 var $$0$lcssa$i75 = 0, $$0$lcssa$i76$i = 0, $$0$lcssa$i84$i = 0, $$0$lcssa$i85 = 0, $$0$lcssa$i97$i = 0, $$01$i = 0, $$01$i$i = 0, $$01$i102$i = 0, $$01$i126$i = 0, $$01$i141$i = 0, $$01$i37$i = 0, $$01$i44 = 0, $$01$i44$i = 0, $$01$i54$i = 0, $$01$i59 = 0, $$01$i61$i = 0, $$01$i66 = 0, $$01$i67$i = 0, $$01$i73 = 0, $$01$i74$i = 0;
 var $$01$i83 = 0, $$01$i95$i = 0, $$01$lcssa$off0$i = 0, $$01$lcssa$off0$i$i = 0, $$01$lcssa$off0$i85$i = 0, $$012$i = 0, $$013$i = 0, $$03$i48 = 0, $$05$i = 0, $$05$i$i = 0, $$05$i79$i = 0, $$07$i = 0.0, $$1$i = 0.0, $$1$lcssa$i$i = 0, $$1$lcssa$i112$i = 0, $$114$i = 0, $$12$i = 0, $$12$i$i = 0, $$12$i110$i = 0, $$12$i119$i = 0;
 var $$12$i134$i = 0, $$12$i134$i$lcssa = 0, $$12$i87$i = 0, $$2$i = 0.0, $$2$us$i = 0.0, $$2$us$us$i = 0.0, $$20$i = 0.0, $$21$i = 0, $$210$$22$i = 0, $$210$$24$i = 0, $$210$i = 0, $$23$i = 0, $$24 = 0, $$25 = 0, $$3$i = 0.0, $$31$i = 0, $$311$i = 0, $$4$i = 0.0, $$412$lcssa$i = 0, $$412184$i = 0;
 var $$5196$i = 0, $$92 = 0, $$a$3$i = 0, $$a$3$us$i = 0, $$a$3$us303$i = 0, $$a$3$us304$i = 0, $$a$3305$i = 0, $$a$3306$i = 0, $$fl$4 = 0, $$l10n$0 = 0, $$lcssa106 = 0, $$lcssa275$i = 0, $$lcssa450 = 0, $$lcssa451 = 0, $$lcssa455 = 0, $$lcssa457 = 0, $$lcssa458 = 0, $$lcssa459 = 0, $$lcssa460 = 0, $$lcssa461 = 0;
 var $$lcssa463 = 0, $$lcssa464 = 0, $$lcssa470 = 0, $$lcssa474 = 0, $$lcssa476 = 0, $$lcssa479 = 0, $$lcssa480 = 0, $$lcssa483 = 0.0, $$lcssa484 = 0, $$lcssa487 = 0, $$lcssa491 = 0, $$mask$i = 0, $$mask$i38 = 0, $$mask1$i = 0, $$mask1$i37 = 0, $$neg151$i = 0, $$neg152$i = 0, $$p$$i = 0, $$p$5 = 0, $$p$i = 0;
 var $$pn$i = 0, $$pr$i = 0, $$pr146$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phi302$iZ2D = 0, $$pre270 = 0, $$pre300$i = 0, $$pre301$i = 0, $$sum$i = 0, $$sum15$i = 0, $$sum16$i = 0, $$z$3$i = 0, $$z$4$i = 0, $$z$4$us$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0;
 var $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0;
 var $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0;
 var $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0;
 var $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0;
 var $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0;
 var $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0;
 var $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0;
 var $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0;
 var $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0.0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0.0, $1162 = 0, $1163 = 0;
 var $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $1169$phi = 0, $117 = 0, $1170 = 0, $1170$phi = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0;
 var $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0.0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0.0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0.0, $431 = 0, $432 = 0.0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0.0;
 var $472 = 0.0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0.0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0.0, $492 = 0.0, $493 = 0.0, $494 = 0.0, $495 = 0.0, $496 = 0.0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0.0, $545 = 0.0, $546 = 0.0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0.0, $56 = 0, $560 = 0.0, $561 = 0.0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0.0, $575 = 0.0, $576 = 0.0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0;
 var $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0.0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0.0, $64 = 0, $640 = 0.0, $641 = 0.0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0;
 var $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0;
 var $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0;
 var $779 = 0, $78 = 0, $780 = 0.0, $781 = 0.0, $782 = 0, $783 = 0.0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0;
 var $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0;
 var $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0;
 var $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0;
 var $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0;
 var $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0;
 var $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0;
 var $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0;
 var $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0;
 var $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $a$0 = 0, $a$1 = 0, $a$1$lcssa$i = 0, $a$1253$i = 0, $a$2 = 0, $a$2$ph$i = 0, $a$3$lcssa$i = 0, $a$3240$i = 0, $a$3240$us$i = 0, $a$5$lcssa$i = 0, $a$5215$i = 0, $a$6$i = 0, $a$7$i = 0, $a$8$ph$i = 0, $arglist_current = 0;
 var $arglist_current11 = 0, $arglist_current14 = 0, $arglist_current17 = 0, $arglist_current2 = 0, $arglist_current20 = 0, $arglist_current23 = 0, $arglist_current26 = 0, $arglist_current29 = 0, $arglist_current32 = 0, $arglist_current35 = 0, $arglist_current38 = 0, $arglist_current41 = 0, $arglist_current44 = 0, $arglist_current47 = 0, $arglist_current5 = 0, $arglist_current50 = 0, $arglist_current53 = 0, $arglist_current56 = 0, $arglist_current59 = 0, $arglist_current62 = 0;
 var $arglist_current8 = 0, $arglist_next = 0, $arglist_next12 = 0, $arglist_next15 = 0, $arglist_next18 = 0, $arglist_next21 = 0, $arglist_next24 = 0, $arglist_next27 = 0, $arglist_next3 = 0, $arglist_next30 = 0, $arglist_next33 = 0, $arglist_next36 = 0, $arglist_next39 = 0, $arglist_next42 = 0, $arglist_next45 = 0, $arglist_next48 = 0, $arglist_next51 = 0, $arglist_next54 = 0, $arglist_next57 = 0, $arglist_next6 = 0;
 var $arglist_next60 = 0, $arglist_next63 = 0, $arglist_next9 = 0, $argpos$0 = 0, $big$i = 0, $buf = 0, $buf$i = 0, $carry$0246$i = 0, $carry3$0234$i = 0, $carry3$0234$us$i = 0, $cnt$0 = 0, $cnt$1 = 0, $cnt$1$lcssa = 0, $d$0$i = 0, $d$0245$i = 0, $d$0247$i = 0, $d$1233$i = 0, $d$1233$us$i = 0, $d$2$lcssa$i = 0, $d$2214$i = 0;
 var $d$3$i = 0, $d$4191$i = 0, $d$5183$i = 0, $d$6195$i = 0, $e$0229$i = 0, $e$1$i = 0, $e$2210$i = 0, $e$3$i = 0, $e$4$ph$i = 0, $e2$i = 0, $ebuf0$i = 0, $estr$0$i = 0, $estr$1$lcssa$i = 0, $estr$1$ph$i = 0, $estr$1201$i = 0, $estr$2$i = 0, $exitcond$i = 0, $expanded = 0, $expanded101 = 0, $expanded102 = 0;
 var $expanded103 = 0, $expanded105 = 0, $expanded106 = 0, $expanded108 = 0, $expanded109 = 0, $expanded110 = 0, $expanded112 = 0, $expanded113 = 0, $expanded115 = 0, $expanded116 = 0, $expanded117 = 0, $expanded119 = 0, $expanded120 = 0, $expanded122 = 0, $expanded123 = 0, $expanded124 = 0, $expanded126 = 0, $expanded127 = 0, $expanded129 = 0, $expanded130 = 0;
 var $expanded131 = 0, $expanded133 = 0, $expanded134 = 0, $expanded136 = 0, $expanded137 = 0, $expanded138 = 0, $expanded140 = 0, $expanded141 = 0, $expanded143 = 0, $expanded144 = 0, $expanded145 = 0, $expanded147 = 0, $expanded148 = 0, $expanded150 = 0, $expanded151 = 0, $expanded152 = 0, $expanded154 = 0, $expanded155 = 0, $expanded157 = 0, $expanded158 = 0;
 var $expanded159 = 0, $expanded161 = 0, $expanded162 = 0, $expanded164 = 0, $expanded165 = 0, $expanded166 = 0, $expanded168 = 0, $expanded169 = 0, $expanded171 = 0, $expanded172 = 0, $expanded173 = 0, $expanded175 = 0, $expanded176 = 0, $expanded178 = 0, $expanded179 = 0, $expanded180 = 0, $expanded182 = 0, $expanded183 = 0, $expanded185 = 0, $expanded186 = 0;
 var $expanded187 = 0, $expanded189 = 0, $expanded190 = 0, $expanded192 = 0, $expanded193 = 0, $expanded194 = 0, $expanded196 = 0, $expanded197 = 0, $expanded199 = 0, $expanded200 = 0, $expanded201 = 0, $expanded203 = 0, $expanded204 = 0, $expanded206 = 0, $expanded207 = 0, $expanded208 = 0, $expanded210 = 0, $expanded211 = 0, $expanded213 = 0, $expanded214 = 0;
 var $expanded215 = 0, $expanded64 = 0, $expanded66 = 0, $expanded67 = 0, $expanded68 = 0, $expanded70 = 0, $expanded71 = 0, $expanded73 = 0, $expanded74 = 0, $expanded75 = 0, $expanded77 = 0, $expanded78 = 0, $expanded80 = 0, $expanded81 = 0, $expanded82 = 0, $expanded84 = 0, $expanded85 = 0, $expanded87 = 0, $expanded88 = 0, $expanded89 = 0;
 var $expanded91 = 0, $expanded92 = 0, $expanded94 = 0, $expanded95 = 0, $expanded96 = 0, $expanded98 = 0, $expanded99 = 0, $fl$0110 = 0, $fl$0170 = 0, $fl$1 = 0, $fl$1$ = 0, $fl$3 = 0, $fl$4 = 0, $fl$6 = 0, $i$0$lcssa = 0, $i$0$lcssa273 = 0, $i$0175 = 0, $i$0228$i = 0, $i$03$i = 0, $i$03$i30 = 0;
 var $i$1$lcssa$i = 0, $i$1186 = 0, $i$1222$i = 0, $i$2162 = 0, $i$2162$lcssa = 0, $i$2209$i = 0, $i$3160 = 0, $i$3205$i = 0, $isdigit = 0, $isdigit$i = 0, $isdigit$i32 = 0, $isdigit10 = 0, $isdigit12 = 0, $isdigit2$i = 0, $isdigit2$i28 = 0, $isdigittmp = 0, $isdigittmp$ = 0, $isdigittmp$i = 0, $isdigittmp$i31 = 0, $isdigittmp1$i = 0;
 var $isdigittmp1$i27 = 0, $isdigittmp11 = 0, $isdigittmp4$i = 0, $isdigittmp4$i29 = 0, $isdigittmp9 = 0, $j$0$i = 0, $j$0221$i = 0, $j$0223$i = 0, $j$1206$i = 0, $j$2$i = 0, $l$0 = 0, $l$0$i = 0, $l$1$i = 0, $l$1174 = 0, $l$2 = 0, $l10n$0 = 0, $l10n$0$lcssa = 0, $l10n$0$phi = 0, $l10n$1 = 0, $l10n$2 = 0;
 var $l10n$3 = 0, $mb = 0, $notlhs$us$us$i = 0, $notrhs$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i100$i = 0, $or$cond$i35$i = 0, $or$cond$i42$i = 0, $or$cond$i52$i = 0, $or$cond$i57 = 0, $or$cond$i59$i = 0, $or$cond$i64 = 0, $or$cond$i71 = 0, $or$cond$i72$i = 0, $or$cond$i79 = 0, $or$cond$i81 = 0, $or$cond$i93$i = 0, $or$cond15 = 0;
 var $or$cond19 = 0, $or$cond22 = 0, $or$cond29$i = 0, $or$cond332 = 0, $or$cond6$i = 0, $p$0 = 0, $p$1 = 0, $p$2 = 0, $p$2$ = 0, $p$3 = 0, $p$4272 = 0, $p$5 = 0, $pad$i = 0, $pl$0 = 0, $pl$0$i = 0, $pl$1 = 0, $pl$1$i = 0, $pl$2 = 0, $prefix$0 = 0, $prefix$0$$i = 0;
 var $prefix$0$i = 0, $prefix$1 = 0, $prefix$2 = 0, $r$0$a$8$i = 0, $re$1179$i = 0, $round$0178$i = 0.0, $round6$1$i = 0.0, $s$0$i = 0, $s$0$us$i = 0, $s$0$us$us$i = 0, $s$1$i = 0, $s$1$lcssa$i = 0, $s$1$us$i = 0, $s$1$us$us$i = 0, $s1$0$i = 0, $s7$0188$i = 0, $s7$1$i = 0, $s8$0$lcssa$i = 0, $s8$0180$i = 0, $s9$0$i = 0;
 var $s9$1192$i = 0, $s9$2$i = 0, $sext = 0, $sext93 = 0, $small$0$i = 0.0, $small$1$i = 0.0, $st$0 = 0, $st$0$lcssa456 = 0, $storemerge = 0, $storemerge13 = 0, $storemerge8108 = 0, $storemerge8169 = 0, $t$0 = 0, $t$1 = 0, $w$$i = 0, $w$0 = 0, $w$1 = 0, $w$2 = 0, $w$30$i = 0, $wc = 0;
 var $ws$0176 = 0, $ws$1187 = 0, $y$03$i = 0, $y$03$i$i = 0, $y$03$i109$i = 0, $y$03$i118$i = 0, $y$03$i133$i = 0, $y$03$i86$i = 0, $z$0$i = 0, $z$0$lcssa = 0, $z$0163 = 0, $z$1 = 0, $z$1$lcssa$i = 0, $z$1252$i = 0, $z$2 = 0, $z$2$i = 0, $z$2$i$lcssa = 0, $z$3$lcssa$i = 0, $z$3239$i = 0, $z$3239$us$i = 0;
 var $z$4$i = 0, $z$4$us$i = 0, $z$6$$i = 0, $z$6$i = 0, $z$6$i$lcssa = 0, $z$6$ph$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 864|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $big$i = sp + 16|0;
 $e2$i = sp + 8|0;
 $buf$i = sp + 836|0;
 $0 = $buf$i;
 $ebuf0$i = sp + 824|0;
 $pad$i = sp + 568|0;
 $buf = sp + 528|0;
 $wc = sp;
 $mb = sp + 520|0;
 $1 = ($f|0)!=(0|0);
 $2 = ((($buf)) + 40|0);
 $3 = $2;
 $4 = ((($buf)) + 39|0);
 $5 = ((($wc)) + 4|0);
 $6 = $wc;
 $7 = ((($ebuf0$i)) + 12|0);
 $8 = ((($ebuf0$i)) + 11|0);
 $9 = $7;
 $10 = (($9) - ($0))|0;
 $11 = (-2 - ($0))|0;
 $12 = (($9) + 2)|0;
 $13 = ((($big$i)) + 288|0);
 $14 = ((($buf$i)) + 9|0);
 $15 = $14;
 $16 = ((($buf$i)) + 8|0);
 $1169 = 0;$1170 = 0;$23 = $fmt;$cnt$0 = 0;$l$0 = 0;$l10n$0 = 0;
 L1: while(1) {
  $17 = ($cnt$0|0)>(-1);
  do {
   if ($17) {
    $18 = (2147483647 - ($cnt$0))|0;
    $19 = ($l$0|0)>($18|0);
    if ($19) {
     $20 = (___errno_location()|0);
     HEAP32[$20>>2] = 75;
     $cnt$1 = -1;
     break;
    } else {
     $21 = (($l$0) + ($cnt$0))|0;
     $cnt$1 = $21;
     break;
    }
   } else {
    $cnt$1 = $cnt$0;
   }
  } while(0);
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $cnt$1$lcssa = $cnt$1;$l10n$0$lcssa = $l10n$0;
   label = 344;
   break;
  } else {
   $1171 = $22;$26 = $23;
  }
  while(1) {
   if ((($1171<<24>>24) == 37)) {
    $28 = $26;$z$0163 = $26;
    label = 9;
    break;
   } else if ((($1171<<24>>24) == 0)) {
    $$lcssa106 = $26;$z$0$lcssa = $26;
    break;
   }
   $25 = ((($26)) + 1|0);
   $$pre = HEAP8[$25>>0]|0;
   $1171 = $$pre;$26 = $25;
  }
  L12: do {
   if ((label|0) == 9) {
    while(1) {
     label = 0;
     $27 = ((($28)) + 1|0);
     $29 = HEAP8[$27>>0]|0;
     $30 = ($29<<24>>24)==(37);
     if (!($30)) {
      $$lcssa106 = $28;$z$0$lcssa = $z$0163;
      break L12;
     }
     $31 = ((($z$0163)) + 1|0);
     $32 = ((($28)) + 2|0);
     $33 = HEAP8[$32>>0]|0;
     $34 = ($33<<24>>24)==(37);
     if ($34) {
      $28 = $32;$z$0163 = $31;
      label = 9;
     } else {
      $$lcssa106 = $32;$z$0$lcssa = $31;
      break;
     }
    }
   }
  } while(0);
  $35 = $z$0$lcssa;
  $36 = $23;
  $37 = (($35) - ($36))|0;
  if ($1) {
   (___fwritex($23,$37,$f)|0);
  }
  $38 = ($z$0$lcssa|0)==($23|0);
  if (!($38)) {
   $l10n$0$phi = $l10n$0;$1170$phi = $1170;$1169$phi = $1169;$23 = $$lcssa106;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$0$phi;$1170 = $1170$phi;$1169 = $1169$phi;
   continue;
  }
  $39 = ((($$lcssa106)) + 1|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40 << 24 >> 24;
  $isdigittmp = (($41) + -48)|0;
  $isdigit = ($isdigittmp>>>0)<(10);
  if ($isdigit) {
   $42 = ((($$lcssa106)) + 2|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = ($43<<24>>24)==(36);
   $45 = ((($$lcssa106)) + 3|0);
   $$92 = $44 ? $45 : $39;
   $$l10n$0 = $44 ? 1 : $l10n$0;
   $isdigittmp$ = $44 ? $isdigittmp : -1;
   $$pre270 = HEAP8[$$92>>0]|0;
   $47 = $$pre270;$argpos$0 = $isdigittmp$;$l10n$1 = $$l10n$0;$storemerge = $$92;
  } else {
   $47 = $40;$argpos$0 = -1;$l10n$1 = $l10n$0;$storemerge = $39;
  }
  $46 = $47 << 24 >> 24;
  $48 = $46 & -32;
  $49 = ($48|0)==(32);
  L24: do {
   if ($49) {
    $51 = $46;$56 = $47;$fl$0170 = 0;$storemerge8169 = $storemerge;
    while(1) {
     $50 = (($51) + -32)|0;
     $52 = 1 << $50;
     $53 = $52 & 75913;
     $54 = ($53|0)==(0);
     if ($54) {
      $66 = $56;$fl$0110 = $fl$0170;$storemerge8108 = $storemerge8169;
      break L24;
     }
     $55 = $56 << 24 >> 24;
     $57 = (($55) + -32)|0;
     $58 = 1 << $57;
     $59 = $58 | $fl$0170;
     $60 = ((($storemerge8169)) + 1|0);
     $61 = HEAP8[$60>>0]|0;
     $62 = $61 << 24 >> 24;
     $63 = $62 & -32;
     $64 = ($63|0)==(32);
     if ($64) {
      $51 = $62;$56 = $61;$fl$0170 = $59;$storemerge8169 = $60;
     } else {
      $66 = $61;$fl$0110 = $59;$storemerge8108 = $60;
      break;
     }
    }
   } else {
    $66 = $47;$fl$0110 = 0;$storemerge8108 = $storemerge;
   }
  } while(0);
  $65 = ($66<<24>>24)==(42);
  do {
   if ($65) {
    $67 = ((($storemerge8108)) + 1|0);
    $68 = HEAP8[$67>>0]|0;
    $69 = $68 << 24 >> 24;
    $isdigittmp11 = (($69) + -48)|0;
    $isdigit12 = ($isdigittmp11>>>0)<(10);
    if ($isdigit12) {
     $70 = ((($storemerge8108)) + 2|0);
     $71 = HEAP8[$70>>0]|0;
     $72 = ($71<<24>>24)==(36);
     if ($72) {
      $73 = (($nl_type) + ($isdigittmp11<<2)|0);
      HEAP32[$73>>2] = 10;
      $74 = HEAP8[$67>>0]|0;
      $75 = $74 << 24 >> 24;
      $76 = (($75) + -48)|0;
      $77 = (($nl_arg) + ($76<<3)|0);
      $78 = $77;
      $79 = $78;
      $80 = HEAP32[$79>>2]|0;
      $81 = (($78) + 4)|0;
      $82 = $81;
      $83 = HEAP32[$82>>2]|0;
      $84 = ((($storemerge8108)) + 3|0);
      $l10n$2 = 1;$storemerge13 = $84;$w$0 = $80;
     } else {
      label = 23;
     }
    } else {
     label = 23;
    }
    if ((label|0) == 23) {
     label = 0;
     $85 = ($l10n$1|0)==(0);
     if (!($85)) {
      $$0 = -1;
      label = 363;
      break L1;
     }
     if (!($1)) {
      $105 = $67;$fl$1 = $fl$0110;$l10n$3 = 0;$w$1 = 0;
      break;
     }
     $arglist_current = HEAP32[$ap>>2]|0;
     $86 = $arglist_current;
     $87 = ((0) + 4|0);
     $expanded64 = $87;
     $expanded = (($expanded64) - 1)|0;
     $88 = (($86) + ($expanded))|0;
     $89 = ((0) + 4|0);
     $expanded68 = $89;
     $expanded67 = (($expanded68) - 1)|0;
     $expanded66 = $expanded67 ^ -1;
     $90 = $88 & $expanded66;
     $91 = $90;
     $92 = HEAP32[$91>>2]|0;
     $arglist_next = ((($91)) + 4|0);
     HEAP32[$ap>>2] = $arglist_next;
     $l10n$2 = 0;$storemerge13 = $67;$w$0 = $92;
    }
    $93 = ($w$0|0)<(0);
    if ($93) {
     $94 = $fl$0110 | 8192;
     $95 = (0 - ($w$0))|0;
     $105 = $storemerge13;$fl$1 = $94;$l10n$3 = $l10n$2;$w$1 = $95;
    } else {
     $105 = $storemerge13;$fl$1 = $fl$0110;$l10n$3 = $l10n$2;$w$1 = $w$0;
    }
   } else {
    $96 = $66 << 24 >> 24;
    $isdigittmp1$i = (($96) + -48)|0;
    $isdigit2$i = ($isdigittmp1$i>>>0)<(10);
    if ($isdigit2$i) {
     $100 = $storemerge8108;$i$03$i = 0;$isdigittmp4$i = $isdigittmp1$i;
     while(1) {
      $97 = ($i$03$i*10)|0;
      $98 = (($97) + ($isdigittmp4$i))|0;
      $99 = ((($100)) + 1|0);
      $101 = HEAP8[$99>>0]|0;
      $102 = $101 << 24 >> 24;
      $isdigittmp$i = (($102) + -48)|0;
      $isdigit$i = ($isdigittmp$i>>>0)<(10);
      if ($isdigit$i) {
       $100 = $99;$i$03$i = $98;$isdigittmp4$i = $isdigittmp$i;
      } else {
       $$lcssa450 = $98;$$lcssa451 = $99;
       break;
      }
     }
     $103 = ($$lcssa450|0)<(0);
     if ($103) {
      $$0 = -1;
      label = 363;
      break L1;
     } else {
      $105 = $$lcssa451;$fl$1 = $fl$0110;$l10n$3 = $l10n$1;$w$1 = $$lcssa450;
     }
    } else {
     $105 = $storemerge8108;$fl$1 = $fl$0110;$l10n$3 = $l10n$1;$w$1 = 0;
    }
   }
  } while(0);
  $104 = HEAP8[$105>>0]|0;
  $106 = ($104<<24>>24)==(46);
  L45: do {
   if ($106) {
    $107 = ((($105)) + 1|0);
    $108 = HEAP8[$107>>0]|0;
    $109 = ($108<<24>>24)==(42);
    if (!($109)) {
     $136 = $108 << 24 >> 24;
     $isdigittmp1$i27 = (($136) + -48)|0;
     $isdigit2$i28 = ($isdigittmp1$i27>>>0)<(10);
     if ($isdigit2$i28) {
      $140 = $107;$i$03$i30 = 0;$isdigittmp4$i29 = $isdigittmp1$i27;
     } else {
      $1172 = $107;$p$0 = 0;
      break;
     }
     while(1) {
      $137 = ($i$03$i30*10)|0;
      $138 = (($137) + ($isdigittmp4$i29))|0;
      $139 = ((($140)) + 1|0);
      $141 = HEAP8[$139>>0]|0;
      $142 = $141 << 24 >> 24;
      $isdigittmp$i31 = (($142) + -48)|0;
      $isdigit$i32 = ($isdigittmp$i31>>>0)<(10);
      if ($isdigit$i32) {
       $140 = $139;$i$03$i30 = $138;$isdigittmp4$i29 = $isdigittmp$i31;
      } else {
       $1172 = $139;$p$0 = $138;
       break L45;
      }
     }
    }
    $110 = ((($105)) + 2|0);
    $111 = HEAP8[$110>>0]|0;
    $112 = $111 << 24 >> 24;
    $isdigittmp9 = (($112) + -48)|0;
    $isdigit10 = ($isdigittmp9>>>0)<(10);
    if ($isdigit10) {
     $113 = ((($105)) + 3|0);
     $114 = HEAP8[$113>>0]|0;
     $115 = ($114<<24>>24)==(36);
     if ($115) {
      $116 = (($nl_type) + ($isdigittmp9<<2)|0);
      HEAP32[$116>>2] = 10;
      $117 = HEAP8[$110>>0]|0;
      $118 = $117 << 24 >> 24;
      $119 = (($118) + -48)|0;
      $120 = (($nl_arg) + ($119<<3)|0);
      $121 = $120;
      $122 = $121;
      $123 = HEAP32[$122>>2]|0;
      $124 = (($121) + 4)|0;
      $125 = $124;
      $126 = HEAP32[$125>>2]|0;
      $127 = ((($105)) + 4|0);
      $1172 = $127;$p$0 = $123;
      break;
     }
    }
    $128 = ($l10n$3|0)==(0);
    if (!($128)) {
     $$0 = -1;
     label = 363;
     break L1;
    }
    if ($1) {
     $arglist_current2 = HEAP32[$ap>>2]|0;
     $129 = $arglist_current2;
     $130 = ((0) + 4|0);
     $expanded71 = $130;
     $expanded70 = (($expanded71) - 1)|0;
     $131 = (($129) + ($expanded70))|0;
     $132 = ((0) + 4|0);
     $expanded75 = $132;
     $expanded74 = (($expanded75) - 1)|0;
     $expanded73 = $expanded74 ^ -1;
     $133 = $131 & $expanded73;
     $134 = $133;
     $135 = HEAP32[$134>>2]|0;
     $arglist_next3 = ((($134)) + 4|0);
     HEAP32[$ap>>2] = $arglist_next3;
     $1172 = $110;$p$0 = $135;
    } else {
     $1172 = $110;$p$0 = 0;
    }
   } else {
    $1172 = $105;$p$0 = -1;
   }
  } while(0);
  $144 = $1172;$st$0 = 0;
  while(1) {
   $143 = HEAP8[$144>>0]|0;
   $145 = $143 << 24 >> 24;
   $146 = (($145) + -65)|0;
   $147 = ($146>>>0)>(57);
   if ($147) {
    $$0 = -1;
    label = 363;
    break L1;
   }
   $148 = ((($144)) + 1|0);
   $149 = ((6376 + (($st$0*58)|0)|0) + ($146)|0);
   $150 = HEAP8[$149>>0]|0;
   $151 = $150&255;
   $152 = (($151) + -1)|0;
   $153 = ($152>>>0)<(8);
   if ($153) {
    $144 = $148;$st$0 = $151;
   } else {
    $$lcssa455 = $144;$$lcssa457 = $148;$$lcssa458 = $150;$$lcssa459 = $151;$st$0$lcssa456 = $st$0;
    break;
   }
  }
  $154 = ($$lcssa458<<24>>24)==(0);
  if ($154) {
   $$0 = -1;
   label = 363;
   break;
  }
  $155 = ($$lcssa458<<24>>24)==(19);
  $156 = ($argpos$0|0)>(-1);
  L64: do {
   if ($155) {
    if ($156) {
     $$0 = -1;
     label = 363;
     break L1;
    } else {
     $1173 = $1169;$1174 = $1170;
     label = 62;
    }
   } else {
    if ($156) {
     $157 = (($nl_type) + ($argpos$0<<2)|0);
     HEAP32[$157>>2] = $$lcssa459;
     $158 = (($nl_arg) + ($argpos$0<<3)|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = ((($158)) + 4|0);
     $161 = HEAP32[$160>>2]|0;
     $1173 = $161;$1174 = $159;
     label = 62;
     break;
    }
    if (!($1)) {
     $$0 = 0;
     label = 363;
     break L1;
    }
    $162 = ($$lcssa458&255)>(20);
    if ($162) {
     $265 = $1170;$292 = $1169;
    } else {
     do {
      switch ($$lcssa459|0) {
      case 11:  {
       $arglist_current11 = HEAP32[$ap>>2]|0;
       $180 = $arglist_current11;
       $181 = ((0) + 4|0);
       $expanded92 = $181;
       $expanded91 = (($expanded92) - 1)|0;
       $182 = (($180) + ($expanded91))|0;
       $183 = ((0) + 4|0);
       $expanded96 = $183;
       $expanded95 = (($expanded96) - 1)|0;
       $expanded94 = $expanded95 ^ -1;
       $184 = $182 & $expanded94;
       $185 = $184;
       $186 = HEAP32[$185>>2]|0;
       $arglist_next12 = ((($185)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next12;
       $265 = $186;$292 = 0;
       break L64;
       break;
      }
      case 17:  {
       $arglist_current29 = HEAP32[$ap>>2]|0;
       $237 = $arglist_current29;
       $238 = ((0) + 8|0);
       $expanded134 = $238;
       $expanded133 = (($expanded134) - 1)|0;
       $239 = (($237) + ($expanded133))|0;
       $240 = ((0) + 8|0);
       $expanded138 = $240;
       $expanded137 = (($expanded138) - 1)|0;
       $expanded136 = $expanded137 ^ -1;
       $241 = $239 & $expanded136;
       $242 = $241;
       $243 = +HEAPF64[$242>>3];
       $arglist_next30 = ((($242)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next30;
       HEAPF64[tempDoublePtr>>3] = $243;$244 = HEAP32[tempDoublePtr>>2]|0;
       $245 = HEAP32[tempDoublePtr+4>>2]|0;
       $265 = $244;$292 = $245;
       break L64;
       break;
      }
      case 12:  {
       $arglist_current14 = HEAP32[$ap>>2]|0;
       $187 = $arglist_current14;
       $188 = ((0) + 8|0);
       $expanded99 = $188;
       $expanded98 = (($expanded99) - 1)|0;
       $189 = (($187) + ($expanded98))|0;
       $190 = ((0) + 8|0);
       $expanded103 = $190;
       $expanded102 = (($expanded103) - 1)|0;
       $expanded101 = $expanded102 ^ -1;
       $191 = $189 & $expanded101;
       $192 = $191;
       $193 = $192;
       $194 = $193;
       $195 = HEAP32[$194>>2]|0;
       $196 = (($193) + 4)|0;
       $197 = $196;
       $198 = HEAP32[$197>>2]|0;
       $arglist_next15 = ((($192)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next15;
       $265 = $195;$292 = $198;
       break L64;
       break;
      }
      case 14:  {
       $arglist_current20 = HEAP32[$ap>>2]|0;
       $211 = $arglist_current20;
       $212 = ((0) + 4|0);
       $expanded113 = $212;
       $expanded112 = (($expanded113) - 1)|0;
       $213 = (($211) + ($expanded112))|0;
       $214 = ((0) + 4|0);
       $expanded117 = $214;
       $expanded116 = (($expanded117) - 1)|0;
       $expanded115 = $expanded116 ^ -1;
       $215 = $213 & $expanded115;
       $216 = $215;
       $217 = HEAP32[$216>>2]|0;
       $arglist_next21 = ((($216)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next21;
       $$mask1$i37 = $217 & 65535;
       $265 = $$mask1$i37;$292 = 0;
       break L64;
       break;
      }
      case 9:  {
       $arglist_current5 = HEAP32[$ap>>2]|0;
       $163 = $arglist_current5;
       $164 = ((0) + 4|0);
       $expanded78 = $164;
       $expanded77 = (($expanded78) - 1)|0;
       $165 = (($163) + ($expanded77))|0;
       $166 = ((0) + 4|0);
       $expanded82 = $166;
       $expanded81 = (($expanded82) - 1)|0;
       $expanded80 = $expanded81 ^ -1;
       $167 = $165 & $expanded80;
       $168 = $167;
       $169 = HEAP32[$168>>2]|0;
       $arglist_next6 = ((($168)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next6;
       $170 = $169;
       $265 = $170;$292 = $1169;
       break L64;
       break;
      }
      case 13:  {
       $arglist_current17 = HEAP32[$ap>>2]|0;
       $199 = $arglist_current17;
       $200 = ((0) + 4|0);
       $expanded106 = $200;
       $expanded105 = (($expanded106) - 1)|0;
       $201 = (($199) + ($expanded105))|0;
       $202 = ((0) + 4|0);
       $expanded110 = $202;
       $expanded109 = (($expanded110) - 1)|0;
       $expanded108 = $expanded109 ^ -1;
       $203 = $201 & $expanded108;
       $204 = $203;
       $205 = HEAP32[$204>>2]|0;
       $arglist_next18 = ((($204)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next18;
       $206 = $205&65535;
       $207 = $206 << 16 >> 16;
       $208 = ($207|0)<(0);
       $209 = $208 << 31 >> 31;
       $sext93 = $205 << 16;
       $210 = $sext93 >> 16;
       $265 = $210;$292 = $209;
       break L64;
       break;
      }
      case 15:  {
       $arglist_current23 = HEAP32[$ap>>2]|0;
       $218 = $arglist_current23;
       $219 = ((0) + 4|0);
       $expanded120 = $219;
       $expanded119 = (($expanded120) - 1)|0;
       $220 = (($218) + ($expanded119))|0;
       $221 = ((0) + 4|0);
       $expanded124 = $221;
       $expanded123 = (($expanded124) - 1)|0;
       $expanded122 = $expanded123 ^ -1;
       $222 = $220 & $expanded122;
       $223 = $222;
       $224 = HEAP32[$223>>2]|0;
       $arglist_next24 = ((($223)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next24;
       $225 = $224&255;
       $226 = $225 << 24 >> 24;
       $227 = ($226|0)<(0);
       $228 = $227 << 31 >> 31;
       $sext = $224 << 24;
       $229 = $sext >> 24;
       $265 = $229;$292 = $228;
       break L64;
       break;
      }
      case 10:  {
       $arglist_current8 = HEAP32[$ap>>2]|0;
       $171 = $arglist_current8;
       $172 = ((0) + 4|0);
       $expanded85 = $172;
       $expanded84 = (($expanded85) - 1)|0;
       $173 = (($171) + ($expanded84))|0;
       $174 = ((0) + 4|0);
       $expanded89 = $174;
       $expanded88 = (($expanded89) - 1)|0;
       $expanded87 = $expanded88 ^ -1;
       $175 = $173 & $expanded87;
       $176 = $175;
       $177 = HEAP32[$176>>2]|0;
       $arglist_next9 = ((($176)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next9;
       $178 = ($177|0)<(0);
       $179 = $178 << 31 >> 31;
       $265 = $177;$292 = $179;
       break L64;
       break;
      }
      case 16:  {
       $arglist_current26 = HEAP32[$ap>>2]|0;
       $230 = $arglist_current26;
       $231 = ((0) + 4|0);
       $expanded127 = $231;
       $expanded126 = (($expanded127) - 1)|0;
       $232 = (($230) + ($expanded126))|0;
       $233 = ((0) + 4|0);
       $expanded131 = $233;
       $expanded130 = (($expanded131) - 1)|0;
       $expanded129 = $expanded130 ^ -1;
       $234 = $232 & $expanded129;
       $235 = $234;
       $236 = HEAP32[$235>>2]|0;
       $arglist_next27 = ((($235)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next27;
       $$mask$i38 = $236 & 255;
       $265 = $$mask$i38;$292 = 0;
       break L64;
       break;
      }
      case 18:  {
       $arglist_current32 = HEAP32[$ap>>2]|0;
       $246 = $arglist_current32;
       $247 = ((0) + 8|0);
       $expanded141 = $247;
       $expanded140 = (($expanded141) - 1)|0;
       $248 = (($246) + ($expanded140))|0;
       $249 = ((0) + 8|0);
       $expanded145 = $249;
       $expanded144 = (($expanded145) - 1)|0;
       $expanded143 = $expanded144 ^ -1;
       $250 = $248 & $expanded143;
       $251 = $250;
       $252 = +HEAPF64[$251>>3];
       $arglist_next33 = ((($251)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next33;
       HEAPF64[tempDoublePtr>>3] = $252;$253 = HEAP32[tempDoublePtr>>2]|0;
       $254 = HEAP32[tempDoublePtr+4>>2]|0;
       $265 = $253;$292 = $254;
       break L64;
       break;
      }
      default: {
       $265 = $1170;$292 = $1169;
       break L64;
      }
      }
     } while(0);
    }
   }
  } while(0);
  if ((label|0) == 62) {
   label = 0;
   if ($1) {
    $265 = $1174;$292 = $1173;
   } else {
    $1169 = $1173;$1170 = $1174;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
    continue;
   }
  }
  $255 = HEAP8[$$lcssa455>>0]|0;
  $256 = $255 << 24 >> 24;
  $257 = ($st$0$lcssa456|0)!=(0);
  $258 = $256 & 15;
  $259 = ($258|0)==(3);
  $or$cond15 = $257 & $259;
  $260 = $256 & -33;
  $t$0 = $or$cond15 ? $260 : $256;
  $261 = $fl$1 & 8192;
  $262 = ($261|0)==(0);
  $263 = $fl$1 & -65537;
  $fl$1$ = $262 ? $fl$1 : $263;
  L86: do {
   switch ($t$0|0) {
   case 112:  {
    $286 = ($p$0>>>0)>(8);
    $287 = $286 ? $p$0 : 8;
    $288 = $fl$1$ | 8;
    $fl$3 = $288;$p$1 = $287;$t$1 = 120;
    label = 73;
    break;
   }
   case 88: case 120:  {
    $fl$3 = $fl$1$;$p$1 = $p$0;$t$1 = $t$0;
    label = 73;
    break;
   }
   case 67:  {
    HEAP32[$wc>>2] = $265;
    HEAP32[$5>>2] = 0;
    $1179 = $wc;$1180 = $6;$p$4272 = -1;
    label = 97;
    break;
   }
   case 83:  {
    $391 = $265;
    $392 = ($p$0|0)==(0);
    if ($392) {
     $1181 = $265;$1182 = $391;$i$0$lcssa273 = 0;
     label = 102;
    } else {
     $1179 = $391;$1180 = $265;$p$4272 = $p$0;
     label = 97;
    }
    break;
   }
   case 110:  {
    switch ($st$0$lcssa456|0) {
    case 2:  {
     $267 = ($cnt$1|0)<(0);
     $268 = $267 << 31 >> 31;
     $269 = $265;
     $270 = $269;
     $271 = $270;
     HEAP32[$271>>2] = $cnt$1;
     $272 = (($270) + 4)|0;
     $273 = $272;
     HEAP32[$273>>2] = $268;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 3:  {
     $274 = $cnt$1&65535;
     $275 = $265;
     HEAP16[$275>>1] = $274;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 0:  {
     $264 = $265;
     HEAP32[$264>>2] = $cnt$1;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 1:  {
     $266 = $265;
     HEAP32[$266>>2] = $cnt$1;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 7:  {
     $279 = ($cnt$1|0)<(0);
     $280 = $279 << 31 >> 31;
     $281 = $265;
     $282 = $281;
     $283 = $282;
     HEAP32[$283>>2] = $cnt$1;
     $284 = (($282) + 4)|0;
     $285 = $284;
     HEAP32[$285>>2] = $280;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 4:  {
     $276 = $cnt$1&255;
     $277 = $265;
     HEAP8[$277>>0] = $276;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 6:  {
     $278 = $265;
     HEAP32[$278>>2] = $cnt$1;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    default: {
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
    }
    }
    break;
   }
   case 111:  {
    $312 = ($265|0)==(0);
    $313 = ($292|0)==(0);
    $314 = $312 & $313;
    if ($314) {
     $$0$lcssa$i51 = $2;
    } else {
     $$03$i48 = $2;$316 = $265;$320 = $292;
     while(1) {
      $315 = $316 & 7;
      $317 = $315 | 48;
      $318 = $317&255;
      $319 = ((($$03$i48)) + -1|0);
      HEAP8[$319>>0] = $318;
      $321 = (_bitshift64Lshr(($316|0),($320|0),3)|0);
      $322 = tempRet0;
      $323 = ($321|0)==(0);
      $324 = ($322|0)==(0);
      $325 = $323 & $324;
      if ($325) {
       $$0$lcssa$i51 = $319;
       break;
      } else {
       $$03$i48 = $319;$316 = $321;$320 = $322;
      }
     }
    }
    $326 = $fl$1$ & 8;
    $327 = ($326|0)==(0);
    $or$cond19 = $327 | $314;
    $$24 = $or$cond19 ? 6856 : (6861);
    $328 = $or$cond19&1;
    $$25 = $328 ^ 1;
    $367 = $265;$369 = $292;$a$0 = $$0$lcssa$i51;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $$25;$prefix$1 = $$24;
    label = 89;
    break;
   }
   case 117:  {
    $337 = $292;$339 = $265;$pl$0 = 0;$prefix$0 = 6856;
    label = 84;
    break;
   }
   case 65: case 71: case 70: case 69: case 97: case 103: case 102: case 101:  {
    HEAP32[tempDoublePtr>>2] = $265;HEAP32[tempDoublePtr+4>>2] = $292;$430 = +HEAPF64[tempDoublePtr>>3];
    HEAP32[$e2$i>>2] = 0;
    $431 = ($292|0)<(0);
    if ($431) {
     $432 = -$430;
     $$07$i = $432;$pl$0$i = 1;$prefix$0$i = 6880;
    } else {
     $433 = $fl$1$ & 2048;
     $434 = ($433|0)==(0);
     if ($434) {
      $435 = $fl$1$ & 1;
      $436 = ($435|0)==(0);
      $$$i = $436 ? (6881) : (6886);
      $$07$i = $430;$pl$0$i = $435;$prefix$0$i = $$$i;
     } else {
      $$07$i = $430;$pl$0$i = 1;$prefix$0$i = (6883);
     }
    }
    HEAPF64[tempDoublePtr>>3] = $$07$i;$437 = HEAP32[tempDoublePtr>>2]|0;
    $438 = HEAP32[tempDoublePtr+4>>2]|0;
    $439 = $438 & 2146435072;
    $440 = ($439>>>0)<(2146435072);
    $441 = (0)<(0);
    $442 = ($439|0)==(2146435072);
    $443 = $442 & $441;
    $444 = $440 | $443;
    do {
     if ($444) {
      $471 = (+_frexpl($$07$i,$e2$i));
      $472 = $471 * 2.0;
      $473 = $472 != 0.0;
      if ($473) {
       $474 = HEAP32[$e2$i>>2]|0;
       $475 = (($474) + -1)|0;
       HEAP32[$e2$i>>2] = $475;
      }
      $476 = $t$0 | 32;
      $477 = ($476|0)==(97);
      if ($477) {
       $478 = $t$0 & 32;
       $479 = ($478|0)==(0);
       $480 = ((($prefix$0$i)) + 9|0);
       $prefix$0$$i = $479 ? $prefix$0$i : $480;
       $481 = $pl$0$i | 2;
       $482 = ($p$0>>>0)>(11);
       $483 = (12 - ($p$0))|0;
       $484 = ($483|0)==(0);
       $485 = $482 | $484;
       do {
        if ($485) {
         $$1$i = $472;
        } else {
         $re$1179$i = $483;$round$0178$i = 8.0;
         while(1) {
          $486 = (($re$1179$i) + -1)|0;
          $487 = $round$0178$i * 16.0;
          $488 = ($486|0)==(0);
          if ($488) {
           $$lcssa483 = $487;
           break;
          } else {
           $re$1179$i = $486;$round$0178$i = $487;
          }
         }
         $489 = HEAP8[$prefix$0$$i>>0]|0;
         $490 = ($489<<24>>24)==(45);
         if ($490) {
          $491 = -$472;
          $492 = $491 - $$lcssa483;
          $493 = $$lcssa483 + $492;
          $494 = -$493;
          $$1$i = $494;
          break;
         } else {
          $495 = $472 + $$lcssa483;
          $496 = $495 - $$lcssa483;
          $$1$i = $496;
          break;
         }
        }
       } while(0);
       $497 = HEAP32[$e2$i>>2]|0;
       $498 = ($497|0)<(0);
       $499 = (0 - ($497))|0;
       $500 = $498 ? $499 : $497;
       $501 = ($500|0)<(0);
       if ($501) {
        $502 = ($500|0)<(0);
        $503 = $502 << 31 >> 31;
        $$05$i$i = $7;$504 = $500;$505 = $503;
        while(1) {
         $506 = (___uremdi3(($504|0),($505|0),10,0)|0);
         $507 = tempRet0;
         $508 = $506 | 48;
         $509 = $508&255;
         $510 = ((($$05$i$i)) + -1|0);
         HEAP8[$510>>0] = $509;
         $511 = (___udivdi3(($504|0),($505|0),10,0)|0);
         $512 = tempRet0;
         $513 = ($505>>>0)>(9);
         $514 = ($504>>>0)>(4294967295);
         $515 = ($505|0)==(9);
         $516 = $515 & $514;
         $517 = $513 | $516;
         if ($517) {
          $$05$i$i = $510;$504 = $511;$505 = $512;
         } else {
          $$lcssa484 = $510;$1183 = $511;$1184 = $512;
          break;
         }
        }
        $$0$lcssa$i48$i = $$lcssa484;$$01$lcssa$off0$i$i = $1183;
       } else {
        $$0$lcssa$i48$i = $7;$$01$lcssa$off0$i$i = $500;
       }
       $518 = ($$01$lcssa$off0$i$i|0)==(0);
       if ($518) {
        $$1$lcssa$i$i = $$0$lcssa$i48$i;
       } else {
        $$12$i$i = $$0$lcssa$i48$i;$y$03$i$i = $$01$lcssa$off0$i$i;
        while(1) {
         $519 = (($y$03$i$i>>>0) % 10)&-1;
         $520 = $519 | 48;
         $521 = $520&255;
         $522 = ((($$12$i$i)) + -1|0);
         HEAP8[$522>>0] = $521;
         $523 = (($y$03$i$i>>>0) / 10)&-1;
         $524 = ($y$03$i$i>>>0)<(10);
         if ($524) {
          $$1$lcssa$i$i = $522;
          break;
         } else {
          $$12$i$i = $522;$y$03$i$i = $523;
         }
        }
       }
       $525 = ($$1$lcssa$i$i|0)==($7|0);
       if ($525) {
        HEAP8[$8>>0] = 48;
        $estr$0$i = $8;
       } else {
        $estr$0$i = $$1$lcssa$i$i;
       }
       $526 = HEAP32[$e2$i>>2]|0;
       $527 = $526 >> 31;
       $528 = $527 & 2;
       $529 = (($528) + 43)|0;
       $530 = $529&255;
       $531 = ((($estr$0$i)) + -1|0);
       HEAP8[$531>>0] = $530;
       $532 = (($t$0) + 15)|0;
       $533 = $532&255;
       $534 = ((($estr$0$i)) + -2|0);
       HEAP8[$534>>0] = $533;
       $535 = $fl$1$ & 8;
       $536 = ($535|0)==(0);
       if ($536) {
        $notrhs$i = ($p$0|0)<(1);
        if ($notrhs$i) {
         $$2$us$us$i = $$1$i;$s$0$us$us$i = $buf$i;
         while(1) {
          $537 = (~~(($$2$us$us$i)));
          $538 = (6840 + ($537)|0);
          $539 = HEAP8[$538>>0]|0;
          $540 = $539&255;
          $541 = $540 | $478;
          $542 = $541&255;
          $543 = ((($s$0$us$us$i)) + 1|0);
          HEAP8[$s$0$us$us$i>>0] = $542;
          $544 = (+($537|0));
          $545 = $$2$us$us$i - $544;
          $546 = $545 * 16.0;
          $547 = $543;
          $548 = (($547) - ($0))|0;
          $549 = ($548|0)!=(1);
          $notlhs$us$us$i = $546 == 0.0;
          $or$cond$i79 = $549 | $notlhs$us$us$i;
          if ($or$cond$i79) {
           $s$1$us$us$i = $543;
          } else {
           $550 = ((($s$0$us$us$i)) + 2|0);
           HEAP8[$543>>0] = 46;
           $s$1$us$us$i = $550;
          }
          $551 = $546 != 0.0;
          if ($551) {
           $$2$us$us$i = $546;$s$0$us$us$i = $s$1$us$us$i;
          } else {
           $s$1$lcssa$i = $s$1$us$us$i;
           break;
          }
         }
        } else {
         $$2$us$i = $$1$i;$s$0$us$i = $buf$i;
         while(1) {
          $552 = (~~(($$2$us$i)));
          $553 = (6840 + ($552)|0);
          $554 = HEAP8[$553>>0]|0;
          $555 = $554&255;
          $556 = $555 | $478;
          $557 = $556&255;
          $558 = ((($s$0$us$i)) + 1|0);
          HEAP8[$s$0$us$i>>0] = $557;
          $559 = (+($552|0));
          $560 = $$2$us$i - $559;
          $561 = $560 * 16.0;
          $562 = $558;
          $563 = (($562) - ($0))|0;
          $564 = ($563|0)==(1);
          if ($564) {
           $565 = ((($s$0$us$i)) + 2|0);
           HEAP8[$558>>0] = 46;
           $s$1$us$i = $565;
          } else {
           $s$1$us$i = $558;
          }
          $566 = $561 != 0.0;
          if ($566) {
           $$2$us$i = $561;$s$0$us$i = $s$1$us$i;
          } else {
           $s$1$lcssa$i = $s$1$us$i;
           break;
          }
         }
        }
       } else {
        $$2$i = $$1$i;$s$0$i = $buf$i;
        while(1) {
         $567 = (~~(($$2$i)));
         $568 = (6840 + ($567)|0);
         $569 = HEAP8[$568>>0]|0;
         $570 = $569&255;
         $571 = $570 | $478;
         $572 = $571&255;
         $573 = ((($s$0$i)) + 1|0);
         HEAP8[$s$0$i>>0] = $572;
         $574 = (+($567|0));
         $575 = $$2$i - $574;
         $576 = $575 * 16.0;
         $577 = $573;
         $578 = (($577) - ($0))|0;
         $579 = ($578|0)==(1);
         if ($579) {
          $580 = ((($s$0$i)) + 2|0);
          HEAP8[$573>>0] = 46;
          $s$1$i = $580;
         } else {
          $s$1$i = $573;
         }
         $581 = $576 != 0.0;
         if ($581) {
          $$2$i = $576;$s$0$i = $s$1$i;
         } else {
          $s$1$lcssa$i = $s$1$i;
          break;
         }
        }
       }
       $582 = ($p$0|0)!=(0);
       $$pre300$i = $s$1$lcssa$i;
       $583 = (($11) + ($$pre300$i))|0;
       $584 = ($583|0)<($p$0|0);
       $or$cond332 = $582 & $584;
       $585 = $534;
       $586 = (($12) + ($p$0))|0;
       $587 = (($586) - ($585))|0;
       $588 = $534;
       $589 = (($10) - ($588))|0;
       $590 = (($589) + ($$pre300$i))|0;
       $l$0$i = $or$cond332 ? $587 : $590;
       $591 = (($l$0$i) + ($481))|0;
       $592 = $fl$1$ & 73728;
       $593 = ($592|0)==(0);
       $594 = ($w$1|0)>($591|0);
       $or$cond$i52$i = $593 & $594;
       if ($or$cond$i52$i) {
        $595 = (($w$1) - ($591))|0;
        $596 = ($595>>>0)>(256);
        $597 = $596 ? 256 : $595;
        _memset(($pad$i|0),32,($597|0))|0;
        $598 = ($595>>>0)>(255);
        if ($598) {
         $$01$i54$i = $595;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $599 = (($$01$i54$i) + -256)|0;
          $600 = ($599>>>0)>(255);
          if ($600) {
           $$01$i54$i = $599;
          } else {
           break;
          }
         }
         $601 = $595 & 255;
         $$0$lcssa$i56$i = $601;
        } else {
         $$0$lcssa$i56$i = $595;
        }
        (___fwritex($pad$i,$$0$lcssa$i56$i,$f)|0);
       }
       (___fwritex($prefix$0$$i,$481,$f)|0);
       $602 = ($592|0)==(65536);
       $or$cond$i59$i = $602 & $594;
       if ($or$cond$i59$i) {
        $603 = (($w$1) - ($591))|0;
        $604 = ($603>>>0)>(256);
        $605 = $604 ? 256 : $603;
        _memset(($pad$i|0),48,($605|0))|0;
        $606 = ($603>>>0)>(255);
        if ($606) {
         $$01$i61$i = $603;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $607 = (($$01$i61$i) + -256)|0;
          $608 = ($607>>>0)>(255);
          if ($608) {
           $$01$i61$i = $607;
          } else {
           break;
          }
         }
         $609 = $603 & 255;
         $$0$lcssa$i63$i = $609;
        } else {
         $$0$lcssa$i63$i = $603;
        }
        (___fwritex($pad$i,$$0$lcssa$i63$i,$f)|0);
       }
       $610 = (($$pre300$i) - ($0))|0;
       (___fwritex($buf$i,$610,$f)|0);
       $611 = $534;
       $612 = (($9) - ($611))|0;
       $613 = (($l$0$i) - ($612))|0;
       $614 = (($613) - ($610))|0;
       $615 = ($614|0)>(0);
       if ($615) {
        $616 = ($614>>>0)>(256);
        $617 = $616 ? 256 : $614;
        _memset(($pad$i|0),48,($617|0))|0;
        $618 = ($614>>>0)>(255);
        if ($618) {
         $$01$i67$i = $614;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $619 = (($$01$i67$i) + -256)|0;
          $620 = ($619>>>0)>(255);
          if ($620) {
           $$01$i67$i = $619;
          } else {
           break;
          }
         }
         $621 = $614 & 255;
         $$0$lcssa$i69$i = $621;
        } else {
         $$0$lcssa$i69$i = $614;
        }
        (___fwritex($pad$i,$$0$lcssa$i69$i,$f)|0);
       }
       (___fwritex($534,$612,$f)|0);
       $622 = ($592|0)==(8192);
       $or$cond$i72$i = $622 & $594;
       if ($or$cond$i72$i) {
        $623 = (($w$1) - ($591))|0;
        $624 = ($623>>>0)>(256);
        $625 = $624 ? 256 : $623;
        _memset(($pad$i|0),32,($625|0))|0;
        $626 = ($623>>>0)>(255);
        if ($626) {
         $$01$i74$i = $623;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $627 = (($$01$i74$i) + -256)|0;
          $628 = ($627>>>0)>(255);
          if ($628) {
           $$01$i74$i = $627;
          } else {
           break;
          }
         }
         $629 = $623 & 255;
         $$0$lcssa$i76$i = $629;
        } else {
         $$0$lcssa$i76$i = $623;
        }
        (___fwritex($pad$i,$$0$lcssa$i76$i,$f)|0);
       }
       $w$$i = $594 ? $w$1 : $591;
       $$0$i = $w$$i;
       break;
      }
      $630 = ($p$0|0)<(0);
      $$p$i = $630 ? 6 : $p$0;
      if ($473) {
       $631 = $472 * 268435456.0;
       $632 = HEAP32[$e2$i>>2]|0;
       $633 = (($632) + -28)|0;
       HEAP32[$e2$i>>2] = $633;
       $$3$i = $631;$635 = $633;
      } else {
       $$pre$i = HEAP32[$e2$i>>2]|0;
       $$3$i = $472;$635 = $$pre$i;
      }
      $634 = ($635|0)<(0);
      $$31$i = $634 ? $big$i : $13;
      $636 = $$31$i;
      $$4$i = $$3$i;$z$0$i = $$31$i;
      while(1) {
       $637 = (~~(($$4$i))>>>0);
       HEAP32[$z$0$i>>2] = $637;
       $638 = ((($z$0$i)) + 4|0);
       $639 = (+($637>>>0));
       $640 = $$4$i - $639;
       $641 = $640 * 1.0E+9;
       $642 = $641 != 0.0;
       if ($642) {
        $$4$i = $641;$z$0$i = $638;
       } else {
        $$lcssa460 = $638;
        break;
       }
      }
      $$pr$i = HEAP32[$e2$i>>2]|0;
      $643 = ($$pr$i|0)>(0);
      if ($643) {
       $645 = $$pr$i;$a$1253$i = $$31$i;$z$1252$i = $$lcssa460;
       while(1) {
        $644 = ($645|0)>(29);
        $646 = $644 ? 29 : $645;
        $d$0245$i = ((($z$1252$i)) + -4|0);
        $647 = ($d$0245$i>>>0)<($a$1253$i>>>0);
        do {
         if ($647) {
          $a$2$ph$i = $a$1253$i;
         } else {
          $carry$0246$i = 0;$d$0247$i = $d$0245$i;
          while(1) {
           $648 = HEAP32[$d$0247$i>>2]|0;
           $649 = (_bitshift64Shl(($648|0),0,($646|0))|0);
           $650 = tempRet0;
           $651 = (_i64Add(($649|0),($650|0),($carry$0246$i|0),0)|0);
           $652 = tempRet0;
           $653 = (___uremdi3(($651|0),($652|0),1000000000,0)|0);
           $654 = tempRet0;
           HEAP32[$d$0247$i>>2] = $653;
           $655 = (___udivdi3(($651|0),($652|0),1000000000,0)|0);
           $656 = tempRet0;
           $d$0$i = ((($d$0247$i)) + -4|0);
           $657 = ($d$0$i>>>0)<($a$1253$i>>>0);
           if ($657) {
            $$lcssa461 = $655;
            break;
           } else {
            $carry$0246$i = $655;$d$0247$i = $d$0$i;
           }
          }
          $658 = ($$lcssa461|0)==(0);
          if ($658) {
           $a$2$ph$i = $a$1253$i;
           break;
          }
          $659 = ((($a$1253$i)) + -4|0);
          HEAP32[$659>>2] = $$lcssa461;
          $a$2$ph$i = $659;
         }
        } while(0);
        $z$2$i = $z$1252$i;
        while(1) {
         $660 = ($z$2$i>>>0)>($a$2$ph$i>>>0);
         if (!($660)) {
          $z$2$i$lcssa = $z$2$i;
          break;
         }
         $661 = ((($z$2$i)) + -4|0);
         $662 = HEAP32[$661>>2]|0;
         $663 = ($662|0)==(0);
         if ($663) {
          $z$2$i = $661;
         } else {
          $z$2$i$lcssa = $z$2$i;
          break;
         }
        }
        $664 = HEAP32[$e2$i>>2]|0;
        $665 = (($664) - ($646))|0;
        HEAP32[$e2$i>>2] = $665;
        $666 = ($665|0)>(0);
        if ($666) {
         $645 = $665;$a$1253$i = $a$2$ph$i;$z$1252$i = $z$2$i$lcssa;
        } else {
         $$pr146$i = $665;$a$1$lcssa$i = $a$2$ph$i;$z$1$lcssa$i = $z$2$i$lcssa;
         break;
        }
       }
      } else {
       $$pr146$i = $$pr$i;$a$1$lcssa$i = $$31$i;$z$1$lcssa$i = $$lcssa460;
      }
      $667 = ($$pr146$i|0)<(0);
      L229: do {
       if ($667) {
        $668 = (($$p$i) + 25)|0;
        $669 = (($668|0) / 9)&-1;
        $670 = (($669) + 1)|0;
        $671 = ($476|0)==(102);
        if (!($671)) {
         $704 = $$pr146$i;$a$3240$i = $a$1$lcssa$i;$z$3239$i = $z$1$lcssa$i;
         while(1) {
          $703 = (0 - ($704))|0;
          $705 = ($703|0)>(9);
          $706 = $705 ? 9 : $703;
          $707 = ($a$3240$i>>>0)<($z$3239$i>>>0);
          do {
           if ($707) {
            $711 = 1 << $706;
            $712 = (($711) + -1)|0;
            $713 = 1000000000 >>> $706;
            $carry3$0234$i = 0;$d$1233$i = $a$3240$i;
            while(1) {
             $714 = HEAP32[$d$1233$i>>2]|0;
             $715 = $714 & $712;
             $716 = $714 >>> $706;
             $717 = (($716) + ($carry3$0234$i))|0;
             HEAP32[$d$1233$i>>2] = $717;
             $718 = Math_imul($715, $713)|0;
             $719 = ((($d$1233$i)) + 4|0);
             $720 = ($719>>>0)<($z$3239$i>>>0);
             if ($720) {
              $carry3$0234$i = $718;$d$1233$i = $719;
             } else {
              $$lcssa463 = $718;
              break;
             }
            }
            $721 = HEAP32[$a$3240$i>>2]|0;
            $722 = ($721|0)==(0);
            $723 = ((($a$3240$i)) + 4|0);
            $$a$3$i = $722 ? $723 : $a$3240$i;
            $724 = ($$lcssa463|0)==(0);
            if ($724) {
             $$a$3306$i = $$a$3$i;$z$4$i = $z$3239$i;
             break;
            }
            $725 = ((($z$3239$i)) + 4|0);
            HEAP32[$z$3239$i>>2] = $$lcssa463;
            $$a$3306$i = $$a$3$i;$z$4$i = $725;
           } else {
            $708 = HEAP32[$a$3240$i>>2]|0;
            $709 = ($708|0)==(0);
            $710 = ((($a$3240$i)) + 4|0);
            $$a$3305$i = $709 ? $710 : $a$3240$i;
            $$a$3306$i = $$a$3305$i;$z$4$i = $z$3239$i;
           }
          } while(0);
          $726 = $z$4$i;
          $727 = $$a$3306$i;
          $728 = (($726) - ($727))|0;
          $729 = $728 >> 2;
          $730 = ($729|0)>($670|0);
          $731 = (($$a$3306$i) + ($670<<2)|0);
          $$z$4$i = $730 ? $731 : $z$4$i;
          $732 = HEAP32[$e2$i>>2]|0;
          $733 = (($732) + ($706))|0;
          HEAP32[$e2$i>>2] = $733;
          $734 = ($733|0)<(0);
          if ($734) {
           $704 = $733;$a$3240$i = $$a$3306$i;$z$3239$i = $$z$4$i;
          } else {
           $a$3$lcssa$i = $$a$3306$i;$z$3$lcssa$i = $$z$4$i;
           break L229;
          }
         }
        }
        $672 = (($$31$i) + ($670<<2)|0);
        $674 = $$pr146$i;$a$3240$us$i = $a$1$lcssa$i;$z$3239$us$i = $z$1$lcssa$i;
        while(1) {
         $673 = (0 - ($674))|0;
         $675 = ($673|0)>(9);
         $676 = $675 ? 9 : $673;
         $677 = ($a$3240$us$i>>>0)<($z$3239$us$i>>>0);
         do {
          if ($677) {
           $702 = 1 << $676;
           $695 = (($702) + -1)|0;
           $699 = 1000000000 >>> $676;
           $carry3$0234$us$i = 0;$d$1233$us$i = $a$3240$us$i;
           while(1) {
            $693 = HEAP32[$d$1233$us$i>>2]|0;
            $694 = $693 & $695;
            $696 = $693 >>> $676;
            $697 = (($696) + ($carry3$0234$us$i))|0;
            HEAP32[$d$1233$us$i>>2] = $697;
            $698 = Math_imul($694, $699)|0;
            $700 = ((($d$1233$us$i)) + 4|0);
            $701 = ($700>>>0)<($z$3239$us$i>>>0);
            if ($701) {
             $carry3$0234$us$i = $698;$d$1233$us$i = $700;
            } else {
             $$lcssa464 = $698;
             break;
            }
           }
           $681 = HEAP32[$a$3240$us$i>>2]|0;
           $682 = ($681|0)==(0);
           $683 = ((($a$3240$us$i)) + 4|0);
           $$a$3$us$i = $682 ? $683 : $a$3240$us$i;
           $684 = ($$lcssa464|0)==(0);
           if ($684) {
            $$a$3$us304$i = $$a$3$us$i;$z$4$us$i = $z$3239$us$i;
            break;
           }
           $685 = ((($z$3239$us$i)) + 4|0);
           HEAP32[$z$3239$us$i>>2] = $$lcssa464;
           $$a$3$us304$i = $$a$3$us$i;$z$4$us$i = $685;
          } else {
           $678 = HEAP32[$a$3240$us$i>>2]|0;
           $679 = ($678|0)==(0);
           $680 = ((($a$3240$us$i)) + 4|0);
           $$a$3$us303$i = $679 ? $680 : $a$3240$us$i;
           $$a$3$us304$i = $$a$3$us303$i;$z$4$us$i = $z$3239$us$i;
          }
         } while(0);
         $686 = $z$4$us$i;
         $687 = (($686) - ($636))|0;
         $688 = $687 >> 2;
         $689 = ($688|0)>($670|0);
         $$z$4$us$i = $689 ? $672 : $z$4$us$i;
         $690 = HEAP32[$e2$i>>2]|0;
         $691 = (($690) + ($676))|0;
         HEAP32[$e2$i>>2] = $691;
         $692 = ($691|0)<(0);
         if ($692) {
          $674 = $691;$a$3240$us$i = $$a$3$us304$i;$z$3239$us$i = $$z$4$us$i;
         } else {
          $a$3$lcssa$i = $$a$3$us304$i;$z$3$lcssa$i = $$z$4$us$i;
          break;
         }
        }
       } else {
        $a$3$lcssa$i = $a$1$lcssa$i;$z$3$lcssa$i = $z$1$lcssa$i;
       }
      } while(0);
      $735 = ($a$3$lcssa$i>>>0)<($z$3$lcssa$i>>>0);
      do {
       if ($735) {
        $736 = $a$3$lcssa$i;
        $737 = (($636) - ($736))|0;
        $738 = $737 >> 2;
        $739 = ($738*9)|0;
        $740 = HEAP32[$a$3$lcssa$i>>2]|0;
        $741 = ($740>>>0)<(10);
        if ($741) {
         $e$1$i = $739;
         break;
        } else {
         $e$0229$i = $739;$i$0228$i = 10;
        }
        while(1) {
         $742 = ($i$0228$i*10)|0;
         $743 = (($e$0229$i) + 1)|0;
         $744 = ($740>>>0)<($742>>>0);
         if ($744) {
          $e$1$i = $743;
          break;
         } else {
          $e$0229$i = $743;$i$0228$i = $742;
         }
        }
       } else {
        $e$1$i = 0;
       }
      } while(0);
      $745 = ($476|0)!=(102);
      $746 = $745 ? $e$1$i : 0;
      $747 = (($$p$i) - ($746))|0;
      $748 = ($476|0)==(103);
      $749 = ($$p$i|0)!=(0);
      $750 = $749 & $748;
      $$neg151$i = $750 << 31 >> 31;
      $751 = (($747) + ($$neg151$i))|0;
      $752 = $z$3$lcssa$i;
      $753 = (($752) - ($636))|0;
      $754 = $753 >> 2;
      $755 = ($754*9)|0;
      $756 = (($755) + -9)|0;
      $757 = ($751|0)<($756|0);
      if ($757) {
       $758 = (($751) + 9216)|0;
       $759 = (($758|0) / 9)&-1;
       $$sum$i = (($759) + -1023)|0;
       $760 = (($$31$i) + ($$sum$i<<2)|0);
       $761 = (($758|0) % 9)&-1;
       $j$0221$i = (($761) + 1)|0;
       $762 = ($j$0221$i|0)<(9);
       if ($762) {
        $i$1222$i = 10;$j$0223$i = $j$0221$i;
        while(1) {
         $763 = ($i$1222$i*10)|0;
         $j$0$i = (($j$0223$i) + 1)|0;
         $exitcond$i = ($j$0$i|0)==(9);
         if ($exitcond$i) {
          $i$1$lcssa$i = $763;
          break;
         } else {
          $i$1222$i = $763;$j$0223$i = $j$0$i;
         }
        }
       } else {
        $i$1$lcssa$i = 10;
       }
       $764 = HEAP32[$760>>2]|0;
       $765 = (($764>>>0) % ($i$1$lcssa$i>>>0))&-1;
       $766 = ($765|0)==(0);
       if ($766) {
        $$sum15$i = (($759) + -1022)|0;
        $767 = (($$31$i) + ($$sum15$i<<2)|0);
        $768 = ($767|0)==($z$3$lcssa$i|0);
        if ($768) {
         $a$7$i = $a$3$lcssa$i;$d$3$i = $760;$e$3$i = $e$1$i;
        } else {
         label = 221;
        }
       } else {
        label = 221;
       }
       do {
        if ((label|0) == 221) {
         label = 0;
         $769 = (($764>>>0) / ($i$1$lcssa$i>>>0))&-1;
         $770 = $769 & 1;
         $771 = ($770|0)==(0);
         $$20$i = $771 ? 9007199254740992.0 : 9007199254740994.0;
         $772 = (($i$1$lcssa$i|0) / 2)&-1;
         $773 = ($765>>>0)<($772>>>0);
         do {
          if ($773) {
           $small$0$i = 0.5;
          } else {
           $774 = ($765|0)==($772|0);
           if ($774) {
            $$sum16$i = (($759) + -1022)|0;
            $775 = (($$31$i) + ($$sum16$i<<2)|0);
            $776 = ($775|0)==($z$3$lcssa$i|0);
            if ($776) {
             $small$0$i = 1.0;
             break;
            }
           }
           $small$0$i = 1.5;
          }
         } while(0);
         $777 = ($pl$0$i|0)==(0);
         do {
          if ($777) {
           $round6$1$i = $$20$i;$small$1$i = $small$0$i;
          } else {
           $778 = HEAP8[$prefix$0$i>>0]|0;
           $779 = ($778<<24>>24)==(45);
           if (!($779)) {
            $round6$1$i = $$20$i;$small$1$i = $small$0$i;
            break;
           }
           $780 = -$$20$i;
           $781 = -$small$0$i;
           $round6$1$i = $780;$small$1$i = $781;
          }
         } while(0);
         $782 = (($764) - ($765))|0;
         HEAP32[$760>>2] = $782;
         $783 = $round6$1$i + $small$1$i;
         $784 = $783 != $round6$1$i;
         if (!($784)) {
          $a$7$i = $a$3$lcssa$i;$d$3$i = $760;$e$3$i = $e$1$i;
          break;
         }
         $785 = (($782) + ($i$1$lcssa$i))|0;
         HEAP32[$760>>2] = $785;
         $786 = ($785>>>0)>(999999999);
         if ($786) {
          $a$5215$i = $a$3$lcssa$i;$d$2214$i = $760;
          while(1) {
           $787 = ((($d$2214$i)) + -4|0);
           HEAP32[$d$2214$i>>2] = 0;
           $788 = ($787>>>0)<($a$5215$i>>>0);
           if ($788) {
            $789 = ((($a$5215$i)) + -4|0);
            HEAP32[$789>>2] = 0;
            $a$6$i = $789;
           } else {
            $a$6$i = $a$5215$i;
           }
           $790 = HEAP32[$787>>2]|0;
           $791 = (($790) + 1)|0;
           HEAP32[$787>>2] = $791;
           $792 = ($791>>>0)>(999999999);
           if ($792) {
            $a$5215$i = $a$6$i;$d$2214$i = $787;
           } else {
            $a$5$lcssa$i = $a$6$i;$d$2$lcssa$i = $787;
            break;
           }
          }
         } else {
          $a$5$lcssa$i = $a$3$lcssa$i;$d$2$lcssa$i = $760;
         }
         $793 = $a$5$lcssa$i;
         $794 = (($636) - ($793))|0;
         $795 = $794 >> 2;
         $796 = ($795*9)|0;
         $797 = HEAP32[$a$5$lcssa$i>>2]|0;
         $798 = ($797>>>0)<(10);
         if ($798) {
          $a$7$i = $a$5$lcssa$i;$d$3$i = $d$2$lcssa$i;$e$3$i = $796;
          break;
         } else {
          $e$2210$i = $796;$i$2209$i = 10;
         }
         while(1) {
          $799 = ($i$2209$i*10)|0;
          $800 = (($e$2210$i) + 1)|0;
          $801 = ($797>>>0)<($799>>>0);
          if ($801) {
           $a$7$i = $a$5$lcssa$i;$d$3$i = $d$2$lcssa$i;$e$3$i = $800;
           break;
          } else {
           $e$2210$i = $800;$i$2209$i = $799;
          }
         }
        }
       } while(0);
       $802 = ((($d$3$i)) + 4|0);
       $803 = ($z$3$lcssa$i>>>0)>($802>>>0);
       $$z$3$i = $803 ? $802 : $z$3$lcssa$i;
       $a$8$ph$i = $a$7$i;$e$4$ph$i = $e$3$i;$z$6$ph$i = $$z$3$i;
      } else {
       $a$8$ph$i = $a$3$lcssa$i;$e$4$ph$i = $e$1$i;$z$6$ph$i = $z$3$lcssa$i;
      }
      $804 = (0 - ($e$4$ph$i))|0;
      $z$6$i = $z$6$ph$i;
      while(1) {
       $805 = ($z$6$i>>>0)>($a$8$ph$i>>>0);
       if (!($805)) {
        $$lcssa275$i = 0;$z$6$i$lcssa = $z$6$i;
        break;
       }
       $806 = ((($z$6$i)) + -4|0);
       $807 = HEAP32[$806>>2]|0;
       $808 = ($807|0)==(0);
       if ($808) {
        $z$6$i = $806;
       } else {
        $$lcssa275$i = 1;$z$6$i$lcssa = $z$6$i;
        break;
       }
      }
      do {
       if ($748) {
        $809 = $749&1;
        $810 = $809 ^ 1;
        $$p$$i = (($810) + ($$p$i))|0;
        $811 = ($$p$$i|0)>($e$4$ph$i|0);
        $812 = ($e$4$ph$i|0)>(-5);
        $or$cond6$i = $811 & $812;
        if ($or$cond6$i) {
         $813 = (($t$0) + -1)|0;
         $$neg152$i = (($$p$$i) + -1)|0;
         $814 = (($$neg152$i) - ($e$4$ph$i))|0;
         $$013$i = $813;$$210$i = $814;
        } else {
         $815 = (($t$0) + -2)|0;
         $816 = (($$p$$i) + -1)|0;
         $$013$i = $815;$$210$i = $816;
        }
        $817 = $fl$1$ & 8;
        $818 = ($817|0)==(0);
        if (!($818)) {
         $$114$i = $$013$i;$$311$i = $$210$i;$$pre$phi302$iZ2D = $817;
         break;
        }
        do {
         if ($$lcssa275$i) {
          $819 = ((($z$6$i$lcssa)) + -4|0);
          $820 = HEAP32[$819>>2]|0;
          $821 = ($820|0)==(0);
          if ($821) {
           $j$2$i = 9;
           break;
          }
          $822 = (($820>>>0) % 10)&-1;
          $823 = ($822|0)==(0);
          if ($823) {
           $i$3205$i = 10;$j$1206$i = 0;
          } else {
           $j$2$i = 0;
           break;
          }
          while(1) {
           $824 = ($i$3205$i*10)|0;
           $825 = (($j$1206$i) + 1)|0;
           $826 = (($820>>>0) % ($824>>>0))&-1;
           $827 = ($826|0)==(0);
           if ($827) {
            $i$3205$i = $824;$j$1206$i = $825;
           } else {
            $j$2$i = $825;
            break;
           }
          }
         } else {
          $j$2$i = 9;
         }
        } while(0);
        $828 = $$013$i | 32;
        $829 = ($828|0)==(102);
        $830 = $z$6$i$lcssa;
        $831 = (($830) - ($636))|0;
        $832 = $831 >> 2;
        $833 = ($832*9)|0;
        $834 = (($833) + -9)|0;
        if ($829) {
         $835 = (($834) - ($j$2$i))|0;
         $836 = ($835|0)<(0);
         $$21$i = $836 ? 0 : $835;
         $837 = ($$210$i|0)<($$21$i|0);
         $$210$$22$i = $837 ? $$210$i : $$21$i;
         $$114$i = $$013$i;$$311$i = $$210$$22$i;$$pre$phi302$iZ2D = 0;
         break;
        } else {
         $838 = (($834) + ($e$4$ph$i))|0;
         $839 = (($838) - ($j$2$i))|0;
         $840 = ($839|0)<(0);
         $$23$i = $840 ? 0 : $839;
         $841 = ($$210$i|0)<($$23$i|0);
         $$210$$24$i = $841 ? $$210$i : $$23$i;
         $$114$i = $$013$i;$$311$i = $$210$$24$i;$$pre$phi302$iZ2D = 0;
         break;
        }
       } else {
        $$pre301$i = $fl$1$ & 8;
        $$114$i = $t$0;$$311$i = $$p$i;$$pre$phi302$iZ2D = $$pre301$i;
       }
      } while(0);
      $842 = $$311$i | $$pre$phi302$iZ2D;
      $843 = ($842|0)!=(0);
      $844 = $843&1;
      $845 = $$114$i | 32;
      $846 = ($845|0)==(102);
      if ($846) {
       $847 = ($e$4$ph$i|0)>(0);
       $848 = $847 ? $e$4$ph$i : 0;
       $$pn$i = $848;$estr$2$i = 0;
      } else {
       $849 = ($e$4$ph$i|0)<(0);
       $850 = $849 ? $804 : $e$4$ph$i;
       $851 = ($850|0)<(0);
       if ($851) {
        $852 = ($850|0)<(0);
        $853 = $852 << 31 >> 31;
        $$05$i79$i = $7;$854 = $850;$855 = $853;
        while(1) {
         $856 = (___uremdi3(($854|0),($855|0),10,0)|0);
         $857 = tempRet0;
         $858 = $856 | 48;
         $859 = $858&255;
         $860 = ((($$05$i79$i)) + -1|0);
         HEAP8[$860>>0] = $859;
         $861 = (___udivdi3(($854|0),($855|0),10,0)|0);
         $862 = tempRet0;
         $863 = ($855>>>0)>(9);
         $864 = ($854>>>0)>(4294967295);
         $865 = ($855|0)==(9);
         $866 = $865 & $864;
         $867 = $863 | $866;
         if ($867) {
          $$05$i79$i = $860;$854 = $861;$855 = $862;
         } else {
          $$lcssa470 = $860;$1185 = $861;$1186 = $862;
          break;
         }
        }
        $$0$lcssa$i84$i = $$lcssa470;$$01$lcssa$off0$i85$i = $1185;
       } else {
        $$0$lcssa$i84$i = $7;$$01$lcssa$off0$i85$i = $850;
       }
       $868 = ($$01$lcssa$off0$i85$i|0)==(0);
       if ($868) {
        $estr$1$ph$i = $$0$lcssa$i84$i;
       } else {
        $$12$i87$i = $$0$lcssa$i84$i;$y$03$i86$i = $$01$lcssa$off0$i85$i;
        while(1) {
         $869 = (($y$03$i86$i>>>0) % 10)&-1;
         $870 = $869 | 48;
         $871 = $870&255;
         $872 = ((($$12$i87$i)) + -1|0);
         HEAP8[$872>>0] = $871;
         $873 = (($y$03$i86$i>>>0) / 10)&-1;
         $874 = ($y$03$i86$i>>>0)<(10);
         if ($874) {
          $estr$1$ph$i = $872;
          break;
         } else {
          $$12$i87$i = $872;$y$03$i86$i = $873;
         }
        }
       }
       $875 = $estr$1$ph$i;
       $876 = (($9) - ($875))|0;
       $877 = ($876|0)<(2);
       if ($877) {
        $estr$1201$i = $estr$1$ph$i;
        while(1) {
         $878 = ((($estr$1201$i)) + -1|0);
         HEAP8[$878>>0] = 48;
         $879 = $878;
         $880 = (($9) - ($879))|0;
         $881 = ($880|0)<(2);
         if ($881) {
          $estr$1201$i = $878;
         } else {
          $estr$1$lcssa$i = $878;
          break;
         }
        }
       } else {
        $estr$1$lcssa$i = $estr$1$ph$i;
       }
       $882 = $e$4$ph$i >> 31;
       $883 = $882 & 2;
       $884 = (($883) + 43)|0;
       $885 = $884&255;
       $886 = ((($estr$1$lcssa$i)) + -1|0);
       HEAP8[$886>>0] = $885;
       $887 = $$114$i&255;
       $888 = ((($estr$1$lcssa$i)) + -2|0);
       HEAP8[$888>>0] = $887;
       $889 = $888;
       $890 = (($9) - ($889))|0;
       $$pn$i = $890;$estr$2$i = $888;
      }
      $891 = (($pl$0$i) + 1)|0;
      $892 = (($891) + ($$311$i))|0;
      $l$1$i = (($892) + ($844))|0;
      $893 = (($l$1$i) + ($$pn$i))|0;
      $894 = $fl$1$ & 73728;
      $895 = ($894|0)==(0);
      $896 = ($w$1|0)>($893|0);
      $or$cond$i93$i = $895 & $896;
      if ($or$cond$i93$i) {
       $897 = (($w$1) - ($893))|0;
       $898 = ($897>>>0)>(256);
       $899 = $898 ? 256 : $897;
       _memset(($pad$i|0),32,($899|0))|0;
       $900 = ($897>>>0)>(255);
       if ($900) {
        $$01$i95$i = $897;
        while(1) {
         (___fwritex($pad$i,256,$f)|0);
         $901 = (($$01$i95$i) + -256)|0;
         $902 = ($901>>>0)>(255);
         if ($902) {
          $$01$i95$i = $901;
         } else {
          break;
         }
        }
        $903 = $897 & 255;
        $$0$lcssa$i97$i = $903;
       } else {
        $$0$lcssa$i97$i = $897;
       }
       (___fwritex($pad$i,$$0$lcssa$i97$i,$f)|0);
      }
      (___fwritex($prefix$0$i,$pl$0$i,$f)|0);
      $904 = ($894|0)==(65536);
      $or$cond$i100$i = $904 & $896;
      if ($or$cond$i100$i) {
       $905 = (($w$1) - ($893))|0;
       $906 = ($905>>>0)>(256);
       $907 = $906 ? 256 : $905;
       _memset(($pad$i|0),48,($907|0))|0;
       $908 = ($905>>>0)>(255);
       if ($908) {
        $$01$i102$i = $905;
        while(1) {
         (___fwritex($pad$i,256,$f)|0);
         $909 = (($$01$i102$i) + -256)|0;
         $910 = ($909>>>0)>(255);
         if ($910) {
          $$01$i102$i = $909;
         } else {
          break;
         }
        }
        $911 = $905 & 255;
        $$0$lcssa$i104$i = $911;
       } else {
        $$0$lcssa$i104$i = $905;
       }
       (___fwritex($pad$i,$$0$lcssa$i104$i,$f)|0);
      }
      if ($846) {
       $912 = ($a$8$ph$i>>>0)>($$31$i>>>0);
       $r$0$a$8$i = $912 ? $$31$i : $a$8$ph$i;
       $d$4191$i = $r$0$a$8$i;
       while(1) {
        $913 = HEAP32[$d$4191$i>>2]|0;
        $914 = ($913|0)==(0);
        if ($914) {
         $$1$lcssa$i112$i = $14;
        } else {
         $$12$i110$i = $14;$y$03$i109$i = $913;
         while(1) {
          $915 = (($y$03$i109$i>>>0) % 10)&-1;
          $916 = $915 | 48;
          $917 = $916&255;
          $918 = ((($$12$i110$i)) + -1|0);
          HEAP8[$918>>0] = $917;
          $919 = (($y$03$i109$i>>>0) / 10)&-1;
          $920 = ($y$03$i109$i>>>0)<(10);
          if ($920) {
           $$1$lcssa$i112$i = $918;
           break;
          } else {
           $$12$i110$i = $918;$y$03$i109$i = $919;
          }
         }
        }
        $921 = ($d$4191$i|0)==($r$0$a$8$i|0);
        do {
         if ($921) {
          $925 = ($$1$lcssa$i112$i|0)==($14|0);
          if (!($925)) {
           $s7$1$i = $$1$lcssa$i112$i;
           break;
          }
          HEAP8[$16>>0] = 48;
          $s7$1$i = $16;
         } else {
          $922 = ($$1$lcssa$i112$i>>>0)>($buf$i>>>0);
          if ($922) {
           $s7$0188$i = $$1$lcssa$i112$i;
          } else {
           $s7$1$i = $$1$lcssa$i112$i;
           break;
          }
          while(1) {
           $923 = ((($s7$0188$i)) + -1|0);
           HEAP8[$923>>0] = 48;
           $924 = ($923>>>0)>($buf$i>>>0);
           if ($924) {
            $s7$0188$i = $923;
           } else {
            $s7$1$i = $923;
            break;
           }
          }
         }
        } while(0);
        $926 = $s7$1$i;
        $927 = (($15) - ($926))|0;
        (___fwritex($s7$1$i,$927,$f)|0);
        $928 = ((($d$4191$i)) + 4|0);
        $929 = ($928>>>0)>($$31$i>>>0);
        if ($929) {
         $$lcssa479 = $928;
         break;
        } else {
         $d$4191$i = $928;
        }
       }
       $930 = ($842|0)==(0);
       if (!($930)) {
        (___fwritex(6936,1,$f)|0);
       }
       $931 = ($$lcssa479>>>0)<($z$6$i$lcssa>>>0);
       $932 = ($$311$i|0)>(0);
       $933 = $932 & $931;
       if ($933) {
        $$412184$i = $$311$i;$d$5183$i = $$lcssa479;
        while(1) {
         $934 = HEAP32[$d$5183$i>>2]|0;
         $935 = ($934|0)==(0);
         if ($935) {
          $s8$0180$i = $14;
          label = 289;
         } else {
          $$12$i119$i = $14;$y$03$i118$i = $934;
          while(1) {
           $936 = (($y$03$i118$i>>>0) % 10)&-1;
           $937 = $936 | 48;
           $938 = $937&255;
           $939 = ((($$12$i119$i)) + -1|0);
           HEAP8[$939>>0] = $938;
           $940 = (($y$03$i118$i>>>0) / 10)&-1;
           $941 = ($y$03$i118$i>>>0)<(10);
           if ($941) {
            $$lcssa480 = $939;
            break;
           } else {
            $$12$i119$i = $939;$y$03$i118$i = $940;
           }
          }
          $942 = ($$lcssa480>>>0)>($buf$i>>>0);
          if ($942) {
           $s8$0180$i = $$lcssa480;
           label = 289;
          } else {
           $s8$0$lcssa$i = $$lcssa480;
          }
         }
         if ((label|0) == 289) {
          while(1) {
           label = 0;
           $943 = ((($s8$0180$i)) + -1|0);
           HEAP8[$943>>0] = 48;
           $944 = ($943>>>0)>($buf$i>>>0);
           if ($944) {
            $s8$0180$i = $943;
            label = 289;
           } else {
            $s8$0$lcssa$i = $943;
            break;
           }
          }
         }
         $945 = ($$412184$i|0)>(9);
         $946 = $945 ? 9 : $$412184$i;
         (___fwritex($s8$0$lcssa$i,$946,$f)|0);
         $947 = ((($d$5183$i)) + 4|0);
         $948 = (($$412184$i) + -9)|0;
         $949 = ($947>>>0)<($z$6$i$lcssa>>>0);
         $950 = $945 & $949;
         if ($950) {
          $$412184$i = $948;$d$5183$i = $947;
         } else {
          $$412$lcssa$i = $948;
          break;
         }
        }
       } else {
        $$412$lcssa$i = $$311$i;
       }
       $951 = ($$412$lcssa$i|0)>(0);
       if ($951) {
        $952 = ($$412$lcssa$i>>>0)>(256);
        $953 = $952 ? 256 : $$412$lcssa$i;
        _memset(($pad$i|0),48,($953|0))|0;
        $954 = ($$412$lcssa$i>>>0)>(255);
        if ($954) {
         $$01$i126$i = $$412$lcssa$i;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $955 = (($$01$i126$i) + -256)|0;
          $956 = ($955>>>0)>(255);
          if ($956) {
           $$01$i126$i = $955;
          } else {
           break;
          }
         }
         $957 = $$412$lcssa$i & 255;
         $$0$lcssa$i128$i = $957;
        } else {
         $$0$lcssa$i128$i = $$412$lcssa$i;
        }
        (___fwritex($pad$i,$$0$lcssa$i128$i,$f)|0);
       }
      } else {
       $958 = ((($a$8$ph$i)) + 4|0);
       $z$6$$i = $$lcssa275$i ? $z$6$i$lcssa : $958;
       $959 = ($$311$i|0)>(-1);
       do {
        if ($959) {
         $960 = ($$pre$phi302$iZ2D|0)==(0);
         $$5196$i = $$311$i;$d$6195$i = $a$8$ph$i;
         while(1) {
          $961 = HEAP32[$d$6195$i>>2]|0;
          $962 = ($961|0)==(0);
          if ($962) {
           label = 303;
          } else {
           $$12$i134$i = $14;$y$03$i133$i = $961;
           while(1) {
            $963 = (($y$03$i133$i>>>0) % 10)&-1;
            $964 = $963 | 48;
            $965 = $964&255;
            $966 = ((($$12$i134$i)) + -1|0);
            HEAP8[$966>>0] = $965;
            $967 = (($y$03$i133$i>>>0) / 10)&-1;
            $968 = ($y$03$i133$i>>>0)<(10);
            if ($968) {
             $$12$i134$i$lcssa = $$12$i134$i;$$lcssa474 = $966;
             break;
            } else {
             $$12$i134$i = $966;$y$03$i133$i = $967;
            }
           }
           $969 = ($$lcssa474|0)==($14|0);
           if ($969) {
            label = 303;
           } else {
            $1187 = $$12$i134$i$lcssa;$s9$0$i = $$lcssa474;
           }
          }
          if ((label|0) == 303) {
           label = 0;
           HEAP8[$16>>0] = 48;
           $1187 = $14;$s9$0$i = $16;
          }
          $970 = ($d$6195$i|0)==($a$8$ph$i|0);
          do {
           if ($970) {
            (___fwritex($s9$0$i,1,$f)|0);
            $974 = ($$5196$i|0)<(1);
            $or$cond29$i = $960 & $974;
            if ($or$cond29$i) {
             $s9$2$i = $1187;
             break;
            }
            (___fwritex(6936,1,$f)|0);
            $s9$2$i = $1187;
           } else {
            $971 = ($s9$0$i>>>0)>($buf$i>>>0);
            if ($971) {
             $s9$1192$i = $s9$0$i;
            } else {
             $s9$2$i = $s9$0$i;
             break;
            }
            while(1) {
             $972 = ((($s9$1192$i)) + -1|0);
             HEAP8[$972>>0] = 48;
             $973 = ($972>>>0)>($buf$i>>>0);
             if ($973) {
              $s9$1192$i = $972;
             } else {
              $s9$2$i = $972;
              break;
             }
            }
           }
          } while(0);
          $975 = $s9$2$i;
          $976 = (($15) - ($975))|0;
          $977 = ($$5196$i|0)>($976|0);
          $978 = $977 ? $976 : $$5196$i;
          (___fwritex($s9$2$i,$978,$f)|0);
          $979 = (($$5196$i) - ($976))|0;
          $980 = ((($d$6195$i)) + 4|0);
          $981 = ($980>>>0)<($z$6$$i>>>0);
          $982 = ($979|0)>(-1);
          $983 = $981 & $982;
          if ($983) {
           $$5196$i = $979;$d$6195$i = $980;
          } else {
           $$lcssa476 = $979;
           break;
          }
         }
         $984 = ($$lcssa476|0)>(0);
         if (!($984)) {
          break;
         }
         $985 = ($$lcssa476>>>0)>(256);
         $986 = $985 ? 256 : $$lcssa476;
         _memset(($pad$i|0),48,($986|0))|0;
         $987 = ($$lcssa476>>>0)>(255);
         if ($987) {
          $$01$i141$i = $$lcssa476;
          while(1) {
           (___fwritex($pad$i,256,$f)|0);
           $988 = (($$01$i141$i) + -256)|0;
           $989 = ($988>>>0)>(255);
           if ($989) {
            $$01$i141$i = $988;
           } else {
            break;
           }
          }
          $990 = $$lcssa476 & 255;
          $$0$lcssa$i143$i = $990;
         } else {
          $$0$lcssa$i143$i = $$lcssa476;
         }
         (___fwritex($pad$i,$$0$lcssa$i143$i,$f)|0);
        } else {
        }
       } while(0);
       $991 = $estr$2$i;
       $992 = (($9) - ($991))|0;
       (___fwritex($estr$2$i,$992,$f)|0);
      }
      $993 = ($894|0)==(8192);
      $or$cond$i$i = $993 & $896;
      if ($or$cond$i$i) {
       $994 = (($w$1) - ($893))|0;
       $995 = ($994>>>0)>(256);
       $996 = $995 ? 256 : $994;
       _memset(($pad$i|0),32,($996|0))|0;
       $997 = ($994>>>0)>(255);
       if ($997) {
        $$01$i$i = $994;
        while(1) {
         (___fwritex($pad$i,256,$f)|0);
         $998 = (($$01$i$i) + -256)|0;
         $999 = ($998>>>0)>(255);
         if ($999) {
          $$01$i$i = $998;
         } else {
          break;
         }
        }
        $1000 = $994 & 255;
        $$0$lcssa$i$i = $1000;
       } else {
        $$0$lcssa$i$i = $994;
       }
       (___fwritex($pad$i,$$0$lcssa$i$i,$f)|0);
      }
      $w$30$i = $896 ? $w$1 : $893;
      $$0$i = $w$30$i;
     } else {
      $445 = $t$0 & 32;
      $446 = ($445|0)!=(0);
      $447 = $446 ? 6904 : 6912;
      $448 = ($$07$i != $$07$i) | (0.0 != 0.0);
      $449 = $446 ? 6920 : 6928;
      $pl$1$i = $448 ? 0 : $pl$0$i;
      $s1$0$i = $448 ? $449 : $447;
      $450 = (($pl$1$i) + 3)|0;
      $451 = $fl$1$ & 8192;
      $452 = ($451|0)==(0);
      $453 = ($w$1|0)>($450|0);
      $or$cond$i35$i = $452 & $453;
      if ($or$cond$i35$i) {
       $454 = (($w$1) - ($450))|0;
       $455 = ($454>>>0)>(256);
       $456 = $455 ? 256 : $454;
       _memset(($pad$i|0),32,($456|0))|0;
       $457 = ($454>>>0)>(255);
       if ($457) {
        $$01$i37$i = $454;
        while(1) {
         (___fwritex($pad$i,256,$f)|0);
         $458 = (($$01$i37$i) + -256)|0;
         $459 = ($458>>>0)>(255);
         if ($459) {
          $$01$i37$i = $458;
         } else {
          break;
         }
        }
        $460 = $454 & 255;
        $$0$lcssa$i39$i = $460;
       } else {
        $$0$lcssa$i39$i = $454;
       }
       (___fwritex($pad$i,$$0$lcssa$i39$i,$f)|0);
      }
      (___fwritex($prefix$0$i,$pl$1$i,$f)|0);
      (___fwritex($s1$0$i,3,$f)|0);
      $461 = $fl$1$ & 73728;
      $462 = ($461|0)==(8192);
      $or$cond$i42$i = $462 & $453;
      if ($or$cond$i42$i) {
       $463 = (($w$1) - ($450))|0;
       $464 = ($463>>>0)>(256);
       $465 = $464 ? 256 : $463;
       _memset(($pad$i|0),32,($465|0))|0;
       $466 = ($463>>>0)>(255);
       if ($466) {
        $$01$i44$i = $463;
        while(1) {
         (___fwritex($pad$i,256,$f)|0);
         $467 = (($$01$i44$i) + -256)|0;
         $468 = ($467>>>0)>(255);
         if ($468) {
          $$01$i44$i = $467;
         } else {
          break;
         }
        }
        $469 = $463 & 255;
        $$0$lcssa$i46$i = $469;
       } else {
        $$0$lcssa$i46$i = $463;
       }
       (___fwritex($pad$i,$$0$lcssa$i46$i,$f)|0);
      }
      $470 = $453 ? $w$1 : $450;
      $$0$i = $470;
     }
    } while(0);
    $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $$0$i;$l10n$0 = $l10n$3;
    continue L1;
    break;
   }
   case 99:  {
    $378 = $265&255;
    HEAP8[$4>>0] = $378;
    $1175 = $292;$1176 = $265;$a$2 = $4;$fl$6 = $263;$p$5 = 1;$pl$2 = 0;$prefix$2 = 6856;$z$2 = $2;
    break;
   }
   case 109:  {
    $379 = (___errno_location()|0);
    $380 = HEAP32[$379>>2]|0;
    $381 = (_strerror(($380|0))|0);
    $a$1 = $381;
    label = 94;
    break;
   }
   case 115:  {
    $382 = $265;
    $383 = ($265|0)!=(0);
    $384 = $383 ? $382 : 6872;
    $a$1 = $384;
    label = 94;
    break;
   }
   case 105: case 100:  {
    $329 = ($292|0)<(0);
    if ($329) {
     $330 = (_i64Subtract(0,0,($265|0),($292|0))|0);
     $331 = tempRet0;
     $337 = $331;$339 = $330;$pl$0 = 1;$prefix$0 = 6856;
     label = 84;
     break L86;
    }
    $332 = $fl$1$ & 2048;
    $333 = ($332|0)==(0);
    if ($333) {
     $334 = $fl$1$ & 1;
     $335 = ($334|0)==(0);
     $$ = $335 ? 6856 : (6858);
     $337 = $292;$339 = $265;$pl$0 = $334;$prefix$0 = $$;
     label = 84;
    } else {
     $337 = $292;$339 = $265;$pl$0 = 1;$prefix$0 = (6857);
     label = 84;
    }
    break;
   }
   default: {
    $1175 = $292;$1176 = $265;$a$2 = $23;$fl$6 = $fl$1$;$p$5 = $p$0;$pl$2 = 0;$prefix$2 = 6856;$z$2 = $2;
   }
   }
  } while(0);
  if ((label|0) == 73) {
   label = 0;
   $289 = $t$1 & 32;
   $290 = ($265|0)==(0);
   $291 = ($292|0)==(0);
   $293 = $290 & $291;
   if ($293) {
    $367 = $265;$369 = $292;$a$0 = $2;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 0;$prefix$1 = 6856;
    label = 89;
   } else {
    $$012$i = $2;$295 = $265;$302 = $292;
    while(1) {
     $294 = $295 & 15;
     $296 = (6840 + ($294)|0);
     $297 = HEAP8[$296>>0]|0;
     $298 = $297&255;
     $299 = $298 | $289;
     $300 = $299&255;
     $301 = ((($$012$i)) + -1|0);
     HEAP8[$301>>0] = $300;
     $303 = (_bitshift64Lshr(($295|0),($302|0),4)|0);
     $304 = tempRet0;
     $305 = ($303|0)==(0);
     $306 = ($304|0)==(0);
     $307 = $305 & $306;
     if ($307) {
      $$lcssa491 = $301;
      break;
     } else {
      $$012$i = $301;$295 = $303;$302 = $304;
     }
    }
    $308 = $fl$3 & 8;
    $309 = ($308|0)==(0);
    if ($309) {
     $367 = $265;$369 = $292;$a$0 = $$lcssa491;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 0;$prefix$1 = 6856;
     label = 89;
    } else {
     $310 = $t$1 >> 4;
     $311 = (6856 + ($310)|0);
     $367 = $265;$369 = $292;$a$0 = $$lcssa491;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 2;$prefix$1 = $311;
     label = 89;
    }
   }
  }
  else if ((label|0) == 84) {
   label = 0;
   $336 = ($337>>>0)>(0);
   $338 = ($339>>>0)>(4294967295);
   $340 = ($337|0)==(0);
   $341 = $340 & $338;
   $342 = $336 | $341;
   if ($342) {
    $$05$i = $2;$343 = $339;$344 = $337;
    while(1) {
     $345 = (___uremdi3(($343|0),($344|0),10,0)|0);
     $346 = tempRet0;
     $347 = $345 | 48;
     $348 = $347&255;
     $349 = ((($$05$i)) + -1|0);
     HEAP8[$349>>0] = $348;
     $350 = (___udivdi3(($343|0),($344|0),10,0)|0);
     $351 = tempRet0;
     $352 = ($344>>>0)>(9);
     $353 = ($343>>>0)>(4294967295);
     $354 = ($344|0)==(9);
     $355 = $354 & $353;
     $356 = $352 | $355;
     if ($356) {
      $$05$i = $349;$343 = $350;$344 = $351;
     } else {
      $$lcssa487 = $349;$1177 = $350;$1178 = $351;
      break;
     }
    }
    $$0$lcssa$i53 = $$lcssa487;$$01$lcssa$off0$i = $1177;
   } else {
    $$0$lcssa$i53 = $2;$$01$lcssa$off0$i = $339;
   }
   $357 = ($$01$lcssa$off0$i|0)==(0);
   if ($357) {
    $367 = $339;$369 = $337;$a$0 = $$0$lcssa$i53;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $pl$0;$prefix$1 = $prefix$0;
    label = 89;
   } else {
    $$12$i = $$0$lcssa$i53;$y$03$i = $$01$lcssa$off0$i;
    while(1) {
     $358 = (($y$03$i>>>0) % 10)&-1;
     $359 = $358 | 48;
     $360 = $359&255;
     $361 = ((($$12$i)) + -1|0);
     HEAP8[$361>>0] = $360;
     $362 = (($y$03$i>>>0) / 10)&-1;
     $363 = ($y$03$i>>>0)<(10);
     if ($363) {
      $367 = $339;$369 = $337;$a$0 = $361;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $pl$0;$prefix$1 = $prefix$0;
      label = 89;
      break;
     } else {
      $$12$i = $361;$y$03$i = $362;
     }
    }
   }
  }
  else if ((label|0) == 94) {
   label = 0;
   $385 = (_memchr($a$1,0,$p$0)|0);
   $386 = ($385|0)==(0|0);
   $387 = $385;
   $388 = $a$1;
   $389 = (($387) - ($388))|0;
   $390 = (($a$1) + ($p$0)|0);
   $z$1 = $386 ? $390 : $385;
   $p$3 = $386 ? $p$0 : $389;
   $1175 = $292;$1176 = $265;$a$2 = $a$1;$fl$6 = $263;$p$5 = $p$3;$pl$2 = 0;$prefix$2 = 6856;$z$2 = $z$1;
  }
  else if ((label|0) == 97) {
   label = 0;
   $i$0175 = 0;$l$1174 = 0;$ws$0176 = $1179;
   while(1) {
    $393 = HEAP32[$ws$0176>>2]|0;
    $394 = ($393|0)==(0);
    if ($394) {
     $i$0$lcssa = $i$0175;$l$2 = $l$1174;
     break;
    }
    $395 = (_wctomb($mb,$393)|0);
    $396 = ($395|0)<(0);
    $397 = (($p$4272) - ($i$0175))|0;
    $398 = ($395>>>0)>($397>>>0);
    $or$cond22 = $396 | $398;
    if ($or$cond22) {
     $i$0$lcssa = $i$0175;$l$2 = $395;
     break;
    }
    $399 = ((($ws$0176)) + 4|0);
    $400 = (($395) + ($i$0175))|0;
    $401 = ($p$4272>>>0)>($400>>>0);
    if ($401) {
     $i$0175 = $400;$l$1174 = $395;$ws$0176 = $399;
    } else {
     $i$0$lcssa = $400;$l$2 = $395;
     break;
    }
   }
   $402 = ($l$2|0)<(0);
   if ($402) {
    $$0 = -1;
    label = 363;
    break;
   } else {
    $1181 = $1180;$1182 = $1179;$i$0$lcssa273 = $i$0$lcssa;
    label = 102;
   }
  }
  if ((label|0) == 89) {
   label = 0;
   $364 = ($p$2|0)>(-1);
   $365 = $fl$4 & -65537;
   $$fl$4 = $364 ? $365 : $fl$4;
   $366 = ($367|0)!=(0);
   $368 = ($369|0)!=(0);
   $370 = $366 | $368;
   $371 = ($p$2|0)!=(0);
   $or$cond = $370 | $371;
   if ($or$cond) {
    $372 = $a$0;
    $373 = (($3) - ($372))|0;
    $374 = $370&1;
    $375 = $374 ^ 1;
    $376 = (($375) + ($373))|0;
    $377 = ($p$2|0)>($376|0);
    $p$2$ = $377 ? $p$2 : $376;
    $1175 = $369;$1176 = $367;$a$2 = $a$0;$fl$6 = $$fl$4;$p$5 = $p$2$;$pl$2 = $pl$1;$prefix$2 = $prefix$1;$z$2 = $2;
   } else {
    $1175 = $369;$1176 = $367;$a$2 = $2;$fl$6 = $$fl$4;$p$5 = 0;$pl$2 = $pl$1;$prefix$2 = $prefix$1;$z$2 = $2;
   }
  }
  else if ((label|0) == 102) {
   label = 0;
   $403 = $fl$1$ & 73728;
   $404 = ($403|0)==(0);
   $405 = ($w$1|0)>($i$0$lcssa273|0);
   $or$cond$i64 = $404 & $405;
   if ($or$cond$i64) {
    $406 = (($w$1) - ($i$0$lcssa273))|0;
    $407 = ($406>>>0)>(256);
    $408 = $407 ? 256 : $406;
    _memset(($pad$i|0),32,($408|0))|0;
    $409 = ($406>>>0)>(255);
    if ($409) {
     $$01$i66 = $406;
     while(1) {
      (___fwritex($pad$i,256,$f)|0);
      $410 = (($$01$i66) + -256)|0;
      $411 = ($410>>>0)>(255);
      if ($411) {
       $$01$i66 = $410;
      } else {
       break;
      }
     }
     $412 = $406 & 255;
     $$0$lcssa$i68 = $412;
    } else {
     $$0$lcssa$i68 = $406;
    }
    (___fwritex($pad$i,$$0$lcssa$i68,$f)|0);
   }
   $413 = ($i$0$lcssa273|0)==(0);
   L463: do {
    if (!($413)) {
     $i$1186 = 0;$ws$1187 = $1182;
     while(1) {
      $414 = HEAP32[$ws$1187>>2]|0;
      $415 = ($414|0)==(0);
      if ($415) {
       break L463;
      }
      $416 = (_wctomb($mb,$414)|0);
      $417 = (($416) + ($i$1186))|0;
      $418 = ($417|0)>($i$0$lcssa273|0);
      if ($418) {
       break L463;
      }
      $419 = ((($ws$1187)) + 4|0);
      (___fwritex($mb,$416,$f)|0);
      $420 = ($417>>>0)<($i$0$lcssa273>>>0);
      if ($420) {
       $i$1186 = $417;$ws$1187 = $419;
      } else {
       break;
      }
     }
    }
   } while(0);
   $421 = ($403|0)==(8192);
   $or$cond$i71 = $421 & $405;
   if ($or$cond$i71) {
    $422 = (($w$1) - ($i$0$lcssa273))|0;
    $423 = ($422>>>0)>(256);
    $424 = $423 ? 256 : $422;
    _memset(($pad$i|0),32,($424|0))|0;
    $425 = ($422>>>0)>(255);
    if ($425) {
     $$01$i73 = $422;
     while(1) {
      (___fwritex($pad$i,256,$f)|0);
      $426 = (($$01$i73) + -256)|0;
      $427 = ($426>>>0)>(255);
      if ($427) {
       $$01$i73 = $426;
      } else {
       break;
      }
     }
     $428 = $422 & 255;
     $$0$lcssa$i75 = $428;
    } else {
     $$0$lcssa$i75 = $422;
    }
    (___fwritex($pad$i,$$0$lcssa$i75,$f)|0);
   }
   $429 = $405 ? $w$1 : $i$0$lcssa273;
   $1169 = $292;$1170 = $1181;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $429;$l10n$0 = $l10n$3;
   continue;
  }
  $1001 = $z$2;
  $1002 = $a$2;
  $1003 = (($1001) - ($1002))|0;
  $1004 = ($p$5|0)<($1003|0);
  $$p$5 = $1004 ? $1003 : $p$5;
  $1005 = (($pl$2) + ($$p$5))|0;
  $1006 = ($w$1|0)<($1005|0);
  $w$2 = $1006 ? $1005 : $w$1;
  $1007 = $fl$6 & 73728;
  $1008 = ($1007|0)==(0);
  $1009 = ($w$2|0)>($1005|0);
  $or$cond$i81 = $1008 & $1009;
  if ($or$cond$i81) {
   $1010 = (($w$2) - ($1005))|0;
   $1011 = ($1010>>>0)>(256);
   $1012 = $1011 ? 256 : $1010;
   _memset(($pad$i|0),32,($1012|0))|0;
   $1013 = ($1010>>>0)>(255);
   if ($1013) {
    $$01$i83 = $1010;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $1014 = (($$01$i83) + -256)|0;
     $1015 = ($1014>>>0)>(255);
     if ($1015) {
      $$01$i83 = $1014;
     } else {
      break;
     }
    }
    $1016 = $1010 & 255;
    $$0$lcssa$i85 = $1016;
   } else {
    $$0$lcssa$i85 = $1010;
   }
   (___fwritex($pad$i,$$0$lcssa$i85,$f)|0);
  }
  (___fwritex($prefix$2,$pl$2,$f)|0);
  $1017 = ($1007|0)==(65536);
  $or$cond$i57 = $1017 & $1009;
  if ($or$cond$i57) {
   $1018 = (($w$2) - ($1005))|0;
   $1019 = ($1018>>>0)>(256);
   $1020 = $1019 ? 256 : $1018;
   _memset(($pad$i|0),48,($1020|0))|0;
   $1021 = ($1018>>>0)>(255);
   if ($1021) {
    $$01$i59 = $1018;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $1022 = (($$01$i59) + -256)|0;
     $1023 = ($1022>>>0)>(255);
     if ($1023) {
      $$01$i59 = $1022;
     } else {
      break;
     }
    }
    $1024 = $1018 & 255;
    $$0$lcssa$i61 = $1024;
   } else {
    $$0$lcssa$i61 = $1018;
   }
   (___fwritex($pad$i,$$0$lcssa$i61,$f)|0);
  }
  $1025 = ($$p$5|0)>($1003|0);
  if ($1025) {
   $1026 = (($$p$5) - ($1003))|0;
   $1027 = ($1026>>>0)>(256);
   $1028 = $1027 ? 256 : $1026;
   _memset(($pad$i|0),48,($1028|0))|0;
   $1029 = ($1026>>>0)>(255);
   if ($1029) {
    $$01$i44 = $1026;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $1030 = (($$01$i44) + -256)|0;
     $1031 = ($1030>>>0)>(255);
     if ($1031) {
      $$01$i44 = $1030;
     } else {
      break;
     }
    }
    $1032 = $1026 & 255;
    $$0$lcssa$i46 = $1032;
   } else {
    $$0$lcssa$i46 = $1026;
   }
   (___fwritex($pad$i,$$0$lcssa$i46,$f)|0);
  }
  (___fwritex($a$2,$1003,$f)|0);
  $1033 = ($1007|0)==(8192);
  $or$cond$i = $1033 & $1009;
  if ($or$cond$i) {
   $1034 = (($w$2) - ($1005))|0;
   $1035 = ($1034>>>0)>(256);
   $1036 = $1035 ? 256 : $1034;
   _memset(($pad$i|0),32,($1036|0))|0;
   $1037 = ($1034>>>0)>(255);
   if ($1037) {
    $$01$i = $1034;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $1038 = (($$01$i) + -256)|0;
     $1039 = ($1038>>>0)>(255);
     if ($1039) {
      $$01$i = $1038;
     } else {
      break;
     }
    }
    $1040 = $1034 & 255;
    $$0$lcssa$i = $1040;
   } else {
    $$0$lcssa$i = $1034;
   }
   (___fwritex($pad$i,$$0$lcssa$i,$f)|0);
  }
  $1169 = $1175;$1170 = $1176;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $w$2;$l10n$0 = $l10n$3;
 }
 if ((label|0) == 344) {
  $1041 = ($f|0)==(0|0);
  if (!($1041)) {
   $$0 = $cnt$1$lcssa;
   STACKTOP = sp;return ($$0|0);
  }
  $1042 = ($l10n$0$lcssa|0)==(0);
  if ($1042) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$2162 = 1;
  }
  while(1) {
   $1043 = (($nl_type) + ($i$2162<<2)|0);
   $1044 = HEAP32[$1043>>2]|0;
   $1045 = ($1044|0)==(0);
   if ($1045) {
    $i$2162$lcssa = $i$2162;
    break;
   }
   $1047 = (($nl_arg) + ($i$2162<<3)|0);
   $1048 = ($1044>>>0)>(20);
   L522: do {
    if (!($1048)) {
     do {
      switch ($1044|0) {
      case 9:  {
       $arglist_current35 = HEAP32[$ap>>2]|0;
       $1049 = $arglist_current35;
       $1050 = ((0) + 4|0);
       $expanded148 = $1050;
       $expanded147 = (($expanded148) - 1)|0;
       $1051 = (($1049) + ($expanded147))|0;
       $1052 = ((0) + 4|0);
       $expanded152 = $1052;
       $expanded151 = (($expanded152) - 1)|0;
       $expanded150 = $expanded151 ^ -1;
       $1053 = $1051 & $expanded150;
       $1054 = $1053;
       $1055 = HEAP32[$1054>>2]|0;
       $arglist_next36 = ((($1054)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next36;
       HEAP32[$1047>>2] = $1055;
       break L522;
       break;
      }
      case 10:  {
       $arglist_current38 = HEAP32[$ap>>2]|0;
       $1056 = $arglist_current38;
       $1057 = ((0) + 4|0);
       $expanded155 = $1057;
       $expanded154 = (($expanded155) - 1)|0;
       $1058 = (($1056) + ($expanded154))|0;
       $1059 = ((0) + 4|0);
       $expanded159 = $1059;
       $expanded158 = (($expanded159) - 1)|0;
       $expanded157 = $expanded158 ^ -1;
       $1060 = $1058 & $expanded157;
       $1061 = $1060;
       $1062 = HEAP32[$1061>>2]|0;
       $arglist_next39 = ((($1061)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next39;
       $1063 = ($1062|0)<(0);
       $1064 = $1063 << 31 >> 31;
       $1065 = $1047;
       $1066 = $1065;
       HEAP32[$1066>>2] = $1062;
       $1067 = (($1065) + 4)|0;
       $1068 = $1067;
       HEAP32[$1068>>2] = $1064;
       break L522;
       break;
      }
      case 11:  {
       $arglist_current41 = HEAP32[$ap>>2]|0;
       $1069 = $arglist_current41;
       $1070 = ((0) + 4|0);
       $expanded162 = $1070;
       $expanded161 = (($expanded162) - 1)|0;
       $1071 = (($1069) + ($expanded161))|0;
       $1072 = ((0) + 4|0);
       $expanded166 = $1072;
       $expanded165 = (($expanded166) - 1)|0;
       $expanded164 = $expanded165 ^ -1;
       $1073 = $1071 & $expanded164;
       $1074 = $1073;
       $1075 = HEAP32[$1074>>2]|0;
       $arglist_next42 = ((($1074)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next42;
       $1076 = $1047;
       $1077 = $1076;
       HEAP32[$1077>>2] = $1075;
       $1078 = (($1076) + 4)|0;
       $1079 = $1078;
       HEAP32[$1079>>2] = 0;
       break L522;
       break;
      }
      case 12:  {
       $arglist_current44 = HEAP32[$ap>>2]|0;
       $1080 = $arglist_current44;
       $1081 = ((0) + 8|0);
       $expanded169 = $1081;
       $expanded168 = (($expanded169) - 1)|0;
       $1082 = (($1080) + ($expanded168))|0;
       $1083 = ((0) + 8|0);
       $expanded173 = $1083;
       $expanded172 = (($expanded173) - 1)|0;
       $expanded171 = $expanded172 ^ -1;
       $1084 = $1082 & $expanded171;
       $1085 = $1084;
       $1086 = $1085;
       $1087 = $1086;
       $1088 = HEAP32[$1087>>2]|0;
       $1089 = (($1086) + 4)|0;
       $1090 = $1089;
       $1091 = HEAP32[$1090>>2]|0;
       $arglist_next45 = ((($1085)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next45;
       $1092 = $1047;
       $1093 = $1092;
       HEAP32[$1093>>2] = $1088;
       $1094 = (($1092) + 4)|0;
       $1095 = $1094;
       HEAP32[$1095>>2] = $1091;
       break L522;
       break;
      }
      case 13:  {
       $arglist_current47 = HEAP32[$ap>>2]|0;
       $1096 = $arglist_current47;
       $1097 = ((0) + 4|0);
       $expanded176 = $1097;
       $expanded175 = (($expanded176) - 1)|0;
       $1098 = (($1096) + ($expanded175))|0;
       $1099 = ((0) + 4|0);
       $expanded180 = $1099;
       $expanded179 = (($expanded180) - 1)|0;
       $expanded178 = $expanded179 ^ -1;
       $1100 = $1098 & $expanded178;
       $1101 = $1100;
       $1102 = HEAP32[$1101>>2]|0;
       $arglist_next48 = ((($1101)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next48;
       $1103 = $1102&65535;
       $1104 = $1103 << 16 >> 16;
       $1105 = ($1104|0)<(0);
       $1106 = $1105 << 31 >> 31;
       $1107 = $1047;
       $1108 = $1107;
       HEAP32[$1108>>2] = $1104;
       $1109 = (($1107) + 4)|0;
       $1110 = $1109;
       HEAP32[$1110>>2] = $1106;
       break L522;
       break;
      }
      case 14:  {
       $arglist_current50 = HEAP32[$ap>>2]|0;
       $1111 = $arglist_current50;
       $1112 = ((0) + 4|0);
       $expanded183 = $1112;
       $expanded182 = (($expanded183) - 1)|0;
       $1113 = (($1111) + ($expanded182))|0;
       $1114 = ((0) + 4|0);
       $expanded187 = $1114;
       $expanded186 = (($expanded187) - 1)|0;
       $expanded185 = $expanded186 ^ -1;
       $1115 = $1113 & $expanded185;
       $1116 = $1115;
       $1117 = HEAP32[$1116>>2]|0;
       $arglist_next51 = ((($1116)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next51;
       $$mask1$i = $1117 & 65535;
       $1118 = $1047;
       $1119 = $1118;
       HEAP32[$1119>>2] = $$mask1$i;
       $1120 = (($1118) + 4)|0;
       $1121 = $1120;
       HEAP32[$1121>>2] = 0;
       break L522;
       break;
      }
      case 15:  {
       $arglist_current53 = HEAP32[$ap>>2]|0;
       $1122 = $arglist_current53;
       $1123 = ((0) + 4|0);
       $expanded190 = $1123;
       $expanded189 = (($expanded190) - 1)|0;
       $1124 = (($1122) + ($expanded189))|0;
       $1125 = ((0) + 4|0);
       $expanded194 = $1125;
       $expanded193 = (($expanded194) - 1)|0;
       $expanded192 = $expanded193 ^ -1;
       $1126 = $1124 & $expanded192;
       $1127 = $1126;
       $1128 = HEAP32[$1127>>2]|0;
       $arglist_next54 = ((($1127)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next54;
       $1129 = $1128&255;
       $1130 = $1129 << 24 >> 24;
       $1131 = ($1130|0)<(0);
       $1132 = $1131 << 31 >> 31;
       $1133 = $1047;
       $1134 = $1133;
       HEAP32[$1134>>2] = $1130;
       $1135 = (($1133) + 4)|0;
       $1136 = $1135;
       HEAP32[$1136>>2] = $1132;
       break L522;
       break;
      }
      case 16:  {
       $arglist_current56 = HEAP32[$ap>>2]|0;
       $1137 = $arglist_current56;
       $1138 = ((0) + 4|0);
       $expanded197 = $1138;
       $expanded196 = (($expanded197) - 1)|0;
       $1139 = (($1137) + ($expanded196))|0;
       $1140 = ((0) + 4|0);
       $expanded201 = $1140;
       $expanded200 = (($expanded201) - 1)|0;
       $expanded199 = $expanded200 ^ -1;
       $1141 = $1139 & $expanded199;
       $1142 = $1141;
       $1143 = HEAP32[$1142>>2]|0;
       $arglist_next57 = ((($1142)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next57;
       $$mask$i = $1143 & 255;
       $1144 = $1047;
       $1145 = $1144;
       HEAP32[$1145>>2] = $$mask$i;
       $1146 = (($1144) + 4)|0;
       $1147 = $1146;
       HEAP32[$1147>>2] = 0;
       break L522;
       break;
      }
      case 17:  {
       $arglist_current59 = HEAP32[$ap>>2]|0;
       $1148 = $arglist_current59;
       $1149 = ((0) + 8|0);
       $expanded204 = $1149;
       $expanded203 = (($expanded204) - 1)|0;
       $1150 = (($1148) + ($expanded203))|0;
       $1151 = ((0) + 8|0);
       $expanded208 = $1151;
       $expanded207 = (($expanded208) - 1)|0;
       $expanded206 = $expanded207 ^ -1;
       $1152 = $1150 & $expanded206;
       $1153 = $1152;
       $1154 = +HEAPF64[$1153>>3];
       $arglist_next60 = ((($1153)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next60;
       HEAPF64[$1047>>3] = $1154;
       break L522;
       break;
      }
      case 18:  {
       $arglist_current62 = HEAP32[$ap>>2]|0;
       $1155 = $arglist_current62;
       $1156 = ((0) + 8|0);
       $expanded211 = $1156;
       $expanded210 = (($expanded211) - 1)|0;
       $1157 = (($1155) + ($expanded210))|0;
       $1158 = ((0) + 8|0);
       $expanded215 = $1158;
       $expanded214 = (($expanded215) - 1)|0;
       $expanded213 = $expanded214 ^ -1;
       $1159 = $1157 & $expanded213;
       $1160 = $1159;
       $1161 = +HEAPF64[$1160>>3];
       $arglist_next63 = ((($1160)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next63;
       HEAPF64[$1047>>3] = $1161;
       break L522;
       break;
      }
      default: {
       break L522;
      }
      }
     } while(0);
    }
   } while(0);
   $1162 = (($i$2162) + 1)|0;
   $1163 = ($1162|0)<(10);
   if ($1163) {
    $i$2162 = $1162;
   } else {
    $$0 = 1;
    label = 363;
    break;
   }
  }
  if ((label|0) == 363) {
   STACKTOP = sp;return ($$0|0);
  }
  $1046 = ($i$2162$lcssa|0)<(10);
  if ($1046) {
   $i$3160 = $i$2162$lcssa;
  } else {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  while(1) {
   $1166 = (($nl_type) + ($i$3160<<2)|0);
   $1167 = HEAP32[$1166>>2]|0;
   $1168 = ($1167|0)==(0);
   $1165 = (($i$3160) + 1)|0;
   if (!($1168)) {
    $$0 = -1;
    label = 363;
    break;
   }
   $1164 = ($1165|0)<(10);
   if ($1164) {
    $i$3160 = $1165;
   } else {
    $$0 = 1;
    label = 363;
    break;
   }
  }
  if ((label|0) == 363) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 363) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _sn_write($f,$s,$l) {
 $f = $f|0;
 $s = $s|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($f)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = ($6>>>0)>($l>>>0);
 $l$ = $7 ? $l : $6;
 _memcpy(($3|0),($s|0),($l$|0))|0;
 $8 = HEAP32[$2>>2]|0;
 $9 = (($8) + ($l$)|0);
 HEAP32[$2>>2] = $9;
 return ($l|0);
}
function _malloc($bytes) {
 $bytes = $bytes|0;
 var $$3$i = 0, $$lcssa = 0, $$lcssa211 = 0, $$lcssa215 = 0, $$lcssa216 = 0, $$lcssa217 = 0, $$lcssa219 = 0, $$lcssa222 = 0, $$lcssa224 = 0, $$lcssa226 = 0, $$lcssa228 = 0, $$lcssa230 = 0, $$lcssa232 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i22$i = 0, $$pre$i25 = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi$i23$iZ2D = 0;
 var $$pre$phi$i26Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phi58$i$iZ2D = 0, $$pre$phiZ2D = 0, $$pre105 = 0, $$pre106 = 0, $$pre14$i$i = 0, $$pre43$i = 0, $$pre56$i$i = 0, $$pre57$i$i = 0, $$pre8$i = 0, $$rsize$0$i = 0, $$rsize$3$i = 0, $$sum = 0, $$sum$i$i = 0, $$sum$i$i$i = 0, $$sum$i13$i = 0, $$sum$i14$i = 0, $$sum$i17$i = 0, $$sum$i19$i = 0;
 var $$sum$i2334 = 0, $$sum$i32 = 0, $$sum$i35 = 0, $$sum1 = 0, $$sum1$i = 0, $$sum1$i$i = 0, $$sum1$i15$i = 0, $$sum1$i20$i = 0, $$sum1$i24 = 0, $$sum10 = 0, $$sum10$i = 0, $$sum10$i$i = 0, $$sum11$i = 0, $$sum11$i$i = 0, $$sum1112 = 0, $$sum112$i = 0, $$sum113$i = 0, $$sum114$i = 0, $$sum115$i = 0, $$sum116$i = 0;
 var $$sum117$i = 0, $$sum118$i = 0, $$sum119$i = 0, $$sum12$i = 0, $$sum12$i$i = 0, $$sum120$i = 0, $$sum121$i = 0, $$sum122$i = 0, $$sum123$i = 0, $$sum124$i = 0, $$sum125$i = 0, $$sum13$i = 0, $$sum13$i$i = 0, $$sum14$i$i = 0, $$sum15$i = 0, $$sum15$i$i = 0, $$sum16$i = 0, $$sum16$i$i = 0, $$sum17$i = 0, $$sum17$i$i = 0;
 var $$sum18$i = 0, $$sum1819$i$i = 0, $$sum2 = 0, $$sum2$i = 0, $$sum2$i$i = 0, $$sum2$i$i$i = 0, $$sum2$i16$i = 0, $$sum2$i18$i = 0, $$sum2$i21$i = 0, $$sum20$i$i = 0, $$sum21$i$i = 0, $$sum22$i$i = 0, $$sum23$i$i = 0, $$sum24$i$i = 0, $$sum25$i$i = 0, $$sum27$i$i = 0, $$sum28$i$i = 0, $$sum29$i$i = 0, $$sum3$i = 0, $$sum3$i27 = 0;
 var $$sum30$i$i = 0, $$sum3132$i$i = 0, $$sum34$i$i = 0, $$sum3536$i$i = 0, $$sum3738$i$i = 0, $$sum39$i$i = 0, $$sum4 = 0, $$sum4$i = 0, $$sum4$i$i = 0, $$sum4$i28 = 0, $$sum40$i$i = 0, $$sum41$i$i = 0, $$sum42$i$i = 0, $$sum5$i = 0, $$sum5$i$i = 0, $$sum56 = 0, $$sum6$i = 0, $$sum67$i$i = 0, $$sum7$i = 0, $$sum8$i = 0;
 var $$sum9 = 0, $$sum9$i = 0, $$sum9$i$i = 0, $$tsize$1$i = 0, $$v$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0;
 var $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0;
 var $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0;
 var $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0;
 var $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0;
 var $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0;
 var $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0;
 var $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0;
 var $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0;
 var $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0;
 var $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0;
 var $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0;
 var $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0;
 var $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0;
 var $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0;
 var $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0;
 var $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0;
 var $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0;
 var $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0;
 var $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0;
 var $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0;
 var $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0;
 var $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0;
 var $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0;
 var $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $F$0$i$i = 0, $F1$0$i = 0, $F4$0 = 0, $F4$0$i$i = 0;
 var $F5$0$i = 0, $I1$0$i$i = 0, $I7$0$i = 0, $I7$0$i$i = 0, $K12$029$i = 0, $K2$07$i$i = 0, $K8$051$i$i = 0, $R$0$i = 0, $R$0$i$i = 0, $R$0$i$i$lcssa = 0, $R$0$i$lcssa = 0, $R$0$i18 = 0, $R$0$i18$lcssa = 0, $R$1$i = 0, $R$1$i$i = 0, $R$1$i20 = 0, $RP$0$i = 0, $RP$0$i$i = 0, $RP$0$i$i$lcssa = 0, $RP$0$i$lcssa = 0;
 var $RP$0$i17 = 0, $RP$0$i17$lcssa = 0, $T$0$lcssa$i = 0, $T$0$lcssa$i$i = 0, $T$0$lcssa$i25$i = 0, $T$028$i = 0, $T$028$i$lcssa = 0, $T$050$i$i = 0, $T$050$i$i$lcssa = 0, $T$06$i$i = 0, $T$06$i$i$lcssa = 0, $br$0$ph$i = 0, $cond$i = 0, $cond$i$i = 0, $cond$i21 = 0, $exitcond$i$i = 0, $i$02$i$i = 0, $idx$0$i = 0, $mem$0 = 0, $nb$0 = 0;
 var $not$$i = 0, $not$$i$i = 0, $not$$i26$i = 0, $oldfirst$0$i$i = 0, $or$cond$i = 0, $or$cond$i30 = 0, $or$cond1$i = 0, $or$cond19$i = 0, $or$cond2$i = 0, $or$cond3$i = 0, $or$cond5$i = 0, $or$cond57$i = 0, $or$cond6$i = 0, $or$cond8$i = 0, $or$cond9$i = 0, $qsize$0$i$i = 0, $rsize$0$i = 0, $rsize$0$i$lcssa = 0, $rsize$0$i15 = 0, $rsize$1$i = 0;
 var $rsize$2$i = 0, $rsize$3$lcssa$i = 0, $rsize$331$i = 0, $rst$0$i = 0, $rst$1$i = 0, $sizebits$0$i = 0, $sp$0$i$i = 0, $sp$0$i$i$i = 0, $sp$084$i = 0, $sp$084$i$lcssa = 0, $sp$183$i = 0, $sp$183$i$lcssa = 0, $ssize$0$$i = 0, $ssize$0$i = 0, $ssize$1$ph$i = 0, $ssize$2$i = 0, $t$0$i = 0, $t$0$i14 = 0, $t$1$i = 0, $t$2$ph$i = 0;
 var $t$2$v$3$i = 0, $t$230$i = 0, $tbase$255$i = 0, $tsize$0$ph$i = 0, $tsize$0323944$i = 0, $tsize$1$i = 0, $tsize$254$i = 0, $v$0$i = 0, $v$0$i$lcssa = 0, $v$0$i16 = 0, $v$1$i = 0, $v$2$i = 0, $v$3$lcssa$i = 0, $v$3$ph$i = 0, $v$332$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($bytes>>>0)<(245);
 do {
  if ($0) {
   $1 = ($bytes>>>0)<(11);
   $2 = (($bytes) + 11)|0;
   $3 = $2 & -8;
   $4 = $1 ? 16 : $3;
   $5 = $4 >>> 3;
   $6 = HEAP32[6944>>2]|0;
   $7 = $6 >>> $5;
   $8 = $7 & 3;
   $9 = ($8|0)==(0);
   if (!($9)) {
    $10 = $7 & 1;
    $11 = $10 ^ 1;
    $12 = (($11) + ($5))|0;
    $13 = $12 << 1;
    $14 = (6984 + ($13<<2)|0);
    $$sum10 = (($13) + 2)|0;
    $15 = (6984 + ($$sum10<<2)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($14|0)==($18|0);
    do {
     if ($19) {
      $20 = 1 << $12;
      $21 = $20 ^ -1;
      $22 = $6 & $21;
      HEAP32[6944>>2] = $22;
     } else {
      $23 = HEAP32[(6960)>>2]|0;
      $24 = ($18>>>0)<($23>>>0);
      if ($24) {
       _abort();
       // unreachable;
      }
      $25 = ((($18)) + 12|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26|0)==($16|0);
      if ($27) {
       HEAP32[$25>>2] = $14;
       HEAP32[$15>>2] = $18;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $28 = $12 << 3;
    $29 = $28 | 3;
    $30 = ((($16)) + 4|0);
    HEAP32[$30>>2] = $29;
    $$sum1112 = $28 | 4;
    $31 = (($16) + ($$sum1112)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = $32 | 1;
    HEAP32[$31>>2] = $33;
    $mem$0 = $17;
    return ($mem$0|0);
   }
   $34 = HEAP32[(6952)>>2]|0;
   $35 = ($4>>>0)>($34>>>0);
   if ($35) {
    $36 = ($7|0)==(0);
    if (!($36)) {
     $37 = $7 << $5;
     $38 = 2 << $5;
     $39 = (0 - ($38))|0;
     $40 = $38 | $39;
     $41 = $37 & $40;
     $42 = (0 - ($41))|0;
     $43 = $41 & $42;
     $44 = (($43) + -1)|0;
     $45 = $44 >>> 12;
     $46 = $45 & 16;
     $47 = $44 >>> $46;
     $48 = $47 >>> 5;
     $49 = $48 & 8;
     $50 = $49 | $46;
     $51 = $47 >>> $49;
     $52 = $51 >>> 2;
     $53 = $52 & 4;
     $54 = $50 | $53;
     $55 = $51 >>> $53;
     $56 = $55 >>> 1;
     $57 = $56 & 2;
     $58 = $54 | $57;
     $59 = $55 >>> $57;
     $60 = $59 >>> 1;
     $61 = $60 & 1;
     $62 = $58 | $61;
     $63 = $59 >>> $61;
     $64 = (($62) + ($63))|0;
     $65 = $64 << 1;
     $66 = (6984 + ($65<<2)|0);
     $$sum4 = (($65) + 2)|0;
     $67 = (6984 + ($$sum4<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = ((($68)) + 8|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($66|0)==($70|0);
     do {
      if ($71) {
       $72 = 1 << $64;
       $73 = $72 ^ -1;
       $74 = $6 & $73;
       HEAP32[6944>>2] = $74;
       $89 = $34;
      } else {
       $75 = HEAP32[(6960)>>2]|0;
       $76 = ($70>>>0)<($75>>>0);
       if ($76) {
        _abort();
        // unreachable;
       }
       $77 = ((($70)) + 12|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($78|0)==($68|0);
       if ($79) {
        HEAP32[$77>>2] = $66;
        HEAP32[$67>>2] = $70;
        $$pre = HEAP32[(6952)>>2]|0;
        $89 = $$pre;
        break;
       } else {
        _abort();
        // unreachable;
       }
      }
     } while(0);
     $80 = $64 << 3;
     $81 = (($80) - ($4))|0;
     $82 = $4 | 3;
     $83 = ((($68)) + 4|0);
     HEAP32[$83>>2] = $82;
     $84 = (($68) + ($4)|0);
     $85 = $81 | 1;
     $$sum56 = $4 | 4;
     $86 = (($68) + ($$sum56)|0);
     HEAP32[$86>>2] = $85;
     $87 = (($68) + ($80)|0);
     HEAP32[$87>>2] = $81;
     $88 = ($89|0)==(0);
     if (!($88)) {
      $90 = HEAP32[(6964)>>2]|0;
      $91 = $89 >>> 3;
      $92 = $91 << 1;
      $93 = (6984 + ($92<<2)|0);
      $94 = HEAP32[6944>>2]|0;
      $95 = 1 << $91;
      $96 = $94 & $95;
      $97 = ($96|0)==(0);
      if ($97) {
       $98 = $94 | $95;
       HEAP32[6944>>2] = $98;
       $$pre105 = (($92) + 2)|0;
       $$pre106 = (6984 + ($$pre105<<2)|0);
       $$pre$phiZ2D = $$pre106;$F4$0 = $93;
      } else {
       $$sum9 = (($92) + 2)|0;
       $99 = (6984 + ($$sum9<<2)|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = HEAP32[(6960)>>2]|0;
       $102 = ($100>>>0)<($101>>>0);
       if ($102) {
        _abort();
        // unreachable;
       } else {
        $$pre$phiZ2D = $99;$F4$0 = $100;
       }
      }
      HEAP32[$$pre$phiZ2D>>2] = $90;
      $103 = ((($F4$0)) + 12|0);
      HEAP32[$103>>2] = $90;
      $104 = ((($90)) + 8|0);
      HEAP32[$104>>2] = $F4$0;
      $105 = ((($90)) + 12|0);
      HEAP32[$105>>2] = $93;
     }
     HEAP32[(6952)>>2] = $81;
     HEAP32[(6964)>>2] = $84;
     $mem$0 = $69;
     return ($mem$0|0);
    }
    $106 = HEAP32[(6948)>>2]|0;
    $107 = ($106|0)==(0);
    if ($107) {
     $nb$0 = $4;
    } else {
     $108 = (0 - ($106))|0;
     $109 = $106 & $108;
     $110 = (($109) + -1)|0;
     $111 = $110 >>> 12;
     $112 = $111 & 16;
     $113 = $110 >>> $112;
     $114 = $113 >>> 5;
     $115 = $114 & 8;
     $116 = $115 | $112;
     $117 = $113 >>> $115;
     $118 = $117 >>> 2;
     $119 = $118 & 4;
     $120 = $116 | $119;
     $121 = $117 >>> $119;
     $122 = $121 >>> 1;
     $123 = $122 & 2;
     $124 = $120 | $123;
     $125 = $121 >>> $123;
     $126 = $125 >>> 1;
     $127 = $126 & 1;
     $128 = $124 | $127;
     $129 = $125 >>> $127;
     $130 = (($128) + ($129))|0;
     $131 = (7248 + ($130<<2)|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ((($132)) + 4|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = $134 & -8;
     $136 = (($135) - ($4))|0;
     $rsize$0$i = $136;$t$0$i = $132;$v$0$i = $132;
     while(1) {
      $137 = ((($t$0$i)) + 16|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = ($138|0)==(0|0);
      if ($139) {
       $140 = ((($t$0$i)) + 20|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = ($141|0)==(0|0);
       if ($142) {
        $rsize$0$i$lcssa = $rsize$0$i;$v$0$i$lcssa = $v$0$i;
        break;
       } else {
        $144 = $141;
       }
      } else {
       $144 = $138;
      }
      $143 = ((($144)) + 4|0);
      $145 = HEAP32[$143>>2]|0;
      $146 = $145 & -8;
      $147 = (($146) - ($4))|0;
      $148 = ($147>>>0)<($rsize$0$i>>>0);
      $$rsize$0$i = $148 ? $147 : $rsize$0$i;
      $$v$0$i = $148 ? $144 : $v$0$i;
      $rsize$0$i = $$rsize$0$i;$t$0$i = $144;$v$0$i = $$v$0$i;
     }
     $149 = HEAP32[(6960)>>2]|0;
     $150 = ($v$0$i$lcssa>>>0)<($149>>>0);
     if ($150) {
      _abort();
      // unreachable;
     }
     $151 = (($v$0$i$lcssa) + ($4)|0);
     $152 = ($v$0$i$lcssa>>>0)<($151>>>0);
     if (!($152)) {
      _abort();
      // unreachable;
     }
     $153 = ((($v$0$i$lcssa)) + 24|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = ((($v$0$i$lcssa)) + 12|0);
     $156 = HEAP32[$155>>2]|0;
     $157 = ($156|0)==($v$0$i$lcssa|0);
     do {
      if ($157) {
       $167 = ((($v$0$i$lcssa)) + 20|0);
       $168 = HEAP32[$167>>2]|0;
       $169 = ($168|0)==(0|0);
       if ($169) {
        $170 = ((($v$0$i$lcssa)) + 16|0);
        $171 = HEAP32[$170>>2]|0;
        $172 = ($171|0)==(0|0);
        if ($172) {
         $R$1$i = 0;
         break;
        } else {
         $R$0$i = $171;$RP$0$i = $170;
        }
       } else {
        $R$0$i = $168;$RP$0$i = $167;
       }
       while(1) {
        $173 = ((($R$0$i)) + 20|0);
        $174 = HEAP32[$173>>2]|0;
        $175 = ($174|0)==(0|0);
        if (!($175)) {
         $R$0$i = $174;$RP$0$i = $173;
         continue;
        }
        $176 = ((($R$0$i)) + 16|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = ($177|0)==(0|0);
        if ($178) {
         $R$0$i$lcssa = $R$0$i;$RP$0$i$lcssa = $RP$0$i;
         break;
        } else {
         $R$0$i = $177;$RP$0$i = $176;
        }
       }
       $179 = ($RP$0$i$lcssa>>>0)<($149>>>0);
       if ($179) {
        _abort();
        // unreachable;
       } else {
        HEAP32[$RP$0$i$lcssa>>2] = 0;
        $R$1$i = $R$0$i$lcssa;
        break;
       }
      } else {
       $158 = ((($v$0$i$lcssa)) + 8|0);
       $159 = HEAP32[$158>>2]|0;
       $160 = ($159>>>0)<($149>>>0);
       if ($160) {
        _abort();
        // unreachable;
       }
       $161 = ((($159)) + 12|0);
       $162 = HEAP32[$161>>2]|0;
       $163 = ($162|0)==($v$0$i$lcssa|0);
       if (!($163)) {
        _abort();
        // unreachable;
       }
       $164 = ((($156)) + 8|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = ($165|0)==($v$0$i$lcssa|0);
       if ($166) {
        HEAP32[$161>>2] = $156;
        HEAP32[$164>>2] = $159;
        $R$1$i = $156;
        break;
       } else {
        _abort();
        // unreachable;
       }
      }
     } while(0);
     $180 = ($154|0)==(0|0);
     do {
      if (!($180)) {
       $181 = ((($v$0$i$lcssa)) + 28|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = (7248 + ($182<<2)|0);
       $184 = HEAP32[$183>>2]|0;
       $185 = ($v$0$i$lcssa|0)==($184|0);
       if ($185) {
        HEAP32[$183>>2] = $R$1$i;
        $cond$i = ($R$1$i|0)==(0|0);
        if ($cond$i) {
         $186 = 1 << $182;
         $187 = $186 ^ -1;
         $188 = HEAP32[(6948)>>2]|0;
         $189 = $188 & $187;
         HEAP32[(6948)>>2] = $189;
         break;
        }
       } else {
        $190 = HEAP32[(6960)>>2]|0;
        $191 = ($154>>>0)<($190>>>0);
        if ($191) {
         _abort();
         // unreachable;
        }
        $192 = ((($154)) + 16|0);
        $193 = HEAP32[$192>>2]|0;
        $194 = ($193|0)==($v$0$i$lcssa|0);
        if ($194) {
         HEAP32[$192>>2] = $R$1$i;
        } else {
         $195 = ((($154)) + 20|0);
         HEAP32[$195>>2] = $R$1$i;
        }
        $196 = ($R$1$i|0)==(0|0);
        if ($196) {
         break;
        }
       }
       $197 = HEAP32[(6960)>>2]|0;
       $198 = ($R$1$i>>>0)<($197>>>0);
       if ($198) {
        _abort();
        // unreachable;
       }
       $199 = ((($R$1$i)) + 24|0);
       HEAP32[$199>>2] = $154;
       $200 = ((($v$0$i$lcssa)) + 16|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ($201|0)==(0|0);
       do {
        if (!($202)) {
         $203 = ($201>>>0)<($197>>>0);
         if ($203) {
          _abort();
          // unreachable;
         } else {
          $204 = ((($R$1$i)) + 16|0);
          HEAP32[$204>>2] = $201;
          $205 = ((($201)) + 24|0);
          HEAP32[$205>>2] = $R$1$i;
          break;
         }
        }
       } while(0);
       $206 = ((($v$0$i$lcssa)) + 20|0);
       $207 = HEAP32[$206>>2]|0;
       $208 = ($207|0)==(0|0);
       if (!($208)) {
        $209 = HEAP32[(6960)>>2]|0;
        $210 = ($207>>>0)<($209>>>0);
        if ($210) {
         _abort();
         // unreachable;
        } else {
         $211 = ((($R$1$i)) + 20|0);
         HEAP32[$211>>2] = $207;
         $212 = ((($207)) + 24|0);
         HEAP32[$212>>2] = $R$1$i;
         break;
        }
       }
      }
     } while(0);
     $213 = ($rsize$0$i$lcssa>>>0)<(16);
     if ($213) {
      $214 = (($rsize$0$i$lcssa) + ($4))|0;
      $215 = $214 | 3;
      $216 = ((($v$0$i$lcssa)) + 4|0);
      HEAP32[$216>>2] = $215;
      $$sum4$i = (($214) + 4)|0;
      $217 = (($v$0$i$lcssa) + ($$sum4$i)|0);
      $218 = HEAP32[$217>>2]|0;
      $219 = $218 | 1;
      HEAP32[$217>>2] = $219;
     } else {
      $220 = $4 | 3;
      $221 = ((($v$0$i$lcssa)) + 4|0);
      HEAP32[$221>>2] = $220;
      $222 = $rsize$0$i$lcssa | 1;
      $$sum$i35 = $4 | 4;
      $223 = (($v$0$i$lcssa) + ($$sum$i35)|0);
      HEAP32[$223>>2] = $222;
      $$sum1$i = (($rsize$0$i$lcssa) + ($4))|0;
      $224 = (($v$0$i$lcssa) + ($$sum1$i)|0);
      HEAP32[$224>>2] = $rsize$0$i$lcssa;
      $225 = HEAP32[(6952)>>2]|0;
      $226 = ($225|0)==(0);
      if (!($226)) {
       $227 = HEAP32[(6964)>>2]|0;
       $228 = $225 >>> 3;
       $229 = $228 << 1;
       $230 = (6984 + ($229<<2)|0);
       $231 = HEAP32[6944>>2]|0;
       $232 = 1 << $228;
       $233 = $231 & $232;
       $234 = ($233|0)==(0);
       if ($234) {
        $235 = $231 | $232;
        HEAP32[6944>>2] = $235;
        $$pre$i = (($229) + 2)|0;
        $$pre8$i = (6984 + ($$pre$i<<2)|0);
        $$pre$phi$iZ2D = $$pre8$i;$F1$0$i = $230;
       } else {
        $$sum3$i = (($229) + 2)|0;
        $236 = (6984 + ($$sum3$i<<2)|0);
        $237 = HEAP32[$236>>2]|0;
        $238 = HEAP32[(6960)>>2]|0;
        $239 = ($237>>>0)<($238>>>0);
        if ($239) {
         _abort();
         // unreachable;
        } else {
         $$pre$phi$iZ2D = $236;$F1$0$i = $237;
        }
       }
       HEAP32[$$pre$phi$iZ2D>>2] = $227;
       $240 = ((($F1$0$i)) + 12|0);
       HEAP32[$240>>2] = $227;
       $241 = ((($227)) + 8|0);
       HEAP32[$241>>2] = $F1$0$i;
       $242 = ((($227)) + 12|0);
       HEAP32[$242>>2] = $230;
      }
      HEAP32[(6952)>>2] = $rsize$0$i$lcssa;
      HEAP32[(6964)>>2] = $151;
     }
     $243 = ((($v$0$i$lcssa)) + 8|0);
     $mem$0 = $243;
     return ($mem$0|0);
    }
   } else {
    $nb$0 = $4;
   }
  } else {
   $244 = ($bytes>>>0)>(4294967231);
   if ($244) {
    $nb$0 = -1;
   } else {
    $245 = (($bytes) + 11)|0;
    $246 = $245 & -8;
    $247 = HEAP32[(6948)>>2]|0;
    $248 = ($247|0)==(0);
    if ($248) {
     $nb$0 = $246;
    } else {
     $249 = (0 - ($246))|0;
     $250 = $245 >>> 8;
     $251 = ($250|0)==(0);
     if ($251) {
      $idx$0$i = 0;
     } else {
      $252 = ($246>>>0)>(16777215);
      if ($252) {
       $idx$0$i = 31;
      } else {
       $253 = (($250) + 1048320)|0;
       $254 = $253 >>> 16;
       $255 = $254 & 8;
       $256 = $250 << $255;
       $257 = (($256) + 520192)|0;
       $258 = $257 >>> 16;
       $259 = $258 & 4;
       $260 = $259 | $255;
       $261 = $256 << $259;
       $262 = (($261) + 245760)|0;
       $263 = $262 >>> 16;
       $264 = $263 & 2;
       $265 = $260 | $264;
       $266 = (14 - ($265))|0;
       $267 = $261 << $264;
       $268 = $267 >>> 15;
       $269 = (($266) + ($268))|0;
       $270 = $269 << 1;
       $271 = (($269) + 7)|0;
       $272 = $246 >>> $271;
       $273 = $272 & 1;
       $274 = $273 | $270;
       $idx$0$i = $274;
      }
     }
     $275 = (7248 + ($idx$0$i<<2)|0);
     $276 = HEAP32[$275>>2]|0;
     $277 = ($276|0)==(0|0);
     L9: do {
      if ($277) {
       $rsize$2$i = $249;$t$1$i = 0;$v$2$i = 0;
       label = 86;
      } else {
       $278 = ($idx$0$i|0)==(31);
       $279 = $idx$0$i >>> 1;
       $280 = (25 - ($279))|0;
       $281 = $278 ? 0 : $280;
       $282 = $246 << $281;
       $rsize$0$i15 = $249;$rst$0$i = 0;$sizebits$0$i = $282;$t$0$i14 = $276;$v$0$i16 = 0;
       while(1) {
        $283 = ((($t$0$i14)) + 4|0);
        $284 = HEAP32[$283>>2]|0;
        $285 = $284 & -8;
        $286 = (($285) - ($246))|0;
        $287 = ($286>>>0)<($rsize$0$i15>>>0);
        if ($287) {
         $288 = ($285|0)==($246|0);
         if ($288) {
          $rsize$331$i = $286;$t$230$i = $t$0$i14;$v$332$i = $t$0$i14;
          label = 90;
          break L9;
         } else {
          $rsize$1$i = $286;$v$1$i = $t$0$i14;
         }
        } else {
         $rsize$1$i = $rsize$0$i15;$v$1$i = $v$0$i16;
        }
        $289 = ((($t$0$i14)) + 20|0);
        $290 = HEAP32[$289>>2]|0;
        $291 = $sizebits$0$i >>> 31;
        $292 = (((($t$0$i14)) + 16|0) + ($291<<2)|0);
        $293 = HEAP32[$292>>2]|0;
        $294 = ($290|0)==(0|0);
        $295 = ($290|0)==($293|0);
        $or$cond19$i = $294 | $295;
        $rst$1$i = $or$cond19$i ? $rst$0$i : $290;
        $296 = ($293|0)==(0|0);
        $297 = $sizebits$0$i << 1;
        if ($296) {
         $rsize$2$i = $rsize$1$i;$t$1$i = $rst$1$i;$v$2$i = $v$1$i;
         label = 86;
         break;
        } else {
         $rsize$0$i15 = $rsize$1$i;$rst$0$i = $rst$1$i;$sizebits$0$i = $297;$t$0$i14 = $293;$v$0$i16 = $v$1$i;
        }
       }
      }
     } while(0);
     if ((label|0) == 86) {
      $298 = ($t$1$i|0)==(0|0);
      $299 = ($v$2$i|0)==(0|0);
      $or$cond$i = $298 & $299;
      if ($or$cond$i) {
       $300 = 2 << $idx$0$i;
       $301 = (0 - ($300))|0;
       $302 = $300 | $301;
       $303 = $247 & $302;
       $304 = ($303|0)==(0);
       if ($304) {
        $nb$0 = $246;
        break;
       }
       $305 = (0 - ($303))|0;
       $306 = $303 & $305;
       $307 = (($306) + -1)|0;
       $308 = $307 >>> 12;
       $309 = $308 & 16;
       $310 = $307 >>> $309;
       $311 = $310 >>> 5;
       $312 = $311 & 8;
       $313 = $312 | $309;
       $314 = $310 >>> $312;
       $315 = $314 >>> 2;
       $316 = $315 & 4;
       $317 = $313 | $316;
       $318 = $314 >>> $316;
       $319 = $318 >>> 1;
       $320 = $319 & 2;
       $321 = $317 | $320;
       $322 = $318 >>> $320;
       $323 = $322 >>> 1;
       $324 = $323 & 1;
       $325 = $321 | $324;
       $326 = $322 >>> $324;
       $327 = (($325) + ($326))|0;
       $328 = (7248 + ($327<<2)|0);
       $329 = HEAP32[$328>>2]|0;
       $t$2$ph$i = $329;$v$3$ph$i = 0;
      } else {
       $t$2$ph$i = $t$1$i;$v$3$ph$i = $v$2$i;
      }
      $330 = ($t$2$ph$i|0)==(0|0);
      if ($330) {
       $rsize$3$lcssa$i = $rsize$2$i;$v$3$lcssa$i = $v$3$ph$i;
      } else {
       $rsize$331$i = $rsize$2$i;$t$230$i = $t$2$ph$i;$v$332$i = $v$3$ph$i;
       label = 90;
      }
     }
     if ((label|0) == 90) {
      while(1) {
       label = 0;
       $331 = ((($t$230$i)) + 4|0);
       $332 = HEAP32[$331>>2]|0;
       $333 = $332 & -8;
       $334 = (($333) - ($246))|0;
       $335 = ($334>>>0)<($rsize$331$i>>>0);
       $$rsize$3$i = $335 ? $334 : $rsize$331$i;
       $t$2$v$3$i = $335 ? $t$230$i : $v$332$i;
       $336 = ((($t$230$i)) + 16|0);
       $337 = HEAP32[$336>>2]|0;
       $338 = ($337|0)==(0|0);
       if (!($338)) {
        $rsize$331$i = $$rsize$3$i;$t$230$i = $337;$v$332$i = $t$2$v$3$i;
        label = 90;
        continue;
       }
       $339 = ((($t$230$i)) + 20|0);
       $340 = HEAP32[$339>>2]|0;
       $341 = ($340|0)==(0|0);
       if ($341) {
        $rsize$3$lcssa$i = $$rsize$3$i;$v$3$lcssa$i = $t$2$v$3$i;
        break;
       } else {
        $rsize$331$i = $$rsize$3$i;$t$230$i = $340;$v$332$i = $t$2$v$3$i;
        label = 90;
       }
      }
     }
     $342 = ($v$3$lcssa$i|0)==(0|0);
     if ($342) {
      $nb$0 = $246;
     } else {
      $343 = HEAP32[(6952)>>2]|0;
      $344 = (($343) - ($246))|0;
      $345 = ($rsize$3$lcssa$i>>>0)<($344>>>0);
      if ($345) {
       $346 = HEAP32[(6960)>>2]|0;
       $347 = ($v$3$lcssa$i>>>0)<($346>>>0);
       if ($347) {
        _abort();
        // unreachable;
       }
       $348 = (($v$3$lcssa$i) + ($246)|0);
       $349 = ($v$3$lcssa$i>>>0)<($348>>>0);
       if (!($349)) {
        _abort();
        // unreachable;
       }
       $350 = ((($v$3$lcssa$i)) + 24|0);
       $351 = HEAP32[$350>>2]|0;
       $352 = ((($v$3$lcssa$i)) + 12|0);
       $353 = HEAP32[$352>>2]|0;
       $354 = ($353|0)==($v$3$lcssa$i|0);
       do {
        if ($354) {
         $364 = ((($v$3$lcssa$i)) + 20|0);
         $365 = HEAP32[$364>>2]|0;
         $366 = ($365|0)==(0|0);
         if ($366) {
          $367 = ((($v$3$lcssa$i)) + 16|0);
          $368 = HEAP32[$367>>2]|0;
          $369 = ($368|0)==(0|0);
          if ($369) {
           $R$1$i20 = 0;
           break;
          } else {
           $R$0$i18 = $368;$RP$0$i17 = $367;
          }
         } else {
          $R$0$i18 = $365;$RP$0$i17 = $364;
         }
         while(1) {
          $370 = ((($R$0$i18)) + 20|0);
          $371 = HEAP32[$370>>2]|0;
          $372 = ($371|0)==(0|0);
          if (!($372)) {
           $R$0$i18 = $371;$RP$0$i17 = $370;
           continue;
          }
          $373 = ((($R$0$i18)) + 16|0);
          $374 = HEAP32[$373>>2]|0;
          $375 = ($374|0)==(0|0);
          if ($375) {
           $R$0$i18$lcssa = $R$0$i18;$RP$0$i17$lcssa = $RP$0$i17;
           break;
          } else {
           $R$0$i18 = $374;$RP$0$i17 = $373;
          }
         }
         $376 = ($RP$0$i17$lcssa>>>0)<($346>>>0);
         if ($376) {
          _abort();
          // unreachable;
         } else {
          HEAP32[$RP$0$i17$lcssa>>2] = 0;
          $R$1$i20 = $R$0$i18$lcssa;
          break;
         }
        } else {
         $355 = ((($v$3$lcssa$i)) + 8|0);
         $356 = HEAP32[$355>>2]|0;
         $357 = ($356>>>0)<($346>>>0);
         if ($357) {
          _abort();
          // unreachable;
         }
         $358 = ((($356)) + 12|0);
         $359 = HEAP32[$358>>2]|0;
         $360 = ($359|0)==($v$3$lcssa$i|0);
         if (!($360)) {
          _abort();
          // unreachable;
         }
         $361 = ((($353)) + 8|0);
         $362 = HEAP32[$361>>2]|0;
         $363 = ($362|0)==($v$3$lcssa$i|0);
         if ($363) {
          HEAP32[$358>>2] = $353;
          HEAP32[$361>>2] = $356;
          $R$1$i20 = $353;
          break;
         } else {
          _abort();
          // unreachable;
         }
        }
       } while(0);
       $377 = ($351|0)==(0|0);
       do {
        if (!($377)) {
         $378 = ((($v$3$lcssa$i)) + 28|0);
         $379 = HEAP32[$378>>2]|0;
         $380 = (7248 + ($379<<2)|0);
         $381 = HEAP32[$380>>2]|0;
         $382 = ($v$3$lcssa$i|0)==($381|0);
         if ($382) {
          HEAP32[$380>>2] = $R$1$i20;
          $cond$i21 = ($R$1$i20|0)==(0|0);
          if ($cond$i21) {
           $383 = 1 << $379;
           $384 = $383 ^ -1;
           $385 = HEAP32[(6948)>>2]|0;
           $386 = $385 & $384;
           HEAP32[(6948)>>2] = $386;
           break;
          }
         } else {
          $387 = HEAP32[(6960)>>2]|0;
          $388 = ($351>>>0)<($387>>>0);
          if ($388) {
           _abort();
           // unreachable;
          }
          $389 = ((($351)) + 16|0);
          $390 = HEAP32[$389>>2]|0;
          $391 = ($390|0)==($v$3$lcssa$i|0);
          if ($391) {
           HEAP32[$389>>2] = $R$1$i20;
          } else {
           $392 = ((($351)) + 20|0);
           HEAP32[$392>>2] = $R$1$i20;
          }
          $393 = ($R$1$i20|0)==(0|0);
          if ($393) {
           break;
          }
         }
         $394 = HEAP32[(6960)>>2]|0;
         $395 = ($R$1$i20>>>0)<($394>>>0);
         if ($395) {
          _abort();
          // unreachable;
         }
         $396 = ((($R$1$i20)) + 24|0);
         HEAP32[$396>>2] = $351;
         $397 = ((($v$3$lcssa$i)) + 16|0);
         $398 = HEAP32[$397>>2]|0;
         $399 = ($398|0)==(0|0);
         do {
          if (!($399)) {
           $400 = ($398>>>0)<($394>>>0);
           if ($400) {
            _abort();
            // unreachable;
           } else {
            $401 = ((($R$1$i20)) + 16|0);
            HEAP32[$401>>2] = $398;
            $402 = ((($398)) + 24|0);
            HEAP32[$402>>2] = $R$1$i20;
            break;
           }
          }
         } while(0);
         $403 = ((($v$3$lcssa$i)) + 20|0);
         $404 = HEAP32[$403>>2]|0;
         $405 = ($404|0)==(0|0);
         if (!($405)) {
          $406 = HEAP32[(6960)>>2]|0;
          $407 = ($404>>>0)<($406>>>0);
          if ($407) {
           _abort();
           // unreachable;
          } else {
           $408 = ((($R$1$i20)) + 20|0);
           HEAP32[$408>>2] = $404;
           $409 = ((($404)) + 24|0);
           HEAP32[$409>>2] = $R$1$i20;
           break;
          }
         }
        }
       } while(0);
       $410 = ($rsize$3$lcssa$i>>>0)<(16);
       L85: do {
        if ($410) {
         $411 = (($rsize$3$lcssa$i) + ($246))|0;
         $412 = $411 | 3;
         $413 = ((($v$3$lcssa$i)) + 4|0);
         HEAP32[$413>>2] = $412;
         $$sum18$i = (($411) + 4)|0;
         $414 = (($v$3$lcssa$i) + ($$sum18$i)|0);
         $415 = HEAP32[$414>>2]|0;
         $416 = $415 | 1;
         HEAP32[$414>>2] = $416;
        } else {
         $417 = $246 | 3;
         $418 = ((($v$3$lcssa$i)) + 4|0);
         HEAP32[$418>>2] = $417;
         $419 = $rsize$3$lcssa$i | 1;
         $$sum$i2334 = $246 | 4;
         $420 = (($v$3$lcssa$i) + ($$sum$i2334)|0);
         HEAP32[$420>>2] = $419;
         $$sum1$i24 = (($rsize$3$lcssa$i) + ($246))|0;
         $421 = (($v$3$lcssa$i) + ($$sum1$i24)|0);
         HEAP32[$421>>2] = $rsize$3$lcssa$i;
         $422 = $rsize$3$lcssa$i >>> 3;
         $423 = ($rsize$3$lcssa$i>>>0)<(256);
         if ($423) {
          $424 = $422 << 1;
          $425 = (6984 + ($424<<2)|0);
          $426 = HEAP32[6944>>2]|0;
          $427 = 1 << $422;
          $428 = $426 & $427;
          $429 = ($428|0)==(0);
          if ($429) {
           $430 = $426 | $427;
           HEAP32[6944>>2] = $430;
           $$pre$i25 = (($424) + 2)|0;
           $$pre43$i = (6984 + ($$pre$i25<<2)|0);
           $$pre$phi$i26Z2D = $$pre43$i;$F5$0$i = $425;
          } else {
           $$sum17$i = (($424) + 2)|0;
           $431 = (6984 + ($$sum17$i<<2)|0);
           $432 = HEAP32[$431>>2]|0;
           $433 = HEAP32[(6960)>>2]|0;
           $434 = ($432>>>0)<($433>>>0);
           if ($434) {
            _abort();
            // unreachable;
           } else {
            $$pre$phi$i26Z2D = $431;$F5$0$i = $432;
           }
          }
          HEAP32[$$pre$phi$i26Z2D>>2] = $348;
          $435 = ((($F5$0$i)) + 12|0);
          HEAP32[$435>>2] = $348;
          $$sum15$i = (($246) + 8)|0;
          $436 = (($v$3$lcssa$i) + ($$sum15$i)|0);
          HEAP32[$436>>2] = $F5$0$i;
          $$sum16$i = (($246) + 12)|0;
          $437 = (($v$3$lcssa$i) + ($$sum16$i)|0);
          HEAP32[$437>>2] = $425;
          break;
         }
         $438 = $rsize$3$lcssa$i >>> 8;
         $439 = ($438|0)==(0);
         if ($439) {
          $I7$0$i = 0;
         } else {
          $440 = ($rsize$3$lcssa$i>>>0)>(16777215);
          if ($440) {
           $I7$0$i = 31;
          } else {
           $441 = (($438) + 1048320)|0;
           $442 = $441 >>> 16;
           $443 = $442 & 8;
           $444 = $438 << $443;
           $445 = (($444) + 520192)|0;
           $446 = $445 >>> 16;
           $447 = $446 & 4;
           $448 = $447 | $443;
           $449 = $444 << $447;
           $450 = (($449) + 245760)|0;
           $451 = $450 >>> 16;
           $452 = $451 & 2;
           $453 = $448 | $452;
           $454 = (14 - ($453))|0;
           $455 = $449 << $452;
           $456 = $455 >>> 15;
           $457 = (($454) + ($456))|0;
           $458 = $457 << 1;
           $459 = (($457) + 7)|0;
           $460 = $rsize$3$lcssa$i >>> $459;
           $461 = $460 & 1;
           $462 = $461 | $458;
           $I7$0$i = $462;
          }
         }
         $463 = (7248 + ($I7$0$i<<2)|0);
         $$sum2$i = (($246) + 28)|0;
         $464 = (($v$3$lcssa$i) + ($$sum2$i)|0);
         HEAP32[$464>>2] = $I7$0$i;
         $$sum3$i27 = (($246) + 16)|0;
         $465 = (($v$3$lcssa$i) + ($$sum3$i27)|0);
         $$sum4$i28 = (($246) + 20)|0;
         $466 = (($v$3$lcssa$i) + ($$sum4$i28)|0);
         HEAP32[$466>>2] = 0;
         HEAP32[$465>>2] = 0;
         $467 = HEAP32[(6948)>>2]|0;
         $468 = 1 << $I7$0$i;
         $469 = $467 & $468;
         $470 = ($469|0)==(0);
         if ($470) {
          $471 = $467 | $468;
          HEAP32[(6948)>>2] = $471;
          HEAP32[$463>>2] = $348;
          $$sum5$i = (($246) + 24)|0;
          $472 = (($v$3$lcssa$i) + ($$sum5$i)|0);
          HEAP32[$472>>2] = $463;
          $$sum6$i = (($246) + 12)|0;
          $473 = (($v$3$lcssa$i) + ($$sum6$i)|0);
          HEAP32[$473>>2] = $348;
          $$sum7$i = (($246) + 8)|0;
          $474 = (($v$3$lcssa$i) + ($$sum7$i)|0);
          HEAP32[$474>>2] = $348;
          break;
         }
         $475 = HEAP32[$463>>2]|0;
         $476 = ((($475)) + 4|0);
         $477 = HEAP32[$476>>2]|0;
         $478 = $477 & -8;
         $479 = ($478|0)==($rsize$3$lcssa$i|0);
         L103: do {
          if ($479) {
           $T$0$lcssa$i = $475;
          } else {
           $480 = ($I7$0$i|0)==(31);
           $481 = $I7$0$i >>> 1;
           $482 = (25 - ($481))|0;
           $483 = $480 ? 0 : $482;
           $484 = $rsize$3$lcssa$i << $483;
           $K12$029$i = $484;$T$028$i = $475;
           while(1) {
            $491 = $K12$029$i >>> 31;
            $492 = (((($T$028$i)) + 16|0) + ($491<<2)|0);
            $487 = HEAP32[$492>>2]|0;
            $493 = ($487|0)==(0|0);
            if ($493) {
             $$lcssa232 = $492;$T$028$i$lcssa = $T$028$i;
             break;
            }
            $485 = $K12$029$i << 1;
            $486 = ((($487)) + 4|0);
            $488 = HEAP32[$486>>2]|0;
            $489 = $488 & -8;
            $490 = ($489|0)==($rsize$3$lcssa$i|0);
            if ($490) {
             $T$0$lcssa$i = $487;
             break L103;
            } else {
             $K12$029$i = $485;$T$028$i = $487;
            }
           }
           $494 = HEAP32[(6960)>>2]|0;
           $495 = ($$lcssa232>>>0)<($494>>>0);
           if ($495) {
            _abort();
            // unreachable;
           } else {
            HEAP32[$$lcssa232>>2] = $348;
            $$sum11$i = (($246) + 24)|0;
            $496 = (($v$3$lcssa$i) + ($$sum11$i)|0);
            HEAP32[$496>>2] = $T$028$i$lcssa;
            $$sum12$i = (($246) + 12)|0;
            $497 = (($v$3$lcssa$i) + ($$sum12$i)|0);
            HEAP32[$497>>2] = $348;
            $$sum13$i = (($246) + 8)|0;
            $498 = (($v$3$lcssa$i) + ($$sum13$i)|0);
            HEAP32[$498>>2] = $348;
            break L85;
           }
          }
         } while(0);
         $499 = ((($T$0$lcssa$i)) + 8|0);
         $500 = HEAP32[$499>>2]|0;
         $501 = HEAP32[(6960)>>2]|0;
         $502 = ($500>>>0)>=($501>>>0);
         $not$$i = ($T$0$lcssa$i>>>0)>=($501>>>0);
         $503 = $502 & $not$$i;
         if ($503) {
          $504 = ((($500)) + 12|0);
          HEAP32[$504>>2] = $348;
          HEAP32[$499>>2] = $348;
          $$sum8$i = (($246) + 8)|0;
          $505 = (($v$3$lcssa$i) + ($$sum8$i)|0);
          HEAP32[$505>>2] = $500;
          $$sum9$i = (($246) + 12)|0;
          $506 = (($v$3$lcssa$i) + ($$sum9$i)|0);
          HEAP32[$506>>2] = $T$0$lcssa$i;
          $$sum10$i = (($246) + 24)|0;
          $507 = (($v$3$lcssa$i) + ($$sum10$i)|0);
          HEAP32[$507>>2] = 0;
          break;
         } else {
          _abort();
          // unreachable;
         }
        }
       } while(0);
       $508 = ((($v$3$lcssa$i)) + 8|0);
       $mem$0 = $508;
       return ($mem$0|0);
      } else {
       $nb$0 = $246;
      }
     }
    }
   }
  }
 } while(0);
 $509 = HEAP32[(6952)>>2]|0;
 $510 = ($509>>>0)<($nb$0>>>0);
 if (!($510)) {
  $511 = (($509) - ($nb$0))|0;
  $512 = HEAP32[(6964)>>2]|0;
  $513 = ($511>>>0)>(15);
  if ($513) {
   $514 = (($512) + ($nb$0)|0);
   HEAP32[(6964)>>2] = $514;
   HEAP32[(6952)>>2] = $511;
   $515 = $511 | 1;
   $$sum2 = (($nb$0) + 4)|0;
   $516 = (($512) + ($$sum2)|0);
   HEAP32[$516>>2] = $515;
   $517 = (($512) + ($509)|0);
   HEAP32[$517>>2] = $511;
   $518 = $nb$0 | 3;
   $519 = ((($512)) + 4|0);
   HEAP32[$519>>2] = $518;
  } else {
   HEAP32[(6952)>>2] = 0;
   HEAP32[(6964)>>2] = 0;
   $520 = $509 | 3;
   $521 = ((($512)) + 4|0);
   HEAP32[$521>>2] = $520;
   $$sum1 = (($509) + 4)|0;
   $522 = (($512) + ($$sum1)|0);
   $523 = HEAP32[$522>>2]|0;
   $524 = $523 | 1;
   HEAP32[$522>>2] = $524;
  }
  $525 = ((($512)) + 8|0);
  $mem$0 = $525;
  return ($mem$0|0);
 }
 $526 = HEAP32[(6956)>>2]|0;
 $527 = ($526>>>0)>($nb$0>>>0);
 if ($527) {
  $528 = (($526) - ($nb$0))|0;
  HEAP32[(6956)>>2] = $528;
  $529 = HEAP32[(6968)>>2]|0;
  $530 = (($529) + ($nb$0)|0);
  HEAP32[(6968)>>2] = $530;
  $531 = $528 | 1;
  $$sum = (($nb$0) + 4)|0;
  $532 = (($529) + ($$sum)|0);
  HEAP32[$532>>2] = $531;
  $533 = $nb$0 | 3;
  $534 = ((($529)) + 4|0);
  HEAP32[$534>>2] = $533;
  $535 = ((($529)) + 8|0);
  $mem$0 = $535;
  return ($mem$0|0);
 }
 $536 = HEAP32[7416>>2]|0;
 $537 = ($536|0)==(0);
 do {
  if ($537) {
   $538 = (_sysconf(30)|0);
   $539 = (($538) + -1)|0;
   $540 = $539 & $538;
   $541 = ($540|0)==(0);
   if ($541) {
    HEAP32[(7424)>>2] = $538;
    HEAP32[(7420)>>2] = $538;
    HEAP32[(7428)>>2] = -1;
    HEAP32[(7432)>>2] = -1;
    HEAP32[(7436)>>2] = 0;
    HEAP32[(7388)>>2] = 0;
    $542 = (_time((0|0))|0);
    $543 = $542 & -16;
    $544 = $543 ^ 1431655768;
    HEAP32[7416>>2] = $544;
    break;
   } else {
    _abort();
    // unreachable;
   }
  }
 } while(0);
 $545 = (($nb$0) + 48)|0;
 $546 = HEAP32[(7424)>>2]|0;
 $547 = (($nb$0) + 47)|0;
 $548 = (($546) + ($547))|0;
 $549 = (0 - ($546))|0;
 $550 = $548 & $549;
 $551 = ($550>>>0)>($nb$0>>>0);
 if (!($551)) {
  $mem$0 = 0;
  return ($mem$0|0);
 }
 $552 = HEAP32[(7384)>>2]|0;
 $553 = ($552|0)==(0);
 if (!($553)) {
  $554 = HEAP32[(7376)>>2]|0;
  $555 = (($554) + ($550))|0;
  $556 = ($555>>>0)<=($554>>>0);
  $557 = ($555>>>0)>($552>>>0);
  $or$cond1$i = $556 | $557;
  if ($or$cond1$i) {
   $mem$0 = 0;
   return ($mem$0|0);
  }
 }
 $558 = HEAP32[(7388)>>2]|0;
 $559 = $558 & 4;
 $560 = ($559|0)==(0);
 L258: do {
  if ($560) {
   $561 = HEAP32[(6968)>>2]|0;
   $562 = ($561|0)==(0|0);
   L260: do {
    if ($562) {
     label = 174;
    } else {
     $sp$0$i$i = (7392);
     while(1) {
      $563 = HEAP32[$sp$0$i$i>>2]|0;
      $564 = ($563>>>0)>($561>>>0);
      if (!($564)) {
       $565 = ((($sp$0$i$i)) + 4|0);
       $566 = HEAP32[$565>>2]|0;
       $567 = (($563) + ($566)|0);
       $568 = ($567>>>0)>($561>>>0);
       if ($568) {
        $$lcssa228 = $sp$0$i$i;$$lcssa230 = $565;
        break;
       }
      }
      $569 = ((($sp$0$i$i)) + 8|0);
      $570 = HEAP32[$569>>2]|0;
      $571 = ($570|0)==(0|0);
      if ($571) {
       label = 174;
       break L260;
      } else {
       $sp$0$i$i = $570;
      }
     }
     $594 = HEAP32[(6956)>>2]|0;
     $595 = (($548) - ($594))|0;
     $596 = $595 & $549;
     $597 = ($596>>>0)<(2147483647);
     if ($597) {
      $598 = (_sbrk(($596|0))|0);
      $599 = HEAP32[$$lcssa228>>2]|0;
      $600 = HEAP32[$$lcssa230>>2]|0;
      $601 = (($599) + ($600)|0);
      $602 = ($598|0)==($601|0);
      $$3$i = $602 ? $596 : 0;
      if ($602) {
       $603 = ($598|0)==((-1)|0);
       if ($603) {
        $tsize$0323944$i = $$3$i;
       } else {
        $tbase$255$i = $598;$tsize$254$i = $$3$i;
        label = 194;
        break L258;
       }
      } else {
       $br$0$ph$i = $598;$ssize$1$ph$i = $596;$tsize$0$ph$i = $$3$i;
       label = 184;
      }
     } else {
      $tsize$0323944$i = 0;
     }
    }
   } while(0);
   do {
    if ((label|0) == 174) {
     $572 = (_sbrk(0)|0);
     $573 = ($572|0)==((-1)|0);
     if ($573) {
      $tsize$0323944$i = 0;
     } else {
      $574 = $572;
      $575 = HEAP32[(7420)>>2]|0;
      $576 = (($575) + -1)|0;
      $577 = $576 & $574;
      $578 = ($577|0)==(0);
      if ($578) {
       $ssize$0$i = $550;
      } else {
       $579 = (($576) + ($574))|0;
       $580 = (0 - ($575))|0;
       $581 = $579 & $580;
       $582 = (($550) - ($574))|0;
       $583 = (($582) + ($581))|0;
       $ssize$0$i = $583;
      }
      $584 = HEAP32[(7376)>>2]|0;
      $585 = (($584) + ($ssize$0$i))|0;
      $586 = ($ssize$0$i>>>0)>($nb$0>>>0);
      $587 = ($ssize$0$i>>>0)<(2147483647);
      $or$cond$i30 = $586 & $587;
      if ($or$cond$i30) {
       $588 = HEAP32[(7384)>>2]|0;
       $589 = ($588|0)==(0);
       if (!($589)) {
        $590 = ($585>>>0)<=($584>>>0);
        $591 = ($585>>>0)>($588>>>0);
        $or$cond2$i = $590 | $591;
        if ($or$cond2$i) {
         $tsize$0323944$i = 0;
         break;
        }
       }
       $592 = (_sbrk(($ssize$0$i|0))|0);
       $593 = ($592|0)==($572|0);
       $ssize$0$$i = $593 ? $ssize$0$i : 0;
       if ($593) {
        $tbase$255$i = $572;$tsize$254$i = $ssize$0$$i;
        label = 194;
        break L258;
       } else {
        $br$0$ph$i = $592;$ssize$1$ph$i = $ssize$0$i;$tsize$0$ph$i = $ssize$0$$i;
        label = 184;
       }
      } else {
       $tsize$0323944$i = 0;
      }
     }
    }
   } while(0);
   L280: do {
    if ((label|0) == 184) {
     $604 = (0 - ($ssize$1$ph$i))|0;
     $605 = ($br$0$ph$i|0)!=((-1)|0);
     $606 = ($ssize$1$ph$i>>>0)<(2147483647);
     $or$cond5$i = $606 & $605;
     $607 = ($545>>>0)>($ssize$1$ph$i>>>0);
     $or$cond6$i = $607 & $or$cond5$i;
     do {
      if ($or$cond6$i) {
       $608 = HEAP32[(7424)>>2]|0;
       $609 = (($547) - ($ssize$1$ph$i))|0;
       $610 = (($609) + ($608))|0;
       $611 = (0 - ($608))|0;
       $612 = $610 & $611;
       $613 = ($612>>>0)<(2147483647);
       if ($613) {
        $614 = (_sbrk(($612|0))|0);
        $615 = ($614|0)==((-1)|0);
        if ($615) {
         (_sbrk(($604|0))|0);
         $tsize$0323944$i = $tsize$0$ph$i;
         break L280;
        } else {
         $616 = (($612) + ($ssize$1$ph$i))|0;
         $ssize$2$i = $616;
         break;
        }
       } else {
        $ssize$2$i = $ssize$1$ph$i;
       }
      } else {
       $ssize$2$i = $ssize$1$ph$i;
      }
     } while(0);
     $617 = ($br$0$ph$i|0)==((-1)|0);
     if ($617) {
      $tsize$0323944$i = $tsize$0$ph$i;
     } else {
      $tbase$255$i = $br$0$ph$i;$tsize$254$i = $ssize$2$i;
      label = 194;
      break L258;
     }
    }
   } while(0);
   $618 = HEAP32[(7388)>>2]|0;
   $619 = $618 | 4;
   HEAP32[(7388)>>2] = $619;
   $tsize$1$i = $tsize$0323944$i;
   label = 191;
  } else {
   $tsize$1$i = 0;
   label = 191;
  }
 } while(0);
 if ((label|0) == 191) {
  $620 = ($550>>>0)<(2147483647);
  if ($620) {
   $621 = (_sbrk(($550|0))|0);
   $622 = (_sbrk(0)|0);
   $623 = ($621|0)!=((-1)|0);
   $624 = ($622|0)!=((-1)|0);
   $or$cond3$i = $623 & $624;
   $625 = ($621>>>0)<($622>>>0);
   $or$cond8$i = $625 & $or$cond3$i;
   if ($or$cond8$i) {
    $626 = $622;
    $627 = $621;
    $628 = (($626) - ($627))|0;
    $629 = (($nb$0) + 40)|0;
    $630 = ($628>>>0)>($629>>>0);
    $$tsize$1$i = $630 ? $628 : $tsize$1$i;
    if ($630) {
     $tbase$255$i = $621;$tsize$254$i = $$tsize$1$i;
     label = 194;
    }
   }
  }
 }
 if ((label|0) == 194) {
  $631 = HEAP32[(7376)>>2]|0;
  $632 = (($631) + ($tsize$254$i))|0;
  HEAP32[(7376)>>2] = $632;
  $633 = HEAP32[(7380)>>2]|0;
  $634 = ($632>>>0)>($633>>>0);
  if ($634) {
   HEAP32[(7380)>>2] = $632;
  }
  $635 = HEAP32[(6968)>>2]|0;
  $636 = ($635|0)==(0|0);
  L299: do {
   if ($636) {
    $637 = HEAP32[(6960)>>2]|0;
    $638 = ($637|0)==(0|0);
    $639 = ($tbase$255$i>>>0)<($637>>>0);
    $or$cond9$i = $638 | $639;
    if ($or$cond9$i) {
     HEAP32[(6960)>>2] = $tbase$255$i;
    }
    HEAP32[(7392)>>2] = $tbase$255$i;
    HEAP32[(7396)>>2] = $tsize$254$i;
    HEAP32[(7404)>>2] = 0;
    $640 = HEAP32[7416>>2]|0;
    HEAP32[(6980)>>2] = $640;
    HEAP32[(6976)>>2] = -1;
    $i$02$i$i = 0;
    while(1) {
     $641 = $i$02$i$i << 1;
     $642 = (6984 + ($641<<2)|0);
     $$sum$i$i = (($641) + 3)|0;
     $643 = (6984 + ($$sum$i$i<<2)|0);
     HEAP32[$643>>2] = $642;
     $$sum1$i$i = (($641) + 2)|0;
     $644 = (6984 + ($$sum1$i$i<<2)|0);
     HEAP32[$644>>2] = $642;
     $645 = (($i$02$i$i) + 1)|0;
     $exitcond$i$i = ($645|0)==(32);
     if ($exitcond$i$i) {
      break;
     } else {
      $i$02$i$i = $645;
     }
    }
    $646 = (($tsize$254$i) + -40)|0;
    $647 = ((($tbase$255$i)) + 8|0);
    $648 = $647;
    $649 = $648 & 7;
    $650 = ($649|0)==(0);
    $651 = (0 - ($648))|0;
    $652 = $651 & 7;
    $653 = $650 ? 0 : $652;
    $654 = (($tbase$255$i) + ($653)|0);
    $655 = (($646) - ($653))|0;
    HEAP32[(6968)>>2] = $654;
    HEAP32[(6956)>>2] = $655;
    $656 = $655 | 1;
    $$sum$i13$i = (($653) + 4)|0;
    $657 = (($tbase$255$i) + ($$sum$i13$i)|0);
    HEAP32[$657>>2] = $656;
    $$sum2$i$i = (($tsize$254$i) + -36)|0;
    $658 = (($tbase$255$i) + ($$sum2$i$i)|0);
    HEAP32[$658>>2] = 40;
    $659 = HEAP32[(7432)>>2]|0;
    HEAP32[(6972)>>2] = $659;
   } else {
    $sp$084$i = (7392);
    while(1) {
     $660 = HEAP32[$sp$084$i>>2]|0;
     $661 = ((($sp$084$i)) + 4|0);
     $662 = HEAP32[$661>>2]|0;
     $663 = (($660) + ($662)|0);
     $664 = ($tbase$255$i|0)==($663|0);
     if ($664) {
      $$lcssa222 = $660;$$lcssa224 = $661;$$lcssa226 = $662;$sp$084$i$lcssa = $sp$084$i;
      label = 204;
      break;
     }
     $665 = ((($sp$084$i)) + 8|0);
     $666 = HEAP32[$665>>2]|0;
     $667 = ($666|0)==(0|0);
     if ($667) {
      break;
     } else {
      $sp$084$i = $666;
     }
    }
    if ((label|0) == 204) {
     $668 = ((($sp$084$i$lcssa)) + 12|0);
     $669 = HEAP32[$668>>2]|0;
     $670 = $669 & 8;
     $671 = ($670|0)==(0);
     if ($671) {
      $672 = ($635>>>0)>=($$lcssa222>>>0);
      $673 = ($635>>>0)<($tbase$255$i>>>0);
      $or$cond57$i = $673 & $672;
      if ($or$cond57$i) {
       $674 = (($$lcssa226) + ($tsize$254$i))|0;
       HEAP32[$$lcssa224>>2] = $674;
       $675 = HEAP32[(6956)>>2]|0;
       $676 = (($675) + ($tsize$254$i))|0;
       $677 = ((($635)) + 8|0);
       $678 = $677;
       $679 = $678 & 7;
       $680 = ($679|0)==(0);
       $681 = (0 - ($678))|0;
       $682 = $681 & 7;
       $683 = $680 ? 0 : $682;
       $684 = (($635) + ($683)|0);
       $685 = (($676) - ($683))|0;
       HEAP32[(6968)>>2] = $684;
       HEAP32[(6956)>>2] = $685;
       $686 = $685 | 1;
       $$sum$i17$i = (($683) + 4)|0;
       $687 = (($635) + ($$sum$i17$i)|0);
       HEAP32[$687>>2] = $686;
       $$sum2$i18$i = (($676) + 4)|0;
       $688 = (($635) + ($$sum2$i18$i)|0);
       HEAP32[$688>>2] = 40;
       $689 = HEAP32[(7432)>>2]|0;
       HEAP32[(6972)>>2] = $689;
       break;
      }
     }
    }
    $690 = HEAP32[(6960)>>2]|0;
    $691 = ($tbase$255$i>>>0)<($690>>>0);
    if ($691) {
     HEAP32[(6960)>>2] = $tbase$255$i;
     $755 = $tbase$255$i;
    } else {
     $755 = $690;
    }
    $692 = (($tbase$255$i) + ($tsize$254$i)|0);
    $sp$183$i = (7392);
    while(1) {
     $693 = HEAP32[$sp$183$i>>2]|0;
     $694 = ($693|0)==($692|0);
     if ($694) {
      $$lcssa219 = $sp$183$i;$sp$183$i$lcssa = $sp$183$i;
      label = 212;
      break;
     }
     $695 = ((($sp$183$i)) + 8|0);
     $696 = HEAP32[$695>>2]|0;
     $697 = ($696|0)==(0|0);
     if ($697) {
      $sp$0$i$i$i = (7392);
      break;
     } else {
      $sp$183$i = $696;
     }
    }
    if ((label|0) == 212) {
     $698 = ((($sp$183$i$lcssa)) + 12|0);
     $699 = HEAP32[$698>>2]|0;
     $700 = $699 & 8;
     $701 = ($700|0)==(0);
     if ($701) {
      HEAP32[$$lcssa219>>2] = $tbase$255$i;
      $702 = ((($sp$183$i$lcssa)) + 4|0);
      $703 = HEAP32[$702>>2]|0;
      $704 = (($703) + ($tsize$254$i))|0;
      HEAP32[$702>>2] = $704;
      $705 = ((($tbase$255$i)) + 8|0);
      $706 = $705;
      $707 = $706 & 7;
      $708 = ($707|0)==(0);
      $709 = (0 - ($706))|0;
      $710 = $709 & 7;
      $711 = $708 ? 0 : $710;
      $712 = (($tbase$255$i) + ($711)|0);
      $$sum112$i = (($tsize$254$i) + 8)|0;
      $713 = (($tbase$255$i) + ($$sum112$i)|0);
      $714 = $713;
      $715 = $714 & 7;
      $716 = ($715|0)==(0);
      $717 = (0 - ($714))|0;
      $718 = $717 & 7;
      $719 = $716 ? 0 : $718;
      $$sum113$i = (($719) + ($tsize$254$i))|0;
      $720 = (($tbase$255$i) + ($$sum113$i)|0);
      $721 = $720;
      $722 = $712;
      $723 = (($721) - ($722))|0;
      $$sum$i19$i = (($711) + ($nb$0))|0;
      $724 = (($tbase$255$i) + ($$sum$i19$i)|0);
      $725 = (($723) - ($nb$0))|0;
      $726 = $nb$0 | 3;
      $$sum1$i20$i = (($711) + 4)|0;
      $727 = (($tbase$255$i) + ($$sum1$i20$i)|0);
      HEAP32[$727>>2] = $726;
      $728 = ($720|0)==($635|0);
      L317: do {
       if ($728) {
        $729 = HEAP32[(6956)>>2]|0;
        $730 = (($729) + ($725))|0;
        HEAP32[(6956)>>2] = $730;
        HEAP32[(6968)>>2] = $724;
        $731 = $730 | 1;
        $$sum42$i$i = (($$sum$i19$i) + 4)|0;
        $732 = (($tbase$255$i) + ($$sum42$i$i)|0);
        HEAP32[$732>>2] = $731;
       } else {
        $733 = HEAP32[(6964)>>2]|0;
        $734 = ($720|0)==($733|0);
        if ($734) {
         $735 = HEAP32[(6952)>>2]|0;
         $736 = (($735) + ($725))|0;
         HEAP32[(6952)>>2] = $736;
         HEAP32[(6964)>>2] = $724;
         $737 = $736 | 1;
         $$sum40$i$i = (($$sum$i19$i) + 4)|0;
         $738 = (($tbase$255$i) + ($$sum40$i$i)|0);
         HEAP32[$738>>2] = $737;
         $$sum41$i$i = (($736) + ($$sum$i19$i))|0;
         $739 = (($tbase$255$i) + ($$sum41$i$i)|0);
         HEAP32[$739>>2] = $736;
         break;
        }
        $$sum2$i21$i = (($tsize$254$i) + 4)|0;
        $$sum114$i = (($$sum2$i21$i) + ($719))|0;
        $740 = (($tbase$255$i) + ($$sum114$i)|0);
        $741 = HEAP32[$740>>2]|0;
        $742 = $741 & 3;
        $743 = ($742|0)==(1);
        if ($743) {
         $744 = $741 & -8;
         $745 = $741 >>> 3;
         $746 = ($741>>>0)<(256);
         L325: do {
          if ($746) {
           $$sum3738$i$i = $719 | 8;
           $$sum124$i = (($$sum3738$i$i) + ($tsize$254$i))|0;
           $747 = (($tbase$255$i) + ($$sum124$i)|0);
           $748 = HEAP32[$747>>2]|0;
           $$sum39$i$i = (($tsize$254$i) + 12)|0;
           $$sum125$i = (($$sum39$i$i) + ($719))|0;
           $749 = (($tbase$255$i) + ($$sum125$i)|0);
           $750 = HEAP32[$749>>2]|0;
           $751 = $745 << 1;
           $752 = (6984 + ($751<<2)|0);
           $753 = ($748|0)==($752|0);
           do {
            if (!($753)) {
             $754 = ($748>>>0)<($755>>>0);
             if ($754) {
              _abort();
              // unreachable;
             }
             $756 = ((($748)) + 12|0);
             $757 = HEAP32[$756>>2]|0;
             $758 = ($757|0)==($720|0);
             if ($758) {
              break;
             }
             _abort();
             // unreachable;
            }
           } while(0);
           $759 = ($750|0)==($748|0);
           if ($759) {
            $760 = 1 << $745;
            $761 = $760 ^ -1;
            $762 = HEAP32[6944>>2]|0;
            $763 = $762 & $761;
            HEAP32[6944>>2] = $763;
            break;
           }
           $764 = ($750|0)==($752|0);
           do {
            if ($764) {
             $$pre57$i$i = ((($750)) + 8|0);
             $$pre$phi58$i$iZ2D = $$pre57$i$i;
            } else {
             $765 = ($750>>>0)<($755>>>0);
             if ($765) {
              _abort();
              // unreachable;
             }
             $766 = ((($750)) + 8|0);
             $767 = HEAP32[$766>>2]|0;
             $768 = ($767|0)==($720|0);
             if ($768) {
              $$pre$phi58$i$iZ2D = $766;
              break;
             }
             _abort();
             // unreachable;
            }
           } while(0);
           $769 = ((($748)) + 12|0);
           HEAP32[$769>>2] = $750;
           HEAP32[$$pre$phi58$i$iZ2D>>2] = $748;
          } else {
           $$sum34$i$i = $719 | 24;
           $$sum115$i = (($$sum34$i$i) + ($tsize$254$i))|0;
           $770 = (($tbase$255$i) + ($$sum115$i)|0);
           $771 = HEAP32[$770>>2]|0;
           $$sum5$i$i = (($tsize$254$i) + 12)|0;
           $$sum116$i = (($$sum5$i$i) + ($719))|0;
           $772 = (($tbase$255$i) + ($$sum116$i)|0);
           $773 = HEAP32[$772>>2]|0;
           $774 = ($773|0)==($720|0);
           do {
            if ($774) {
             $$sum67$i$i = $719 | 16;
             $$sum122$i = (($$sum2$i21$i) + ($$sum67$i$i))|0;
             $784 = (($tbase$255$i) + ($$sum122$i)|0);
             $785 = HEAP32[$784>>2]|0;
             $786 = ($785|0)==(0|0);
             if ($786) {
              $$sum123$i = (($$sum67$i$i) + ($tsize$254$i))|0;
              $787 = (($tbase$255$i) + ($$sum123$i)|0);
              $788 = HEAP32[$787>>2]|0;
              $789 = ($788|0)==(0|0);
              if ($789) {
               $R$1$i$i = 0;
               break;
              } else {
               $R$0$i$i = $788;$RP$0$i$i = $787;
              }
             } else {
              $R$0$i$i = $785;$RP$0$i$i = $784;
             }
             while(1) {
              $790 = ((($R$0$i$i)) + 20|0);
              $791 = HEAP32[$790>>2]|0;
              $792 = ($791|0)==(0|0);
              if (!($792)) {
               $R$0$i$i = $791;$RP$0$i$i = $790;
               continue;
              }
              $793 = ((($R$0$i$i)) + 16|0);
              $794 = HEAP32[$793>>2]|0;
              $795 = ($794|0)==(0|0);
              if ($795) {
               $R$0$i$i$lcssa = $R$0$i$i;$RP$0$i$i$lcssa = $RP$0$i$i;
               break;
              } else {
               $R$0$i$i = $794;$RP$0$i$i = $793;
              }
             }
             $796 = ($RP$0$i$i$lcssa>>>0)<($755>>>0);
             if ($796) {
              _abort();
              // unreachable;
             } else {
              HEAP32[$RP$0$i$i$lcssa>>2] = 0;
              $R$1$i$i = $R$0$i$i$lcssa;
              break;
             }
            } else {
             $$sum3536$i$i = $719 | 8;
             $$sum117$i = (($$sum3536$i$i) + ($tsize$254$i))|0;
             $775 = (($tbase$255$i) + ($$sum117$i)|0);
             $776 = HEAP32[$775>>2]|0;
             $777 = ($776>>>0)<($755>>>0);
             if ($777) {
              _abort();
              // unreachable;
             }
             $778 = ((($776)) + 12|0);
             $779 = HEAP32[$778>>2]|0;
             $780 = ($779|0)==($720|0);
             if (!($780)) {
              _abort();
              // unreachable;
             }
             $781 = ((($773)) + 8|0);
             $782 = HEAP32[$781>>2]|0;
             $783 = ($782|0)==($720|0);
             if ($783) {
              HEAP32[$778>>2] = $773;
              HEAP32[$781>>2] = $776;
              $R$1$i$i = $773;
              break;
             } else {
              _abort();
              // unreachable;
             }
            }
           } while(0);
           $797 = ($771|0)==(0|0);
           if ($797) {
            break;
           }
           $$sum30$i$i = (($tsize$254$i) + 28)|0;
           $$sum118$i = (($$sum30$i$i) + ($719))|0;
           $798 = (($tbase$255$i) + ($$sum118$i)|0);
           $799 = HEAP32[$798>>2]|0;
           $800 = (7248 + ($799<<2)|0);
           $801 = HEAP32[$800>>2]|0;
           $802 = ($720|0)==($801|0);
           do {
            if ($802) {
             HEAP32[$800>>2] = $R$1$i$i;
             $cond$i$i = ($R$1$i$i|0)==(0|0);
             if (!($cond$i$i)) {
              break;
             }
             $803 = 1 << $799;
             $804 = $803 ^ -1;
             $805 = HEAP32[(6948)>>2]|0;
             $806 = $805 & $804;
             HEAP32[(6948)>>2] = $806;
             break L325;
            } else {
             $807 = HEAP32[(6960)>>2]|0;
             $808 = ($771>>>0)<($807>>>0);
             if ($808) {
              _abort();
              // unreachable;
             }
             $809 = ((($771)) + 16|0);
             $810 = HEAP32[$809>>2]|0;
             $811 = ($810|0)==($720|0);
             if ($811) {
              HEAP32[$809>>2] = $R$1$i$i;
             } else {
              $812 = ((($771)) + 20|0);
              HEAP32[$812>>2] = $R$1$i$i;
             }
             $813 = ($R$1$i$i|0)==(0|0);
             if ($813) {
              break L325;
             }
            }
           } while(0);
           $814 = HEAP32[(6960)>>2]|0;
           $815 = ($R$1$i$i>>>0)<($814>>>0);
           if ($815) {
            _abort();
            // unreachable;
           }
           $816 = ((($R$1$i$i)) + 24|0);
           HEAP32[$816>>2] = $771;
           $$sum3132$i$i = $719 | 16;
           $$sum119$i = (($$sum3132$i$i) + ($tsize$254$i))|0;
           $817 = (($tbase$255$i) + ($$sum119$i)|0);
           $818 = HEAP32[$817>>2]|0;
           $819 = ($818|0)==(0|0);
           do {
            if (!($819)) {
             $820 = ($818>>>0)<($814>>>0);
             if ($820) {
              _abort();
              // unreachable;
             } else {
              $821 = ((($R$1$i$i)) + 16|0);
              HEAP32[$821>>2] = $818;
              $822 = ((($818)) + 24|0);
              HEAP32[$822>>2] = $R$1$i$i;
              break;
             }
            }
           } while(0);
           $$sum120$i = (($$sum2$i21$i) + ($$sum3132$i$i))|0;
           $823 = (($tbase$255$i) + ($$sum120$i)|0);
           $824 = HEAP32[$823>>2]|0;
           $825 = ($824|0)==(0|0);
           if ($825) {
            break;
           }
           $826 = HEAP32[(6960)>>2]|0;
           $827 = ($824>>>0)<($826>>>0);
           if ($827) {
            _abort();
            // unreachable;
           } else {
            $828 = ((($R$1$i$i)) + 20|0);
            HEAP32[$828>>2] = $824;
            $829 = ((($824)) + 24|0);
            HEAP32[$829>>2] = $R$1$i$i;
            break;
           }
          }
         } while(0);
         $$sum9$i$i = $744 | $719;
         $$sum121$i = (($$sum9$i$i) + ($tsize$254$i))|0;
         $830 = (($tbase$255$i) + ($$sum121$i)|0);
         $831 = (($744) + ($725))|0;
         $oldfirst$0$i$i = $830;$qsize$0$i$i = $831;
        } else {
         $oldfirst$0$i$i = $720;$qsize$0$i$i = $725;
        }
        $832 = ((($oldfirst$0$i$i)) + 4|0);
        $833 = HEAP32[$832>>2]|0;
        $834 = $833 & -2;
        HEAP32[$832>>2] = $834;
        $835 = $qsize$0$i$i | 1;
        $$sum10$i$i = (($$sum$i19$i) + 4)|0;
        $836 = (($tbase$255$i) + ($$sum10$i$i)|0);
        HEAP32[$836>>2] = $835;
        $$sum11$i$i = (($qsize$0$i$i) + ($$sum$i19$i))|0;
        $837 = (($tbase$255$i) + ($$sum11$i$i)|0);
        HEAP32[$837>>2] = $qsize$0$i$i;
        $838 = $qsize$0$i$i >>> 3;
        $839 = ($qsize$0$i$i>>>0)<(256);
        if ($839) {
         $840 = $838 << 1;
         $841 = (6984 + ($840<<2)|0);
         $842 = HEAP32[6944>>2]|0;
         $843 = 1 << $838;
         $844 = $842 & $843;
         $845 = ($844|0)==(0);
         do {
          if ($845) {
           $846 = $842 | $843;
           HEAP32[6944>>2] = $846;
           $$pre$i22$i = (($840) + 2)|0;
           $$pre56$i$i = (6984 + ($$pre$i22$i<<2)|0);
           $$pre$phi$i23$iZ2D = $$pre56$i$i;$F4$0$i$i = $841;
          } else {
           $$sum29$i$i = (($840) + 2)|0;
           $847 = (6984 + ($$sum29$i$i<<2)|0);
           $848 = HEAP32[$847>>2]|0;
           $849 = HEAP32[(6960)>>2]|0;
           $850 = ($848>>>0)<($849>>>0);
           if (!($850)) {
            $$pre$phi$i23$iZ2D = $847;$F4$0$i$i = $848;
            break;
           }
           _abort();
           // unreachable;
          }
         } while(0);
         HEAP32[$$pre$phi$i23$iZ2D>>2] = $724;
         $851 = ((($F4$0$i$i)) + 12|0);
         HEAP32[$851>>2] = $724;
         $$sum27$i$i = (($$sum$i19$i) + 8)|0;
         $852 = (($tbase$255$i) + ($$sum27$i$i)|0);
         HEAP32[$852>>2] = $F4$0$i$i;
         $$sum28$i$i = (($$sum$i19$i) + 12)|0;
         $853 = (($tbase$255$i) + ($$sum28$i$i)|0);
         HEAP32[$853>>2] = $841;
         break;
        }
        $854 = $qsize$0$i$i >>> 8;
        $855 = ($854|0)==(0);
        do {
         if ($855) {
          $I7$0$i$i = 0;
         } else {
          $856 = ($qsize$0$i$i>>>0)>(16777215);
          if ($856) {
           $I7$0$i$i = 31;
           break;
          }
          $857 = (($854) + 1048320)|0;
          $858 = $857 >>> 16;
          $859 = $858 & 8;
          $860 = $854 << $859;
          $861 = (($860) + 520192)|0;
          $862 = $861 >>> 16;
          $863 = $862 & 4;
          $864 = $863 | $859;
          $865 = $860 << $863;
          $866 = (($865) + 245760)|0;
          $867 = $866 >>> 16;
          $868 = $867 & 2;
          $869 = $864 | $868;
          $870 = (14 - ($869))|0;
          $871 = $865 << $868;
          $872 = $871 >>> 15;
          $873 = (($870) + ($872))|0;
          $874 = $873 << 1;
          $875 = (($873) + 7)|0;
          $876 = $qsize$0$i$i >>> $875;
          $877 = $876 & 1;
          $878 = $877 | $874;
          $I7$0$i$i = $878;
         }
        } while(0);
        $879 = (7248 + ($I7$0$i$i<<2)|0);
        $$sum12$i$i = (($$sum$i19$i) + 28)|0;
        $880 = (($tbase$255$i) + ($$sum12$i$i)|0);
        HEAP32[$880>>2] = $I7$0$i$i;
        $$sum13$i$i = (($$sum$i19$i) + 16)|0;
        $881 = (($tbase$255$i) + ($$sum13$i$i)|0);
        $$sum14$i$i = (($$sum$i19$i) + 20)|0;
        $882 = (($tbase$255$i) + ($$sum14$i$i)|0);
        HEAP32[$882>>2] = 0;
        HEAP32[$881>>2] = 0;
        $883 = HEAP32[(6948)>>2]|0;
        $884 = 1 << $I7$0$i$i;
        $885 = $883 & $884;
        $886 = ($885|0)==(0);
        if ($886) {
         $887 = $883 | $884;
         HEAP32[(6948)>>2] = $887;
         HEAP32[$879>>2] = $724;
         $$sum15$i$i = (($$sum$i19$i) + 24)|0;
         $888 = (($tbase$255$i) + ($$sum15$i$i)|0);
         HEAP32[$888>>2] = $879;
         $$sum16$i$i = (($$sum$i19$i) + 12)|0;
         $889 = (($tbase$255$i) + ($$sum16$i$i)|0);
         HEAP32[$889>>2] = $724;
         $$sum17$i$i = (($$sum$i19$i) + 8)|0;
         $890 = (($tbase$255$i) + ($$sum17$i$i)|0);
         HEAP32[$890>>2] = $724;
         break;
        }
        $891 = HEAP32[$879>>2]|0;
        $892 = ((($891)) + 4|0);
        $893 = HEAP32[$892>>2]|0;
        $894 = $893 & -8;
        $895 = ($894|0)==($qsize$0$i$i|0);
        L411: do {
         if ($895) {
          $T$0$lcssa$i25$i = $891;
         } else {
          $896 = ($I7$0$i$i|0)==(31);
          $897 = $I7$0$i$i >>> 1;
          $898 = (25 - ($897))|0;
          $899 = $896 ? 0 : $898;
          $900 = $qsize$0$i$i << $899;
          $K8$051$i$i = $900;$T$050$i$i = $891;
          while(1) {
           $907 = $K8$051$i$i >>> 31;
           $908 = (((($T$050$i$i)) + 16|0) + ($907<<2)|0);
           $903 = HEAP32[$908>>2]|0;
           $909 = ($903|0)==(0|0);
           if ($909) {
            $$lcssa = $908;$T$050$i$i$lcssa = $T$050$i$i;
            break;
           }
           $901 = $K8$051$i$i << 1;
           $902 = ((($903)) + 4|0);
           $904 = HEAP32[$902>>2]|0;
           $905 = $904 & -8;
           $906 = ($905|0)==($qsize$0$i$i|0);
           if ($906) {
            $T$0$lcssa$i25$i = $903;
            break L411;
           } else {
            $K8$051$i$i = $901;$T$050$i$i = $903;
           }
          }
          $910 = HEAP32[(6960)>>2]|0;
          $911 = ($$lcssa>>>0)<($910>>>0);
          if ($911) {
           _abort();
           // unreachable;
          } else {
           HEAP32[$$lcssa>>2] = $724;
           $$sum23$i$i = (($$sum$i19$i) + 24)|0;
           $912 = (($tbase$255$i) + ($$sum23$i$i)|0);
           HEAP32[$912>>2] = $T$050$i$i$lcssa;
           $$sum24$i$i = (($$sum$i19$i) + 12)|0;
           $913 = (($tbase$255$i) + ($$sum24$i$i)|0);
           HEAP32[$913>>2] = $724;
           $$sum25$i$i = (($$sum$i19$i) + 8)|0;
           $914 = (($tbase$255$i) + ($$sum25$i$i)|0);
           HEAP32[$914>>2] = $724;
           break L317;
          }
         }
        } while(0);
        $915 = ((($T$0$lcssa$i25$i)) + 8|0);
        $916 = HEAP32[$915>>2]|0;
        $917 = HEAP32[(6960)>>2]|0;
        $918 = ($916>>>0)>=($917>>>0);
        $not$$i26$i = ($T$0$lcssa$i25$i>>>0)>=($917>>>0);
        $919 = $918 & $not$$i26$i;
        if ($919) {
         $920 = ((($916)) + 12|0);
         HEAP32[$920>>2] = $724;
         HEAP32[$915>>2] = $724;
         $$sum20$i$i = (($$sum$i19$i) + 8)|0;
         $921 = (($tbase$255$i) + ($$sum20$i$i)|0);
         HEAP32[$921>>2] = $916;
         $$sum21$i$i = (($$sum$i19$i) + 12)|0;
         $922 = (($tbase$255$i) + ($$sum21$i$i)|0);
         HEAP32[$922>>2] = $T$0$lcssa$i25$i;
         $$sum22$i$i = (($$sum$i19$i) + 24)|0;
         $923 = (($tbase$255$i) + ($$sum22$i$i)|0);
         HEAP32[$923>>2] = 0;
         break;
        } else {
         _abort();
         // unreachable;
        }
       }
      } while(0);
      $$sum1819$i$i = $711 | 8;
      $924 = (($tbase$255$i) + ($$sum1819$i$i)|0);
      $mem$0 = $924;
      return ($mem$0|0);
     } else {
      $sp$0$i$i$i = (7392);
     }
    }
    while(1) {
     $925 = HEAP32[$sp$0$i$i$i>>2]|0;
     $926 = ($925>>>0)>($635>>>0);
     if (!($926)) {
      $927 = ((($sp$0$i$i$i)) + 4|0);
      $928 = HEAP32[$927>>2]|0;
      $929 = (($925) + ($928)|0);
      $930 = ($929>>>0)>($635>>>0);
      if ($930) {
       $$lcssa215 = $925;$$lcssa216 = $928;$$lcssa217 = $929;
       break;
      }
     }
     $931 = ((($sp$0$i$i$i)) + 8|0);
     $932 = HEAP32[$931>>2]|0;
     $sp$0$i$i$i = $932;
    }
    $$sum$i14$i = (($$lcssa216) + -47)|0;
    $$sum1$i15$i = (($$lcssa216) + -39)|0;
    $933 = (($$lcssa215) + ($$sum1$i15$i)|0);
    $934 = $933;
    $935 = $934 & 7;
    $936 = ($935|0)==(0);
    $937 = (0 - ($934))|0;
    $938 = $937 & 7;
    $939 = $936 ? 0 : $938;
    $$sum2$i16$i = (($$sum$i14$i) + ($939))|0;
    $940 = (($$lcssa215) + ($$sum2$i16$i)|0);
    $941 = ((($635)) + 16|0);
    $942 = ($940>>>0)<($941>>>0);
    $943 = $942 ? $635 : $940;
    $944 = ((($943)) + 8|0);
    $945 = (($tsize$254$i) + -40)|0;
    $946 = ((($tbase$255$i)) + 8|0);
    $947 = $946;
    $948 = $947 & 7;
    $949 = ($948|0)==(0);
    $950 = (0 - ($947))|0;
    $951 = $950 & 7;
    $952 = $949 ? 0 : $951;
    $953 = (($tbase$255$i) + ($952)|0);
    $954 = (($945) - ($952))|0;
    HEAP32[(6968)>>2] = $953;
    HEAP32[(6956)>>2] = $954;
    $955 = $954 | 1;
    $$sum$i$i$i = (($952) + 4)|0;
    $956 = (($tbase$255$i) + ($$sum$i$i$i)|0);
    HEAP32[$956>>2] = $955;
    $$sum2$i$i$i = (($tsize$254$i) + -36)|0;
    $957 = (($tbase$255$i) + ($$sum2$i$i$i)|0);
    HEAP32[$957>>2] = 40;
    $958 = HEAP32[(7432)>>2]|0;
    HEAP32[(6972)>>2] = $958;
    $959 = ((($943)) + 4|0);
    HEAP32[$959>>2] = 27;
    ;HEAP32[$944>>2]=HEAP32[(7392)>>2]|0;HEAP32[$944+4>>2]=HEAP32[(7392)+4>>2]|0;HEAP32[$944+8>>2]=HEAP32[(7392)+8>>2]|0;HEAP32[$944+12>>2]=HEAP32[(7392)+12>>2]|0;
    HEAP32[(7392)>>2] = $tbase$255$i;
    HEAP32[(7396)>>2] = $tsize$254$i;
    HEAP32[(7404)>>2] = 0;
    HEAP32[(7400)>>2] = $944;
    $960 = ((($943)) + 28|0);
    HEAP32[$960>>2] = 7;
    $961 = ((($943)) + 32|0);
    $962 = ($961>>>0)<($$lcssa217>>>0);
    if ($962) {
     $964 = $960;
     while(1) {
      $963 = ((($964)) + 4|0);
      HEAP32[$963>>2] = 7;
      $965 = ((($964)) + 8|0);
      $966 = ($965>>>0)<($$lcssa217>>>0);
      if ($966) {
       $964 = $963;
      } else {
       break;
      }
     }
    }
    $967 = ($943|0)==($635|0);
    if (!($967)) {
     $968 = $943;
     $969 = $635;
     $970 = (($968) - ($969))|0;
     $971 = HEAP32[$959>>2]|0;
     $972 = $971 & -2;
     HEAP32[$959>>2] = $972;
     $973 = $970 | 1;
     $974 = ((($635)) + 4|0);
     HEAP32[$974>>2] = $973;
     HEAP32[$943>>2] = $970;
     $975 = $970 >>> 3;
     $976 = ($970>>>0)<(256);
     if ($976) {
      $977 = $975 << 1;
      $978 = (6984 + ($977<<2)|0);
      $979 = HEAP32[6944>>2]|0;
      $980 = 1 << $975;
      $981 = $979 & $980;
      $982 = ($981|0)==(0);
      if ($982) {
       $983 = $979 | $980;
       HEAP32[6944>>2] = $983;
       $$pre$i$i = (($977) + 2)|0;
       $$pre14$i$i = (6984 + ($$pre$i$i<<2)|0);
       $$pre$phi$i$iZ2D = $$pre14$i$i;$F$0$i$i = $978;
      } else {
       $$sum4$i$i = (($977) + 2)|0;
       $984 = (6984 + ($$sum4$i$i<<2)|0);
       $985 = HEAP32[$984>>2]|0;
       $986 = HEAP32[(6960)>>2]|0;
       $987 = ($985>>>0)<($986>>>0);
       if ($987) {
        _abort();
        // unreachable;
       } else {
        $$pre$phi$i$iZ2D = $984;$F$0$i$i = $985;
       }
      }
      HEAP32[$$pre$phi$i$iZ2D>>2] = $635;
      $988 = ((($F$0$i$i)) + 12|0);
      HEAP32[$988>>2] = $635;
      $989 = ((($635)) + 8|0);
      HEAP32[$989>>2] = $F$0$i$i;
      $990 = ((($635)) + 12|0);
      HEAP32[$990>>2] = $978;
      break;
     }
     $991 = $970 >>> 8;
     $992 = ($991|0)==(0);
     if ($992) {
      $I1$0$i$i = 0;
     } else {
      $993 = ($970>>>0)>(16777215);
      if ($993) {
       $I1$0$i$i = 31;
      } else {
       $994 = (($991) + 1048320)|0;
       $995 = $994 >>> 16;
       $996 = $995 & 8;
       $997 = $991 << $996;
       $998 = (($997) + 520192)|0;
       $999 = $998 >>> 16;
       $1000 = $999 & 4;
       $1001 = $1000 | $996;
       $1002 = $997 << $1000;
       $1003 = (($1002) + 245760)|0;
       $1004 = $1003 >>> 16;
       $1005 = $1004 & 2;
       $1006 = $1001 | $1005;
       $1007 = (14 - ($1006))|0;
       $1008 = $1002 << $1005;
       $1009 = $1008 >>> 15;
       $1010 = (($1007) + ($1009))|0;
       $1011 = $1010 << 1;
       $1012 = (($1010) + 7)|0;
       $1013 = $970 >>> $1012;
       $1014 = $1013 & 1;
       $1015 = $1014 | $1011;
       $I1$0$i$i = $1015;
      }
     }
     $1016 = (7248 + ($I1$0$i$i<<2)|0);
     $1017 = ((($635)) + 28|0);
     HEAP32[$1017>>2] = $I1$0$i$i;
     $1018 = ((($635)) + 20|0);
     HEAP32[$1018>>2] = 0;
     HEAP32[$941>>2] = 0;
     $1019 = HEAP32[(6948)>>2]|0;
     $1020 = 1 << $I1$0$i$i;
     $1021 = $1019 & $1020;
     $1022 = ($1021|0)==(0);
     if ($1022) {
      $1023 = $1019 | $1020;
      HEAP32[(6948)>>2] = $1023;
      HEAP32[$1016>>2] = $635;
      $1024 = ((($635)) + 24|0);
      HEAP32[$1024>>2] = $1016;
      $1025 = ((($635)) + 12|0);
      HEAP32[$1025>>2] = $635;
      $1026 = ((($635)) + 8|0);
      HEAP32[$1026>>2] = $635;
      break;
     }
     $1027 = HEAP32[$1016>>2]|0;
     $1028 = ((($1027)) + 4|0);
     $1029 = HEAP32[$1028>>2]|0;
     $1030 = $1029 & -8;
     $1031 = ($1030|0)==($970|0);
     L452: do {
      if ($1031) {
       $T$0$lcssa$i$i = $1027;
      } else {
       $1032 = ($I1$0$i$i|0)==(31);
       $1033 = $I1$0$i$i >>> 1;
       $1034 = (25 - ($1033))|0;
       $1035 = $1032 ? 0 : $1034;
       $1036 = $970 << $1035;
       $K2$07$i$i = $1036;$T$06$i$i = $1027;
       while(1) {
        $1043 = $K2$07$i$i >>> 31;
        $1044 = (((($T$06$i$i)) + 16|0) + ($1043<<2)|0);
        $1039 = HEAP32[$1044>>2]|0;
        $1045 = ($1039|0)==(0|0);
        if ($1045) {
         $$lcssa211 = $1044;$T$06$i$i$lcssa = $T$06$i$i;
         break;
        }
        $1037 = $K2$07$i$i << 1;
        $1038 = ((($1039)) + 4|0);
        $1040 = HEAP32[$1038>>2]|0;
        $1041 = $1040 & -8;
        $1042 = ($1041|0)==($970|0);
        if ($1042) {
         $T$0$lcssa$i$i = $1039;
         break L452;
        } else {
         $K2$07$i$i = $1037;$T$06$i$i = $1039;
        }
       }
       $1046 = HEAP32[(6960)>>2]|0;
       $1047 = ($$lcssa211>>>0)<($1046>>>0);
       if ($1047) {
        _abort();
        // unreachable;
       } else {
        HEAP32[$$lcssa211>>2] = $635;
        $1048 = ((($635)) + 24|0);
        HEAP32[$1048>>2] = $T$06$i$i$lcssa;
        $1049 = ((($635)) + 12|0);
        HEAP32[$1049>>2] = $635;
        $1050 = ((($635)) + 8|0);
        HEAP32[$1050>>2] = $635;
        break L299;
       }
      }
     } while(0);
     $1051 = ((($T$0$lcssa$i$i)) + 8|0);
     $1052 = HEAP32[$1051>>2]|0;
     $1053 = HEAP32[(6960)>>2]|0;
     $1054 = ($1052>>>0)>=($1053>>>0);
     $not$$i$i = ($T$0$lcssa$i$i>>>0)>=($1053>>>0);
     $1055 = $1054 & $not$$i$i;
     if ($1055) {
      $1056 = ((($1052)) + 12|0);
      HEAP32[$1056>>2] = $635;
      HEAP32[$1051>>2] = $635;
      $1057 = ((($635)) + 8|0);
      HEAP32[$1057>>2] = $1052;
      $1058 = ((($635)) + 12|0);
      HEAP32[$1058>>2] = $T$0$lcssa$i$i;
      $1059 = ((($635)) + 24|0);
      HEAP32[$1059>>2] = 0;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   }
  } while(0);
  $1060 = HEAP32[(6956)>>2]|0;
  $1061 = ($1060>>>0)>($nb$0>>>0);
  if ($1061) {
   $1062 = (($1060) - ($nb$0))|0;
   HEAP32[(6956)>>2] = $1062;
   $1063 = HEAP32[(6968)>>2]|0;
   $1064 = (($1063) + ($nb$0)|0);
   HEAP32[(6968)>>2] = $1064;
   $1065 = $1062 | 1;
   $$sum$i32 = (($nb$0) + 4)|0;
   $1066 = (($1063) + ($$sum$i32)|0);
   HEAP32[$1066>>2] = $1065;
   $1067 = $nb$0 | 3;
   $1068 = ((($1063)) + 4|0);
   HEAP32[$1068>>2] = $1067;
   $1069 = ((($1063)) + 8|0);
   $mem$0 = $1069;
   return ($mem$0|0);
  }
 }
 $1070 = (___errno_location()|0);
 HEAP32[$1070>>2] = 12;
 $mem$0 = 0;
 return ($mem$0|0);
}
function _free($mem) {
 $mem = $mem|0;
 var $$lcssa = 0, $$pre = 0, $$pre$phi59Z2D = 0, $$pre$phi61Z2D = 0, $$pre$phiZ2D = 0, $$pre57 = 0, $$pre58 = 0, $$pre60 = 0, $$sum = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum1718 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0;
 var $$sum25 = 0, $$sum26 = 0, $$sum27 = 0, $$sum28 = 0, $$sum29 = 0, $$sum3 = 0, $$sum30 = 0, $$sum31 = 0, $$sum5 = 0, $$sum67 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $F16$0 = 0, $I18$0 = 0, $K19$052 = 0, $R$0 = 0, $R$0$lcssa = 0, $R$1 = 0;
 var $R7$0 = 0, $R7$0$lcssa = 0, $R7$1 = 0, $RP$0 = 0, $RP$0$lcssa = 0, $RP9$0 = 0, $RP9$0$lcssa = 0, $T$0$lcssa = 0, $T$051 = 0, $T$051$lcssa = 0, $cond = 0, $cond47 = 0, $not$ = 0, $p$0 = 0, $psize$0 = 0, $psize$1 = 0, $sp$0$i = 0, $sp$0$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mem|0)==(0|0);
 if ($0) {
  return;
 }
 $1 = ((($mem)) + -8|0);
 $2 = HEAP32[(6960)>>2]|0;
 $3 = ($1>>>0)<($2>>>0);
 if ($3) {
  _abort();
  // unreachable;
 }
 $4 = ((($mem)) + -4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 3;
 $7 = ($6|0)==(1);
 if ($7) {
  _abort();
  // unreachable;
 }
 $8 = $5 & -8;
 $$sum = (($8) + -8)|0;
 $9 = (($mem) + ($$sum)|0);
 $10 = $5 & 1;
 $11 = ($10|0)==(0);
 do {
  if ($11) {
   $12 = HEAP32[$1>>2]|0;
   $13 = ($6|0)==(0);
   if ($13) {
    return;
   }
   $$sum2 = (-8 - ($12))|0;
   $14 = (($mem) + ($$sum2)|0);
   $15 = (($12) + ($8))|0;
   $16 = ($14>>>0)<($2>>>0);
   if ($16) {
    _abort();
    // unreachable;
   }
   $17 = HEAP32[(6964)>>2]|0;
   $18 = ($14|0)==($17|0);
   if ($18) {
    $$sum3 = (($8) + -4)|0;
    $103 = (($mem) + ($$sum3)|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = $104 & 3;
    $106 = ($105|0)==(3);
    if (!($106)) {
     $p$0 = $14;$psize$0 = $15;
     break;
    }
    HEAP32[(6952)>>2] = $15;
    $107 = $104 & -2;
    HEAP32[$103>>2] = $107;
    $108 = $15 | 1;
    $$sum20 = (($$sum2) + 4)|0;
    $109 = (($mem) + ($$sum20)|0);
    HEAP32[$109>>2] = $108;
    HEAP32[$9>>2] = $15;
    return;
   }
   $19 = $12 >>> 3;
   $20 = ($12>>>0)<(256);
   if ($20) {
    $$sum30 = (($$sum2) + 8)|0;
    $21 = (($mem) + ($$sum30)|0);
    $22 = HEAP32[$21>>2]|0;
    $$sum31 = (($$sum2) + 12)|0;
    $23 = (($mem) + ($$sum31)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = $19 << 1;
    $26 = (6984 + ($25<<2)|0);
    $27 = ($22|0)==($26|0);
    if (!($27)) {
     $28 = ($22>>>0)<($2>>>0);
     if ($28) {
      _abort();
      // unreachable;
     }
     $29 = ((($22)) + 12|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($14|0);
     if (!($31)) {
      _abort();
      // unreachable;
     }
    }
    $32 = ($24|0)==($22|0);
    if ($32) {
     $33 = 1 << $19;
     $34 = $33 ^ -1;
     $35 = HEAP32[6944>>2]|0;
     $36 = $35 & $34;
     HEAP32[6944>>2] = $36;
     $p$0 = $14;$psize$0 = $15;
     break;
    }
    $37 = ($24|0)==($26|0);
    if ($37) {
     $$pre60 = ((($24)) + 8|0);
     $$pre$phi61Z2D = $$pre60;
    } else {
     $38 = ($24>>>0)<($2>>>0);
     if ($38) {
      _abort();
      // unreachable;
     }
     $39 = ((($24)) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==($14|0);
     if ($41) {
      $$pre$phi61Z2D = $39;
     } else {
      _abort();
      // unreachable;
     }
    }
    $42 = ((($22)) + 12|0);
    HEAP32[$42>>2] = $24;
    HEAP32[$$pre$phi61Z2D>>2] = $22;
    $p$0 = $14;$psize$0 = $15;
    break;
   }
   $$sum22 = (($$sum2) + 24)|0;
   $43 = (($mem) + ($$sum22)|0);
   $44 = HEAP32[$43>>2]|0;
   $$sum23 = (($$sum2) + 12)|0;
   $45 = (($mem) + ($$sum23)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($14|0);
   do {
    if ($47) {
     $$sum25 = (($$sum2) + 20)|0;
     $57 = (($mem) + ($$sum25)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      $$sum24 = (($$sum2) + 16)|0;
      $60 = (($mem) + ($$sum24)|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if ($62) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $61;$RP$0 = $60;
      }
     } else {
      $R$0 = $58;$RP$0 = $57;
     }
     while(1) {
      $63 = ((($R$0)) + 20|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = ($64|0)==(0|0);
      if (!($65)) {
       $R$0 = $64;$RP$0 = $63;
       continue;
      }
      $66 = ((($R$0)) + 16|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==(0|0);
      if ($68) {
       $R$0$lcssa = $R$0;$RP$0$lcssa = $RP$0;
       break;
      } else {
       $R$0 = $67;$RP$0 = $66;
      }
     }
     $69 = ($RP$0$lcssa>>>0)<($2>>>0);
     if ($69) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0$lcssa>>2] = 0;
      $R$1 = $R$0$lcssa;
      break;
     }
    } else {
     $$sum29 = (($$sum2) + 8)|0;
     $48 = (($mem) + ($$sum29)|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49>>>0)<($2>>>0);
     if ($50) {
      _abort();
      // unreachable;
     }
     $51 = ((($49)) + 12|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==($14|0);
     if (!($53)) {
      _abort();
      // unreachable;
     }
     $54 = ((($46)) + 8|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==($14|0);
     if ($56) {
      HEAP32[$51>>2] = $46;
      HEAP32[$54>>2] = $49;
      $R$1 = $46;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $70 = ($44|0)==(0|0);
   if ($70) {
    $p$0 = $14;$psize$0 = $15;
   } else {
    $$sum26 = (($$sum2) + 28)|0;
    $71 = (($mem) + ($$sum26)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (7248 + ($72<<2)|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($14|0)==($74|0);
    if ($75) {
     HEAP32[$73>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $76 = 1 << $72;
      $77 = $76 ^ -1;
      $78 = HEAP32[(6948)>>2]|0;
      $79 = $78 & $77;
      HEAP32[(6948)>>2] = $79;
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    } else {
     $80 = HEAP32[(6960)>>2]|0;
     $81 = ($44>>>0)<($80>>>0);
     if ($81) {
      _abort();
      // unreachable;
     }
     $82 = ((($44)) + 16|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==($14|0);
     if ($84) {
      HEAP32[$82>>2] = $R$1;
     } else {
      $85 = ((($44)) + 20|0);
      HEAP32[$85>>2] = $R$1;
     }
     $86 = ($R$1|0)==(0|0);
     if ($86) {
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    }
    $87 = HEAP32[(6960)>>2]|0;
    $88 = ($R$1>>>0)<($87>>>0);
    if ($88) {
     _abort();
     // unreachable;
    }
    $89 = ((($R$1)) + 24|0);
    HEAP32[$89>>2] = $44;
    $$sum27 = (($$sum2) + 16)|0;
    $90 = (($mem) + ($$sum27)|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($91|0)==(0|0);
    do {
     if (!($92)) {
      $93 = ($91>>>0)<($87>>>0);
      if ($93) {
       _abort();
       // unreachable;
      } else {
       $94 = ((($R$1)) + 16|0);
       HEAP32[$94>>2] = $91;
       $95 = ((($91)) + 24|0);
       HEAP32[$95>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum28 = (($$sum2) + 20)|0;
    $96 = (($mem) + ($$sum28)|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($97|0)==(0|0);
    if ($98) {
     $p$0 = $14;$psize$0 = $15;
    } else {
     $99 = HEAP32[(6960)>>2]|0;
     $100 = ($97>>>0)<($99>>>0);
     if ($100) {
      _abort();
      // unreachable;
     } else {
      $101 = ((($R$1)) + 20|0);
      HEAP32[$101>>2] = $97;
      $102 = ((($97)) + 24|0);
      HEAP32[$102>>2] = $R$1;
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    }
   }
  } else {
   $p$0 = $1;$psize$0 = $8;
  }
 } while(0);
 $110 = ($p$0>>>0)<($9>>>0);
 if (!($110)) {
  _abort();
  // unreachable;
 }
 $$sum19 = (($8) + -4)|0;
 $111 = (($mem) + ($$sum19)|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = $112 & 1;
 $114 = ($113|0)==(0);
 if ($114) {
  _abort();
  // unreachable;
 }
 $115 = $112 & 2;
 $116 = ($115|0)==(0);
 if ($116) {
  $117 = HEAP32[(6968)>>2]|0;
  $118 = ($9|0)==($117|0);
  if ($118) {
   $119 = HEAP32[(6956)>>2]|0;
   $120 = (($119) + ($psize$0))|0;
   HEAP32[(6956)>>2] = $120;
   HEAP32[(6968)>>2] = $p$0;
   $121 = $120 | 1;
   $122 = ((($p$0)) + 4|0);
   HEAP32[$122>>2] = $121;
   $123 = HEAP32[(6964)>>2]|0;
   $124 = ($p$0|0)==($123|0);
   if (!($124)) {
    return;
   }
   HEAP32[(6964)>>2] = 0;
   HEAP32[(6952)>>2] = 0;
   return;
  }
  $125 = HEAP32[(6964)>>2]|0;
  $126 = ($9|0)==($125|0);
  if ($126) {
   $127 = HEAP32[(6952)>>2]|0;
   $128 = (($127) + ($psize$0))|0;
   HEAP32[(6952)>>2] = $128;
   HEAP32[(6964)>>2] = $p$0;
   $129 = $128 | 1;
   $130 = ((($p$0)) + 4|0);
   HEAP32[$130>>2] = $129;
   $131 = (($p$0) + ($128)|0);
   HEAP32[$131>>2] = $128;
   return;
  }
  $132 = $112 & -8;
  $133 = (($132) + ($psize$0))|0;
  $134 = $112 >>> 3;
  $135 = ($112>>>0)<(256);
  do {
   if ($135) {
    $136 = (($mem) + ($8)|0);
    $137 = HEAP32[$136>>2]|0;
    $$sum1718 = $8 | 4;
    $138 = (($mem) + ($$sum1718)|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = $134 << 1;
    $141 = (6984 + ($140<<2)|0);
    $142 = ($137|0)==($141|0);
    if (!($142)) {
     $143 = HEAP32[(6960)>>2]|0;
     $144 = ($137>>>0)<($143>>>0);
     if ($144) {
      _abort();
      // unreachable;
     }
     $145 = ((($137)) + 12|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = ($146|0)==($9|0);
     if (!($147)) {
      _abort();
      // unreachable;
     }
    }
    $148 = ($139|0)==($137|0);
    if ($148) {
     $149 = 1 << $134;
     $150 = $149 ^ -1;
     $151 = HEAP32[6944>>2]|0;
     $152 = $151 & $150;
     HEAP32[6944>>2] = $152;
     break;
    }
    $153 = ($139|0)==($141|0);
    if ($153) {
     $$pre58 = ((($139)) + 8|0);
     $$pre$phi59Z2D = $$pre58;
    } else {
     $154 = HEAP32[(6960)>>2]|0;
     $155 = ($139>>>0)<($154>>>0);
     if ($155) {
      _abort();
      // unreachable;
     }
     $156 = ((($139)) + 8|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = ($157|0)==($9|0);
     if ($158) {
      $$pre$phi59Z2D = $156;
     } else {
      _abort();
      // unreachable;
     }
    }
    $159 = ((($137)) + 12|0);
    HEAP32[$159>>2] = $139;
    HEAP32[$$pre$phi59Z2D>>2] = $137;
   } else {
    $$sum5 = (($8) + 16)|0;
    $160 = (($mem) + ($$sum5)|0);
    $161 = HEAP32[$160>>2]|0;
    $$sum67 = $8 | 4;
    $162 = (($mem) + ($$sum67)|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = ($163|0)==($9|0);
    do {
     if ($164) {
      $$sum9 = (($8) + 12)|0;
      $175 = (($mem) + ($$sum9)|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = ($176|0)==(0|0);
      if ($177) {
       $$sum8 = (($8) + 8)|0;
       $178 = (($mem) + ($$sum8)|0);
       $179 = HEAP32[$178>>2]|0;
       $180 = ($179|0)==(0|0);
       if ($180) {
        $R7$1 = 0;
        break;
       } else {
        $R7$0 = $179;$RP9$0 = $178;
       }
      } else {
       $R7$0 = $176;$RP9$0 = $175;
      }
      while(1) {
       $181 = ((($R7$0)) + 20|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = ($182|0)==(0|0);
       if (!($183)) {
        $R7$0 = $182;$RP9$0 = $181;
        continue;
       }
       $184 = ((($R7$0)) + 16|0);
       $185 = HEAP32[$184>>2]|0;
       $186 = ($185|0)==(0|0);
       if ($186) {
        $R7$0$lcssa = $R7$0;$RP9$0$lcssa = $RP9$0;
        break;
       } else {
        $R7$0 = $185;$RP9$0 = $184;
       }
      }
      $187 = HEAP32[(6960)>>2]|0;
      $188 = ($RP9$0$lcssa>>>0)<($187>>>0);
      if ($188) {
       _abort();
       // unreachable;
      } else {
       HEAP32[$RP9$0$lcssa>>2] = 0;
       $R7$1 = $R7$0$lcssa;
       break;
      }
     } else {
      $165 = (($mem) + ($8)|0);
      $166 = HEAP32[$165>>2]|0;
      $167 = HEAP32[(6960)>>2]|0;
      $168 = ($166>>>0)<($167>>>0);
      if ($168) {
       _abort();
       // unreachable;
      }
      $169 = ((($166)) + 12|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = ($170|0)==($9|0);
      if (!($171)) {
       _abort();
       // unreachable;
      }
      $172 = ((($163)) + 8|0);
      $173 = HEAP32[$172>>2]|0;
      $174 = ($173|0)==($9|0);
      if ($174) {
       HEAP32[$169>>2] = $163;
       HEAP32[$172>>2] = $166;
       $R7$1 = $163;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $189 = ($161|0)==(0|0);
    if (!($189)) {
     $$sum12 = (($8) + 20)|0;
     $190 = (($mem) + ($$sum12)|0);
     $191 = HEAP32[$190>>2]|0;
     $192 = (7248 + ($191<<2)|0);
     $193 = HEAP32[$192>>2]|0;
     $194 = ($9|0)==($193|0);
     if ($194) {
      HEAP32[$192>>2] = $R7$1;
      $cond47 = ($R7$1|0)==(0|0);
      if ($cond47) {
       $195 = 1 << $191;
       $196 = $195 ^ -1;
       $197 = HEAP32[(6948)>>2]|0;
       $198 = $197 & $196;
       HEAP32[(6948)>>2] = $198;
       break;
      }
     } else {
      $199 = HEAP32[(6960)>>2]|0;
      $200 = ($161>>>0)<($199>>>0);
      if ($200) {
       _abort();
       // unreachable;
      }
      $201 = ((($161)) + 16|0);
      $202 = HEAP32[$201>>2]|0;
      $203 = ($202|0)==($9|0);
      if ($203) {
       HEAP32[$201>>2] = $R7$1;
      } else {
       $204 = ((($161)) + 20|0);
       HEAP32[$204>>2] = $R7$1;
      }
      $205 = ($R7$1|0)==(0|0);
      if ($205) {
       break;
      }
     }
     $206 = HEAP32[(6960)>>2]|0;
     $207 = ($R7$1>>>0)<($206>>>0);
     if ($207) {
      _abort();
      // unreachable;
     }
     $208 = ((($R7$1)) + 24|0);
     HEAP32[$208>>2] = $161;
     $$sum13 = (($8) + 8)|0;
     $209 = (($mem) + ($$sum13)|0);
     $210 = HEAP32[$209>>2]|0;
     $211 = ($210|0)==(0|0);
     do {
      if (!($211)) {
       $212 = ($210>>>0)<($206>>>0);
       if ($212) {
        _abort();
        // unreachable;
       } else {
        $213 = ((($R7$1)) + 16|0);
        HEAP32[$213>>2] = $210;
        $214 = ((($210)) + 24|0);
        HEAP32[$214>>2] = $R7$1;
        break;
       }
      }
     } while(0);
     $$sum14 = (($8) + 12)|0;
     $215 = (($mem) + ($$sum14)|0);
     $216 = HEAP32[$215>>2]|0;
     $217 = ($216|0)==(0|0);
     if (!($217)) {
      $218 = HEAP32[(6960)>>2]|0;
      $219 = ($216>>>0)<($218>>>0);
      if ($219) {
       _abort();
       // unreachable;
      } else {
       $220 = ((($R7$1)) + 20|0);
       HEAP32[$220>>2] = $216;
       $221 = ((($216)) + 24|0);
       HEAP32[$221>>2] = $R7$1;
       break;
      }
     }
    }
   }
  } while(0);
  $222 = $133 | 1;
  $223 = ((($p$0)) + 4|0);
  HEAP32[$223>>2] = $222;
  $224 = (($p$0) + ($133)|0);
  HEAP32[$224>>2] = $133;
  $225 = HEAP32[(6964)>>2]|0;
  $226 = ($p$0|0)==($225|0);
  if ($226) {
   HEAP32[(6952)>>2] = $133;
   return;
  } else {
   $psize$1 = $133;
  }
 } else {
  $227 = $112 & -2;
  HEAP32[$111>>2] = $227;
  $228 = $psize$0 | 1;
  $229 = ((($p$0)) + 4|0);
  HEAP32[$229>>2] = $228;
  $230 = (($p$0) + ($psize$0)|0);
  HEAP32[$230>>2] = $psize$0;
  $psize$1 = $psize$0;
 }
 $231 = $psize$1 >>> 3;
 $232 = ($psize$1>>>0)<(256);
 if ($232) {
  $233 = $231 << 1;
  $234 = (6984 + ($233<<2)|0);
  $235 = HEAP32[6944>>2]|0;
  $236 = 1 << $231;
  $237 = $235 & $236;
  $238 = ($237|0)==(0);
  if ($238) {
   $239 = $235 | $236;
   HEAP32[6944>>2] = $239;
   $$pre = (($233) + 2)|0;
   $$pre57 = (6984 + ($$pre<<2)|0);
   $$pre$phiZ2D = $$pre57;$F16$0 = $234;
  } else {
   $$sum11 = (($233) + 2)|0;
   $240 = (6984 + ($$sum11<<2)|0);
   $241 = HEAP32[$240>>2]|0;
   $242 = HEAP32[(6960)>>2]|0;
   $243 = ($241>>>0)<($242>>>0);
   if ($243) {
    _abort();
    // unreachable;
   } else {
    $$pre$phiZ2D = $240;$F16$0 = $241;
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = $p$0;
  $244 = ((($F16$0)) + 12|0);
  HEAP32[$244>>2] = $p$0;
  $245 = ((($p$0)) + 8|0);
  HEAP32[$245>>2] = $F16$0;
  $246 = ((($p$0)) + 12|0);
  HEAP32[$246>>2] = $234;
  return;
 }
 $247 = $psize$1 >>> 8;
 $248 = ($247|0)==(0);
 if ($248) {
  $I18$0 = 0;
 } else {
  $249 = ($psize$1>>>0)>(16777215);
  if ($249) {
   $I18$0 = 31;
  } else {
   $250 = (($247) + 1048320)|0;
   $251 = $250 >>> 16;
   $252 = $251 & 8;
   $253 = $247 << $252;
   $254 = (($253) + 520192)|0;
   $255 = $254 >>> 16;
   $256 = $255 & 4;
   $257 = $256 | $252;
   $258 = $253 << $256;
   $259 = (($258) + 245760)|0;
   $260 = $259 >>> 16;
   $261 = $260 & 2;
   $262 = $257 | $261;
   $263 = (14 - ($262))|0;
   $264 = $258 << $261;
   $265 = $264 >>> 15;
   $266 = (($263) + ($265))|0;
   $267 = $266 << 1;
   $268 = (($266) + 7)|0;
   $269 = $psize$1 >>> $268;
   $270 = $269 & 1;
   $271 = $270 | $267;
   $I18$0 = $271;
  }
 }
 $272 = (7248 + ($I18$0<<2)|0);
 $273 = ((($p$0)) + 28|0);
 HEAP32[$273>>2] = $I18$0;
 $274 = ((($p$0)) + 16|0);
 $275 = ((($p$0)) + 20|0);
 HEAP32[$275>>2] = 0;
 HEAP32[$274>>2] = 0;
 $276 = HEAP32[(6948)>>2]|0;
 $277 = 1 << $I18$0;
 $278 = $276 & $277;
 $279 = ($278|0)==(0);
 L199: do {
  if ($279) {
   $280 = $276 | $277;
   HEAP32[(6948)>>2] = $280;
   HEAP32[$272>>2] = $p$0;
   $281 = ((($p$0)) + 24|0);
   HEAP32[$281>>2] = $272;
   $282 = ((($p$0)) + 12|0);
   HEAP32[$282>>2] = $p$0;
   $283 = ((($p$0)) + 8|0);
   HEAP32[$283>>2] = $p$0;
  } else {
   $284 = HEAP32[$272>>2]|0;
   $285 = ((($284)) + 4|0);
   $286 = HEAP32[$285>>2]|0;
   $287 = $286 & -8;
   $288 = ($287|0)==($psize$1|0);
   L201: do {
    if ($288) {
     $T$0$lcssa = $284;
    } else {
     $289 = ($I18$0|0)==(31);
     $290 = $I18$0 >>> 1;
     $291 = (25 - ($290))|0;
     $292 = $289 ? 0 : $291;
     $293 = $psize$1 << $292;
     $K19$052 = $293;$T$051 = $284;
     while(1) {
      $300 = $K19$052 >>> 31;
      $301 = (((($T$051)) + 16|0) + ($300<<2)|0);
      $296 = HEAP32[$301>>2]|0;
      $302 = ($296|0)==(0|0);
      if ($302) {
       $$lcssa = $301;$T$051$lcssa = $T$051;
       break;
      }
      $294 = $K19$052 << 1;
      $295 = ((($296)) + 4|0);
      $297 = HEAP32[$295>>2]|0;
      $298 = $297 & -8;
      $299 = ($298|0)==($psize$1|0);
      if ($299) {
       $T$0$lcssa = $296;
       break L201;
      } else {
       $K19$052 = $294;$T$051 = $296;
      }
     }
     $303 = HEAP32[(6960)>>2]|0;
     $304 = ($$lcssa>>>0)<($303>>>0);
     if ($304) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$$lcssa>>2] = $p$0;
      $305 = ((($p$0)) + 24|0);
      HEAP32[$305>>2] = $T$051$lcssa;
      $306 = ((($p$0)) + 12|0);
      HEAP32[$306>>2] = $p$0;
      $307 = ((($p$0)) + 8|0);
      HEAP32[$307>>2] = $p$0;
      break L199;
     }
    }
   } while(0);
   $308 = ((($T$0$lcssa)) + 8|0);
   $309 = HEAP32[$308>>2]|0;
   $310 = HEAP32[(6960)>>2]|0;
   $311 = ($309>>>0)>=($310>>>0);
   $not$ = ($T$0$lcssa>>>0)>=($310>>>0);
   $312 = $311 & $not$;
   if ($312) {
    $313 = ((($309)) + 12|0);
    HEAP32[$313>>2] = $p$0;
    HEAP32[$308>>2] = $p$0;
    $314 = ((($p$0)) + 8|0);
    HEAP32[$314>>2] = $309;
    $315 = ((($p$0)) + 12|0);
    HEAP32[$315>>2] = $T$0$lcssa;
    $316 = ((($p$0)) + 24|0);
    HEAP32[$316>>2] = 0;
    break;
   } else {
    _abort();
    // unreachable;
   }
  }
 } while(0);
 $317 = HEAP32[(6976)>>2]|0;
 $318 = (($317) + -1)|0;
 HEAP32[(6976)>>2] = $318;
 $319 = ($318|0)==(0);
 if ($319) {
  $sp$0$in$i = (7400);
 } else {
  return;
 }
 while(1) {
  $sp$0$i = HEAP32[$sp$0$in$i>>2]|0;
  $320 = ($sp$0$i|0)==(0|0);
  $321 = ((($sp$0$i)) + 8|0);
  if ($320) {
   break;
  } else {
   $sp$0$in$i = $321;
  }
 }
 HEAP32[(6976)>>2] = -1;
 return;
}
function _realloc($oldmem,$bytes) {
 $oldmem = $oldmem|0;
 $bytes = $bytes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $mem$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($oldmem|0)==(0|0);
 if ($0) {
  $1 = (_malloc($bytes)|0);
  $mem$0 = $1;
  return ($mem$0|0);
 }
 $2 = ($bytes>>>0)>(4294967231);
 if ($2) {
  $3 = (___errno_location()|0);
  HEAP32[$3>>2] = 12;
  $mem$0 = 0;
  return ($mem$0|0);
 }
 $4 = ($bytes>>>0)<(11);
 $5 = (($bytes) + 11)|0;
 $6 = $5 & -8;
 $7 = $4 ? 16 : $6;
 $8 = ((($oldmem)) + -8|0);
 $9 = (_try_realloc_chunk($8,$7)|0);
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = ((($9)) + 8|0);
  $mem$0 = $11;
  return ($mem$0|0);
 }
 $12 = (_malloc($bytes)|0);
 $13 = ($12|0)==(0|0);
 if ($13) {
  $mem$0 = 0;
  return ($mem$0|0);
 }
 $14 = ((($oldmem)) + -4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & -8;
 $17 = $15 & 3;
 $18 = ($17|0)==(0);
 $19 = $18 ? 8 : 4;
 $20 = (($16) - ($19))|0;
 $21 = ($20>>>0)<($bytes>>>0);
 $22 = $21 ? $20 : $bytes;
 _memcpy(($12|0),($oldmem|0),($22|0))|0;
 _free($oldmem);
 $mem$0 = $12;
 return ($mem$0|0);
}
function _try_realloc_chunk($p,$nb) {
 $p = $p|0;
 $nb = $nb|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum22 = 0, $$sum23 = 0, $$sum2728 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum78 = 0;
 var $$sum910 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $R$0 = 0, $R$0$lcssa = 0, $R$1 = 0, $RP$0 = 0, $RP$0$lcssa = 0, $cond = 0, $newp$0 = 0, $notlhs = 0;
 var $notrhs = 0, $or$cond$not = 0, $or$cond30 = 0, $storemerge = 0, $storemerge21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($p)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -8;
 $3 = (($p) + ($2)|0);
 $4 = HEAP32[(6960)>>2]|0;
 $5 = $1 & 3;
 $notlhs = ($p>>>0)>=($4>>>0);
 $notrhs = ($5|0)!=(1);
 $or$cond$not = $notrhs & $notlhs;
 $6 = ($p>>>0)<($3>>>0);
 $or$cond30 = $or$cond$not & $6;
 if (!($or$cond30)) {
  _abort();
  // unreachable;
 }
 $$sum2728 = $2 | 4;
 $7 = (($p) + ($$sum2728)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($10) {
  _abort();
  // unreachable;
 }
 $11 = ($5|0)==(0);
 if ($11) {
  $12 = ($nb>>>0)<(256);
  if ($12) {
   $newp$0 = 0;
   return ($newp$0|0);
  }
  $13 = (($nb) + 4)|0;
  $14 = ($2>>>0)<($13>>>0);
  if (!($14)) {
   $15 = (($2) - ($nb))|0;
   $16 = HEAP32[(7424)>>2]|0;
   $17 = $16 << 1;
   $18 = ($15>>>0)>($17>>>0);
   if (!($18)) {
    $newp$0 = $p;
    return ($newp$0|0);
   }
  }
  $newp$0 = 0;
  return ($newp$0|0);
 }
 $19 = ($2>>>0)<($nb>>>0);
 if (!($19)) {
  $20 = (($2) - ($nb))|0;
  $21 = ($20>>>0)>(15);
  if (!($21)) {
   $newp$0 = $p;
   return ($newp$0|0);
  }
  $22 = (($p) + ($nb)|0);
  $23 = $1 & 1;
  $24 = $23 | $nb;
  $25 = $24 | 2;
  HEAP32[$0>>2] = $25;
  $$sum23 = (($nb) + 4)|0;
  $26 = (($p) + ($$sum23)|0);
  $27 = $20 | 3;
  HEAP32[$26>>2] = $27;
  $28 = HEAP32[$7>>2]|0;
  $29 = $28 | 1;
  HEAP32[$7>>2] = $29;
  _dispose_chunk($22,$20);
  $newp$0 = $p;
  return ($newp$0|0);
 }
 $30 = HEAP32[(6968)>>2]|0;
 $31 = ($3|0)==($30|0);
 if ($31) {
  $32 = HEAP32[(6956)>>2]|0;
  $33 = (($32) + ($2))|0;
  $34 = ($33>>>0)>($nb>>>0);
  if (!($34)) {
   $newp$0 = 0;
   return ($newp$0|0);
  }
  $35 = (($33) - ($nb))|0;
  $36 = (($p) + ($nb)|0);
  $37 = $1 & 1;
  $38 = $37 | $nb;
  $39 = $38 | 2;
  HEAP32[$0>>2] = $39;
  $$sum22 = (($nb) + 4)|0;
  $40 = (($p) + ($$sum22)|0);
  $41 = $35 | 1;
  HEAP32[$40>>2] = $41;
  HEAP32[(6968)>>2] = $36;
  HEAP32[(6956)>>2] = $35;
  $newp$0 = $p;
  return ($newp$0|0);
 }
 $42 = HEAP32[(6964)>>2]|0;
 $43 = ($3|0)==($42|0);
 if ($43) {
  $44 = HEAP32[(6952)>>2]|0;
  $45 = (($44) + ($2))|0;
  $46 = ($45>>>0)<($nb>>>0);
  if ($46) {
   $newp$0 = 0;
   return ($newp$0|0);
  }
  $47 = (($45) - ($nb))|0;
  $48 = ($47>>>0)>(15);
  if ($48) {
   $49 = (($p) + ($nb)|0);
   $50 = (($p) + ($45)|0);
   $51 = $1 & 1;
   $52 = $51 | $nb;
   $53 = $52 | 2;
   HEAP32[$0>>2] = $53;
   $$sum19 = (($nb) + 4)|0;
   $54 = (($p) + ($$sum19)|0);
   $55 = $47 | 1;
   HEAP32[$54>>2] = $55;
   HEAP32[$50>>2] = $47;
   $$sum20 = (($45) + 4)|0;
   $56 = (($p) + ($$sum20)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $57 & -2;
   HEAP32[$56>>2] = $58;
   $storemerge = $49;$storemerge21 = $47;
  } else {
   $59 = $1 & 1;
   $60 = $59 | $45;
   $61 = $60 | 2;
   HEAP32[$0>>2] = $61;
   $$sum17 = (($45) + 4)|0;
   $62 = (($p) + ($$sum17)|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = $63 | 1;
   HEAP32[$62>>2] = $64;
   $storemerge = 0;$storemerge21 = 0;
  }
  HEAP32[(6952)>>2] = $storemerge21;
  HEAP32[(6964)>>2] = $storemerge;
  $newp$0 = $p;
  return ($newp$0|0);
 }
 $65 = $8 & 2;
 $66 = ($65|0)==(0);
 if (!($66)) {
  $newp$0 = 0;
  return ($newp$0|0);
 }
 $67 = $8 & -8;
 $68 = (($67) + ($2))|0;
 $69 = ($68>>>0)<($nb>>>0);
 if ($69) {
  $newp$0 = 0;
  return ($newp$0|0);
 }
 $70 = (($68) - ($nb))|0;
 $71 = $8 >>> 3;
 $72 = ($8>>>0)<(256);
 do {
  if ($72) {
   $$sum15 = (($2) + 8)|0;
   $73 = (($p) + ($$sum15)|0);
   $74 = HEAP32[$73>>2]|0;
   $$sum16 = (($2) + 12)|0;
   $75 = (($p) + ($$sum16)|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = $71 << 1;
   $78 = (6984 + ($77<<2)|0);
   $79 = ($74|0)==($78|0);
   if (!($79)) {
    $80 = ($74>>>0)<($4>>>0);
    if ($80) {
     _abort();
     // unreachable;
    }
    $81 = ((($74)) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ($82|0)==($3|0);
    if (!($83)) {
     _abort();
     // unreachable;
    }
   }
   $84 = ($76|0)==($74|0);
   if ($84) {
    $85 = 1 << $71;
    $86 = $85 ^ -1;
    $87 = HEAP32[6944>>2]|0;
    $88 = $87 & $86;
    HEAP32[6944>>2] = $88;
    break;
   }
   $89 = ($76|0)==($78|0);
   if ($89) {
    $$pre = ((($76)) + 8|0);
    $$pre$phiZ2D = $$pre;
   } else {
    $90 = ($76>>>0)<($4>>>0);
    if ($90) {
     _abort();
     // unreachable;
    }
    $91 = ((($76)) + 8|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==($3|0);
    if ($93) {
     $$pre$phiZ2D = $91;
    } else {
     _abort();
     // unreachable;
    }
   }
   $94 = ((($74)) + 12|0);
   HEAP32[$94>>2] = $76;
   HEAP32[$$pre$phiZ2D>>2] = $74;
  } else {
   $$sum = (($2) + 24)|0;
   $95 = (($p) + ($$sum)|0);
   $96 = HEAP32[$95>>2]|0;
   $$sum2 = (($2) + 12)|0;
   $97 = (($p) + ($$sum2)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==($3|0);
   do {
    if ($99) {
     $$sum4 = (($2) + 20)|0;
     $109 = (($p) + ($$sum4)|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($110|0)==(0|0);
     if ($111) {
      $$sum3 = (($2) + 16)|0;
      $112 = (($p) + ($$sum3)|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = ($113|0)==(0|0);
      if ($114) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $113;$RP$0 = $112;
      }
     } else {
      $R$0 = $110;$RP$0 = $109;
     }
     while(1) {
      $115 = ((($R$0)) + 20|0);
      $116 = HEAP32[$115>>2]|0;
      $117 = ($116|0)==(0|0);
      if (!($117)) {
       $R$0 = $116;$RP$0 = $115;
       continue;
      }
      $118 = ((($R$0)) + 16|0);
      $119 = HEAP32[$118>>2]|0;
      $120 = ($119|0)==(0|0);
      if ($120) {
       $R$0$lcssa = $R$0;$RP$0$lcssa = $RP$0;
       break;
      } else {
       $R$0 = $119;$RP$0 = $118;
      }
     }
     $121 = ($RP$0$lcssa>>>0)<($4>>>0);
     if ($121) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0$lcssa>>2] = 0;
      $R$1 = $R$0$lcssa;
      break;
     }
    } else {
     $$sum14 = (($2) + 8)|0;
     $100 = (($p) + ($$sum14)|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($101>>>0)<($4>>>0);
     if ($102) {
      _abort();
      // unreachable;
     }
     $103 = ((($101)) + 12|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = ($104|0)==($3|0);
     if (!($105)) {
      _abort();
      // unreachable;
     }
     $106 = ((($98)) + 8|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = ($107|0)==($3|0);
     if ($108) {
      HEAP32[$103>>2] = $98;
      HEAP32[$106>>2] = $101;
      $R$1 = $98;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $122 = ($96|0)==(0|0);
   if (!($122)) {
    $$sum11 = (($2) + 28)|0;
    $123 = (($p) + ($$sum11)|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (7248 + ($124<<2)|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ($3|0)==($126|0);
    if ($127) {
     HEAP32[$125>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $128 = 1 << $124;
      $129 = $128 ^ -1;
      $130 = HEAP32[(6948)>>2]|0;
      $131 = $130 & $129;
      HEAP32[(6948)>>2] = $131;
      break;
     }
    } else {
     $132 = HEAP32[(6960)>>2]|0;
     $133 = ($96>>>0)<($132>>>0);
     if ($133) {
      _abort();
      // unreachable;
     }
     $134 = ((($96)) + 16|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ($135|0)==($3|0);
     if ($136) {
      HEAP32[$134>>2] = $R$1;
     } else {
      $137 = ((($96)) + 20|0);
      HEAP32[$137>>2] = $R$1;
     }
     $138 = ($R$1|0)==(0|0);
     if ($138) {
      break;
     }
    }
    $139 = HEAP32[(6960)>>2]|0;
    $140 = ($R$1>>>0)<($139>>>0);
    if ($140) {
     _abort();
     // unreachable;
    }
    $141 = ((($R$1)) + 24|0);
    HEAP32[$141>>2] = $96;
    $$sum12 = (($2) + 16)|0;
    $142 = (($p) + ($$sum12)|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = ($143|0)==(0|0);
    do {
     if (!($144)) {
      $145 = ($143>>>0)<($139>>>0);
      if ($145) {
       _abort();
       // unreachable;
      } else {
       $146 = ((($R$1)) + 16|0);
       HEAP32[$146>>2] = $143;
       $147 = ((($143)) + 24|0);
       HEAP32[$147>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum13 = (($2) + 20)|0;
    $148 = (($p) + ($$sum13)|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = ($149|0)==(0|0);
    if (!($150)) {
     $151 = HEAP32[(6960)>>2]|0;
     $152 = ($149>>>0)<($151>>>0);
     if ($152) {
      _abort();
      // unreachable;
     } else {
      $153 = ((($R$1)) + 20|0);
      HEAP32[$153>>2] = $149;
      $154 = ((($149)) + 24|0);
      HEAP32[$154>>2] = $R$1;
      break;
     }
    }
   }
  }
 } while(0);
 $155 = ($70>>>0)<(16);
 if ($155) {
  $156 = $1 & 1;
  $157 = $68 | $156;
  $158 = $157 | 2;
  HEAP32[$0>>2] = $158;
  $$sum910 = $68 | 4;
  $159 = (($p) + ($$sum910)|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = $160 | 1;
  HEAP32[$159>>2] = $161;
  $newp$0 = $p;
  return ($newp$0|0);
 } else {
  $162 = (($p) + ($nb)|0);
  $163 = $1 & 1;
  $164 = $163 | $nb;
  $165 = $164 | 2;
  HEAP32[$0>>2] = $165;
  $$sum5 = (($nb) + 4)|0;
  $166 = (($p) + ($$sum5)|0);
  $167 = $70 | 3;
  HEAP32[$166>>2] = $167;
  $$sum78 = $68 | 4;
  $168 = (($p) + ($$sum78)|0);
  $169 = HEAP32[$168>>2]|0;
  $170 = $169 | 1;
  HEAP32[$168>>2] = $170;
  _dispose_chunk($162,$70);
  $newp$0 = $p;
  return ($newp$0|0);
 }
 return (0)|0;
}
function _dispose_chunk($p,$psize) {
 $p = $p|0;
 $psize = $psize|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$lcssa = 0, $$pre = 0, $$pre$phi50Z2D = 0, $$pre$phi52Z2D = 0, $$pre$phiZ2D = 0, $$pre48 = 0, $$pre49 = 0, $$pre51 = 0, $$sum = 0, $$sum1 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum16 = 0, $$sum17 = 0;
 var $$sum18 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum25 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $F16$0 = 0, $I19$0 = 0, $K20$043 = 0, $R$0 = 0, $R$0$lcssa = 0, $R$1 = 0, $R7$0 = 0, $R7$0$lcssa = 0, $R7$1 = 0, $RP$0 = 0, $RP$0$lcssa = 0, $RP9$0 = 0, $RP9$0$lcssa = 0, $T$0$lcssa = 0, $T$042 = 0, $T$042$lcssa = 0, $cond = 0;
 var $cond39 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($p) + ($psize)|0);
 $1 = ((($p)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 1;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = HEAP32[$p>>2]|0;
   $6 = $2 & 3;
   $7 = ($6|0)==(0);
   if ($7) {
    return;
   }
   $8 = (0 - ($5))|0;
   $9 = (($p) + ($8)|0);
   $10 = (($5) + ($psize))|0;
   $11 = HEAP32[(6960)>>2]|0;
   $12 = ($9>>>0)<($11>>>0);
   if ($12) {
    _abort();
    // unreachable;
   }
   $13 = HEAP32[(6964)>>2]|0;
   $14 = ($9|0)==($13|0);
   if ($14) {
    $$sum = (($psize) + 4)|0;
    $99 = (($p) + ($$sum)|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = $100 & 3;
    $102 = ($101|0)==(3);
    if (!($102)) {
     $$0 = $9;$$02 = $10;
     break;
    }
    HEAP32[(6952)>>2] = $10;
    $103 = $100 & -2;
    HEAP32[$99>>2] = $103;
    $104 = $10 | 1;
    $$sum14 = (4 - ($5))|0;
    $105 = (($p) + ($$sum14)|0);
    HEAP32[$105>>2] = $104;
    HEAP32[$0>>2] = $10;
    return;
   }
   $15 = $5 >>> 3;
   $16 = ($5>>>0)<(256);
   if ($16) {
    $$sum24 = (8 - ($5))|0;
    $17 = (($p) + ($$sum24)|0);
    $18 = HEAP32[$17>>2]|0;
    $$sum25 = (12 - ($5))|0;
    $19 = (($p) + ($$sum25)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $15 << 1;
    $22 = (6984 + ($21<<2)|0);
    $23 = ($18|0)==($22|0);
    if (!($23)) {
     $24 = ($18>>>0)<($11>>>0);
     if ($24) {
      _abort();
      // unreachable;
     }
     $25 = ((($18)) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26|0)==($9|0);
     if (!($27)) {
      _abort();
      // unreachable;
     }
    }
    $28 = ($20|0)==($18|0);
    if ($28) {
     $29 = 1 << $15;
     $30 = $29 ^ -1;
     $31 = HEAP32[6944>>2]|0;
     $32 = $31 & $30;
     HEAP32[6944>>2] = $32;
     $$0 = $9;$$02 = $10;
     break;
    }
    $33 = ($20|0)==($22|0);
    if ($33) {
     $$pre51 = ((($20)) + 8|0);
     $$pre$phi52Z2D = $$pre51;
    } else {
     $34 = ($20>>>0)<($11>>>0);
     if ($34) {
      _abort();
      // unreachable;
     }
     $35 = ((($20)) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==($9|0);
     if ($37) {
      $$pre$phi52Z2D = $35;
     } else {
      _abort();
      // unreachable;
     }
    }
    $38 = ((($18)) + 12|0);
    HEAP32[$38>>2] = $20;
    HEAP32[$$pre$phi52Z2D>>2] = $18;
    $$0 = $9;$$02 = $10;
    break;
   }
   $$sum16 = (24 - ($5))|0;
   $39 = (($p) + ($$sum16)|0);
   $40 = HEAP32[$39>>2]|0;
   $$sum17 = (12 - ($5))|0;
   $41 = (($p) + ($$sum17)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==($9|0);
   do {
    if ($43) {
     $$sum18 = (16 - ($5))|0;
     $$sum19 = (($$sum18) + 4)|0;
     $53 = (($p) + ($$sum19)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ($54|0)==(0|0);
     if ($55) {
      $56 = (($p) + ($$sum18)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(0|0);
      if ($58) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $57;$RP$0 = $56;
      }
     } else {
      $R$0 = $54;$RP$0 = $53;
     }
     while(1) {
      $59 = ((($R$0)) + 20|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if (!($61)) {
       $R$0 = $60;$RP$0 = $59;
       continue;
      }
      $62 = ((($R$0)) + 16|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($63|0)==(0|0);
      if ($64) {
       $R$0$lcssa = $R$0;$RP$0$lcssa = $RP$0;
       break;
      } else {
       $R$0 = $63;$RP$0 = $62;
      }
     }
     $65 = ($RP$0$lcssa>>>0)<($11>>>0);
     if ($65) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0$lcssa>>2] = 0;
      $R$1 = $R$0$lcssa;
      break;
     }
    } else {
     $$sum23 = (8 - ($5))|0;
     $44 = (($p) + ($$sum23)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($11>>>0);
     if ($46) {
      _abort();
      // unreachable;
     }
     $47 = ((($45)) + 12|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==($9|0);
     if (!($49)) {
      _abort();
      // unreachable;
     }
     $50 = ((($42)) + 8|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($9|0);
     if ($52) {
      HEAP32[$47>>2] = $42;
      HEAP32[$50>>2] = $45;
      $R$1 = $42;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $66 = ($40|0)==(0|0);
   if ($66) {
    $$0 = $9;$$02 = $10;
   } else {
    $$sum20 = (28 - ($5))|0;
    $67 = (($p) + ($$sum20)|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (7248 + ($68<<2)|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($9|0)==($70|0);
    if ($71) {
     HEAP32[$69>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $72 = 1 << $68;
      $73 = $72 ^ -1;
      $74 = HEAP32[(6948)>>2]|0;
      $75 = $74 & $73;
      HEAP32[(6948)>>2] = $75;
      $$0 = $9;$$02 = $10;
      break;
     }
    } else {
     $76 = HEAP32[(6960)>>2]|0;
     $77 = ($40>>>0)<($76>>>0);
     if ($77) {
      _abort();
      // unreachable;
     }
     $78 = ((($40)) + 16|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($79|0)==($9|0);
     if ($80) {
      HEAP32[$78>>2] = $R$1;
     } else {
      $81 = ((($40)) + 20|0);
      HEAP32[$81>>2] = $R$1;
     }
     $82 = ($R$1|0)==(0|0);
     if ($82) {
      $$0 = $9;$$02 = $10;
      break;
     }
    }
    $83 = HEAP32[(6960)>>2]|0;
    $84 = ($R$1>>>0)<($83>>>0);
    if ($84) {
     _abort();
     // unreachable;
    }
    $85 = ((($R$1)) + 24|0);
    HEAP32[$85>>2] = $40;
    $$sum21 = (16 - ($5))|0;
    $86 = (($p) + ($$sum21)|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87|0)==(0|0);
    do {
     if (!($88)) {
      $89 = ($87>>>0)<($83>>>0);
      if ($89) {
       _abort();
       // unreachable;
      } else {
       $90 = ((($R$1)) + 16|0);
       HEAP32[$90>>2] = $87;
       $91 = ((($87)) + 24|0);
       HEAP32[$91>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum22 = (($$sum21) + 4)|0;
    $92 = (($p) + ($$sum22)|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ($93|0)==(0|0);
    if ($94) {
     $$0 = $9;$$02 = $10;
    } else {
     $95 = HEAP32[(6960)>>2]|0;
     $96 = ($93>>>0)<($95>>>0);
     if ($96) {
      _abort();
      // unreachable;
     } else {
      $97 = ((($R$1)) + 20|0);
      HEAP32[$97>>2] = $93;
      $98 = ((($93)) + 24|0);
      HEAP32[$98>>2] = $R$1;
      $$0 = $9;$$02 = $10;
      break;
     }
    }
   }
  } else {
   $$0 = $p;$$02 = $psize;
  }
 } while(0);
 $106 = HEAP32[(6960)>>2]|0;
 $107 = ($0>>>0)<($106>>>0);
 if ($107) {
  _abort();
  // unreachable;
 }
 $$sum1 = (($psize) + 4)|0;
 $108 = (($p) + ($$sum1)|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = $109 & 2;
 $111 = ($110|0)==(0);
 if ($111) {
  $112 = HEAP32[(6968)>>2]|0;
  $113 = ($0|0)==($112|0);
  if ($113) {
   $114 = HEAP32[(6956)>>2]|0;
   $115 = (($114) + ($$02))|0;
   HEAP32[(6956)>>2] = $115;
   HEAP32[(6968)>>2] = $$0;
   $116 = $115 | 1;
   $117 = ((($$0)) + 4|0);
   HEAP32[$117>>2] = $116;
   $118 = HEAP32[(6964)>>2]|0;
   $119 = ($$0|0)==($118|0);
   if (!($119)) {
    return;
   }
   HEAP32[(6964)>>2] = 0;
   HEAP32[(6952)>>2] = 0;
   return;
  }
  $120 = HEAP32[(6964)>>2]|0;
  $121 = ($0|0)==($120|0);
  if ($121) {
   $122 = HEAP32[(6952)>>2]|0;
   $123 = (($122) + ($$02))|0;
   HEAP32[(6952)>>2] = $123;
   HEAP32[(6964)>>2] = $$0;
   $124 = $123 | 1;
   $125 = ((($$0)) + 4|0);
   HEAP32[$125>>2] = $124;
   $126 = (($$0) + ($123)|0);
   HEAP32[$126>>2] = $123;
   return;
  }
  $127 = $109 & -8;
  $128 = (($127) + ($$02))|0;
  $129 = $109 >>> 3;
  $130 = ($109>>>0)<(256);
  do {
   if ($130) {
    $$sum12 = (($psize) + 8)|0;
    $131 = (($p) + ($$sum12)|0);
    $132 = HEAP32[$131>>2]|0;
    $$sum13 = (($psize) + 12)|0;
    $133 = (($p) + ($$sum13)|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = $129 << 1;
    $136 = (6984 + ($135<<2)|0);
    $137 = ($132|0)==($136|0);
    if (!($137)) {
     $138 = ($132>>>0)<($106>>>0);
     if ($138) {
      _abort();
      // unreachable;
     }
     $139 = ((($132)) + 12|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = ($140|0)==($0|0);
     if (!($141)) {
      _abort();
      // unreachable;
     }
    }
    $142 = ($134|0)==($132|0);
    if ($142) {
     $143 = 1 << $129;
     $144 = $143 ^ -1;
     $145 = HEAP32[6944>>2]|0;
     $146 = $145 & $144;
     HEAP32[6944>>2] = $146;
     break;
    }
    $147 = ($134|0)==($136|0);
    if ($147) {
     $$pre49 = ((($134)) + 8|0);
     $$pre$phi50Z2D = $$pre49;
    } else {
     $148 = ($134>>>0)<($106>>>0);
     if ($148) {
      _abort();
      // unreachable;
     }
     $149 = ((($134)) + 8|0);
     $150 = HEAP32[$149>>2]|0;
     $151 = ($150|0)==($0|0);
     if ($151) {
      $$pre$phi50Z2D = $149;
     } else {
      _abort();
      // unreachable;
     }
    }
    $152 = ((($132)) + 12|0);
    HEAP32[$152>>2] = $134;
    HEAP32[$$pre$phi50Z2D>>2] = $132;
   } else {
    $$sum2 = (($psize) + 24)|0;
    $153 = (($p) + ($$sum2)|0);
    $154 = HEAP32[$153>>2]|0;
    $$sum3 = (($psize) + 12)|0;
    $155 = (($p) + ($$sum3)|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = ($156|0)==($0|0);
    do {
     if ($157) {
      $$sum5 = (($psize) + 20)|0;
      $167 = (($p) + ($$sum5)|0);
      $168 = HEAP32[$167>>2]|0;
      $169 = ($168|0)==(0|0);
      if ($169) {
       $$sum4 = (($psize) + 16)|0;
       $170 = (($p) + ($$sum4)|0);
       $171 = HEAP32[$170>>2]|0;
       $172 = ($171|0)==(0|0);
       if ($172) {
        $R7$1 = 0;
        break;
       } else {
        $R7$0 = $171;$RP9$0 = $170;
       }
      } else {
       $R7$0 = $168;$RP9$0 = $167;
      }
      while(1) {
       $173 = ((($R7$0)) + 20|0);
       $174 = HEAP32[$173>>2]|0;
       $175 = ($174|0)==(0|0);
       if (!($175)) {
        $R7$0 = $174;$RP9$0 = $173;
        continue;
       }
       $176 = ((($R7$0)) + 16|0);
       $177 = HEAP32[$176>>2]|0;
       $178 = ($177|0)==(0|0);
       if ($178) {
        $R7$0$lcssa = $R7$0;$RP9$0$lcssa = $RP9$0;
        break;
       } else {
        $R7$0 = $177;$RP9$0 = $176;
       }
      }
      $179 = ($RP9$0$lcssa>>>0)<($106>>>0);
      if ($179) {
       _abort();
       // unreachable;
      } else {
       HEAP32[$RP9$0$lcssa>>2] = 0;
       $R7$1 = $R7$0$lcssa;
       break;
      }
     } else {
      $$sum11 = (($psize) + 8)|0;
      $158 = (($p) + ($$sum11)|0);
      $159 = HEAP32[$158>>2]|0;
      $160 = ($159>>>0)<($106>>>0);
      if ($160) {
       _abort();
       // unreachable;
      }
      $161 = ((($159)) + 12|0);
      $162 = HEAP32[$161>>2]|0;
      $163 = ($162|0)==($0|0);
      if (!($163)) {
       _abort();
       // unreachable;
      }
      $164 = ((($156)) + 8|0);
      $165 = HEAP32[$164>>2]|0;
      $166 = ($165|0)==($0|0);
      if ($166) {
       HEAP32[$161>>2] = $156;
       HEAP32[$164>>2] = $159;
       $R7$1 = $156;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $180 = ($154|0)==(0|0);
    if (!($180)) {
     $$sum8 = (($psize) + 28)|0;
     $181 = (($p) + ($$sum8)|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = (7248 + ($182<<2)|0);
     $184 = HEAP32[$183>>2]|0;
     $185 = ($0|0)==($184|0);
     if ($185) {
      HEAP32[$183>>2] = $R7$1;
      $cond39 = ($R7$1|0)==(0|0);
      if ($cond39) {
       $186 = 1 << $182;
       $187 = $186 ^ -1;
       $188 = HEAP32[(6948)>>2]|0;
       $189 = $188 & $187;
       HEAP32[(6948)>>2] = $189;
       break;
      }
     } else {
      $190 = HEAP32[(6960)>>2]|0;
      $191 = ($154>>>0)<($190>>>0);
      if ($191) {
       _abort();
       // unreachable;
      }
      $192 = ((($154)) + 16|0);
      $193 = HEAP32[$192>>2]|0;
      $194 = ($193|0)==($0|0);
      if ($194) {
       HEAP32[$192>>2] = $R7$1;
      } else {
       $195 = ((($154)) + 20|0);
       HEAP32[$195>>2] = $R7$1;
      }
      $196 = ($R7$1|0)==(0|0);
      if ($196) {
       break;
      }
     }
     $197 = HEAP32[(6960)>>2]|0;
     $198 = ($R7$1>>>0)<($197>>>0);
     if ($198) {
      _abort();
      // unreachable;
     }
     $199 = ((($R7$1)) + 24|0);
     HEAP32[$199>>2] = $154;
     $$sum9 = (($psize) + 16)|0;
     $200 = (($p) + ($$sum9)|0);
     $201 = HEAP32[$200>>2]|0;
     $202 = ($201|0)==(0|0);
     do {
      if (!($202)) {
       $203 = ($201>>>0)<($197>>>0);
       if ($203) {
        _abort();
        // unreachable;
       } else {
        $204 = ((($R7$1)) + 16|0);
        HEAP32[$204>>2] = $201;
        $205 = ((($201)) + 24|0);
        HEAP32[$205>>2] = $R7$1;
        break;
       }
      }
     } while(0);
     $$sum10 = (($psize) + 20)|0;
     $206 = (($p) + ($$sum10)|0);
     $207 = HEAP32[$206>>2]|0;
     $208 = ($207|0)==(0|0);
     if (!($208)) {
      $209 = HEAP32[(6960)>>2]|0;
      $210 = ($207>>>0)<($209>>>0);
      if ($210) {
       _abort();
       // unreachable;
      } else {
       $211 = ((($R7$1)) + 20|0);
       HEAP32[$211>>2] = $207;
       $212 = ((($207)) + 24|0);
       HEAP32[$212>>2] = $R7$1;
       break;
      }
     }
    }
   }
  } while(0);
  $213 = $128 | 1;
  $214 = ((($$0)) + 4|0);
  HEAP32[$214>>2] = $213;
  $215 = (($$0) + ($128)|0);
  HEAP32[$215>>2] = $128;
  $216 = HEAP32[(6964)>>2]|0;
  $217 = ($$0|0)==($216|0);
  if ($217) {
   HEAP32[(6952)>>2] = $128;
   return;
  } else {
   $$1 = $128;
  }
 } else {
  $218 = $109 & -2;
  HEAP32[$108>>2] = $218;
  $219 = $$02 | 1;
  $220 = ((($$0)) + 4|0);
  HEAP32[$220>>2] = $219;
  $221 = (($$0) + ($$02)|0);
  HEAP32[$221>>2] = $$02;
  $$1 = $$02;
 }
 $222 = $$1 >>> 3;
 $223 = ($$1>>>0)<(256);
 if ($223) {
  $224 = $222 << 1;
  $225 = (6984 + ($224<<2)|0);
  $226 = HEAP32[6944>>2]|0;
  $227 = 1 << $222;
  $228 = $226 & $227;
  $229 = ($228|0)==(0);
  if ($229) {
   $230 = $226 | $227;
   HEAP32[6944>>2] = $230;
   $$pre = (($224) + 2)|0;
   $$pre48 = (6984 + ($$pre<<2)|0);
   $$pre$phiZ2D = $$pre48;$F16$0 = $225;
  } else {
   $$sum7 = (($224) + 2)|0;
   $231 = (6984 + ($$sum7<<2)|0);
   $232 = HEAP32[$231>>2]|0;
   $233 = HEAP32[(6960)>>2]|0;
   $234 = ($232>>>0)<($233>>>0);
   if ($234) {
    _abort();
    // unreachable;
   } else {
    $$pre$phiZ2D = $231;$F16$0 = $232;
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = $$0;
  $235 = ((($F16$0)) + 12|0);
  HEAP32[$235>>2] = $$0;
  $236 = ((($$0)) + 8|0);
  HEAP32[$236>>2] = $F16$0;
  $237 = ((($$0)) + 12|0);
  HEAP32[$237>>2] = $225;
  return;
 }
 $238 = $$1 >>> 8;
 $239 = ($238|0)==(0);
 if ($239) {
  $I19$0 = 0;
 } else {
  $240 = ($$1>>>0)>(16777215);
  if ($240) {
   $I19$0 = 31;
  } else {
   $241 = (($238) + 1048320)|0;
   $242 = $241 >>> 16;
   $243 = $242 & 8;
   $244 = $238 << $243;
   $245 = (($244) + 520192)|0;
   $246 = $245 >>> 16;
   $247 = $246 & 4;
   $248 = $247 | $243;
   $249 = $244 << $247;
   $250 = (($249) + 245760)|0;
   $251 = $250 >>> 16;
   $252 = $251 & 2;
   $253 = $248 | $252;
   $254 = (14 - ($253))|0;
   $255 = $249 << $252;
   $256 = $255 >>> 15;
   $257 = (($254) + ($256))|0;
   $258 = $257 << 1;
   $259 = (($257) + 7)|0;
   $260 = $$1 >>> $259;
   $261 = $260 & 1;
   $262 = $261 | $258;
   $I19$0 = $262;
  }
 }
 $263 = (7248 + ($I19$0<<2)|0);
 $264 = ((($$0)) + 28|0);
 HEAP32[$264>>2] = $I19$0;
 $265 = ((($$0)) + 16|0);
 $266 = ((($$0)) + 20|0);
 HEAP32[$266>>2] = 0;
 HEAP32[$265>>2] = 0;
 $267 = HEAP32[(6948)>>2]|0;
 $268 = 1 << $I19$0;
 $269 = $267 & $268;
 $270 = ($269|0)==(0);
 if ($270) {
  $271 = $267 | $268;
  HEAP32[(6948)>>2] = $271;
  HEAP32[$263>>2] = $$0;
  $272 = ((($$0)) + 24|0);
  HEAP32[$272>>2] = $263;
  $273 = ((($$0)) + 12|0);
  HEAP32[$273>>2] = $$0;
  $274 = ((($$0)) + 8|0);
  HEAP32[$274>>2] = $$0;
  return;
 }
 $275 = HEAP32[$263>>2]|0;
 $276 = ((($275)) + 4|0);
 $277 = HEAP32[$276>>2]|0;
 $278 = $277 & -8;
 $279 = ($278|0)==($$1|0);
 L191: do {
  if ($279) {
   $T$0$lcssa = $275;
  } else {
   $280 = ($I19$0|0)==(31);
   $281 = $I19$0 >>> 1;
   $282 = (25 - ($281))|0;
   $283 = $280 ? 0 : $282;
   $284 = $$1 << $283;
   $K20$043 = $284;$T$042 = $275;
   while(1) {
    $291 = $K20$043 >>> 31;
    $292 = (((($T$042)) + 16|0) + ($291<<2)|0);
    $287 = HEAP32[$292>>2]|0;
    $293 = ($287|0)==(0|0);
    if ($293) {
     $$lcssa = $292;$T$042$lcssa = $T$042;
     break;
    }
    $285 = $K20$043 << 1;
    $286 = ((($287)) + 4|0);
    $288 = HEAP32[$286>>2]|0;
    $289 = $288 & -8;
    $290 = ($289|0)==($$1|0);
    if ($290) {
     $T$0$lcssa = $287;
     break L191;
    } else {
     $K20$043 = $285;$T$042 = $287;
    }
   }
   $294 = HEAP32[(6960)>>2]|0;
   $295 = ($$lcssa>>>0)<($294>>>0);
   if ($295) {
    _abort();
    // unreachable;
   }
   HEAP32[$$lcssa>>2] = $$0;
   $296 = ((($$0)) + 24|0);
   HEAP32[$296>>2] = $T$042$lcssa;
   $297 = ((($$0)) + 12|0);
   HEAP32[$297>>2] = $$0;
   $298 = ((($$0)) + 8|0);
   HEAP32[$298>>2] = $$0;
   return;
  }
 } while(0);
 $299 = ((($T$0$lcssa)) + 8|0);
 $300 = HEAP32[$299>>2]|0;
 $301 = HEAP32[(6960)>>2]|0;
 $302 = ($300>>>0)>=($301>>>0);
 $not$ = ($T$0$lcssa>>>0)>=($301>>>0);
 $303 = $302 & $not$;
 if (!($303)) {
  _abort();
  // unreachable;
 }
 $304 = ((($300)) + 12|0);
 HEAP32[$304>>2] = $$0;
 HEAP32[$299>>2] = $$0;
 $305 = ((($$0)) + 8|0);
 HEAP32[$305>>2] = $300;
 $306 = ((($$0)) + 12|0);
 HEAP32[$306>>2] = $T$0$lcssa;
 $307 = ((($$0)) + 24|0);
 HEAP32[$307>>2] = 0;
 return;
}
function runPostSets() {

}
function _i64Subtract(a, b, c, d) {
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a - c)>>>0;
    h = (b - d)>>>0;
    h = (b - d - (((c>>>0) > (a>>>0))|0))>>>0; // Borrow one from high word to low word on underflow.
    return ((tempRet0 = h,l|0)|0);
}
function _memset(ptr, value, num) {
    ptr = ptr|0; value = value|0; num = num|0;
    var stop = 0, value4 = 0, stop4 = 0, unaligned = 0;
    stop = (ptr + num)|0;
    if ((num|0) >= 20) {
      // This is unaligned, but quite large, so work hard to get to aligned settings
      value = value & 0xff;
      unaligned = ptr & 3;
      value4 = value | (value << 8) | (value << 16) | (value << 24);
      stop4 = stop & ~3;
      if (unaligned) {
        unaligned = (ptr + 4 - unaligned)|0;
        while ((ptr|0) < (unaligned|0)) { // no need to check for stop, since we have large num
          HEAP8[((ptr)>>0)]=value;
          ptr = (ptr+1)|0;
        }
      }
      while ((ptr|0) < (stop4|0)) {
        HEAP32[((ptr)>>2)]=value4;
        ptr = (ptr+4)|0;
      }
    }
    while ((ptr|0) < (stop|0)) {
      HEAP8[((ptr)>>0)]=value;
      ptr = (ptr+1)|0;
    }
    return (ptr-num)|0;
}
function _bitshift64Shl(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = (high << bits) | ((low&(ander << (32 - bits))) >>> (32 - bits));
      return low << bits;
    }
    tempRet0 = low << (bits - 32);
    return 0;
}
function _strlen(ptr) {
    ptr = ptr|0;
    var curr = 0;
    curr = ptr;
    while (((HEAP8[((curr)>>0)])|0)) {
      curr = (curr + 1)|0;
    }
    return (curr - ptr)|0;
}
function _i64Add(a, b, c, d) {
    /*
      x = a + b*2^32
      y = c + d*2^32
      result = l + h*2^32
    */
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a + c)>>>0;
    h = (b + d + (((l>>>0) < (a>>>0))|0))>>>0; // Add carry from low word to high word on overflow.
    return ((tempRet0 = h,l|0)|0);
}
function _memcpy(dest, src, num) {
    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    if ((num|0) >= 4096) return _emscripten_memcpy_big(dest|0, src|0, num|0)|0;
    ret = dest|0;
    if ((dest&3) == (src&3)) {
      while (dest & 3) {
        if ((num|0) == 0) return ret|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
        dest = (dest+1)|0;
        src = (src+1)|0;
        num = (num-1)|0;
      }
      while ((num|0) >= 4) {
        HEAP32[((dest)>>2)]=((HEAP32[((src)>>2)])|0);
        dest = (dest+4)|0;
        src = (src+4)|0;
        num = (num-4)|0;
      }
    }
    while ((num|0) > 0) {
      HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      dest = (dest+1)|0;
      src = (src+1)|0;
      num = (num-1)|0;
    }
    return ret|0;
}
function _saveSetjmp(env, label, table, size) {
    // Not particularly fast: slow table lookup of setjmpId to label. But setjmp
    // prevents relooping anyhow, so slowness is to be expected. And typical case
    // is 1 setjmp per invocation, or less.
    env = env|0;
    label = label|0;
    table = table|0;
    size = size|0;
    var i = 0;
    setjmpId = (setjmpId+1)|0;
    HEAP32[((env)>>2)]=setjmpId;
    while ((i|0) < (size|0)) {
      if (((HEAP32[(((table)+((i<<3)))>>2)])|0) == 0) {
        HEAP32[(((table)+((i<<3)))>>2)]=setjmpId;
        HEAP32[(((table)+((i<<3)+4))>>2)]=label;
        // prepare next slot
        HEAP32[(((table)+((i<<3)+8))>>2)]=0;
        tempRet0 = size;
        return table | 0;
      }
      i = i+1|0;
    }
    // grow the table
    size = (size*2)|0;
    table = _realloc(table|0, 8*(size+1|0)|0) | 0;
    table = _saveSetjmp(env|0, label|0, table|0, size|0) | 0;
    tempRet0 = size;
    return table | 0;
}
function _bitshift64Lshr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >>> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = 0;
    return (high >>> (bits - 32))|0;
}
function _testSetjmp(id, table, size) {
    id = id|0;
    table = table|0;
    size = size|0;
    var i = 0, curr = 0;
    while ((i|0) < (size|0)) {
      curr = ((HEAP32[(((table)+((i<<3)))>>2)])|0);
      if ((curr|0) == 0) break;
      if ((curr|0) == (id|0)) {
        return ((HEAP32[(((table)+((i<<3)+4))>>2)])|0);
      }
      i = i+1|0;
    }
    return 0;
}
function _bitshift64Ashr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = (high|0) < 0 ? -1 : 0;
    return (high >> (bits - 32))|0;
  }
function _llvm_cttz_i32(x) {
    x = x|0;
    var ret = 0;
    ret = ((HEAP8[(((cttz_i8)+(x & 0xff))>>0)])|0);
    if ((ret|0) < 8) return ret|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 8)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 8)|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 16)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 16)|0;
    return (((HEAP8[(((cttz_i8)+(x >>> 24))>>0)])|0) + 24)|0;
  }

// ======== compiled code from system/lib/compiler-rt , see readme therein
function ___muldsi3($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $3 = 0, $6 = 0, $8 = 0, $11 = 0, $12 = 0;
  $1 = $a & 65535;
  $2 = $b & 65535;
  $3 = Math_imul($2, $1) | 0;
  $6 = $a >>> 16;
  $8 = ($3 >>> 16) + (Math_imul($2, $6) | 0) | 0;
  $11 = $b >>> 16;
  $12 = Math_imul($11, $1) | 0;
  return (tempRet0 = (($8 >>> 16) + (Math_imul($11, $6) | 0) | 0) + ((($8 & 65535) + $12 | 0) >>> 16) | 0, 0 | ($8 + $12 << 16 | $3 & 65535)) | 0;
}
function ___divdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $7$0 = 0, $7$1 = 0, $8$0 = 0, $10$0 = 0;
  $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0;
  $4$1 = tempRet0;
  $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0;
  $7$0 = $2$0 ^ $1$0;
  $7$1 = $2$1 ^ $1$1;
  $8$0 = ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, 0) | 0;
  $10$0 = _i64Subtract($8$0 ^ $7$0, tempRet0 ^ $7$1, $7$0, $7$1) | 0;
  return $10$0 | 0;
}
function ___remdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $rem = 0, $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $10$0 = 0, $10$1 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $rem = __stackBase__ | 0;
  $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0;
  $4$1 = tempRet0;
  $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0;
  ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, $rem) | 0;
  $10$0 = _i64Subtract(HEAP32[$rem >> 2] ^ $1$0, HEAP32[$rem + 4 >> 2] ^ $1$1, $1$0, $1$1) | 0;
  $10$1 = tempRet0;
  STACKTOP = __stackBase__;
  return (tempRet0 = $10$1, $10$0) | 0;
}
function ___muldi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $x_sroa_0_0_extract_trunc = 0, $y_sroa_0_0_extract_trunc = 0, $1$0 = 0, $1$1 = 0, $2 = 0;
  $x_sroa_0_0_extract_trunc = $a$0;
  $y_sroa_0_0_extract_trunc = $b$0;
  $1$0 = ___muldsi3($x_sroa_0_0_extract_trunc, $y_sroa_0_0_extract_trunc) | 0;
  $1$1 = tempRet0;
  $2 = Math_imul($a$1, $y_sroa_0_0_extract_trunc) | 0;
  return (tempRet0 = ((Math_imul($b$1, $x_sroa_0_0_extract_trunc) | 0) + $2 | 0) + $1$1 | $1$1 & 0, 0 | $1$0 & -1) | 0;
}
function ___udivdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $1$0 = 0;
  $1$0 = ___udivmoddi4($a$0, $a$1, $b$0, $b$1, 0) | 0;
  return $1$0 | 0;
}
function ___uremdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $rem = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $rem = __stackBase__ | 0;
  ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) | 0;
  STACKTOP = __stackBase__;
  return (tempRet0 = HEAP32[$rem + 4 >> 2] | 0, HEAP32[$rem >> 2] | 0) | 0;
}
function ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  $rem = $rem | 0;
  var $n_sroa_0_0_extract_trunc = 0, $n_sroa_1_4_extract_shift$0 = 0, $n_sroa_1_4_extract_trunc = 0, $d_sroa_0_0_extract_trunc = 0, $d_sroa_1_4_extract_shift$0 = 0, $d_sroa_1_4_extract_trunc = 0, $4 = 0, $17 = 0, $37 = 0, $49 = 0, $51 = 0, $57 = 0, $58 = 0, $66 = 0, $78 = 0, $86 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $105 = 0, $117 = 0, $119 = 0, $125 = 0, $126 = 0, $130 = 0, $q_sroa_1_1_ph = 0, $q_sroa_0_1_ph = 0, $r_sroa_1_1_ph = 0, $r_sroa_0_1_ph = 0, $sr_1_ph = 0, $d_sroa_0_0_insert_insert99$0 = 0, $d_sroa_0_0_insert_insert99$1 = 0, $137$0 = 0, $137$1 = 0, $carry_0203 = 0, $sr_1202 = 0, $r_sroa_0_1201 = 0, $r_sroa_1_1200 = 0, $q_sroa_0_1199 = 0, $q_sroa_1_1198 = 0, $147 = 0, $149 = 0, $r_sroa_0_0_insert_insert42$0 = 0, $r_sroa_0_0_insert_insert42$1 = 0, $150$1 = 0, $151$0 = 0, $152 = 0, $154$0 = 0, $r_sroa_0_0_extract_trunc = 0, $r_sroa_1_4_extract_trunc = 0, $155 = 0, $carry_0_lcssa$0 = 0, $carry_0_lcssa$1 = 0, $r_sroa_0_1_lcssa = 0, $r_sroa_1_1_lcssa = 0, $q_sroa_0_1_lcssa = 0, $q_sroa_1_1_lcssa = 0, $q_sroa_0_0_insert_ext75$0 = 0, $q_sroa_0_0_insert_ext75$1 = 0, $q_sroa_0_0_insert_insert77$1 = 0, $_0$0 = 0, $_0$1 = 0;
  $n_sroa_0_0_extract_trunc = $a$0;
  $n_sroa_1_4_extract_shift$0 = $a$1;
  $n_sroa_1_4_extract_trunc = $n_sroa_1_4_extract_shift$0;
  $d_sroa_0_0_extract_trunc = $b$0;
  $d_sroa_1_4_extract_shift$0 = $b$1;
  $d_sroa_1_4_extract_trunc = $d_sroa_1_4_extract_shift$0;
  if (($n_sroa_1_4_extract_trunc | 0) == 0) {
    $4 = ($rem | 0) != 0;
    if (($d_sroa_1_4_extract_trunc | 0) == 0) {
      if ($4) {
        HEAP32[$rem >> 2] = ($n_sroa_0_0_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
        HEAP32[$rem + 4 >> 2] = 0;
      }
      $_0$1 = 0;
      $_0$0 = ($n_sroa_0_0_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    } else {
      if (!$4) {
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      HEAP32[$rem >> 2] = $a$0 & -1;
      HEAP32[$rem + 4 >> 2] = $a$1 & 0;
      $_0$1 = 0;
      $_0$0 = 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    }
  }
  $17 = ($d_sroa_1_4_extract_trunc | 0) == 0;
  do {
    if (($d_sroa_0_0_extract_trunc | 0) == 0) {
      if ($17) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
          HEAP32[$rem + 4 >> 2] = 0;
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      if (($n_sroa_0_0_extract_trunc | 0) == 0) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = 0;
          HEAP32[$rem + 4 >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_1_4_extract_trunc >>> 0);
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_1_4_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $37 = $d_sroa_1_4_extract_trunc - 1 | 0;
      if (($37 & $d_sroa_1_4_extract_trunc | 0) == 0) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = 0 | $a$0 & -1;
          HEAP32[$rem + 4 >> 2] = $37 & $n_sroa_1_4_extract_trunc | $a$1 & 0;
        }
        $_0$1 = 0;
        $_0$0 = $n_sroa_1_4_extract_trunc >>> ((_llvm_cttz_i32($d_sroa_1_4_extract_trunc | 0) | 0) >>> 0);
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $49 = Math_clz32($d_sroa_1_4_extract_trunc | 0) | 0;
      $51 = $49 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
      if ($51 >>> 0 <= 30) {
        $57 = $51 + 1 | 0;
        $58 = 31 - $51 | 0;
        $sr_1_ph = $57;
        $r_sroa_0_1_ph = $n_sroa_1_4_extract_trunc << $58 | $n_sroa_0_0_extract_trunc >>> ($57 >>> 0);
        $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($57 >>> 0);
        $q_sroa_0_1_ph = 0;
        $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $58;
        break;
      }
      if (($rem | 0) == 0) {
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      HEAP32[$rem >> 2] = 0 | $a$0 & -1;
      HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
      $_0$1 = 0;
      $_0$0 = 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    } else {
      if (!$17) {
        $117 = Math_clz32($d_sroa_1_4_extract_trunc | 0) | 0;
        $119 = $117 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        if ($119 >>> 0 <= 31) {
          $125 = $119 + 1 | 0;
          $126 = 31 - $119 | 0;
          $130 = $119 - 31 >> 31;
          $sr_1_ph = $125;
          $r_sroa_0_1_ph = $n_sroa_0_0_extract_trunc >>> ($125 >>> 0) & $130 | $n_sroa_1_4_extract_trunc << $126;
          $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($125 >>> 0) & $130;
          $q_sroa_0_1_ph = 0;
          $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $126;
          break;
        }
        if (($rem | 0) == 0) {
          $_0$1 = 0;
          $_0$0 = 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        HEAP32[$rem >> 2] = 0 | $a$0 & -1;
        HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $66 = $d_sroa_0_0_extract_trunc - 1 | 0;
      if (($66 & $d_sroa_0_0_extract_trunc | 0) != 0) {
        $86 = (Math_clz32($d_sroa_0_0_extract_trunc | 0) | 0) + 33 | 0;
        $88 = $86 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        $89 = 64 - $88 | 0;
        $91 = 32 - $88 | 0;
        $92 = $91 >> 31;
        $95 = $88 - 32 | 0;
        $105 = $95 >> 31;
        $sr_1_ph = $88;
        $r_sroa_0_1_ph = $91 - 1 >> 31 & $n_sroa_1_4_extract_trunc >>> ($95 >>> 0) | ($n_sroa_1_4_extract_trunc << $91 | $n_sroa_0_0_extract_trunc >>> ($88 >>> 0)) & $105;
        $r_sroa_1_1_ph = $105 & $n_sroa_1_4_extract_trunc >>> ($88 >>> 0);
        $q_sroa_0_1_ph = $n_sroa_0_0_extract_trunc << $89 & $92;
        $q_sroa_1_1_ph = ($n_sroa_1_4_extract_trunc << $89 | $n_sroa_0_0_extract_trunc >>> ($95 >>> 0)) & $92 | $n_sroa_0_0_extract_trunc << $91 & $88 - 33 >> 31;
        break;
      }
      if (($rem | 0) != 0) {
        HEAP32[$rem >> 2] = $66 & $n_sroa_0_0_extract_trunc;
        HEAP32[$rem + 4 >> 2] = 0;
      }
      if (($d_sroa_0_0_extract_trunc | 0) == 1) {
        $_0$1 = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$0 = 0 | $a$0 & -1;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      } else {
        $78 = _llvm_cttz_i32($d_sroa_0_0_extract_trunc | 0) | 0;
        $_0$1 = 0 | $n_sroa_1_4_extract_trunc >>> ($78 >>> 0);
        $_0$0 = $n_sroa_1_4_extract_trunc << 32 - $78 | $n_sroa_0_0_extract_trunc >>> ($78 >>> 0) | 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
    }
  } while (0);
  if (($sr_1_ph | 0) == 0) {
    $q_sroa_1_1_lcssa = $q_sroa_1_1_ph;
    $q_sroa_0_1_lcssa = $q_sroa_0_1_ph;
    $r_sroa_1_1_lcssa = $r_sroa_1_1_ph;
    $r_sroa_0_1_lcssa = $r_sroa_0_1_ph;
    $carry_0_lcssa$1 = 0;
    $carry_0_lcssa$0 = 0;
  } else {
    $d_sroa_0_0_insert_insert99$0 = 0 | $b$0 & -1;
    $d_sroa_0_0_insert_insert99$1 = $d_sroa_1_4_extract_shift$0 | $b$1 & 0;
    $137$0 = _i64Add($d_sroa_0_0_insert_insert99$0 | 0, $d_sroa_0_0_insert_insert99$1 | 0, -1, -1) | 0;
    $137$1 = tempRet0;
    $q_sroa_1_1198 = $q_sroa_1_1_ph;
    $q_sroa_0_1199 = $q_sroa_0_1_ph;
    $r_sroa_1_1200 = $r_sroa_1_1_ph;
    $r_sroa_0_1201 = $r_sroa_0_1_ph;
    $sr_1202 = $sr_1_ph;
    $carry_0203 = 0;
    while (1) {
      $147 = $q_sroa_0_1199 >>> 31 | $q_sroa_1_1198 << 1;
      $149 = $carry_0203 | $q_sroa_0_1199 << 1;
      $r_sroa_0_0_insert_insert42$0 = 0 | ($r_sroa_0_1201 << 1 | $q_sroa_1_1198 >>> 31);
      $r_sroa_0_0_insert_insert42$1 = $r_sroa_0_1201 >>> 31 | $r_sroa_1_1200 << 1 | 0;
      _i64Subtract($137$0, $137$1, $r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1) | 0;
      $150$1 = tempRet0;
      $151$0 = $150$1 >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1;
      $152 = $151$0 & 1;
      $154$0 = _i64Subtract($r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1, $151$0 & $d_sroa_0_0_insert_insert99$0, ((($150$1 | 0) < 0 ? -1 : 0) >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1) & $d_sroa_0_0_insert_insert99$1) | 0;
      $r_sroa_0_0_extract_trunc = $154$0;
      $r_sroa_1_4_extract_trunc = tempRet0;
      $155 = $sr_1202 - 1 | 0;
      if (($155 | 0) == 0) {
        break;
      } else {
        $q_sroa_1_1198 = $147;
        $q_sroa_0_1199 = $149;
        $r_sroa_1_1200 = $r_sroa_1_4_extract_trunc;
        $r_sroa_0_1201 = $r_sroa_0_0_extract_trunc;
        $sr_1202 = $155;
        $carry_0203 = $152;
      }
    }
    $q_sroa_1_1_lcssa = $147;
    $q_sroa_0_1_lcssa = $149;
    $r_sroa_1_1_lcssa = $r_sroa_1_4_extract_trunc;
    $r_sroa_0_1_lcssa = $r_sroa_0_0_extract_trunc;
    $carry_0_lcssa$1 = 0;
    $carry_0_lcssa$0 = $152;
  }
  $q_sroa_0_0_insert_ext75$0 = $q_sroa_0_1_lcssa;
  $q_sroa_0_0_insert_ext75$1 = 0;
  $q_sroa_0_0_insert_insert77$1 = $q_sroa_1_1_lcssa | $q_sroa_0_0_insert_ext75$1;
  if (($rem | 0) != 0) {
    HEAP32[$rem >> 2] = 0 | $r_sroa_0_1_lcssa;
    HEAP32[$rem + 4 >> 2] = $r_sroa_1_1_lcssa | 0;
  }
  $_0$1 = (0 | $q_sroa_0_0_insert_ext75$0) >>> 31 | $q_sroa_0_0_insert_insert77$1 << 1 | ($q_sroa_0_0_insert_ext75$1 << 1 | $q_sroa_0_0_insert_ext75$0 >>> 31) & 0 | $carry_0_lcssa$1;
  $_0$0 = ($q_sroa_0_0_insert_ext75$0 << 1 | 0 >>> 31) & -2 | $carry_0_lcssa$0;
  return (tempRet0 = $_0$1, $_0$0) | 0;
}
// =======================================================================



  
function dynCall_ii(index,a1) {
  index = index|0;
  a1=a1|0;
  return FUNCTION_TABLE_ii[index&15](a1|0)|0;
}


function dynCall_iiii(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0;
  return FUNCTION_TABLE_iiii[index&15](a1|0,a2|0,a3|0)|0;
}


function dynCall_vii(index,a1,a2) {
  index = index|0;
  a1=a1|0; a2=a2|0;
  FUNCTION_TABLE_vii[index&15](a1|0,a2|0);
}


function dynCall_iii(index,a1,a2) {
  index = index|0;
  a1=a1|0; a2=a2|0;
  return FUNCTION_TABLE_iii[index&15](a1|0,a2|0)|0;
}


function dynCall_iiiii(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
  return FUNCTION_TABLE_iiiii[index&15](a1|0,a2|0,a3|0,a4|0)|0;
}

function b0(p0) { p0 = p0|0; nullFunc_ii(0);return 0; }
function b1(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; nullFunc_iiii(1);return 0; }
function b2(p0,p1) { p0 = p0|0;p1 = p1|0; nullFunc_vii(2); }
function b3(p0,p1) { p0 = p0|0;p1 = p1|0; nullFunc_iii(3);return 0; }
function b4(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; nullFunc_iiiii(4);return 0; }

// EMSCRIPTEN_END_FUNCS
var FUNCTION_TABLE_ii = [b0,b0,_pmain,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,_panic,b0,b0];
var FUNCTION_TABLE_iiii = [b1,_sn_write,b1,_reader,b1,b1,b1,b1,b1,b1,b1,_getF,b1,b1,b1,b1];
var FUNCTION_TABLE_vii = [b2,b2,b2,b2,b2,_growstack,_f_call,_f_parser,_dothecall,b2,_f_luaopen,b2,b2,b2,b2,b2];
var FUNCTION_TABLE_iii = [b3,b3,b3,b3,b3,b3,b3,b3,b3,_lua_newstate,b3,b3,b3,b3,b3,b3];
var FUNCTION_TABLE_iiiii = [b4,b4,b4,b4,_writer,b4,b4,b4,b4,b4,b4,b4,_l_alloc,b4,b4,b4];

  return { _testSetjmp: _testSetjmp, _i64Subtract: _i64Subtract, _free: _free, _main: _main, _i64Add: _i64Add, _strlen: _strlen, _memset: _memset, _malloc: _malloc, _saveSetjmp: _saveSetjmp, _memcpy: _memcpy, _bitshift64Lshr: _bitshift64Lshr, _bitshift64Shl: _bitshift64Shl, runPostSets: runPostSets, stackAlloc: stackAlloc, stackSave: stackSave, stackRestore: stackRestore, establishStackSpace: establishStackSpace, setThrew: setThrew, setTempRet0: setTempRet0, getTempRet0: getTempRet0, dynCall_ii: dynCall_ii, dynCall_iiii: dynCall_iiii, dynCall_vii: dynCall_vii, dynCall_iii: dynCall_iii, dynCall_iiiii: dynCall_iiiii };
})
// EMSCRIPTEN_END_ASM
(Module.asmGlobalArg, Module.asmLibraryArg, buffer);
var real__testSetjmp = asm["_testSetjmp"]; asm["_testSetjmp"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__testSetjmp.apply(null, arguments);
};

var real__i64Subtract = asm["_i64Subtract"]; asm["_i64Subtract"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__i64Subtract.apply(null, arguments);
};

var real__free = asm["_free"]; asm["_free"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__free.apply(null, arguments);
};

var real__main = asm["_main"]; asm["_main"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__main.apply(null, arguments);
};

var real__i64Add = asm["_i64Add"]; asm["_i64Add"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__i64Add.apply(null, arguments);
};

var real__strlen = asm["_strlen"]; asm["_strlen"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__strlen.apply(null, arguments);
};

var real__malloc = asm["_malloc"]; asm["_malloc"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__malloc.apply(null, arguments);
};

var real__saveSetjmp = asm["_saveSetjmp"]; asm["_saveSetjmp"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__saveSetjmp.apply(null, arguments);
};

var real__bitshift64Lshr = asm["_bitshift64Lshr"]; asm["_bitshift64Lshr"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__bitshift64Lshr.apply(null, arguments);
};

var real__bitshift64Shl = asm["_bitshift64Shl"]; asm["_bitshift64Shl"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__bitshift64Shl.apply(null, arguments);
};
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
;

Runtime.stackAlloc = asm['stackAlloc'];
Runtime.stackSave = asm['stackSave'];
Runtime.stackRestore = asm['stackRestore'];
Runtime.establishStackSpace = asm['establishStackSpace'];

Runtime.setTempRet0 = asm['setTempRet0'];
Runtime.getTempRet0 = asm['getTempRet0'];


// TODO: strip out parts of this we do not need

//======= begin closure i64 code =======

// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */

var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };


  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.

    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };


  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.


  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};


  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }

    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };


  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };


  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };


  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }

    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }

    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));

    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };


  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.


  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;


  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);


  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);


  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);


  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);


  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);


  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);


  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };


  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };


  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (this.isZero()) {
      return '0';
    }

    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }

    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));

    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);

      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };


  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };


  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };


  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };


  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };


  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };


  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };


  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };


  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }

    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }

    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };


  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };


  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };


  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }

    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }

    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }

    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));

      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);

      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }

      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }

      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };


  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };


  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };


  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };


  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };


  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };


  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };

  //======= begin jsbn =======

  var navigator = { appName: 'Modern Browser' }; // polyfill a little

  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/

  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */

  // Basic JavaScript BN library - subset useful for RSA encryption.

  // Bits per digit
  var dbits;

  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);

  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }

  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }

  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.

  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }

  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);

  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;

  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;

  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }

  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }

  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }

  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }

  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }

  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }

  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }

  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }

  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }

  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }

  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }

  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }

  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }

  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }

  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }

  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }

  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }

  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }

  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }

  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }

  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;

  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }

  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }

  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }

  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }

  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }

  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }

  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;

  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }

  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }

  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }

  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;

  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;

  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);

  // jsbn2 stuff

  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }

  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }

  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }

  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }

  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }

  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }

  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }

  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;

  //======= end jsbn =======

  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();

//======= end closure i64 code =======



// === Auto-generated postamble setup entry stuff ===


function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun']) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString(Module['thisProgram']), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);

  initialStackTop = STACKTOP;

  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    exit(ret, /* implicit = */ true);
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
      throw e;
    }
  } finally {
    calledMain = true;
  }
}




function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    if (ABORT) return; 

    ensureInitRuntime();

    preMain();

    if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
      Module.printErr('pre-main prep time: ' + (Date.now() - preloadStartTime) + ' ms');
    }

    if (Module['onRuntimeInitialized']) Module['onRuntimeInitialized']();

    if (Module['_main'] && shouldRunNow) Module['callMain'](args);

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;

function exit(status, implicit) {
  if (implicit && Module['noExitRuntime']) {
    Module.printErr('exit(' + status + ') implicitly called by end of main(), but noExitRuntime, so not exiting the runtime (you can use emscripten_force_exit, if you want to force a true shutdown)');
    return;
  }

  if (Module['noExitRuntime']) {
    Module.printErr('exit(' + status + ') called, but noExitRuntime, so halting execution but not exiting the runtime or preventing further async execution (you can use emscripten_force_exit, if you want to force a true shutdown)');
  } else {

    ABORT = true;
    EXITSTATUS = status;
    STACKTOP = initialStackTop;

    exitRuntime();

    if (Module['onExit']) Module['onExit'](status);
  }

  if (ENVIRONMENT_IS_NODE) {
    // Work around a node.js bug where stdout buffer is not flushed at process exit:
    // Instead of process.exit() directly, wait for stdout flush event.
    // See https://github.com/joyent/node/issues/1669 and https://github.com/kripken/emscripten/issues/2582
    // Workaround is based on https://github.com/RReverser/acorn/commit/50ab143cecc9ed71a2d66f78b4aec3bb2e9844f6
    process['stdout']['once']('drain', function () {
      process['exit'](status);
    });
    console.log(' '); // Make sure to print something to force the drain event to occur, in case the stdout buffer was empty.
    // Work around another node bug where sometimes 'drain' is never fired - make another effort
    // to emit the exit status, after a significant delay (if node hasn't fired drain by then, give up)
    setTimeout(function() {
      process['exit'](status);
    }, 500);
  } else
  if (ENVIRONMENT_IS_SHELL && typeof quit === 'function') {
    quit(status);
  }
  // if we reach here, we must throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;

var abortDecorators = [];

function abort(what) {
  if (what !== undefined) {
    Module.print(what);
    Module.printErr(what);
    what = JSON.stringify(what)
  } else {
    what = '';
  }

  ABORT = true;
  EXITSTATUS = 1;

  var extra = '';

  var output = 'abort(' + what + ') at ' + stackTrace() + extra;
  if (abortDecorators) {
    abortDecorators.forEach(function(decorator) {
      output = decorator(output, what);
    });
  }
  throw output;
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}


run();

// {{POST_RUN_ADDITIONS}}






// {{MODULE_ADDITIONS}}



